-- MariaDB dump 10.19  Distrib 10.5.22-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: heat
-- ------------------------------------------------------
-- Server version	10.5.22-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `event`
--

DROP TABLE IF EXISTS `event`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `event` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `uuid` varchar(36) DEFAULT NULL,
  `stack_id` varchar(36) NOT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `resource_action` varchar(255) DEFAULT NULL,
  `resource_status` varchar(255) DEFAULT NULL,
  `resource_name` varchar(255) DEFAULT NULL,
  `physical_resource_id` varchar(255) DEFAULT NULL,
  `resource_status_reason` varchar(255) DEFAULT NULL,
  `resource_type` varchar(255) DEFAULT NULL,
  `resource_properties` blob DEFAULT NULL,
  `rsrc_prop_data_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uuid` (`uuid`),
  KEY `stack_id` (`stack_id`),
  KEY `ev_rsrc_prop_data_ref` (`rsrc_prop_data_id`),
  CONSTRAINT `ev_rsrc_prop_data_ref` FOREIGN KEY (`rsrc_prop_data_id`) REFERENCES `resource_properties_data` (`id`),
  CONSTRAINT `event_ibfk_1` FOREIGN KEY (`stack_id`) REFERENCES `stack` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2805 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `event`
--

LOCK TABLES `event` WRITE;
/*!40000 ALTER TABLE `event` DISABLE KEYS */;
INSERT INTO `event` VALUES (1,'bdac9d79-c53d-4c47-96fe-2133ca2bd786','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:39',NULL,'CREATE','IN_PROGRESS','overcloud','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2,'26776911-ca69-447c-af39-bc5ae307dddf','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:41',NULL,'CREATE','IN_PROGRESS','ControllerRoleUserData','overcloud-ControllerRoleUserData-5y5n3zvzfo6v','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(3,'1ac45e62-23bd-4063-8cb4-69b9865b077c','31c02a8a-fc05-4bb6-85ee-dfd1af948588','2026-06-13 07:56:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerRoleUserData-5y5n3zvzfo6v','31c02a8a-fc05-4bb6-85ee-dfd1af948588','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(4,'fa45088c-a3d2-4a76-8440-e33d7a468d67','31c02a8a-fc05-4bb6-85ee-dfd1af948588','2026-06-13 07:56:41',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ControllerRoleUserData-5y5n3zvzfo6v-userdata-ds36k7whys44','state changed','OS::Heat::MultipartMime',NULL,NULL),(5,'dcb30c59-cea7-4857-9cfc-38af13b55ceb','31c02a8a-fc05-4bb6-85ee-dfd1af948588','2026-06-13 07:56:41',NULL,'CREATE','COMPLETE','userdata','9cc1b981-991f-473e-a9ca-0515859c6239','state changed','OS::Heat::MultipartMime',NULL,NULL),(6,'22504384-3d8e-4518-af4d-0ae17aec2d61','31c02a8a-fc05-4bb6-85ee-dfd1af948588','2026-06-13 07:56:41',NULL,'CREATE','COMPLETE','overcloud-ControllerRoleUserData-5y5n3zvzfo6v','31c02a8a-fc05-4bb6-85ee-dfd1af948588','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(7,'62f7ea49-2ace-4b96-87eb-6c2a16d4e173','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:42',NULL,'CREATE','IN_PROGRESS','ServiceNetMap','overcloud-ServiceNetMap-663uubkwpssz','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(8,'d547f75b-52f6-49c0-9063-effdef5682c7','bfc5ca27-0e1a-4d10-ba09-6dcc166c23ee','2026-06-13 07:56:42',NULL,'CREATE','IN_PROGRESS','overcloud-ServiceNetMap-663uubkwpssz','bfc5ca27-0e1a-4d10-ba09-6dcc166c23ee','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(9,'195a72bb-75d3-49cc-bf51-09f312ac4768','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:42',NULL,'CREATE','COMPLETE','ControllerRoleUserData','31c02a8a-fc05-4bb6-85ee-dfd1af948588','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(10,'25dd42f0-f50b-4c70-8877-3b46c6ca19e0','bfc5ca27-0e1a-4d10-ba09-6dcc166c23ee','2026-06-13 07:56:42',NULL,'CREATE','IN_PROGRESS','ServiceNetMapValue','overcloud-ServiceNetMap-663uubkwpssz-ServiceNetMapValue-ipy3lqtlly62','state changed','OS::Heat::Value',NULL,2),(11,'e064317d-d8fc-4c9d-a707-bf3fb47d8358','bfc5ca27-0e1a-4d10-ba09-6dcc166c23ee','2026-06-13 07:56:42',NULL,'CREATE','COMPLETE','ServiceNetMapValue','overcloud-ServiceNetMap-663uubkwpssz-ServiceNetMapValue-ipy3lqtlly62','state changed','OS::Heat::Value',NULL,2),(12,'c6411a93-41af-46b9-8204-a6091478b08d','bfc5ca27-0e1a-4d10-ba09-6dcc166c23ee','2026-06-13 07:56:42',NULL,'CREATE','COMPLETE','overcloud-ServiceNetMap-663uubkwpssz','bfc5ca27-0e1a-4d10-ba09-6dcc166c23ee','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(13,'59351f09-63f5-4e79-80a3-77494aac6fcb','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:43',NULL,'CREATE','IN_PROGRESS','NodeTimesyncUserData','overcloud-NodeTimesyncUserData-yuce6kz6b3y5','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(14,'f4dfc182-74d2-4bbf-99ed-268b26cef205','068fb633-af31-4d19-8a5e-5ce2bbfce121','2026-06-13 07:56:43',NULL,'CREATE','IN_PROGRESS','overcloud-NodeTimesyncUserData-yuce6kz6b3y5','068fb633-af31-4d19-8a5e-5ce2bbfce121','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(15,'853a43be-22f6-47b2-9a26-04f9a746f116','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:43',NULL,'CREATE','COMPLETE','ServiceNetMap','bfc5ca27-0e1a-4d10-ba09-6dcc166c23ee','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(16,'866f1083-7f7d-42a5-86ca-7947769020f1','068fb633-af31-4d19-8a5e-5ce2bbfce121','2026-06-13 07:56:43',NULL,'CREATE','IN_PROGRESS','timesync_chrony','overcloud-NodeTimesyncUserData-yuce6kz6b3y5-timesync_chrony-eru472vbj2ya','state changed','OS::Heat::SoftwareConfig',NULL,3),(17,'c843b337-eba4-4ccc-8531-2dd3621b5d5e','068fb633-af31-4d19-8a5e-5ce2bbfce121','2026-06-13 07:56:43',NULL,'CREATE','COMPLETE','timesync_chrony','4acedf5e-6ce2-4fe3-b0ee-39b6cc6f3dbd','state changed','OS::Heat::SoftwareConfig',NULL,3),(18,'c8d2ab6d-0e54-4486-bd44-aafee37f0533','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-f4qie5hfzzgo','state changed','OS::Heat::Value',NULL,5),(19,'8a2503a0-9e74-4daf-9711-d12194f491be','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-f4qie5hfzzgo','state changed','OS::Heat::Value',NULL,5),(20,'4daaf4a5-bde0-458c-890b-5973def1d11f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-4geg3bun5xap','state changed','OS::Heat::Value',NULL,7),(21,'5f7e05d7-0542-4010-a4f8-5d2994417cef','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-4geg3bun5xap','state changed','OS::Heat::Value',NULL,7),(22,'0c48d3f1-ccd9-421b-afb3-b28dde297271','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-bhdoiqyme7n3','state changed','OS::Heat::Value',NULL,8),(23,'fd684808-3e43-4e82-bec0-7a438b1945de','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-yhf4eq4rizoc','state changed','OS::Heat::Value',NULL,9),(24,'26bd311d-3664-4b5f-9d67-8cce7512d06b','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-bhdoiqyme7n3','state changed','OS::Heat::Value',NULL,8),(25,'acabe423-1133-40d4-8c93-96980162d8f1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-qhfxbqv2mshr','state changed','OS::Heat::Value',NULL,10),(26,'64f94165-1718-453a-b074-f92f7fb5d075','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-yhf4eq4rizoc','state changed','OS::Heat::Value',NULL,9),(27,'9bb1f099-a8d9-4bde-932b-b8c4178ec43a','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-qhfxbqv2mshr','state changed','OS::Heat::Value',NULL,10),(28,'0a5b9f1f-4154-4c46-bf64-3ac0adf91b92','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','BlockStorageRoleUserData','overcloud-BlockStorageRoleUserData-7bnrlr6y5we5','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(29,'f2ccb69d-2f8f-4682-8cfc-a6a0597a1069','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-4bsnhm5cekbq','state changed','OS::Heat::Value',NULL,15),(30,'95f255a3-2e62-445e-b9e4-932498218fa1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','ControlVirtualIP','overcloud-ControlVirtualIP-wgszm7qcx5l4','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,16),(31,'1c3aa5cc-36dd-4540-bc41-61578ae201b1','471b99d7-bbab-4ca6-ae6e-9d431246c76c','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageRoleUserData-7bnrlr6y5we5','471b99d7-bbab-4ca6-ae6e-9d431246c76c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(32,'a894c28c-be55-4680-9855-1196a9d38795','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-4bsnhm5cekbq','state changed','OS::Heat::Value',NULL,15),(33,'740f5ba3-e1e0-471a-b40c-a478e381afec','fc445f45-ca34-492a-98f2-a885d6d5c08d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControlVirtualIP-wgszm7qcx5l4','fc445f45-ca34-492a-98f2-a885d6d5c08d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(34,'839daffd-c23b-46b0-aaf4-42b231a6a9d0','fc445f45-ca34-492a-98f2-a885d6d5c08d','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','overcloud-ControlVirtualIP-wgszm7qcx5l4','fc445f45-ca34-492a-98f2-a885d6d5c08d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(35,'e08d1c52-357a-4400-85ff-29b09d29eafb','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-ic27rlox34ua','state changed','OS::Heat::Value',NULL,17),(36,'b23639a1-d7d4-4687-a5f9-16cc7a5f9e0f','471b99d7-bbab-4ca6-ae6e-9d431246c76c','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-BlockStorageRoleUserData-7bnrlr6y5we5-userdata-4rg4mkbgyo2a','state changed','OS::Heat::MultipartMime',NULL,NULL),(37,'80ef5a9a-ac06-4eec-941e-f3a375761b5d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-ic27rlox34ua','state changed','OS::Heat::Value',NULL,17),(38,'3b5edd7a-985d-49b6-b7c4-0a8aa66d5131','471b99d7-bbab-4ca6-ae6e-9d431246c76c','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','userdata','6ee2a276-3d16-45a2-9fb3-fed5f718e7b4','state changed','OS::Heat::MultipartMime',NULL,NULL),(39,'0c5c1567-b562-4f3b-b091-48532a75ec5a','471b99d7-bbab-4ca6-ae6e-9d431246c76c','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','overcloud-BlockStorageRoleUserData-7bnrlr6y5we5','471b99d7-bbab-4ca6-ae6e-9d431246c76c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(40,'953fb5ff-b73b-4d3b-9363-46316d22bbe2','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-egjjqfpm5hwp','state changed','OS::Heat::Value',NULL,21),(41,'53303a89-0ba1-424f-a376-9ae7e470dbd1','068fb633-af31-4d19-8a5e-5ce2bbfce121','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','timesync_sync','overcloud-NodeTimesyncUserData-yuce6kz6b3y5-timesync_sync-wyflhj2c3lhk','state changed','OS::Heat::SoftwareConfig',NULL,22),(42,'f7dd52c6-5843-4888-92a6-fd8138fdb87c','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-egjjqfpm5hwp','state changed','OS::Heat::Value',NULL,21),(43,'9a5ba286-c898-4914-8049-cb0521816b94','068fb633-af31-4d19-8a5e-5ce2bbfce121','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','timesync_sync','6c862946-65e7-45eb-9356-dfe9d7df2044','state changed','OS::Heat::SoftwareConfig',NULL,22),(44,'505216eb-ed23-4266-8221-1d1a4c3ce13f','068fb633-af31-4d19-8a5e-5ce2bbfce121','2026-06-13 07:56:44',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeTimesyncUserData-yuce6kz6b3y5-userdata-mpjwk7vt27mp','state changed','OS::Heat::MultipartMime',NULL,24),(45,'8d167d23-1f4d-4d3b-aff1-8984282ade48','068fb633-af31-4d19-8a5e-5ce2bbfce121','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','userdata','d2b94f07-eb36-4397-b693-08da175dd857','state changed','OS::Heat::MultipartMime',NULL,24),(46,'0be20594-3f45-4b3b-ba0c-ee63c5916a0f','068fb633-af31-4d19-8a5e-5ce2bbfce121','2026-06-13 07:56:44',NULL,'CREATE','COMPLETE','overcloud-NodeTimesyncUserData-yuce6kz6b3y5','068fb633-af31-4d19-8a5e-5ce2bbfce121','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(47,'57e8c7d9-49e1-41b1-87b2-384254d322ee','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:45',NULL,'CREATE','IN_PROGRESS','CephStorageRoleUserData','overcloud-CephStorageRoleUserData-fsdy4fj67n4m','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(48,'1f7881e6-0911-469e-beeb-0715dddfd567','b0f311e9-b3eb-43bf-a39e-57237173f44b','2026-06-13 07:56:45',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageRoleUserData-fsdy4fj67n4m','b0f311e9-b3eb-43bf-a39e-57237173f44b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(49,'38c0e1c7-37bc-4fa1-8e74-af24975f6efd','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:45',NULL,'CREATE','COMPLETE','BlockStorageRoleUserData','471b99d7-bbab-4ca6-ae6e-9d431246c76c','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(50,'3a5cfec3-e89e-41f8-9729-01e7d9e17757','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:45',NULL,'CREATE','COMPLETE','ControlVirtualIP','fc445f45-ca34-492a-98f2-a885d6d5c08d','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,16),(51,'9d0cebf7-cb08-4fd7-a129-605583c43638','b0f311e9-b3eb-43bf-a39e-57237173f44b','2026-06-13 07:56:45',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CephStorageRoleUserData-fsdy4fj67n4m-userdata-i2xxia6vur4e','state changed','OS::Heat::MultipartMime',NULL,NULL),(52,'f769ed07-0922-4da6-b11c-c2e29af85058','b0f311e9-b3eb-43bf-a39e-57237173f44b','2026-06-13 07:56:45',NULL,'CREATE','COMPLETE','userdata','80d0e4bb-8879-48f5-9014-2597f6430349','state changed','OS::Heat::MultipartMime',NULL,NULL),(53,'50b67d19-0abd-401d-af29-57e832d84706','b0f311e9-b3eb-43bf-a39e-57237173f44b','2026-06-13 07:56:45',NULL,'CREATE','COMPLETE','overcloud-CephStorageRoleUserData-fsdy4fj67n4m','b0f311e9-b3eb-43bf-a39e-57237173f44b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(54,'9c504b70-835e-4f1c-ad07-f5d0dd850b5e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:45',NULL,'CREATE','COMPLETE','NodeTimesyncUserData','068fb633-af31-4d19-8a5e-5ce2bbfce121','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(55,'1fa194e0-70cf-4818-9208-c8ae5fb09f3d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:45',NULL,'CREATE','IN_PROGRESS','Networks','overcloud-Networks-pfhydddqmdbg','state changed','OS::TripleO::Network',NULL,27),(56,'53734cd9-5da5-479f-9f2b-25646f996da1','185af874-535e-4327-aed7-1a3c676b06f3','2026-06-13 07:56:45',NULL,'CREATE','IN_PROGRESS','overcloud-Networks-pfhydddqmdbg','185af874-535e-4327-aed7-1a3c676b06f3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(57,'f51e8ac4-be44-436f-95d2-6bcc255d3f82','185af874-535e-4327-aed7-1a3c676b06f3','2026-06-13 07:56:46',NULL,'CREATE','IN_PROGRESS','NetworkIpVersionMap','overcloud-Networks-pfhydddqmdbg-NetworkIpVersionMap-kdrvaiphaeex','state changed','OS::Heat::Value',NULL,29),(58,'32ffd4a1-4bfb-4c8d-b40b-22f66459e80c','185af874-535e-4327-aed7-1a3c676b06f3','2026-06-13 07:56:46',NULL,'CREATE','COMPLETE','NetworkIpVersionMap','overcloud-Networks-pfhydddqmdbg-NetworkIpVersionMap-kdrvaiphaeex','state changed','OS::Heat::Value',NULL,29),(59,'c750c1b6-4651-4eec-a3ff-419deb56cdb8','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:46',NULL,'CREATE','IN_PROGRESS','NodeUserData','overcloud-NodeUserData-envuv6cs527s','state changed','OS::TripleO::NodeUserData',NULL,NULL),(60,'3f9859b2-8bf1-4962-bdc5-a7d3bae1743e','3669b9cf-c618-4148-adf0-22a91f6439e4','2026-06-13 07:56:46',NULL,'CREATE','IN_PROGRESS','overcloud-NodeUserData-envuv6cs527s','3669b9cf-c618-4148-adf0-22a91f6439e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(61,'06a27c4a-1654-465c-a210-639272822f05','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:46',NULL,'CREATE','COMPLETE','CephStorageRoleUserData','b0f311e9-b3eb-43bf-a39e-57237173f44b','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(62,'d992b580-e8f6-4366-954e-76b5ebc5ee5a','3669b9cf-c618-4148-adf0-22a91f6439e4','2026-06-13 07:56:46',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeUserData-envuv6cs527s-userdata-edz332nsqafr','state changed','OS::Heat::MultipartMime',NULL,NULL),(63,'0cd0cb35-9729-4756-b248-de30d081683b','3669b9cf-c618-4148-adf0-22a91f6439e4','2026-06-13 07:56:46',NULL,'CREATE','COMPLETE','userdata','7ca99897-eb25-4905-8932-863d796de1d0','state changed','OS::Heat::MultipartMime',NULL,NULL),(64,'a4a73816-3fa1-4495-a01f-d9b3bec60186','3669b9cf-c618-4148-adf0-22a91f6439e4','2026-06-13 07:56:46',NULL,'CREATE','COMPLETE','overcloud-NodeUserData-envuv6cs527s','3669b9cf-c618-4148-adf0-22a91f6439e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(65,'8e0b9209-2a03-4649-a7f7-61b6aa4aa426','185af874-535e-4327-aed7-1a3c676b06f3','2026-06-13 07:56:47',NULL,'CREATE','IN_PROGRESS','NetworkExtraConfig','overcloud-Networks-pfhydddqmdbg-NetworkExtraConfig-6qqioongd525','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(66,'9c8a66a9-34ea-434d-b028-3366d6aceb98','185af874-535e-4327-aed7-1a3c676b06f3','2026-06-13 07:56:47',NULL,'CREATE','COMPLETE','NetworkExtraConfig','78691aab-a4cd-4a6d-a781-8e6a2ddf4728','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(67,'038be75f-e326-4344-b4fc-313d74982ffe','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:47',NULL,'CREATE','IN_PROGRESS','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-b4epo5sxubdb','state changed','OS::Heat::Value',NULL,31),(68,'a6219f1e-a498-4f1b-b285-d9df9af2db8f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:47',NULL,'CREATE','COMPLETE','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-b4epo5sxubdb','state changed','OS::Heat::Value',NULL,31),(69,'9fd8d33a-ddc8-4dcd-8157-6f07ef51e137','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:47',NULL,'CREATE','COMPLETE','NodeUserData','3669b9cf-c618-4148-adf0-22a91f6439e4','state changed','OS::TripleO::NodeUserData',NULL,NULL),(70,'d3a9523e-a2a7-43d9-967d-827534ce0632','185af874-535e-4327-aed7-1a3c676b06f3','2026-06-13 07:56:48',NULL,'CREATE','IN_PROGRESS','NetworkAttributesMap','overcloud-Networks-pfhydddqmdbg-NetworkAttributesMap-ylruvhoembnz','state changed','OS::Heat::Value',NULL,34),(71,'a3845af9-bb6d-4488-b27d-fe8a45dfef2b','185af874-535e-4327-aed7-1a3c676b06f3','2026-06-13 07:56:48',NULL,'CREATE','COMPLETE','NetworkAttributesMap','overcloud-Networks-pfhydddqmdbg-NetworkAttributesMap-ylruvhoembnz','state changed','OS::Heat::Value',NULL,34),(72,'b0c2221a-e32a-425d-9057-3d510727b0bf','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:48',NULL,'CREATE','IN_PROGRESS','CellControllerComputeRoleUserData','overcloud-CellControllerComputeRoleUserData-iehttc3k4kli','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(73,'f626540e-9acd-47f4-a928-a94e8e9eb5d1','7f0973de-6211-4203-a82a-977862854b7c','2026-06-13 07:56:48',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeRoleUserData-iehttc3k4kli','7f0973de-6211-4203-a82a-977862854b7c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(74,'3e646c12-4bb7-42b8-b202-2e61240ce255','7f0973de-6211-4203-a82a-977862854b7c','2026-06-13 07:56:48',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerComputeRoleUserData-iehttc3k4kli-userdata-at35neuvqzik','state changed','OS::Heat::MultipartMime',NULL,NULL),(75,'5b832d46-bf95-4c92-bb17-ff10c7f62819','7f0973de-6211-4203-a82a-977862854b7c','2026-06-13 07:56:48',NULL,'CREATE','COMPLETE','userdata','10fe11b0-9477-4d36-ae79-f0c3e87b3c1f','state changed','OS::Heat::MultipartMime',NULL,NULL),(76,'530efe75-1e02-4b4a-9d1d-ce1a44e08bbb','7f0973de-6211-4203-a82a-977862854b7c','2026-06-13 07:56:48',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeRoleUserData-iehttc3k4kli','7f0973de-6211-4203-a82a-977862854b7c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(77,'ddc54849-b845-45a9-9fd7-c1475f1532af','185af874-535e-4327-aed7-1a3c676b06f3','2026-06-13 07:56:49',NULL,'CREATE','IN_PROGRESS','NetworkCidrMap','overcloud-Networks-pfhydddqmdbg-NetworkCidrMap-qu54sevk3avd','state changed','OS::Heat::Value',NULL,35),(78,'58b3c457-4d5f-4076-8a2b-1e69231b5d23','185af874-535e-4327-aed7-1a3c676b06f3','2026-06-13 07:56:49',NULL,'CREATE','COMPLETE','NetworkCidrMap','overcloud-Networks-pfhydddqmdbg-NetworkCidrMap-qu54sevk3avd','state changed','OS::Heat::Value',NULL,35),(79,'358a24d5-8bee-4a5f-8974-87838d468821','185af874-535e-4327-aed7-1a3c676b06f3','2026-06-13 07:56:49',NULL,'CREATE','COMPLETE','overcloud-Networks-pfhydddqmdbg','185af874-535e-4327-aed7-1a3c676b06f3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(80,'948a0622-530d-44a3-aeb7-6ae0a156a220','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:49',NULL,'CREATE','IN_PROGRESS','NetworkerRoleUserData','overcloud-NetworkerRoleUserData-7hsrfct6ot3u','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(81,'1247de0e-f7ff-4289-b07f-6aabce9a9441','314cdfb4-9ced-4524-a99e-61e3ed0095c7','2026-06-13 07:56:49',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerRoleUserData-7hsrfct6ot3u','314cdfb4-9ced-4524-a99e-61e3ed0095c7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(82,'65e28453-7adb-4280-812f-1af4f5aa588e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:49',NULL,'CREATE','COMPLETE','CellControllerComputeRoleUserData','7f0973de-6211-4203-a82a-977862854b7c','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(83,'25772aec-69a7-4898-95e6-3276023c3415','314cdfb4-9ced-4524-a99e-61e3ed0095c7','2026-06-13 07:56:49',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NetworkerRoleUserData-7hsrfct6ot3u-userdata-doaj6upxbsxd','state changed','OS::Heat::MultipartMime',NULL,NULL),(84,'d03916a5-11ca-44cc-b93d-1a473ad03a02','314cdfb4-9ced-4524-a99e-61e3ed0095c7','2026-06-13 07:56:49',NULL,'CREATE','COMPLETE','userdata','3b1ffc21-6764-4ae7-81dc-1f100d8c9e61','state changed','OS::Heat::MultipartMime',NULL,NULL),(85,'58ca8e4b-1a48-4146-af28-7092a2f1d639','314cdfb4-9ced-4524-a99e-61e3ed0095c7','2026-06-13 07:56:49',NULL,'CREATE','COMPLETE','overcloud-NetworkerRoleUserData-7hsrfct6ot3u','314cdfb4-9ced-4524-a99e-61e3ed0095c7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(86,'56798377-df7f-4470-9d78-c89d5312df4e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:49',NULL,'CREATE','COMPLETE','Networks','185af874-535e-4327-aed7-1a3c676b06f3','state changed','OS::TripleO::Network',NULL,27),(87,'c29087ab-9aaf-4bdc-87ac-eb94c0eb25b4','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','InternalApiVirtualIP','overcloud-InternalApiVirtualIP-hfiehufczdwg','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,40),(88,'4638b04f-a3d7-40eb-84ca-097c26e490bd','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','ComputeNetworkConfig','overcloud-ComputeNetworkConfig-go6e7yrdgsdx','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(89,'76b83821-1a7a-4ec7-908d-d66b9ea3b93b','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkConfig','overcloud-NetworkerNetworkConfig-5wq6etb4wkuh','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(90,'b3e078a5-3903-4597-925a-364ad590501a','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','ComputeNetworkConfig','e99ad410-b582-4fd6-b041-981e25787269','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(91,'ae6718cd-c761-497e-9d79-0031023a116e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','NetworkerNetworkConfig','cd709590-aea7-41f5-b92f-024393882519','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(92,'d8e4cc26-56b8-4639-9bcd-6c2c173eadbe','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','StorageMgmtVirtualIP','overcloud-StorageMgmtVirtualIP-c76twstcm2hp','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,41),(93,'d50c18b5-cfb8-4b1d-b462-5ace85fa742f','6c6bc1b3-8beb-4a60-bf51-66bfc6dce17b','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','overcloud-InternalApiVirtualIP-hfiehufczdwg','6c6bc1b3-8beb-4a60-bf51-66bfc6dce17b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(94,'e091130f-28de-4728-ab45-36107e31f758','6c6bc1b3-8beb-4a60-bf51-66bfc6dce17b','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','overcloud-InternalApiVirtualIP-hfiehufczdwg','6c6bc1b3-8beb-4a60-bf51-66bfc6dce17b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(95,'ef4bdf8e-16db-4496-b658-f2326493e47d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','CellControllerRoleUserData','overcloud-CellControllerRoleUserData-zwx3ifalkek6','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(96,'14ccc48d-3457-4862-9473-6391f43634af','f6dc250a-c84b-46c0-8848-669a25bc10b0','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','overcloud-StorageMgmtVirtualIP-c76twstcm2hp','f6dc250a-c84b-46c0-8848-669a25bc10b0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(97,'28563f23-8333-410c-8407-c905fec99204','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','NetworkerRoleUserData','314cdfb4-9ced-4524-a99e-61e3ed0095c7','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(98,'b4db4046-11e6-4bc0-8db4-d615370419ce','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkConfig','overcloud-ObjectStorageNetworkConfig-zseqhkel6qao','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(99,'23a95bdf-06e1-4bc2-b31f-bdd5eec5a3ef','f6dc250a-c84b-46c0-8848-669a25bc10b0','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','overcloud-StorageMgmtVirtualIP-c76twstcm2hp','f6dc250a-c84b-46c0-8848-669a25bc10b0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(100,'1422e66b-6211-4050-bc5f-26635363dfde','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','StorageMgmtVirtualIP','f6dc250a-c84b-46c0-8848-669a25bc10b0','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,41),(101,'a67170ef-da50-47a6-a4b4-218e59b84283','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','InternalApiVirtualIP','6c6bc1b3-8beb-4a60-bf51-66bfc6dce17b','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,40),(102,'e3997455-97c0-4485-a8ba-ee7e0fbbd549','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','ObjectStorageNetworkConfig','8bbad79f-f72a-46f9-8ca2-9c197ffca58e','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(103,'0d122edc-6d18-4baf-a270-02e3b04bf859','2f000695-4670-46ab-af2b-691df7356fd4','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerRoleUserData-zwx3ifalkek6','2f000695-4670-46ab-af2b-691df7356fd4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(104,'eb0152b1-7bf4-4ce0-a75d-ced66319fdb7','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','StorageVirtualIP','overcloud-StorageVirtualIP-7edhi7y5tpw4','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,42),(105,'73d33fc1-a9fc-4483-bbec-0b2f5ff83093','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkConfig','overcloud-CellControllerNetworkConfig-n3jcw2gaipa5','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(106,'1960520b-f7e8-4214-8a57-2612dac8e318','90731c90-484d-4246-8367-fd05d4895706','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','overcloud-StorageVirtualIP-7edhi7y5tpw4','90731c90-484d-4246-8367-fd05d4895706','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(107,'e0fc91a1-4a58-4c2a-95d0-ca8b32045f0e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','CellControllerNetworkConfig','15ccc70f-e49b-4938-a88a-0f26633bef6d','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(108,'f3b142c7-fc88-46ed-bfbb-4f1f305e11b1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','ControllerNetworkConfig','overcloud-ControllerNetworkConfig-5tzaieuwfhvw','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(109,'95305313-a072-4a16-8cef-3ba89ff5145e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','ControllerNetworkConfig','399184d2-9143-4ca5-a619-dd4f438491ae','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(110,'629ba1ae-b5e0-4813-84f4-60cf453cf074','2f000695-4670-46ab-af2b-691df7356fd4','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerRoleUserData-zwx3ifalkek6-userdata-e6dn74lndbns','state changed','OS::Heat::MultipartMime',NULL,NULL),(111,'54d78004-c664-4bcc-acb7-55c3bb494b52','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','PublicVirtualIP','overcloud-PublicVirtualIP-mgb25g4ymq2l','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,46),(112,'9b70a723-2df8-45cc-af17-000932eec03d','90731c90-484d-4246-8367-fd05d4895706','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','overcloud-StorageVirtualIP-7edhi7y5tpw4','90731c90-484d-4246-8367-fd05d4895706','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(113,'4dad23b3-01c4-48a5-89ab-03627cf13eef','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkConfig','overcloud-BlockStorageNetworkConfig-7plzwdgw7ll5','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(114,'21e3e785-0d80-4f49-9d28-2e90f857d0a4','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:50',NULL,'CREATE','IN_PROGRESS','NetCidrMapValue','overcloud-NetCidrMapValue-inglz6yqeebe','state changed','OS::Heat::Value',NULL,47),(115,'383e80c3-4dd9-4fc4-93a3-27b58e1a4ef1','2f000695-4670-46ab-af2b-691df7356fd4','2026-06-13 07:56:50',NULL,'CREATE','COMPLETE','userdata','d23d6bfc-96b0-4555-a393-5ab165d509ce','state changed','OS::Heat::MultipartMime',NULL,NULL),(116,'8277fd2e-2658-43f9-9b68-7b309a6049f1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkConfig','overcloud-CellControllerComputeNetworkConfig-ab24z2dpokrs','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(117,'bff41441-b28a-43de-b0e5-8c46e98179c1','2f000695-4670-46ab-af2b-691df7356fd4','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','overcloud-CellControllerRoleUserData-zwx3ifalkek6','2f000695-4670-46ab-af2b-691df7356fd4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(118,'0e24ee83-3faf-4b2a-9086-5ffad89ccfaa','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','IN_PROGRESS','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-g6anf4s7umbn','state changed','OS::Heat::Value',NULL,49),(119,'f6379734-058a-4879-aa2d-67f259674cbe','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-g6anf4s7umbn','state changed','OS::Heat::Value',NULL,49),(120,'04b8aa08-39f6-446c-8a89-bc0d9e113e1c','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','BlockStorageNetworkConfig','354ee786-bf3f-4bf3-900d-62496f81d3e4','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(121,'8a93ac76-c528-46d3-b157-ff28771b74fc','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkConfig','baf5c9d8-3825-49cc-83da-9b15dd7682c5','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(122,'14a2c9f7-5794-4071-8c6b-fd9530b5205e','5aed0243-4ebb-4302-b4fc-0ec1184127c6','2026-06-13 07:56:51',NULL,'CREATE','IN_PROGRESS','overcloud-PublicVirtualIP-mgb25g4ymq2l','5aed0243-4ebb-4302-b4fc-0ec1184127c6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(123,'458bd19d-648a-4eb9-a814-38876313c5b6','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkConfig','overcloud-CephStorageNetworkConfig-ji5lzwd2s65i','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(124,'a12632ed-56af-4758-a594-246aeccd5853','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','NetCidrMapValue','overcloud-NetCidrMapValue-inglz6yqeebe','state changed','OS::Heat::Value',NULL,47),(125,'745a7e3e-6681-4ac9-bacc-c4baede443a3','5aed0243-4ebb-4302-b4fc-0ec1184127c6','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','overcloud-PublicVirtualIP-mgb25g4ymq2l','5aed0243-4ebb-4302-b4fc-0ec1184127c6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(126,'124dbf84-a566-4e1e-9b45-86d7c5ba652c','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','CephStorageNetworkConfig','ae4545bb-2332-458b-88b3-346516667419','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(127,'0169c20c-b241-452f-8811-3a4322858d87','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','IN_PROGRESS','ComputeRoleUserData','overcloud-ComputeRoleUserData-cf2hpc3ldfo3','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(128,'a85b4960-09b9-4c24-b9e7-490ac9032da9','9a5d6165-c573-45f8-bba4-b7b3b721fb5c','2026-06-13 07:56:51',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeRoleUserData-cf2hpc3ldfo3','9a5d6165-c573-45f8-bba4-b7b3b721fb5c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(129,'143284af-de7d-4b36-81ba-411beeafaade','9a5d6165-c573-45f8-bba4-b7b3b721fb5c','2026-06-13 07:56:51',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ComputeRoleUserData-cf2hpc3ldfo3-userdata-u3g5meaasczk','state changed','OS::Heat::MultipartMime',NULL,NULL),(130,'2789da8e-84f0-4e96-b2b2-b7c68e870fcf','9a5d6165-c573-45f8-bba4-b7b3b721fb5c','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','userdata','164af4b8-3137-47fc-bf42-eb7b5157d248','state changed','OS::Heat::MultipartMime',NULL,NULL),(131,'b7e0263a-7b29-4eb5-b371-1493ff42bd7e','9a5d6165-c573-45f8-bba4-b7b3b721fb5c','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','overcloud-ComputeRoleUserData-cf2hpc3ldfo3','9a5d6165-c573-45f8-bba4-b7b3b721fb5c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(132,'4422fbfd-8ad1-4e7e-8f68-f66cca225c4b','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','StorageVirtualIP','90731c90-484d-4246-8367-fd05d4895706','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,42),(133,'5539b431-b1b5-48a6-ad96-38bb116834cd','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:51',NULL,'CREATE','COMPLETE','CellControllerRoleUserData','2f000695-4670-46ab-af2b-691df7356fd4','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(134,'e5afbb97-e195-44bd-818f-812483158154','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:52',NULL,'CREATE','COMPLETE','PublicVirtualIP','5aed0243-4ebb-4302-b4fc-0ec1184127c6','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,46),(135,'cb1e647a-9e25-427b-b287-e07fce5abc0a','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:52',NULL,'CREATE','IN_PROGRESS','VipMap','overcloud-VipMap-pravw26d7svh','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,55),(136,'4b2b258a-6f6c-4209-a254-4bb9724c13db','9d6f363a-24d3-4f01-bc7e-d2dfadee40e9','2026-06-13 07:56:52',NULL,'CREATE','IN_PROGRESS','overcloud-VipMap-pravw26d7svh','9d6f363a-24d3-4f01-bc7e-d2dfadee40e9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(137,'0124dda8-df85-4aa9-9cd9-f61d5560d886','9d6f363a-24d3-4f01-bc7e-d2dfadee40e9','2026-06-13 07:56:52',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-VipMap-pravw26d7svh-NetIpMapValue-qicbiv6yi76i','state changed','OS::Heat::Value',NULL,56),(138,'49bd931b-c7b7-402c-99e4-288f9cdb5bec','9d6f363a-24d3-4f01-bc7e-d2dfadee40e9','2026-06-13 07:56:52',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-VipMap-pravw26d7svh-NetIpMapValue-qicbiv6yi76i','state changed','OS::Heat::Value',NULL,56),(139,'771312bc-e7d9-4886-b261-6a0a26f3e3bb','9d6f363a-24d3-4f01-bc7e-d2dfadee40e9','2026-06-13 07:56:52',NULL,'CREATE','COMPLETE','overcloud-VipMap-pravw26d7svh','9d6f363a-24d3-4f01-bc7e-d2dfadee40e9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(140,'c096b0e5-668b-41aa-87eb-93c68cc93a54','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:52',NULL,'CREATE','IN_PROGRESS','ObjectStorageRoleUserData','overcloud-ObjectStorageRoleUserData-vmqtadp2tpwx','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(141,'7454fb03-3074-4870-a7b6-37d9d59c1dca','7d50e085-03c3-47af-b983-fb838cceadc4','2026-06-13 07:56:52',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageRoleUserData-vmqtadp2tpwx','7d50e085-03c3-47af-b983-fb838cceadc4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(142,'19a53cef-a6bf-4561-9dd0-cff0f0f7cc94','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:52',NULL,'CREATE','COMPLETE','ComputeRoleUserData','9a5d6165-c573-45f8-bba4-b7b3b721fb5c','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(143,'72dbea7d-04c5-4b8d-aec9-18b8afc2d324','7d50e085-03c3-47af-b983-fb838cceadc4','2026-06-13 07:56:52',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ObjectStorageRoleUserData-vmqtadp2tpwx-userdata-ikyj7k3jkrn6','state changed','OS::Heat::MultipartMime',NULL,NULL),(144,'df72c4f5-805d-49b1-970f-437bee492119','7d50e085-03c3-47af-b983-fb838cceadc4','2026-06-13 07:56:52',NULL,'CREATE','COMPLETE','userdata','c062e9a1-7790-4ca7-8264-eea5be3fe188','state changed','OS::Heat::MultipartMime',NULL,NULL),(145,'fbf17949-3e33-42ed-8acc-6c26457dc7f1','7d50e085-03c3-47af-b983-fb838cceadc4','2026-06-13 07:56:52',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageRoleUserData-vmqtadp2tpwx','7d50e085-03c3-47af-b983-fb838cceadc4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(146,'1d4f11ed-3a9a-4478-ad49-d357955e4ef2','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:53',NULL,'CREATE','COMPLETE','VipMap','9d6f363a-24d3-4f01-bc7e-d2dfadee40e9','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,55),(147,'0bdf4687-2568-4550-9a5f-a0cb74ac0a3f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:53',NULL,'CREATE','IN_PROGRESS','NodeAdminUserData','overcloud-NodeAdminUserData-fxgfkkcrz3eo','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(148,'4f3ed3f1-e806-4078-abf7-9fdde623c652','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:53',NULL,'CREATE','IN_PROGRESS','VipHosts','overcloud-VipHosts-grqyj3vwfr3t','state changed','OS::Heat::Value',NULL,60),(149,'448f4096-2352-44fb-90b9-151be5a42831','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:53',NULL,'CREATE','COMPLETE','ObjectStorageRoleUserData','7d50e085-03c3-47af-b983-fb838cceadc4','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(150,'cff8a1e7-6fdc-4d96-9766-53da7faff8fc','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:53',NULL,'CREATE','IN_PROGRESS','EndpointMap','overcloud-EndpointMap-czyg727if3pf','state changed','OS::TripleO::EndpointMap',NULL,61),(151,'8ba0fad1-98b5-49e7-80fd-383b0d84b86d','827ee0c3-c88e-414e-89fb-8add8b9cf9e0','2026-06-13 07:56:53',NULL,'CREATE','IN_PROGRESS','overcloud-NodeAdminUserData-fxgfkkcrz3eo','827ee0c3-c88e-414e-89fb-8add8b9cf9e0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(152,'bc0317d4-7f00-417f-a6f3-1bcaf403d0a7','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:53',NULL,'CREATE','COMPLETE','VipHosts','overcloud-VipHosts-grqyj3vwfr3t','state changed','OS::Heat::Value',NULL,60),(153,'b0e0ca2e-85f1-464f-ac06-0b577dfcee19','9d0982c1-5e8e-4384-8b83-d43c455f6088','2026-06-13 07:56:53',NULL,'CREATE','IN_PROGRESS','overcloud-EndpointMap-czyg727if3pf','9d0982c1-5e8e-4384-8b83-d43c455f6088','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(154,'da33d32d-c8f0-4783-a1cc-9af84ba6671a','827ee0c3-c88e-414e-89fb-8add8b9cf9e0','2026-06-13 07:56:53',NULL,'CREATE','IN_PROGRESS','user_config','overcloud-NodeAdminUserData-fxgfkkcrz3eo-user_config-nplur6aq4sjz','state changed','OS::Heat::CloudConfig',NULL,64),(155,'fa92424c-c4d4-4b07-84e2-f42f47dc2b2a','9d0982c1-5e8e-4384-8b83-d43c455f6088','2026-06-13 07:56:53',NULL,'CREATE','COMPLETE','overcloud-EndpointMap-czyg727if3pf','9d0982c1-5e8e-4384-8b83-d43c455f6088','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(156,'9cbecb21-ec33-4eb0-bd8d-c0b268d25ce0','827ee0c3-c88e-414e-89fb-8add8b9cf9e0','2026-06-13 07:56:53',NULL,'CREATE','COMPLETE','user_config','4f00a128-2a1c-4943-ae0b-641b7635b2a2','state changed','OS::Heat::CloudConfig',NULL,64),(157,'39365f35-0fa6-4588-b53f-31938c257c1c','827ee0c3-c88e-414e-89fb-8add8b9cf9e0','2026-06-13 07:56:54',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeAdminUserData-fxgfkkcrz3eo-userdata-bllmfsdsnmin','state changed','OS::Heat::MultipartMime',NULL,65),(158,'bcea6fe6-d37b-49cb-88ea-5bd1b616dbd6','827ee0c3-c88e-414e-89fb-8add8b9cf9e0','2026-06-13 07:56:54',NULL,'CREATE','COMPLETE','userdata','d7f1edf1-dcaf-4110-9cd7-f6fc0a8b1dfb','state changed','OS::Heat::MultipartMime',NULL,65),(159,'f1364b44-fad7-4b8c-b8d7-2fc8010ce97d','827ee0c3-c88e-414e-89fb-8add8b9cf9e0','2026-06-13 07:56:54',NULL,'CREATE','COMPLETE','overcloud-NodeAdminUserData-fxgfkkcrz3eo','827ee0c3-c88e-414e-89fb-8add8b9cf9e0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(160,'e1e3f677-ed64-4349-a4a1-9d99f029e56f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:54',NULL,'CREATE','IN_PROGRESS','CloudNames','overcloud-CloudNames-m6vdei5kczhn','state changed','OS::Heat::Value',NULL,66),(161,'a6935f03-198d-4928-b951-e7dda0d074b9','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:54',NULL,'CREATE','COMPLETE','CloudNames','overcloud-CloudNames-m6vdei5kczhn','state changed','OS::Heat::Value',NULL,66),(162,'5612e1a7-8e2e-44d1-b183-6286c55ca427','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:54',NULL,'CREATE','COMPLETE','NodeAdminUserData','827ee0c3-c88e-414e-89fb-8add8b9cf9e0','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(163,'6bf18de9-8be0-4826-8920-b6b13d4d40e0','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','COMPLETE','EndpointMap','9d0982c1-5e8e-4384-8b83-d43c455f6088','state changed','OS::TripleO::EndpointMap',NULL,61),(164,'8b700f0d-8ada-489b-b0c8-4c7a9fa63179','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','ComputeUserData','overcloud-ComputeUserData-kfdmcyagns2r','state changed','OS::Heat::MultipartMime',NULL,69),(165,'4fb5eccc-1e1f-471d-9b5e-e4748509c3bd','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','NetworkerUserData','overcloud-NetworkerUserData-4q6oyrz32mhs','state changed','OS::Heat::MultipartMime',NULL,70),(166,'43d1622b-b74d-4975-9aa2-a36ce6879a2f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','BlockStorageUserData','overcloud-BlockStorageUserData-3wj3mvdzsuvl','state changed','OS::Heat::MultipartMime',NULL,68),(167,'dd6696a1-8ae2-4564-9e6c-4057c8182ad2','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','CellControllerUserData','overcloud-CellControllerUserData-mnduqat2nrv4','state changed','OS::Heat::MultipartMime',NULL,71),(168,'1bf1e4c7-5f8b-45a2-8c61-798b6914a181','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','CellControllerComputeUserData','overcloud-CellControllerComputeUserData-oaj4y53rthup','state changed','OS::Heat::MultipartMime',NULL,72),(169,'37bacfda-9bf4-4faa-8102-1c29891b5640','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','CephStorageUserData','overcloud-CephStorageUserData-5756cm3yfdp2','state changed','OS::Heat::MultipartMime',NULL,73),(170,'32734bc3-8062-49ff-b299-a67fbbfac05a','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','ObjectStorageUserData','overcloud-ObjectStorageUserData-52xuf7xeqcxo','state changed','OS::Heat::MultipartMime',NULL,75),(171,'bb6a3227-c70e-4870-8ea8-0d265dff39eb','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','COMPLETE','NetworkerUserData','73ea7fdd-cddd-481d-8624-06f739664915','state changed','OS::Heat::MultipartMime',NULL,70),(172,'4fd605da-57ec-4c86-badb-4b8101609d16','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','EndpointMapData','overcloud-EndpointMapData-kltramegshew','state changed','OS::Heat::Value',NULL,77),(173,'795e5dea-8bbb-4201-bb81-a96a8abc1021','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','ControllerUserData','overcloud-ControllerUserData-ovx56t37hhon','state changed','OS::Heat::MultipartMime',NULL,78),(174,'48090a26-4b65-4183-a67d-74376178a3d1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','COMPLETE','CellControllerUserData','ff317d0d-64a2-45e7-a295-d7ef219931d6','state changed','OS::Heat::MultipartMime',NULL,71),(175,'1c0d8d00-6e30-482e-9fea-dac3f6351757','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','COMPLETE','ComputeUserData','f588373c-8574-4ff5-b868-0ebda1ffa146','state changed','OS::Heat::MultipartMime',NULL,69),(176,'dc0ee462-1398-44d3-a4db-652f6340ef55','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','COMPLETE','BlockStorageUserData','8bdf1813-09c4-4ff6-ad81-e86ed257891d','state changed','OS::Heat::MultipartMime',NULL,68),(177,'065e6b1c-e639-4d43-ba3c-c47ee8b0f757','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','COMPLETE','EndpointMapData','overcloud-EndpointMapData-kltramegshew','state changed','OS::Heat::Value',NULL,77),(178,'34a689f1-00fb-4fe3-9b48-c440fb661aff','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','COMPLETE','ObjectStorageUserData','7ec7c02b-6f51-46e3-9dc6-d2150e28a0d1','state changed','OS::Heat::MultipartMime',NULL,75),(179,'56527cc9-ff2e-4823-a3ad-37eb542ad588','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','COMPLETE','CephStorageUserData','f8b8c355-1543-4332-b35a-dd4fb4980992','state changed','OS::Heat::MultipartMime',NULL,73),(180,'52efa3e0-870b-4b5e-96cd-3343b4ebc8ec','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','COMPLETE','CellControllerComputeUserData','ec36a1f2-c4e7-422c-ab65-2e454f28f5e6','state changed','OS::Heat::MultipartMime',NULL,72),(181,'4f2dfdb2-effd-467a-a52a-69468771ac35','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','COMPLETE','ControllerUserData','dc09851c-7dc7-4e30-97c9-51298701296f','state changed','OS::Heat::MultipartMime',NULL,78),(182,'bf88cb8e-06d8-48e4-8fa6-926803ae6c94','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChain','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4','state changed','OS::TripleO::CellControllerComputeServices',NULL,80),(183,'643bd167-eddd-4a98-843c-50c1b5312a8f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChain','overcloud-NetworkerServiceChain-d2tavcvid3zd','state changed','OS::TripleO::NetworkerServices',NULL,81),(184,'9fc7cf83-b872-4a97-bbd4-de7055ce2da4','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChain','overcloud-ObjectStorageServiceChain-bmfxdpyutifu','state changed','OS::TripleO::ObjectStorageServices',NULL,79),(185,'8f3e9451-566a-4a02-8be9-55bbb3bce1bf','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','ComputeServiceChain','overcloud-ComputeServiceChain-wgl7ydi5ubp5','state changed','OS::TripleO::ComputeServices',NULL,82),(186,'0631b3a0-34a0-408f-82a7-c2e6dbcfc5a8','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChain','overcloud-CellControllerServiceChain-rgx7vpmyupzc','state changed','OS::TripleO::CellControllerServices',NULL,83),(187,'9c92f303-ea9d-4150-9bbd-8f135cb83aba','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChain','overcloud-CephStorageServiceChain-xrxptjyr46zi','state changed','OS::TripleO::CephStorageServices',NULL,84),(188,'68dfebb0-9ad9-4d3b-b666-130baca60d81','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:55',NULL,'CREATE','IN_PROGRESS','ControllerServiceChain','overcloud-ControllerServiceChain-yt3pkirjlivz','state changed','OS::TripleO::ControllerServices',NULL,86),(189,'f5961c46-c656-42d2-b8f8-9b670016a442','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-bmfxdpyutifu','e8726d51-214b-4ea9-ae78-805ee8f97794','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(190,'58acb783-d9f0-44de-b599-bced1ce0f921','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChain','overcloud-BlockStorageServiceChain-ww35ljptrtjj','state changed','OS::TripleO::BlockStorageServices',NULL,87),(191,'8ac85d1b-7bb5-468c-8ec4-c1821cd3a891','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-d2tavcvid3zd','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(192,'07b0cad0-7402-49f1-a8f5-79ade1061d83','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5','ff12385a-9ac7-4e5c-bc33-073b021ba451','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(193,'1be1833f-727c-4325-9282-849f4af0a4be','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4','0ff63522-48f8-4fcd-a882-eb3249febb04','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(194,'e02a1d51-2a31-4608-8a4e-9e3c23617c9f','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-xrxptjyr46zi','a5716f06-aedc-46dd-b08c-db1fb66fce30','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(195,'d944b2d5-4bb6-4a43-a41b-da25189088fa','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz','c7d3c374-e753-4982-bfd2-6e25c8731be3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(196,'3d0f1e7d-a8bc-45b6-8a23-481a3f6ae08a','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-rgx7vpmyupzc','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(197,'7fc3ec62-47b0-452d-929b-6b0f14f6e435','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-ww35ljptrtjj','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(198,'28342e8e-f828-4903-a0b9-def435bd70fe','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5','state changed','OS::Heat::ResourceChain',NULL,88),(199,'5fdd5c5f-78f0-4d55-ad68-0f33a90d8693','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceChain-m7xoc5ygnd75','state changed','OS::Heat::ResourceChain',NULL,89),(200,'c1a298f9-1cc3-401f-8f05-f41f260830b3','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceChain-kpojgptkctva','state changed','OS::Heat::ResourceChain',NULL,90),(201,'7428a864-de60-4431-a75a-dda798a0065c','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceChain-6kezjctielpy','state changed','OS::Heat::ResourceChain',NULL,91),(202,'b60672a7-57ef-49c3-a9a6-013a01d7cda6','b457d49f-0f09-4d42-b7e7-a2e92d5f3d49','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceChain-6kezjctielpy','b457d49f-0f09-4d42-b7e7-a2e92d5f3d49','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(203,'24d4e7de-8e0d-4176-a1bf-e619e14ef379','65240023-8c1a-4de2-b28a-7319b0d5c4ff','2026-06-13 07:56:56',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceChain-kpojgptkctva','65240023-8c1a-4de2-b28a-7319b0d5c4ff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(204,'4a64d290-92ec-4194-a9e0-10b8b78daf6d','b457d49f-0f09-4d42-b7e7-a2e92d5f3d49','2026-06-13 07:56:56',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceChain-6kezjctielpy','b457d49f-0f09-4d42-b7e7-a2e92d5f3d49','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(205,'98e8b3b0-a700-4e0b-8e3b-7b04cbdf1bb1','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceChain-utlgjvmijoey','state changed','OS::Heat::ResourceChain',NULL,92),(206,'7fd584b4-6294-4e64-92b4-9d3e390e9adc','65240023-8c1a-4de2-b28a-7319b0d5c4ff','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceChain-kpojgptkctva','65240023-8c1a-4de2-b28a-7319b0d5c4ff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(207,'7c35d4a8-41ad-4ec5-8244-0bb3b8431f22','3fd5de85-f8cc-4857-b222-7881ae106c51','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceChain-m7xoc5ygnd75','3fd5de85-f8cc-4857-b222-7881ae106c51','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(208,'92b93c9a-455f-4e18-a8d9-e40437cc98eb','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld','state changed','OS::Heat::ResourceChain',NULL,93),(209,'65963ed9-b227-497a-bd0a-dba7a0e03337','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceChain-5hgvbvaanrrh','state changed','OS::Heat::ResourceChain',NULL,94),(210,'bc6d4fe2-6a6c-4586-be91-64011a8a0a14','ed93bf6a-00e6-42c5-acc7-f1b154eaf4e1','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceChain-utlgjvmijoey','ed93bf6a-00e6-42c5-acc7-f1b154eaf4e1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(211,'7c966805-891f-4d4b-87ee-5ea30a8cb7cf','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceChain-dghjn55nuyub','state changed','OS::Heat::ResourceChain',NULL,95),(212,'cff008d6-87c4-491d-9a18-6b185d254408','ed93bf6a-00e6-42c5-acc7-f1b154eaf4e1','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceChain-utlgjvmijoey','ed93bf6a-00e6-42c5-acc7-f1b154eaf4e1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(213,'5a7811cd-1a35-44f6-9784-a6301d945577','3fd5de85-f8cc-4857-b222-7881ae106c51','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceChain-m7xoc5ygnd75','3fd5de85-f8cc-4857-b222-7881ae106c51','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(214,'f44ab3d2-ede2-4afe-878d-6d7d92843c9b','cb284e8f-96e4-409f-bb3c-e48e361c262d','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceChain-5hgvbvaanrrh','cb284e8f-96e4-409f-bb3c-e48e361c262d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(215,'2648d4a4-9857-48ef-930d-c0afacf864ca','1c4752d8-12d7-42bc-baea-98811428c1b8','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceChain-dghjn55nuyub','1c4752d8-12d7-42bc-baea-98811428c1b8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(216,'5f21a53b-95e4-4719-b42b-938a1ac40265','cb284e8f-96e4-409f-bb3c-e48e361c262d','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceChain-5hgvbvaanrrh','cb284e8f-96e4-409f-bb3c-e48e361c262d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(217,'5982a831-3463-4e2d-8be9-dc5cec8e05d3','1c4752d8-12d7-42bc-baea-98811428c1b8','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceChain-dghjn55nuyub','1c4752d8-12d7-42bc-baea-98811428c1b8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(218,'e3a715da-8301-46fc-96bf-94b930ed9cb9','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','ServiceChain','1c4752d8-12d7-42bc-baea-98811428c1b8','state changed','OS::Heat::ResourceChain',NULL,95),(219,'f5c571fd-5662-44ac-a5a1-988f61d6d7f9','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld','58400164-6682-49a5-8096-1c79361644a9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(220,'4cc34742-a405-486f-a681-723234b2acab','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PreDeployStepTasks-ltq374usk5n4','state changed','OS::Heat::Value',NULL,96),(221,'ad4bb907-7768-4d7b-9bfa-f2ef2968f4f2','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-DockerPuppetTasks-3mdhfhvxny7z','state changed','OS::Heat::Value',NULL,97),(222,'716a8a9c-6c26-4941-a103-1fb866154abe','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerServiceChain-rgx7vpmyupzc-GlobalConfigSettings-2lxlkvxkwwhl','state changed','OS::Heat::Value',NULL,98),(223,'dc5f179e-afa4-4168-8da1-89d78c8bfd0e','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PreDeployStepTasks-ltq374usk5n4','state changed','OS::Heat::Value',NULL,96),(224,'316aa7fd-ef00-4a05-864d-ff25ce29c7cd','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-DockerPuppetTasks-3mdhfhvxny7z','state changed','OS::Heat::Value',NULL,97),(225,'3eb92511-af0a-49af-8225-84855b7f67f3','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerServiceChain-rgx7vpmyupzc-GlobalConfigSettings-2lxlkvxkwwhl','state changed','OS::Heat::Value',NULL,98),(226,'e6b0ef41-349f-4c45-be77-f1d2de7e18a0','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ExternalDeployTasks-mgqkrgn4gxnf','state changed','OS::Heat::Value',NULL,99),(227,'a2b1a20a-7137-463c-bbc5-db0fecc89c78','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ScaleTasks-ov5nhktgmux5','state changed','OS::Heat::Value',NULL,100),(228,'a508d8ff-c1c6-4653-9ee9-7fad4e23297c','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ExternalDeployTasks-mgqkrgn4gxnf','state changed','OS::Heat::Value',NULL,99),(229,'2c383733-ce49-4f3e-9450-4b4c26f3bf52','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ScaleTasks-ov5nhktgmux5','state changed','OS::Heat::Value',NULL,100),(230,'72983af6-41ba-43eb-9a40-7e771cdfa4c1','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerServiceChain-rgx7vpmyupzc-FirewallFrontendRules-s4udxudrjysv','state changed','OS::Heat::Value',NULL,101),(231,'1fdf47a8-bc3b-46f5-9fc3-fbc7daa314ef','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ExternalPostDeployTasks-ses47bub6wzm','state changed','OS::Heat::Value',NULL,102),(232,'c82ed651-fe2f-432f-a843-12e7ec2407e5','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ExternalPostDeployTasks-ses47bub6wzm','state changed','OS::Heat::Value',NULL,102),(233,'46c6316a-1beb-4eb0-b503-3f3c247d09ba','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-HostFirewallTasks-tfvkew2au4au','state changed','OS::Heat::Value',NULL,103),(234,'9f325cbf-8fc4-4fcb-8569-a65171eb4712','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerServiceChain-rgx7vpmyupzc-FirewallFrontendRules-s4udxudrjysv','state changed','OS::Heat::Value',NULL,101),(235,'c29eb7a0-7ef3-4a85-81c7-636a2e4fc99d','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-HostFirewallTasks-tfvkew2au4au','state changed','OS::Heat::Value',NULL,103),(236,'711a4b17-b735-491f-9728-4668ccf42a5d','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceConfigSettings-uuo5bw5vgkz4','state changed','OS::Heat::Value',NULL,104),(237,'b65ed712-f37b-47d9-8977-6d4881a0b0d0','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceConfigSettings-uuo5bw5vgkz4','state changed','OS::Heat::Value',NULL,104),(238,'fa619906-c907-42fa-8413-47de4ed35fd2','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','ServiceChain','cb284e8f-96e4-409f-bb3c-e48e361c262d','state changed','OS::Heat::ResourceChain',NULL,94),(239,'4969e92f-2848-4f34-adf9-1adc80447474','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-HostPrepTasks-r6hk6r5cmj6m','state changed','OS::Heat::Value',NULL,107),(240,'5c21283d-8325-4cb1-a394-96a79c2cc4a9','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerServiceChain-rgx7vpmyupzc-DockerConfigScripts-4junbkkhtc2l','state changed','OS::Heat::Value',NULL,106),(241,'a12362cf-81f4-4af5-8acf-c59622c2fb9d','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PuppetConfig-5lxentxz2cof','state changed','OS::Heat::Value',NULL,105),(242,'e8516c69-2c42-424b-b453-3d95998b070d','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-HostPrepTasks-r6hk6r5cmj6m','state changed','OS::Heat::Value',NULL,107),(243,'920e913c-10e9-49a6-ae6e-d5cb1ebb43d0','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PuppetStepConfig-amba45rhg5qf','state changed','OS::Heat::Value',NULL,108),(244,'a3fcae74-7e45-45b7-9f71-02618e8f8137','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ExternalUpdateTasks-5372z7lkdy5y','state changed','OS::Heat::Value',NULL,110),(245,'e530e22f-2079-4095-907a-7dd1110ae854','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PuppetStepConfig-amba45rhg5qf','state changed','OS::Heat::Value',NULL,108),(246,'2c8867fb-83a6-478b-ae3f-bb6d7bdcb7a6','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ExternalUpdateTasks-5372z7lkdy5y','state changed','OS::Heat::Value',NULL,110),(247,'d76c189b-982f-446e-84b6-61397642575b','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerServiceChain-rgx7vpmyupzc-DockerConfig-mlgs3iw7owda','state changed','OS::Heat::Value',NULL,109),(248,'37e6921b-15b5-40b8-b8d2-8cded9349dc2','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PreUpgradeRollingTasks-fchfjntdvlvk','state changed','OS::Heat::Value',NULL,111),(249,'783bc7c1-627d-439b-89d1-efc84ab9cebe','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ContainerPuppetTasks-inpv6tz4mc3q','state changed','OS::Heat::Value',NULL,113),(250,'dfca3ab0-c0a1-4073-b957-87aebacd2191','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PreUpgradeRollingTasks-fchfjntdvlvk','state changed','OS::Heat::Value',NULL,111),(251,'9224d99f-ee7f-4001-915e-3b9e1ae91b67','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-IpaRegistrationTasks-krkoncv4cknh','state changed','OS::Heat::Value',NULL,114),(252,'7aedea97-1ad0-4b9c-9462-4b6df4b5265f','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ContainerPuppetTasks-inpv6tz4mc3q','state changed','OS::Heat::Value',NULL,113),(253,'88e3d9fe-4e8d-471f-a5ba-fb77e2614d17','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceServerMetadataHook-h2c43k2dzvyd','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,112),(254,'1f3629f8-f533-43c8-babd-00b778165d27','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PuppetConfig-5lxentxz2cof','state changed','OS::Heat::Value',NULL,105),(255,'d7c9eada-5589-4e8c-8573-96066ffc158a','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:57',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerServiceChain-rgx7vpmyupzc-DockerConfigScripts-4junbkkhtc2l','state changed','OS::Heat::Value',NULL,106),(256,'10d34639-4dd2-4604-94bf-eac5e78dfee2','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerServiceChain-rgx7vpmyupzc-AnsibleGroupVars-4xiitesct3hk','state changed','OS::Heat::Value',NULL,115),(257,'953e5c51-9849-4fb9-8e4b-f1ef6a81ed6d','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerServiceChain-rgx7vpmyupzc-AnsibleGroupVars-4xiitesct3hk','state changed','OS::Heat::Value',NULL,115),(258,'efa1c6be-34e5-4999-ad03-226aa0e7ae2e','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-IpaRegistrationTasks-krkoncv4cknh','state changed','OS::Heat::Value',NULL,114),(259,'34403dfb-18da-4197-8e9d-b682919f2c56','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ServiceChain','65240023-8c1a-4de2-b28a-7319b0d5c4ff','state changed','OS::Heat::ResourceChain',NULL,90),(260,'329b03a9-bbf4-4b6d-ac9b-04c6f71fd6f5','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceNames-srjfc2ghtjeo','state changed','OS::Heat::Value',NULL,116),(261,'453192c6-0eed-4ced-923e-15dfc893e45d','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CephStorageServiceChain-xrxptjyr46zi-AnsibleGroupVars-eu2potsar76l','state changed','OS::Heat::Value',NULL,117),(262,'b170df95-9670-4cd5-9236-75ba1662f1aa','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerServiceChain-rgx7vpmyupzc-DockerConfig-mlgs3iw7owda','state changed','OS::Heat::Value',NULL,109),(263,'280f31d5-1081-4f84-9649-d817ca640577','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-DeployStepsTasks-b2t3r3njffax','state changed','OS::Heat::Value',NULL,118),(264,'abe8a43f-12de-4ee4-816d-d4cd1fa97fe1','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CephStorageServiceChain-xrxptjyr46zi-AnsibleGroupVars-eu2potsar76l','state changed','OS::Heat::Value',NULL,117),(265,'f868d98a-3b47-48bd-aa33-935f71094470','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ServiceChain','3fd5de85-f8cc-4857-b222-7881ae106c51','state changed','OS::Heat::ResourceChain',NULL,89),(266,'4810be32-33a2-4f0a-b03e-adfe393af01a','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-DeployStepsTasks-b2t3r3njffax','state changed','OS::Heat::Value',NULL,118),(267,'79ab4f1b-b4bc-4548-8e9b-8c27cbda7d4f','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-UpgradeTasks-enuswucl3lve','state changed','OS::Heat::Value',NULL,120),(268,'e7206668-0dae-46e2-bc8d-77d0f778eb6e','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceNames-srjfc2ghtjeo','state changed','OS::Heat::Value',NULL,116),(269,'732a51ac-4b95-495e-bcf7-e715e3f4c74f','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ServiceChain','b457d49f-0f09-4d42-b7e7-a2e92d5f3d49','state changed','OS::Heat::ResourceChain',NULL,91),(270,'c52e8f66-682a-4611-b961-ef87db7ebe51','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-UpgradeTasks-enuswucl3lve','state changed','OS::Heat::Value',NULL,120),(271,'99642432-88d6-41a4-97d4-fbbd693b7890','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-DockerPuppetTasks-ruhecq56lxqc','state changed','OS::Heat::Value',NULL,121),(272,'9a6d7dae-8e31-49fd-a948-85693f42d168','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PostUpgradeTasks-cd3i3swx2kt7','state changed','OS::Heat::Value',NULL,119),(273,'b7363e1f-f13e-47d7-8502-b054d297e7ef','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceServerMetadataHook-h2c43k2dzvyd','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(274,'abc76977-290b-4a51-bebe-7453b9183cea','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-DockerConfigScripts-6bjfmftcifiy','state changed','OS::Heat::Value',NULL,124),(275,'e2585858-6488-4e2e-8c6a-d28b1b8dcab4','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-IpaRegistrationTasks-gg5fdjxnpm7x','state changed','OS::Heat::Value',NULL,123),(276,'c2102ba7-cb89-45c6-8fb1-4e7965064068','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ServiceChain','ed93bf6a-00e6-42c5-acc7-f1b154eaf4e1','state changed','OS::Heat::ResourceChain',NULL,92),(277,'620c0bdf-bb9e-487d-9b6d-984126b18b2e','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PostUpdateTasks-axmbecv7gy4p','state changed','OS::Heat::Value',NULL,125),(278,'d625c084-5a96-48b5-97e4-a60a67e8f8d3','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-DockerPuppetTasks-ruhecq56lxqc','state changed','OS::Heat::Value',NULL,121),(279,'ed244cf4-54a8-4417-8bb1-8e8518561e4a','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-rgx7vpmyupzc-KeystoneResourcesConfigs-nlb3dwsnyvbj','state changed','OS::Heat::Value',NULL,122),(280,'a973ad2e-5f39-4f63-9a3b-3c0f460ec5ba','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerServiceChain-rgx7vpmyupzc-FirewallRules-przsmqqd5uzk','state changed','OS::Heat::Value',NULL,126),(281,'e240850c-43ef-4793-a26c-a869c9a46d39','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-DockerConfigScripts-6bjfmftcifiy','state changed','OS::Heat::Value',NULL,124),(282,'a41bcea2-98d5-4cd3-959b-04f44b2f5567','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-UpgradeBatchTasks-uijxcmns62ei','state changed','OS::Heat::Value',NULL,127),(283,'6ce32a40-347d-4ae9-a1fe-54690e5613bc','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ScaleTasks-cmlwxidyzb2y','state changed','OS::Heat::Value',NULL,129),(284,'b04a37bb-3675-4a2a-a17c-8318e8c930cd','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-UpdateTasks-vv2yp7txswta','state changed','OS::Heat::Value',NULL,130),(285,'ad4c70ce-98ed-4507-a372-a62aaa296a26','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-GlobalConfigSettings-7owci2ijuq5e','state changed','OS::Heat::Value',NULL,128),(286,'b359514c-adf1-4122-8a6a-5b7586add035','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PostUpgradeTasks-cd3i3swx2kt7','state changed','OS::Heat::Value',NULL,119),(287,'b0ceef3a-1a70-4c2c-8a90-2643344f3764','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-PostUpdateTasks-axmbecv7gy4p','state changed','OS::Heat::Value',NULL,125),(288,'595972d2-b4c0-4a71-9c72-7ddb2c750611','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-MonitoringSubscriptionsConfig-67zhznt5r5ow','state changed','OS::Heat::Value',NULL,131),(289,'6ec54d42-c9aa-4a25-a363-823be86b0b26','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-IpaRegistrationTasks-gg5fdjxnpm7x','state changed','OS::Heat::Value',NULL,123),(290,'cf07efa4-5afe-4b95-854c-700b9128f02d','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-UpgradeBatchTasks-uijxcmns62ei','state changed','OS::Heat::Value',NULL,127),(291,'ba10108b-27ea-4eb2-b82e-39303e41875e','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-d2tavcvid3zd-KeystoneResourcesConfigs-hmysjvhhteqr','state changed','OS::Heat::Value',NULL,133),(292,'faac53f4-e562-4dd7-aa02-2d2256744c7d','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-UpdateTasks-yvzbl3znvzcl','state changed','OS::Heat::Value',NULL,132),(293,'0552b90c-979b-4836-8cc1-33a713642f99','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(294,'808369e3-aa51-448b-8509-7ed8b98a57b6','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ScaleTasks-cmlwxidyzb2y','state changed','OS::Heat::Value',NULL,129),(295,'19bd1791-2765-4525-894e-6f94639246d9','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PreUpgradeRollingTasks-dezmfk5lgdf2','state changed','OS::Heat::Value',NULL,137),(296,'40281270-2c7e-4dee-9082-45541cf46d06','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-UpgradeBatchTasks-auoqczv55hf5','state changed','OS::Heat::Value',NULL,135),(297,'f57febce-525e-40c2-96e6-c0afc905b9e2','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-d2tavcvid3zd-KeystoneResourcesConfigs-hmysjvhhteqr','state changed','OS::Heat::Value',NULL,133),(298,'2a66fd7c-3463-4d2d-bc37-bfa36c15f634','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PreUpgradeRollingTasks-dezmfk5lgdf2','state changed','OS::Heat::Value',NULL,137),(299,'b915228b-fc2c-442f-b0f4-2e60c145c0a5','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-HostPrepTasks-2a3x6q552gv4','state changed','OS::Heat::Value',NULL,136),(300,'0e27e0c3-74ed-4e29-bb9d-c98b472a5399','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceServerMetadataHook-bn7nmtmbftrr','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,134),(301,'dda4d2ae-924b-4eea-a5a9-493dcca273ea','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-rgx7vpmyupzc-KeystoneResourcesConfigs-nlb3dwsnyvbj','state changed','OS::Heat::Value',NULL,122),(302,'9708f9c3-a761-4460-ab71-c2dce7acf8dc','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerServiceChain-rgx7vpmyupzc-FirewallRules-przsmqqd5uzk','state changed','OS::Heat::Value',NULL,126),(303,'3c62b7f1-fb7b-4b16-aecc-fefc1fca907e','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-MonitoringSubscriptionsConfig-67zhznt5r5ow','state changed','OS::Heat::Value',NULL,131),(304,'9e775af5-d66d-41bd-bcb7-cacfd4f5e439','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-UpdateTasks-ilhx35rwrobb','state changed','OS::Heat::Value',NULL,139),(305,'ff100f65-4249-4f69-b651-55b91a1dca31','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-UpdateTasks-vv2yp7txswta','state changed','OS::Heat::Value',NULL,130),(306,'63e4739a-ce02-483b-b051-08f2322a94a7','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-UpdateTasks-yvzbl3znvzcl','state changed','OS::Heat::Value',NULL,132),(307,'81a4d148-4a5c-47c0-8861-af2f1e11f430','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ExternalPostDeployTasks-2ouslhyoomkj','state changed','OS::Heat::Value',NULL,140),(308,'5ad7b980-78dd-4a32-b63b-9f0a750aef35','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-rgx7vpmyupzc-MonitoringSubscriptionsConfig-rswmgxvyc3cu','state changed','OS::Heat::Value',NULL,138),(309,'19277468-b829-4c57-b941-5c9ed6c90039','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CephStorageServiceChain-xrxptjyr46zi-PuppetConfig-q3gcfzjajcyt','state changed','OS::Heat::Value',NULL,144),(310,'26906b7e-97a9-4a9c-a4cd-ca018a53e32f','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceNames-wjlk2y42m4lq','state changed','OS::Heat::Value',NULL,143),(311,'d316736a-ce00-48ed-82ff-1782bd1abaf5','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceConfigSettings-2ne7bcqwulmw','state changed','OS::Heat::Value',NULL,145),(312,'f1dfe709-568a-49e3-8887-53286c2a28b7','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CephStorageServiceChain-xrxptjyr46zi-PuppetConfig-q3gcfzjajcyt','state changed','OS::Heat::Value',NULL,144),(313,'71576926-4251-4672-bd44-2a37a8b5d7c4','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-UpgradeBatchTasks-auoqczv55hf5','state changed','OS::Heat::Value',NULL,135),(314,'e1d2abe2-7a9d-44a1-9d03-6520e6788941','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceConfigSettings-2ne7bcqwulmw','state changed','OS::Heat::Value',NULL,145),(315,'3cb373cc-80ef-4184-911d-487b42f41908','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-HostPrepTasks-2a3x6q552gv4','state changed','OS::Heat::Value',NULL,136),(316,'be39f9f6-f655-4033-a48c-8187a9d82e82','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ScaleTasks-4yn7t6rka3hk','state changed','OS::Heat::Value',NULL,148),(317,'23f4906d-b6a5-445d-b1a4-4b53e45a7c37','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-AnsibleGroupVars-celspydzmsvo','state changed','OS::Heat::Value',NULL,147),(318,'09207955-2d3f-4c5e-88ef-b2004b2dc6cb','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-UpgradeTasks-zhwxfffjss4h','state changed','OS::Heat::Value',NULL,149),(319,'ae7a008a-a8b9-4637-b82d-382ae8eaf6ea','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-UpdateTasks-ilhx35rwrobb','state changed','OS::Heat::Value',NULL,139),(320,'12005381-3a99-49ed-85f3-b670928f6c63','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-HostPrepTasks-aah6u4fh3lxl','state changed','OS::Heat::Value',NULL,150),(321,'245306b2-4091-4671-a2b5-9a651f284b31','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ExternalPostDeployTasks-2ouslhyoomkj','state changed','OS::Heat::Value',NULL,140),(322,'16c8a0e6-c023-4815-8a88-17c5443210e6','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-HostPrepTasks-aah6u4fh3lxl','state changed','OS::Heat::Value',NULL,150),(323,'e3a0a206-7c38-4242-b1d7-049c23fcfe2e','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceNames-wjlk2y42m4lq','state changed','OS::Heat::Value',NULL,143),(324,'f0880138-b0c8-4a43-bf62-d70feec097ea','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ExternalUpdateTasks-g4danpmczw5f','state changed','OS::Heat::Value',NULL,152),(325,'7f590c0a-deb1-44ad-acbb-c026533a6e2c','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-GlobalConfigSettings-7owci2ijuq5e','state changed','OS::Heat::Value',NULL,128),(326,'c9707639-266c-4bca-b6b3-7f3bd0a852d1','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceServerMetadataHook-3ptvkurujr34','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,153),(327,'45a1deba-aa44-4426-89ad-99b6e39f1f67','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-AnsibleGroupVars-celspydzmsvo','state changed','OS::Heat::Value',NULL,147),(328,'3c1bfda5-a343-4e7d-b8b4-bfe0fe7d6062','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerServiceChain-rgx7vpmyupzc-KollaConfig-uhu2cdfw6j2s','state changed','OS::Heat::Value',NULL,142),(329,'44069047-b2a2-4a2e-917a-1d190af516f0','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-MonitoringSubscriptionsConfig-qjnwqlgofzrm','state changed','OS::Heat::Value',NULL,151),(330,'c131bf7f-568a-4a5f-9df4-f8b7e31c2f8f','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-UpgradeTasks-zhwxfffjss4h','state changed','OS::Heat::Value',NULL,149),(331,'3697ef9c-01df-41d9-bc28-1f4bd2862d74','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-KeystoneResourcesConfigs-wjzyegupg3h5','state changed','OS::Heat::Value',NULL,154),(332,'e5629954-9f80-4e3e-8fd3-b5bc0a92ae63','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ExternalPostDeployTasks-hofaq6giojfx','state changed','OS::Heat::Value',NULL,158),(333,'ad99088f-dece-4354-adc6-95ef082115b6','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ExternalUpdateTasks-g4danpmczw5f','state changed','OS::Heat::Value',NULL,152),(334,'628bbbeb-5f3f-4de1-a053-f3b8bd50b390','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceServerMetadataHook-3ptvkurujr34','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(335,'b18353e9-f908-4991-8162-4f33c95809ab','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ScaleTasks-4yn7t6rka3hk','state changed','OS::Heat::Value',NULL,148),(336,'22ae92c4-9931-4eac-9eb2-3b1ba79231cb','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ContainerPuppetTasks-3igpn2ix3v6q','state changed','OS::Heat::Value',NULL,155),(337,'e2a01153-b14b-4ff8-9397-76bacd19346e','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-UpgradeBatchTasks-usbysty73ynf','state changed','OS::Heat::Value',NULL,157),(338,'533095ea-25cc-4465-ad4b-514ac5b6e72d','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ExternalUpgradeTasks-dac5ey7a7zsq','state changed','OS::Heat::Value',NULL,146),(339,'c809e3ad-451e-45b6-a40b-9ddf4bdff82a','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-DeployStepsTasks-75oxyrwphhzz','state changed','OS::Heat::Value',NULL,156),(340,'1e534e49-aef5-4424-b542-0143ea0a1770','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-KeystoneResourcesConfigs-wjzyegupg3h5','state changed','OS::Heat::Value',NULL,154),(341,'e274997a-96d0-43ef-85ca-a416248d0494','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ExternalPostDeployTasks-hofaq6giojfx','state changed','OS::Heat::Value',NULL,158),(342,'3b7d4c6f-91d0-4b1b-894a-78bfe441b961','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-KeystoneResourcesConfigs-gvxt3lajz5zy','state changed','OS::Heat::Value',NULL,162),(343,'8f213d3e-60d0-4ebf-a3c2-ccf5100e5248','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-HostFirewallTasks-2m7zwehz4vnu','state changed','OS::Heat::Value',NULL,159),(344,'3937b8da-4694-4cc3-a67b-818b098c8e05','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-MonitoringSubscriptionsConfig-qjnwqlgofzrm','state changed','OS::Heat::Value',NULL,151),(345,'80c47abb-b494-4036-b270-e3d4d7956d2d','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-DockerConfigScripts-6y5aa7v6gpac','state changed','OS::Heat::Value',NULL,164),(346,'38dab527-bd11-48e3-9c11-f9ce0fe1442a','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-PostUpdateTasks-epaeynby22gp','state changed','OS::Heat::Value',NULL,167),(347,'7db595fa-9a91-4862-86ef-6854caaba81c','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ExternalPostDeployTasks-3flubz2eeu6d','state changed','OS::Heat::Value',NULL,163),(348,'97196e95-1b71-4f1c-a6ac-a62b0b955c04','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-KeystoneResourcesConfigs-gvxt3lajz5zy','state changed','OS::Heat::Value',NULL,162),(349,'d21472af-0eed-4614-bce5-f348bd5fa066','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-HostPrepTasks-d3efrqbmkj2t','state changed','OS::Heat::Value',NULL,160),(350,'0ee6281c-7548-4fcd-8f6d-2c759e2a6e26','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-rgx7vpmyupzc-MonitoringSubscriptionsConfig-rswmgxvyc3cu','state changed','OS::Heat::Value',NULL,138),(351,'864096c1-68fb-4ac6-95ff-f53b6753139e','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ContainerPuppetTasks-7ccvoizeqgwv','state changed','OS::Heat::Value',NULL,161),(352,'ed31fdf7-9ea0-4df0-b6cd-34d1b2370d74','929dd4f1-d14f-45d2-9cc6-218484a7f826','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceServerMetadataHook-bn7nmtmbftrr','929dd4f1-d14f-45d2-9cc6-218484a7f826','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(353,'c6cd09f3-ebca-498d-8b03-7ea328ee7d6e','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-UpgradeBatchTasks-usbysty73ynf','state changed','OS::Heat::Value',NULL,157),(354,'ea6a9a53-1389-43d4-9907-99c672027a8d','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-UpgradeTasks-j3x5aueeyjnh','state changed','OS::Heat::Value',NULL,166),(355,'544b7fb4-5236-4aea-b59e-08faf5e1aa20','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-UpdateTasks-5r2yybl3xtf7','state changed','OS::Heat::Value',NULL,169),(356,'bdeb3db7-7668-4f8d-88f2-66891c29c099','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-PostUpdateTasks-epaeynby22gp','state changed','OS::Heat::Value',NULL,167),(357,'c4948749-a2b3-4a38-a70b-e768b6988b52','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ContainerPuppetTasks-3igpn2ix3v6q','state changed','OS::Heat::Value',NULL,155),(358,'9af1b8b0-facd-4449-aad8-488cf11724eb','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-KollaConfig-ga4oayrqxdks','state changed','OS::Heat::Value',NULL,173),(359,'17e5bf39-cad6-4e93-9b82-a706f6e18714','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-GlobalConfigSettings-xwojr75m2r4j','state changed','OS::Heat::Value',NULL,165),(360,'0528d2d7-0a16-4246-a536-61f01b02f187','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PuppetStepConfig-akfgrve2xpym','state changed','OS::Heat::Value',NULL,171),(361,'4f88eebe-d7d0-45f6-ae7b-a22aed39f1ca','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerServiceChain-rgx7vpmyupzc-KollaConfig-uhu2cdfw6j2s','state changed','OS::Heat::Value',NULL,142),(362,'36b7dbbd-fa39-47b3-82bc-9c3a827a4024','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceNames-g326sa3utzyb','state changed','OS::Heat::Value',NULL,168),(363,'a09ff578-7ae5-4176-9936-3d06b98feba0','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-DockerConfigScripts-6y5aa7v6gpac','state changed','OS::Heat::Value',NULL,164),(364,'24f96adb-7760-45f5-a552-d1a18f205c3c','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PreDeployStepTasks-xcr5gwlbf476','state changed','OS::Heat::Value',NULL,174),(365,'6d737585-b25e-4168-ba1d-215bdca5b820','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-HostFirewallTasks-2m7zwehz4vnu','state changed','OS::Heat::Value',NULL,159),(366,'11d63bfb-6cf9-4e74-ac2f-dd6d16186bfa','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-KollaConfig-ga4oayrqxdks','state changed','OS::Heat::Value',NULL,173),(367,'4014a2f3-9b57-4df6-8def-aabe168009db','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceServerMetadataHook-h2c43k2dzvyd-IncomingMetadataSettings-r5zybr5z4aar','state changed','OS::Heat::Value',NULL,172),(368,'3a8ed0a1-d826-417b-a56d-ece28f600f35','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-UpdateTasks-5r2yybl3xtf7','state changed','OS::Heat::Value',NULL,169),(369,'84712b3c-bd23-4408-bc03-16caa2bba300','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ExternalUpdateTasks-g6wi6klbx2px','state changed','OS::Heat::Value',NULL,175),(370,'413fb29e-44ce-4bfe-9941-e967dcc9d5ae','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PreDeployStepTasks-xcr5gwlbf476','state changed','OS::Heat::Value',NULL,174),(371,'72a6b76f-fa39-46dd-a9d5-15cf6ac8ddfc','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-BlockStorageServiceChain-ww35ljptrtjj-DockerConfigScripts-uyxzqvdjgot6','state changed','OS::Heat::Value',NULL,177),(372,'d4cb2f1a-8e83-4c9f-92a5-aab915b78d21','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ExternalPostDeployTasks-3flubz2eeu6d','state changed','OS::Heat::Value',NULL,163),(373,'640b5c6e-89c5-436f-b92d-831b3b028d55','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceNames-jy4bqubdreeg','state changed','OS::Heat::Value',NULL,170),(374,'9d760f78-9c7d-4199-bb4f-d2e13c0cfa8f','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PuppetStepConfig-akfgrve2xpym','state changed','OS::Heat::Value',NULL,171),(375,'318735c1-d30b-43a0-a69e-4e5a536e6c2c','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-DeployStepsTasks-75oxyrwphhzz','state changed','OS::Heat::Value',NULL,156),(376,'0bd3dabf-ee3c-4cd6-80ca-6ae48af5d79a','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-BlockStorageServiceChain-ww35ljptrtjj-FirewallFrontendRules-rwjx5gi3tpej','state changed','OS::Heat::Value',NULL,176),(377,'2493917e-f820-49d1-8e96-d3795487da72','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ExternalUpgradeTasks-dac5ey7a7zsq','state changed','OS::Heat::Value',NULL,146),(378,'52cb4314-cbb1-4580-a1af-03326c6b2e62','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-ww35ljptrtjj-MonitoringSubscriptionsConfig-f7bw22t3ytsp','state changed','OS::Heat::Value',NULL,181),(379,'ef95052a-f001-4f3e-9e34-4374bfc68b70','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-BlockStorageServiceChain-ww35ljptrtjj-DockerConfigScripts-uyxzqvdjgot6','state changed','OS::Heat::Value',NULL,177),(380,'58e95d01-9d06-4c96-874a-b411b2dc3393','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-UpgradeTasks-j3x5aueeyjnh','state changed','OS::Heat::Value',NULL,166),(381,'b8543478-6c7d-4f8c-a894-f019dd097821','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ContainerPuppetTasks-kku542nybadz','state changed','OS::Heat::Value',NULL,179),(382,'5bdc24bf-2dd4-4d11-9572-f7976eb4ca35','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-ww35ljptrtjj-MonitoringSubscriptionsConfig-f7bw22t3ytsp','state changed','OS::Heat::Value',NULL,181),(383,'fb0e7f4a-e4cc-4f6d-9756-3cb57f2134ff','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ExternalUpdateTasks-g6wi6klbx2px','state changed','OS::Heat::Value',NULL,175),(384,'9d9b5061-58e0-424c-956c-3f1ee9fa4836','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-IpaRegistrationTasks-nmkq4aoa43ez','state changed','OS::Heat::Value',NULL,185),(385,'e7e3a97d-4080-4447-8d52-2155551d1ce6','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-BlockStorageServiceChain-ww35ljptrtjj-KollaConfig-5yw3bwnfqblj','state changed','OS::Heat::Value',NULL,178),(386,'3baa99b3-b9c3-40ea-aa95-41c860e9e616','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-FirewallRules-uea2qrtglqpp','state changed','OS::Heat::Value',NULL,182),(387,'6ce691bd-515e-47f1-8932-31ff817d7aac','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ScaleTasks-w666f7ybf5yv','state changed','OS::Heat::Value',NULL,183),(388,'49a02373-68f8-4bfa-b935-6c0c812d9e73','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-IpaRegistrationTasks-nmkq4aoa43ez','state changed','OS::Heat::Value',NULL,185),(389,'72fc2660-75b3-4f48-aab9-15ea1d3dc694','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PostUpgradeTasks-p3iingukz6j6','state changed','OS::Heat::Value',NULL,186),(390,'45527885-0c55-4b11-ac84-771aae98c8b0','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-HostPrepTasks-d3efrqbmkj2t','state changed','OS::Heat::Value',NULL,160),(391,'ccd860a0-2374-4118-ab1d-8878550ad770','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:58',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ContainerPuppetTasks-kku542nybadz','state changed','OS::Heat::Value',NULL,179),(392,'3da06153-9f4f-485c-aa8d-34a06f8dcfed','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:58',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-BlockStorageServiceChain-ww35ljptrtjj-GlobalConfigSettings-3sog3fhodaac','state changed','OS::Heat::Value',NULL,180),(393,'329960a5-44f1-40d9-ad8a-30bd850f9969','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ContainerPuppetTasks-7ccvoizeqgwv','state changed','OS::Heat::Value',NULL,161),(394,'e041c659-b967-476e-8960-4ab389f0f0ad','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceConfigSettings-opsy7taqrfwq','state changed','OS::Heat::Value',NULL,188),(395,'ee57365a-905a-4cb2-8af6-fbdee492869f','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-FirewallRules-uea2qrtglqpp','state changed','OS::Heat::Value',NULL,182),(396,'549addcf-7692-4ba7-af9f-0add8db25459','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceConfigSettings-opsy7taqrfwq','state changed','OS::Heat::Value',NULL,188),(397,'de04dce6-b3e0-4f30-bfe0-81cb331d77b7','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-GlobalConfigSettings-xwojr75m2r4j','state changed','OS::Heat::Value',NULL,165),(398,'7c0b8604-6131-4e51-b3a3-cb5349446a75','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PreUpgradeRollingTasks-zny4g2urmvzf','state changed','OS::Heat::Value',NULL,184),(399,'6ab4a2f6-d0b6-48aa-9695-4b6a5ee2f63f','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceServerMetadataHook-h2c43k2dzvyd-IncomingMetadataSettings-r5zybr5z4aar','state changed','OS::Heat::Value',NULL,172),(400,'20f37c4b-d31f-40fe-98f8-f28334c3dcc6','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-BlockStorageServiceChain-ww35ljptrtjj-FirewallFrontendRules-rwjx5gi3tpej','state changed','OS::Heat::Value',NULL,176),(401,'9915cb7b-4089-4b1d-870b-cda25d919e93','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ExternalPostDeployTasks-2xd6uxn5n5mz','state changed','OS::Heat::Value',NULL,193),(402,'011a21f2-b568-4d67-ba17-59f71ef7a1db','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceNames-g326sa3utzyb','state changed','OS::Heat::Value',NULL,168),(403,'9742e8fc-0855-4c4b-bbfd-4f0236ea3079','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-DeployStepsTasks-f33ot42tih7j','state changed','OS::Heat::Value',NULL,189),(404,'9dc920ca-225b-4b60-aaec-3210307f41ed','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PuppetStepConfig-tqpv2cirvzfj','state changed','OS::Heat::Value',NULL,187),(405,'ba1f8f69-53e8-44dc-ac6a-4dca22a45c21','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PostUpgradeTasks-p3iingukz6j6','state changed','OS::Heat::Value',NULL,186),(406,'975dfd16-6de8-4cb9-a9b9-534c4f893576','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ExternalPostDeployTasks-2xd6uxn5n5mz','state changed','OS::Heat::Value',NULL,193),(407,'d1896d14-5c52-426b-98c0-66c1a91d7925','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ExternalUpgradeTasks-6cx76lttm7ut','state changed','OS::Heat::Value',NULL,194),(408,'dbd618e8-bf6c-471f-bb40-641877572532','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-ww35ljptrtjj-KeystoneResourcesConfigs-q7jrnmk5d32c','state changed','OS::Heat::Value',NULL,190),(409,'17d643a8-7449-4907-b695-fcd6fad9679e','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ExternalUpgradeTasks-hvdw6zaax7yx','state changed','OS::Heat::Value',NULL,197),(410,'9899d033-6ba7-4d7a-a4ec-84cdd8510737','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-BlockStorageServiceChain-ww35ljptrtjj-KollaConfig-5yw3bwnfqblj','state changed','OS::Heat::Value',NULL,178),(411,'22213eb4-b68c-4df9-8d72-b3b71e9a07ac','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ScaleTasks-w666f7ybf5yv','state changed','OS::Heat::Value',NULL,183),(412,'1694404c-e904-4f5d-9d01-9550d772cee3','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceNames-jy4bqubdreeg','state changed','OS::Heat::Value',NULL,170),(413,'e9ced6e5-fe5c-425e-a1f7-6437d3500079','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ExternalUpgradeTasks-hvdw6zaax7yx','state changed','OS::Heat::Value',NULL,197),(414,'5f175994-aa64-491c-ae9d-a49b91cebcd7','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-UpgradeTasks-jsffzjrf7wfb','state changed','OS::Heat::Value',NULL,191),(415,'a180d49b-f8bc-455f-bdbf-87fc9967481b','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-DeployStepsTasks-f33ot42tih7j','state changed','OS::Heat::Value',NULL,189),(416,'ee598e18-b16a-4f6b-87a5-a7696c163895','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-NetworkerServiceChain-d2tavcvid3zd-AnsibleGroupVars-7iyjlewi7gil','state changed','OS::Heat::Value',NULL,196),(417,'abfdea0b-9071-4fdb-8d61-e8c013ad1fda','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ExternalPostDeployTasks-o5jtgpom2wjj','state changed','OS::Heat::Value',NULL,192),(418,'3c47ec6d-4344-4ee6-a392-9466a3886e90','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceServerMetadataHook-h2c43k2dzvyd-IndividualServices-icmnimn63h6a','state changed','OS::Heat::Value',NULL,202),(419,'a36c74c8-8e4c-44b7-97ea-c3380670e169','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-DeployStepsTasks-fumq3thxc7zj','state changed','OS::Heat::Value',NULL,198),(420,'5effffa1-7e6f-4d98-b5e2-4b3b5c2b6404','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ExternalUpgradeTasks-6cx76lttm7ut','state changed','OS::Heat::Value',NULL,194),(421,'0f24c14d-2a2d-42d6-9c09-71eeafcb7c8c','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceServerMetadataHook-3ptvkurujr34-IncomingMetadataSettings-jc3iphs2mjlt','state changed','OS::Heat::Value',NULL,195),(422,'5a44ff74-6950-495f-8b30-3aaeef07ce0e','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceServerMetadataHook-h2c43k2dzvyd-IndividualServices-icmnimn63h6a','state changed','OS::Heat::Value',NULL,202),(423,'c8025493-d4cc-4d7a-8087-6e597a875b18','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ExternalDeployTasks-j4qikdy3b7w3','state changed','OS::Heat::Value',NULL,199),(424,'56d43cc3-3689-4a89-a6ed-df65c4d046da','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-PostUpgradeTasks-3tla7r4o4oor','state changed','OS::Heat::Value',NULL,206),(425,'b59711dc-fd86-4bb2-a133-c328c86e12fd','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PuppetStepConfig-yzeo2bzkg2w4','state changed','OS::Heat::Value',NULL,203),(426,'beb0dd92-49e6-47d9-8cad-5f38bed42304','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-PostUpgradeTasks-3tla7r4o4oor','state changed','OS::Heat::Value',NULL,206),(427,'cede2dad-6c32-4970-9436-cf68ffe19245','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-UpgradeTasks-qb7s6dyc7heh','state changed','OS::Heat::Value',NULL,200),(428,'c28e9f19-6e56-4d88-a3f0-b787be213f72','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PreUpgradeRollingTasks-m65osjwr5dxj','state changed','OS::Heat::Value',NULL,207),(429,'b522a16a-6184-4b31-b745-6d6635b0b686','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-DeployStepsTasks-fumq3thxc7zj','state changed','OS::Heat::Value',NULL,198),(430,'6f219857-3b35-48b6-be27-5f62f1d68196','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-ww35ljptrtjj-KeystoneResourcesConfigs-q7jrnmk5d32c','state changed','OS::Heat::Value',NULL,190),(431,'dd5c9345-d37e-417d-97e3-33aaa70f5af6','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-NetworkerServiceChain-d2tavcvid3zd-PuppetConfig-fz3vovy4n5dr','state changed','OS::Heat::Value',NULL,204),(432,'28e6f8d1-83ec-4495-ac76-99c83aec9373','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceServerMetadataHook-h2c43k2dzvyd-CompactServices-222c6b5flzjp','state changed','OS::Heat::Value',NULL,211),(433,'6ce3ae75-3262-4d1a-9575-a40e309bf653','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-UpgradeTasks-jsffzjrf7wfb','state changed','OS::Heat::Value',NULL,191),(434,'f7451497-3321-46a9-8814-df858878451b','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PuppetStepConfig-yzeo2bzkg2w4','state changed','OS::Heat::Value',NULL,203),(435,'09a9483e-3b77-4dab-885a-87c03dc3c110','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-BlockStorageServiceChain-ww35ljptrtjj-GlobalConfigSettings-3sog3fhodaac','state changed','OS::Heat::Value',NULL,180),(436,'fe75046b-df1d-478b-b381-d94e7e9acae5','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PuppetConfig-wfcktx4zy7ul','state changed','OS::Heat::Value',NULL,201),(437,'ed4cc15d-922f-4966-bb15-be678fc34024','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceServerMetadataHook-h2c43k2dzvyd-CompactServices-222c6b5flzjp','state changed','OS::Heat::Value',NULL,211),(438,'eaaeea06-b652-467a-bcb8-0dd323faef6e','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PreUpgradeRollingTasks-zny4g2urmvzf','state changed','OS::Heat::Value',NULL,184),(439,'0040cc2f-7f93-4b1f-9c35-6d93c856f03e','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-NetworkerServiceChain-d2tavcvid3zd-AnsibleGroupVars-7iyjlewi7gil','state changed','OS::Heat::Value',NULL,196),(440,'0bc47fa5-f87d-42de-8e2b-be82849dea75','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceNames-bcke3tcahvq4','state changed','OS::Heat::Value',NULL,208),(441,'90794fa9-11f9-401a-a44d-91ccd6e3931d','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-DeployStepsTasks-ghxexh4rjikc','state changed','OS::Heat::Value',NULL,212),(442,'c02ad8d4-27a3-4e45-a81a-45a08680752f','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PostUpdateTasks-kfr7t7q3rhju','state changed','OS::Heat::Value',NULL,216),(443,'efacdf65-0a97-44c6-830b-8609f417de13','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-rgx7vpmyupzc-ServiceServerMetadataHook-h2c43k2dzvyd','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(444,'8c16002e-70e0-42a2-8481-c8285d99c721','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PreUpgradeRollingTasks-m65osjwr5dxj','state changed','OS::Heat::Value',NULL,207),(445,'daed5a26-2f79-44bc-80df-1b6818f66a81','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-PreUpgradeRollingTasks-w7zwo67qmlru','state changed','OS::Heat::Value',NULL,215),(446,'a707b872-eb08-43bc-a433-674b09c3fb43','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PuppetStepConfig-tqpv2cirvzfj','state changed','OS::Heat::Value',NULL,187),(447,'0f7f7c62-0d83-437c-b5db-633f56be16b2','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ExternalDeployTasks-lgsrcaoyormy','state changed','OS::Heat::Value',NULL,205),(448,'6b5bda72-c0b4-4c20-a849-a1d799f01e61','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-FirewallRules-snqq5mbahts4','state changed','OS::Heat::Value',NULL,219),(449,'eb548e62-0816-46d4-9e46-86738d283108','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PostUpdateTasks-kfr7t7q3rhju','state changed','OS::Heat::Value',NULL,216),(450,'771fdc0c-92b7-4e6f-b527-c15a2dc0b534','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ExternalDeployTasks-j4qikdy3b7w3','state changed','OS::Heat::Value',NULL,199),(451,'19ef30b9-5021-4ba9-99d4-dc697e078464','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-FirewallFrontendRules-jbrkz434oyei','state changed','OS::Heat::Value',NULL,217),(452,'5f93cec9-aba4-4f35-84eb-336d861fce45','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-DockerPuppetTasks-udhhemg5e2q5','state changed','OS::Heat::Value',NULL,214),(453,'d3f4d9a7-afe3-4c41-8e2a-ee259424e794','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-FirewallRules-snqq5mbahts4','state changed','OS::Heat::Value',NULL,219),(454,'5f70a2f5-b37c-4841-80ae-cd29755eb00a','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-IpaRegistrationTasks-nnvnxifd3kzm','state changed','OS::Heat::Value',NULL,210),(455,'ab5feda0-c492-4e01-b59d-39ac5a28e3cd','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ScaleTasks-oppj3u4vud2x','state changed','OS::Heat::Value',NULL,220),(456,'cd5a9579-3308-4dcf-841c-499addc99643','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PostUpdateTasks-w3lachmmq6ue','state changed','OS::Heat::Value',NULL,213),(457,'8ea1e60f-1eb4-46b5-9134-44e399cee763','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-NetworkerServiceChain-d2tavcvid3zd-PuppetConfig-fz3vovy4n5dr','state changed','OS::Heat::Value',NULL,204),(458,'3ba5633b-6fa5-462b-9437-1049c69d7bd1','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ExternalUpgradeTasks-klut5jx2jkyo','state changed','OS::Heat::Value',NULL,223),(459,'3f50cab2-ff2b-4f84-a8a6-be8cb59469d8','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ExternalUpgradeTasks-klut5jx2jkyo','state changed','OS::Heat::Value',NULL,223),(460,'f41be82c-321e-4010-869b-86c135786c7e','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-DeployStepsTasks-ghxexh4rjikc','state changed','OS::Heat::Value',NULL,212),(461,'46e3ccc4-0d63-4ea0-953c-755e7a36faf7','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ExternalPostDeployTasks-o5jtgpom2wjj','state changed','OS::Heat::Value',NULL,192),(462,'42ff4eb4-3f6b-419c-b7a2-3c8808c0be93','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-DockerPuppetTasks-fbabgyujypbt','state changed','OS::Heat::Value',NULL,222),(463,'d35b4baa-3180-4bf2-ad1b-697c2b3d0584','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceServerMetadataHook-3ptvkurujr34-IncomingMetadataSettings-jc3iphs2mjlt','state changed','OS::Heat::Value',NULL,195),(464,'05605bdc-49fd-4c59-8c98-795c101bb144','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-PreUpgradeRollingTasks-w7zwo67qmlru','state changed','OS::Heat::Value',NULL,215),(465,'5527bcc0-4a0f-49f3-b29d-9ac854427164','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-IpaRegistrationTasks-625gejb7jtfv','state changed','OS::Heat::Value',NULL,226),(466,'bad13e95-ce25-4927-a679-2e78658b314a','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceNames-bcke3tcahvq4','state changed','OS::Heat::Value',NULL,208),(467,'62914c67-767e-4a6c-8927-a870d53c96b8','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','989dce8a-b4e6-45f7-b4dd-dd8878ea95eb','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,112),(468,'53a154ef-16ad-4368-8059-15da96853e90','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PreDeployStepTasks-adudfvd6r2vd','state changed','OS::Heat::Value',NULL,218),(469,'d7a9e984-8e29-4ba9-84c5-eef722dbaf2e','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PuppetConfig-hzfth4qymw5d','state changed','OS::Heat::Value',NULL,225),(470,'acdd2e8d-1983-47fb-950a-906f064f74e7','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-BlockStorageServiceChain-ww35ljptrtjj-FirewallRules-uy3aotcoggz7','state changed','OS::Heat::Value',NULL,221),(471,'42aebbfe-1dbe-4e52-a676-36f95c82e13a','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-DockerPuppetTasks-udhhemg5e2q5','state changed','OS::Heat::Value',NULL,214),(472,'5e6971b2-344b-4e14-bf48-8aa560b6f25e','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-DockerConfig-z26qmfeqrso2','state changed','OS::Heat::Value',NULL,229),(473,'935a4643-4146-4862-8d6d-e1faa90246ac','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-FirewallFrontendRules-jbrkz434oyei','state changed','OS::Heat::Value',NULL,217),(474,'8b3ec714-fc2c-4715-91df-b8e79fc88b46','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-UpgradeTasks-qb7s6dyc7heh','state changed','OS::Heat::Value',NULL,200),(475,'33f7d385-1694-40c4-82e6-aeebbcd25e18','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ScaleTasks-oppj3u4vud2x','state changed','OS::Heat::Value',NULL,220),(476,'9a4df583-27ee-47a0-86dd-5cbc34d29051','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-xrxptjyr46zi-MonitoringSubscriptionsConfig-f2ci6avf7z2v','state changed','OS::Heat::Value',NULL,228),(477,'24f77242-f49e-41d5-9f6a-2a4aaa3d9994','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-UpgradeTasks-jx2whrof4bn3','state changed','OS::Heat::Value',NULL,227),(478,'c4680ed4-b8ea-4950-a0d5-a6937eec7aab','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-DockerConfig-z26qmfeqrso2','state changed','OS::Heat::Value',NULL,229),(479,'29ec89ff-ccbf-42fc-ab95-5a4eeedf4ef2','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ExternalUpdateTasks-kkkpsh4v4wou','state changed','OS::Heat::Value',NULL,232),(480,'c8229c3e-a190-48dd-b93b-b36a711d3ba2','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CephStorageServiceChain-xrxptjyr46zi-FirewallFrontendRules-dyap24usmihz','state changed','OS::Heat::Value',NULL,224),(481,'26375e5a-aa7a-4846-831b-87817dc2be81','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-PuppetConfig-wfcktx4zy7ul','state changed','OS::Heat::Value',NULL,201),(482,'4fa6edbe-2d4c-4dc3-9f22-3665ec6d54c9','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-IpaRegistrationTasks-625gejb7jtfv','state changed','OS::Heat::Value',NULL,226),(483,'c359a753-8b09-40f7-8e00-1429bf1ef663','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ExternalUpdateTasks-kkkpsh4v4wou','state changed','OS::Heat::Value',NULL,232),(484,'86528749-1d62-4f91-8996-2879313d6c40','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PostUpgradeTasks-rnh4dl3oifge','state changed','OS::Heat::Value',NULL,235),(485,'7be1bb7b-3dc0-4242-a968-01e8d50e6505','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-HostFirewallTasks-unl2uzptm6dd','state changed','OS::Heat::Value',NULL,234),(486,'9087f369-0369-40c6-8cf4-9cc976a011c1','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-xrxptjyr46zi-MonitoringSubscriptionsConfig-f2ci6avf7z2v','state changed','OS::Heat::Value',NULL,228),(487,'10574b09-5766-49e0-8e82-321dae22ac7c','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PostUpgradeTasks-rnh4dl3oifge','state changed','OS::Heat::Value',NULL,235),(488,'fac66910-f28f-4c65-9ac1-220f6e994fbf','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-UpgradeBatchTasks-eu3xjkevl4vx','state changed','OS::Heat::Value',NULL,236),(489,'ec77706f-e249-4b7e-a361-84771cf15b86','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ExternalDeployTasks-lgsrcaoyormy','state changed','OS::Heat::Value',NULL,205),(490,'ab13bc0b-5bdc-48ef-a58d-9f2058366326','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-UpgradeBatchTasks-rfmq3qlr66fu','state changed','OS::Heat::Value',NULL,230),(491,'7aff6b07-57fd-4586-8144-aff67dbad77f','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-DockerPuppetTasks-fbabgyujypbt','state changed','OS::Heat::Value',NULL,222),(492,'2781e3fa-aaba-4097-ba37-8d2cbab17dc9','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-HostFirewallTasks-unl2uzptm6dd','state changed','OS::Heat::Value',NULL,234),(493,'b06d38b5-9313-4a5a-a737-a505e6d6a042','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceServerMetadataHook-3ptvkurujr34-CompactServices-4mu5g772h3vl','state changed','OS::Heat::Value',NULL,239),(494,'2457f567-8229-4189-8230-92a4d888c6a6','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','CompactServices','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceServerMetadataHook-3ptvkurujr34-CompactServices-4mu5g772h3vl','state changed','OS::Heat::Value',NULL,239),(495,'1deadab6-75d0-4970-8495-08634b126fe0','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PuppetConfig-vxig7hfqyewl','state changed','OS::Heat::Value',NULL,237),(496,'1e27aea8-33e5-49bc-9295-b1fd3956c7c6','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-FirewallFrontendRules-wii66gjxecxv','state changed','OS::Heat::Value',NULL,233),(497,'fda0e98d-934d-40ae-83f4-1556ca3f18f0','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PuppetConfig-hzfth4qymw5d','state changed','OS::Heat::Value',NULL,225),(498,'7310aff9-602c-4ba1-8b7f-3f396177a2fd','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceServerMetadataHook-6rynzzbywgzv','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,238),(499,'641c0f10-6607-4cf2-848e-8fd32162abcc','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-IpaRegistrationTasks-nnvnxifd3kzm','state changed','OS::Heat::Value',NULL,210),(500,'8cb27ef3-1b55-447c-9bf7-c1b2d81e82ba','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-BlockStorageServiceChain-ww35ljptrtjj-AnsibleGroupVars-hy6iznuw6q64','state changed','OS::Heat::Value',NULL,241),(501,'7e59cdc4-0bd5-4741-8cbd-6d6ff3abd394','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PostUpdateTasks-w3lachmmq6ue','state changed','OS::Heat::Value',NULL,213),(502,'c3768979-876d-44cb-abff-29b420c9d436','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-UpgradeBatchTasks-eu3xjkevl4vx','state changed','OS::Heat::Value',NULL,236),(503,'c46a3588-e0f1-40a8-b70a-e14bc698ebca','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PostUpdateTasks-e3ox67lke2d2','state changed','OS::Heat::Value',NULL,245),(504,'ee48ae74-e806-4c19-96c0-2268110d52b5','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-UpgradeTasks-jx2whrof4bn3','state changed','OS::Heat::Value',NULL,227),(505,'bbdd21fc-8d04-49be-b5ad-cafefc3bec3f','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ExternalDeployTasks-p64kfjtqmaui','state changed','OS::Heat::Value',NULL,244),(506,'c2d147fa-16d7-4a1b-ad4e-e00f30abe815','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-xrxptjyr46zi-KeystoneResourcesConfigs-24ntj7cbohuc','state changed','OS::Heat::Value',NULL,242),(507,'0ccd0b45-f688-40f7-89bb-82ce6cb0db4d','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PostUpdateTasks-e3ox67lke2d2','state changed','OS::Heat::Value',NULL,245),(508,'65dfbce5-75fe-4ad9-9138-9fdc28036d00','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-BlockStorageServiceChain-ww35ljptrtjj-AnsibleGroupVars-hy6iznuw6q64','state changed','OS::Heat::Value',NULL,241),(509,'b073076f-d1ab-4c25-bf23-d24b71c2cbf6','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-BlockStorageServiceChain-ww35ljptrtjj-DockerConfig-mo4xsd246tyc','state changed','OS::Heat::Value',NULL,249),(510,'752f567f-9302-42ef-8ea4-491a99eabc73','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ExternalDeployTasks-p64kfjtqmaui','state changed','OS::Heat::Value',NULL,244),(511,'1ec9a55a-6227-4253-b4c9-62f2872a480a','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-DockerConfig-pag5zvhlycos','state changed','OS::Heat::Value',NULL,246),(512,'6057ccb0-502b-47eb-8847-f7fbc1e5840c','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-PreDeployStepTasks-adudfvd6r2vd','state changed','OS::Heat::Value',NULL,218),(513,'3a776a35-e1d8-40da-ac71-c540477651fa','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PuppetConfig-vxig7hfqyewl','state changed','OS::Heat::Value',NULL,237),(514,'6435ab03-8e35-464b-9a63-fc1d298de54c','929dd4f1-d14f-45d2-9cc6-218484a7f826','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceServerMetadataHook-bn7nmtmbftrr-IncomingMetadataSettings-tgrp3v6tk3fg','state changed','OS::Heat::Value',NULL,240),(515,'c2d8d231-32d8-4a23-873e-2372721f00cc','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-rgx7vpmyupzc','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(516,'3c16b7bb-1066-495c-b0d5-542e0e3b366a','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-BlockStorageServiceChain-ww35ljptrtjj-FirewallRules-uy3aotcoggz7','state changed','OS::Heat::Value',NULL,221),(517,'be6a5602-eb5b-4ee2-82d0-2c4fa09b1c42','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-HostFirewallTasks-d2fjgn4iijaa','state changed','OS::Heat::Value',NULL,243),(518,'155f7eda-ac09-4f54-87c9-d10b0896ced6','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-BlockStorageServiceChain-ww35ljptrtjj-DockerConfig-mo4xsd246tyc','state changed','OS::Heat::Value',NULL,249),(519,'e400e0b3-3378-4691-bffd-252002a41af8','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-AnsibleGroupVars-7cyhker3sdr5','state changed','OS::Heat::Value',NULL,253),(520,'80db03bc-d943-4674-97d0-15d1cad7fc47','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CephStorageServiceChain-xrxptjyr46zi-FirewallRules-mn3wz3i4xwy6','state changed','OS::Heat::Value',NULL,250),(521,'4e4b69bd-4a1a-469e-8fe0-ca696b62446b','59f354a0-e1b8-4068-8eb1-0a384639ca1e','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceServerMetadataHook-6rynzzbywgzv','59f354a0-e1b8-4068-8eb1-0a384639ca1e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(522,'073c85ac-4277-4e56-8c4a-1a7771338e82','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CephStorageServiceChain-xrxptjyr46zi-FirewallFrontendRules-dyap24usmihz','state changed','OS::Heat::Value',NULL,224),(523,'48707b49-c10f-4971-bebe-2b149fcd426d','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-xrxptjyr46zi-KeystoneResourcesConfigs-24ntj7cbohuc','state changed','OS::Heat::Value',NULL,242),(524,'3146b73d-d81f-4591-8337-81cbcae72e48','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-AnsibleGroupVars-7cyhker3sdr5','state changed','OS::Heat::Value',NULL,253),(525,'ddb75df9-c2ae-4289-9f81-8638d1304f15','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-DockerConfig-pag5zvhlycos','state changed','OS::Heat::Value',NULL,246),(526,'935d16b0-b177-4f76-9857-e28cb5c38f43','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceServerMetadataHook-3ptvkurujr34-IndividualServices-jkon47c5ebqm','state changed','OS::Heat::Value',NULL,254),(527,'db719a9f-a136-4236-bdd7-16de05707e5a','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-UpdateTasks-mdxtsm3kba44','state changed','OS::Heat::Value',NULL,248),(528,'e97f2b0c-2e0b-4117-9341-baa6e0302dba','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ExternalUpgradeTasks-b22r2bqksx44','state changed','OS::Heat::Value',NULL,255),(529,'ab5c5354-4a2a-4b4e-bb97-72d8c98847b4','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-UpgradeBatchTasks-rfmq3qlr66fu','state changed','OS::Heat::Value',NULL,230),(530,'33e9c9cd-538f-41d3-8ad0-914df4144195','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CephStorageServiceChain-xrxptjyr46zi-FirewallRules-mn3wz3i4xwy6','state changed','OS::Heat::Value',NULL,250),(531,'c7589006-70c9-4d5b-9d2d-c5384558adc1','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ExternalUpdateTasks-a5mhqyzjdrt7','state changed','OS::Heat::Value',NULL,257),(532,'e439c285-c87d-4725-b269-051526af76d1','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ExternalUpgradeTasks-b22r2bqksx44','state changed','OS::Heat::Value',NULL,255),(533,'1472b773-2b2d-44cd-b632-2639051b9df8','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ExternalDeployTasks-d3zlytvn6ybe','state changed','OS::Heat::Value',NULL,251),(534,'7f2e631d-da80-46f4-b59e-ccafeeb1981c','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ExternalUpdateTasks-a5mhqyzjdrt7','state changed','OS::Heat::Value',NULL,257),(535,'db0435c8-4ba0-4dee-a2c8-66d03f275d6a','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceServerMetadataHook-3ptvkurujr34-IndividualServices-jkon47c5ebqm','state changed','OS::Heat::Value',NULL,254),(536,'009623f8-6c00-4064-ad58-45f8a37007f9','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ExternalUpgradeTasks-2oyojh35cauy','state changed','OS::Heat::Value',NULL,258),(537,'05756a55-0a91-4ecf-b223-ad4762c91a9d','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ServiceServerMetadataHook-3ptvkurujr34','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(538,'0314434b-7f06-438b-bc1e-c7411784deb1','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PostUpgradeTasks-owzn2hzdrhgj','state changed','OS::Heat::Value',NULL,259),(539,'907130d6-3c56-4a11-8431-90506b186f4e','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ExternalUpgradeTasks-2oyojh35cauy','state changed','OS::Heat::Value',NULL,258),(540,'0074027e-f694-42c8-b66a-3dae5c22c4fd','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ScaleTasks-y4oqihx2ltno','state changed','OS::Heat::Value',NULL,260),(541,'c6a032e7-945f-4f63-abbe-f5ca3e3b2042','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PostUpgradeTasks-owzn2hzdrhgj','state changed','OS::Heat::Value',NULL,259),(542,'f2639444-3291-48b6-a773-db7c923c6e6d','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ScaleTasks-y4oqihx2ltno','state changed','OS::Heat::Value',NULL,260),(543,'aa7cac34-6251-498e-a201-35bf110857f9','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-FirewallFrontendRules-wii66gjxecxv','state changed','OS::Heat::Value',NULL,233),(544,'ddd56764-54b8-4cd6-b663-073ba13b1f27','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-KollaConfig-fafjfy3hecfa','state changed','OS::Heat::Value',NULL,262),(545,'ce68e235-3869-4e85-8529-451b9095e575','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PreDeployStepTasks-und6jz247x2a','state changed','OS::Heat::Value',NULL,256),(546,'83ba5f9b-cd9c-485f-a77a-2b46fb00e130','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-HostFirewallTasks-24jmubi4cisd','state changed','OS::Heat::Value',NULL,264),(547,'acef05f8-aaf0-459f-b7d7-4db656e7e11f','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CephStorageServiceChain-xrxptjyr46zi-DockerConfig-rcbv3hrbgoex','state changed','OS::Heat::Value',NULL,265),(548,'5d5ff5a5-781a-454d-bdbe-65682537c82e','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-KollaConfig-fafjfy3hecfa','state changed','OS::Heat::Value',NULL,262),(549,'a0974f12-8297-4d23-8bbc-90280972f8f7','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-HostFirewallTasks-24jmubi4cisd','state changed','OS::Heat::Value',NULL,264),(550,'140ea2df-9198-4732-aa5f-e1f249c203e8','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:56:59',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CephStorageServiceChain-xrxptjyr46zi-DockerConfig-rcbv3hrbgoex','state changed','OS::Heat::Value',NULL,265),(551,'31bb776d-4e7e-4a76-8411-9780fe5de5f9','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-NetworkerServiceChain-d2tavcvid3zd-KollaConfig-bzynnaxvzrwi','state changed','OS::Heat::Value',NULL,266),(552,'17e10b63-211c-478f-88fe-c7054755aa28','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-NetworkerServiceChain-d2tavcvid3zd-KollaConfig-bzynnaxvzrwi','state changed','OS::Heat::Value',NULL,266),(553,'64efde84-524d-424f-98eb-25538517931a','929dd4f1-d14f-45d2-9cc6-218484a7f826','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceServerMetadataHook-bn7nmtmbftrr-IncomingMetadataSettings-tgrp3v6tk3fg','state changed','OS::Heat::Value',NULL,240),(554,'4292c3c8-9d29-4c3b-ab42-15ba49ae079d','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-HostFirewallTasks-d2fjgn4iijaa','state changed','OS::Heat::Value',NULL,243),(555,'d16a9f86-3c32-4fc8-835c-a478a0ca9520','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceConfigSettings-pm2nwqtyavju','state changed','OS::Heat::Value',NULL,261),(556,'0e6d1c06-17f6-4472-8ce0-e516d2ccd62a','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-UpdateTasks-mdxtsm3kba44','state changed','OS::Heat::Value',NULL,248),(557,'197aeacb-815f-4625-9525-4ceafa305c4e','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CephStorageServiceChain-xrxptjyr46zi-GlobalConfigSettings-bwpnfb2rl5gz','state changed','OS::Heat::Value',NULL,269),(558,'c900d4e4-e630-429e-a8ed-4908173ed10e','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-DockerPuppetTasks-gzweria5fnef','state changed','OS::Heat::Value',NULL,267),(559,'9880f58c-27bc-4945-8446-a071a25614ad','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CephStorageServiceChain-xrxptjyr46zi-GlobalConfigSettings-bwpnfb2rl5gz','state changed','OS::Heat::Value',NULL,269),(560,'2724bf21-bcc4-406a-9edd-542225aa73b1','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-BlockStorageServiceChain-ww35ljptrtjj-ExternalDeployTasks-d3zlytvn6ybe','state changed','OS::Heat::Value',NULL,251),(561,'25306d63-a59b-45e4-b4f2-c233ff83ca4a','59f354a0-e1b8-4068-8eb1-0a384639ca1e','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceServerMetadataHook-6rynzzbywgzv-IncomingMetadataSettings-v7bbqfwllvn6','state changed','OS::Heat::Value',NULL,268),(562,'a485f5e2-198f-45ff-bf8f-fc12447c974c','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ContainerPuppetTasks-x4hrl6pwvg7b','state changed','OS::Heat::Value',NULL,270),(563,'b7efe232-ef0d-47c4-bad2-3c74df6356ef','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ContainerPuppetTasks-x4hrl6pwvg7b','state changed','OS::Heat::Value',NULL,270),(564,'3a381d23-f2a7-415a-9390-819e7629e0ab','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-PreDeployStepTasks-und6jz247x2a','state changed','OS::Heat::Value',NULL,256),(565,'ef04ddfb-9bb2-4338-94d2-5a9e986e04fe','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceConfigSettings-pm2nwqtyavju','state changed','OS::Heat::Value',NULL,261),(566,'834c1a3d-3642-4575-b5da-66d45f8b6895','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-PreUpgradeRollingTasks-jslssqe6rm5j','state changed','OS::Heat::Value',NULL,272),(567,'2bc6cbec-e78e-4e1e-8898-008f3b33443e','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-PreUpgradeRollingTasks-jslssqe6rm5j','state changed','OS::Heat::Value',NULL,272),(568,'2831026c-5c00-4b82-b26a-3262ed5d663a','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','2','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-2-gm36g76o45qa','state changed','OS::TripleO::Services::Collectd',NULL,271),(569,'b08c7499-1a94-4b6e-a8fe-e4b91f1b9d96','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-DockerPuppetTasks-gzweria5fnef','state changed','OS::Heat::Value',NULL,267),(570,'ea4b8287-945b-4a95-a0ce-015f2f57e706','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','CellControllerServiceChain','436f3ae9-d9a8-4170-ad09-a9c3a33c9b32','state changed','OS::TripleO::CellControllerServices',NULL,83),(571,'547f73b8-86e1-4f51-bdd4-0f132f291a9d','59f354a0-e1b8-4068-8eb1-0a384639ca1e','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceServerMetadataHook-6rynzzbywgzv-IncomingMetadataSettings-v7bbqfwllvn6','state changed','OS::Heat::Value',NULL,268),(572,'44f18033-3f27-44b7-9801-86ebb8c841b8','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceConfigSettings-qhighzt4qggp','state changed','OS::Heat::Value',NULL,275),(573,'e392ad8c-be26-40a5-8f7c-aa5a39713cc5','929dd4f1-d14f-45d2-9cc6-218484a7f826','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceServerMetadataHook-bn7nmtmbftrr-IndividualServices-co6v6ras5h2b','state changed','OS::Heat::Value',NULL,273),(574,'a9b4744c-d5cd-4a32-90c4-511c1e2445bd','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-PreDeployStepTasks-tn6iivxcr7at','state changed','OS::Heat::Value',NULL,277),(575,'f9c72194-ab1e-4668-b78b-539184076617','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceConfigSettings-qhighzt4qggp','state changed','OS::Heat::Value',NULL,275),(576,'d27ce082-1288-4b8a-b504-f5859f70058f','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-PreDeployStepTasks-tn6iivxcr7at','state changed','OS::Heat::Value',NULL,277),(577,'bb0175a0-e9ba-46f2-b5e3-7b6fb23eed2b','929dd4f1-d14f-45d2-9cc6-218484a7f826','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceServerMetadataHook-bn7nmtmbftrr-CompactServices-qyik422u5p6h','state changed','OS::Heat::Value',NULL,276),(578,'0ae9482c-24d1-4c92-a684-a8ada1259c56','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CephStorageServiceChain-xrxptjyr46zi-DockerConfigScripts-bt7r2kqrhb46','state changed','OS::Heat::Value',NULL,278),(579,'320cf64c-69c5-438a-9cc0-f5728da59b2b','929dd4f1-d14f-45d2-9cc6-218484a7f826','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceServerMetadataHook-bn7nmtmbftrr-CompactServices-qyik422u5p6h','state changed','OS::Heat::Value',NULL,276),(580,'2c5a12f7-ae7b-47cd-9ffc-0c412caa6ae7','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CephStorageServiceChain-xrxptjyr46zi-DockerConfigScripts-bt7r2kqrhb46','state changed','OS::Heat::Value',NULL,278),(581,'4d62d196-70e8-462c-a3da-fc5c2d046aae','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-NetworkerServiceChain-d2tavcvid3zd-DockerConfigScripts-sospmm2sc4cg','state changed','OS::Heat::Value',NULL,281),(582,'9f54b2ef-d4fe-4dc8-adf3-3b76fd97bb19','59f354a0-e1b8-4068-8eb1-0a384639ca1e','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceServerMetadataHook-6rynzzbywgzv-CompactServices-bccbu42nhg5t','state changed','OS::Heat::Value',NULL,283),(583,'4cb97b57-6446-4b2e-a0b2-a7f2c645b755','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-NetworkerServiceChain-d2tavcvid3zd-DockerConfigScripts-sospmm2sc4cg','state changed','OS::Heat::Value',NULL,281),(584,'6c2c85f7-636c-4745-802f-25a9a4410736','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-IpaRegistrationTasks-avwc6g7rpfgu','state changed','OS::Heat::Value',NULL,279),(585,'ced69344-1d34-4cbd-94d5-ea38696c80d2','59f354a0-e1b8-4068-8eb1-0a384639ca1e','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceServerMetadataHook-6rynzzbywgzv-IndividualServices-v6bbwn2buz5z','state changed','OS::Heat::Value',NULL,286),(586,'eb65ba86-ed41-4a7a-8902-f0acb24bc0b7','929dd4f1-d14f-45d2-9cc6-218484a7f826','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceServerMetadataHook-bn7nmtmbftrr-IndividualServices-co6v6ras5h2b','state changed','OS::Heat::Value',NULL,273),(587,'b8ccd370-af8c-436d-8b62-b7e1ee149784','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CephStorageServiceChain-xrxptjyr46zi-PuppetStepConfig-ej5s346lo7i5','state changed','OS::Heat::Value',NULL,289),(588,'ebf5ef69-5401-4159-96db-bb8aff7ecef8','59f354a0-e1b8-4068-8eb1-0a384639ca1e','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceServerMetadataHook-6rynzzbywgzv-IndividualServices-v6bbwn2buz5z','state changed','OS::Heat::Value',NULL,286),(589,'eb025d02-7ace-49d4-a479-3e701c131231','8b545d52-6830-4d13-aa0b-16c0b652cece','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-2-gm36g76o45qa','8b545d52-6830-4d13-aa0b-16c0b652cece','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(590,'2b71ac25-27c3-4ae8-9c8b-10e2ba90c653','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ExternalDeployTasks-ib6hldbfikgs','state changed','OS::Heat::Value',NULL,287),(591,'b52b498d-2873-41fc-b4d4-eec8d7149d1d','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CephStorageServiceChain-xrxptjyr46zi-PuppetStepConfig-ej5s346lo7i5','state changed','OS::Heat::Value',NULL,289),(592,'69264820-174d-41fa-982a-fb182997d54d','59f354a0-e1b8-4068-8eb1-0a384639ca1e','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceServerMetadataHook-6rynzzbywgzv-CompactServices-bccbu42nhg5t','state changed','OS::Heat::Value',NULL,283),(593,'0797d112-15c5-4e5e-b509-116301735c27','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ExternalUpdateTasks-z7ntbc2chcwh','state changed','OS::Heat::Value',NULL,294),(594,'4846e357-280d-4cf9-b4fd-9aaa022b3f94','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-PreDeployStepTasks-qavzge7e53sy','state changed','OS::Heat::Value',NULL,296),(595,'f8d1034d-044c-415c-9066-f6d35b17e0a4','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-IpaRegistrationTasks-avwc6g7rpfgu','state changed','OS::Heat::Value',NULL,279),(596,'2a30e4a0-9fa2-43cd-bb45-f58303cd49bd','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-PreDeployStepTasks-qavzge7e53sy','state changed','OS::Heat::Value',NULL,296),(597,'8eb407e0-b997-4938-aaf8-3ea87fa904cc','929dd4f1-d14f-45d2-9cc6-218484a7f826','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-bmfxdpyutifu-ServiceServerMetadataHook-bn7nmtmbftrr','929dd4f1-d14f-45d2-9cc6-218484a7f826','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(598,'a9f92cf1-b93b-4d22-9cc6-a1df59281b5c','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-ExternalUpdateTasks-z7ntbc2chcwh','state changed','OS::Heat::Value',NULL,294),(599,'2122b8d6-c2e6-4ad8-9436-147107949f89','59f354a0-e1b8-4068-8eb1-0a384639ca1e','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4-ServiceServerMetadataHook-6rynzzbywgzv','59f354a0-e1b8-4068-8eb1-0a384639ca1e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(600,'1c2a7381-e2d0-4943-bce2-0f73e4b184da','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-HostFirewallTasks-xkgbg2w3bhjk','state changed','OS::Heat::Value',NULL,301),(601,'2be1ab2c-d321-4358-ae0f-9cd0b061eabc','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ContainerPuppetTasks-2iqwrigm55vd','state changed','OS::Heat::Value',NULL,300),(602,'de657f55-7ede-4879-bdd3-6ae298bfadaf','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ExternalDeployTasks-ib6hldbfikgs','state changed','OS::Heat::Value',NULL,287),(603,'e67faa00-90ad-4c3e-bfb2-74e61e294fe6','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-HostFirewallTasks-xkgbg2w3bhjk','state changed','OS::Heat::Value',NULL,301),(604,'5e402a11-c6ab-4f18-9661-b3dddcb11b77','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-HostPrepTasks-fiddmthw2grp','state changed','OS::Heat::Value',NULL,298),(605,'35aeed3d-ce99-4c20-b22c-a96ee66c5ea2','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-ContainerPuppetTasks-2iqwrigm55vd','state changed','OS::Heat::Value',NULL,300),(606,'d6205401-347f-4e90-ad66-d4535698fe64','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','161eb6d5-5429-4b6e-aa57-202e7f0ca9ef','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,153),(607,'e2cef309-587b-4cb4-9be1-fe69f7c38231','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CephStorageServiceChain-xrxptjyr46zi-KollaConfig-rygir3wgi7nw','state changed','OS::Heat::Value',NULL,312),(608,'db2b3d96-c845-40f6-aad3-6d75a21e1323','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-NetworkerServiceChain-d2tavcvid3zd-FirewallFrontendRules-4zkchhknyxi3','state changed','OS::Heat::Value',NULL,315),(609,'61bdf5c1-2f57-4c99-b414-29e6d9e8300d','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceServerMetadataHook-o7k5yvaewc3b','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,310),(610,'b1312e1e-6dd4-4234-bee0-84ca0092a225','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-ww35ljptrtjj','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(611,'e84b41ef-99fb-474a-bf12-7bcc3ef51ad2','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CephStorageServiceChain-xrxptjyr46zi-KollaConfig-rygir3wgi7nw','state changed','OS::Heat::Value',NULL,312),(612,'dadf37b4-4a28-4514-902b-a6d47a88cea1','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-PostUpdateTasks-jo5qfhtqgrmk','state changed','OS::Heat::Value',NULL,317),(613,'7a50c9e2-6243-4810-a8aa-7d29eef340ca','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-NetworkerServiceChain-d2tavcvid3zd-FirewallFrontendRules-4zkchhknyxi3','state changed','OS::Heat::Value',NULL,315),(614,'b43ee67b-0858-4e1b-8549-78ae781a0709','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-PostUpdateTasks-jo5qfhtqgrmk','state changed','OS::Heat::Value',NULL,317),(615,'c70d1998-91e4-4886-8183-053aec7cf5f6','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-HostPrepTasks-fiddmthw2grp','state changed','OS::Heat::Value',NULL,298),(616,'2f7d3918-26b2-4bdf-991b-bc56502ce744','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','59f354a0-e1b8-4068-8eb1-0a384639ca1e','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,238),(617,'53cd5013-9281-4e1b-959f-0b710af8a92d','0ff63522-48f8-4fcd-a882-eb3249febb04','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-ypgm4gekd4x4','0ff63522-48f8-4fcd-a882-eb3249febb04','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(618,'85b0121e-2ce7-4f5e-af7b-c6cdfed48a0e','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-UpgradeBatchTasks-zrff77spnykz','state changed','OS::Heat::Value',NULL,329),(619,'6f2a128f-d707-436b-bb81-70f2067f36ed','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-NetworkerServiceChain-d2tavcvid3zd-GlobalConfigSettings-4porhmj7rtae','state changed','OS::Heat::Value',NULL,331),(620,'c61bebcf-b70f-433a-82ca-349c7b805bb6','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceServerMetadataHook-izw5zbol5siu','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,332),(621,'1d55fddc-1257-4be4-b219-66d8e3e0dce2','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-UpgradeBatchTasks-zrff77spnykz','state changed','OS::Heat::Value',NULL,329),(622,'0d91b8da-18eb-4358-8100-e91ce7cf652f','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-NetworkerServiceChain-d2tavcvid3zd-GlobalConfigSettings-4porhmj7rtae','state changed','OS::Heat::Value',NULL,331),(623,'75b70cab-b7dc-481e-a1a7-0a53ea54218d','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-NetworkerServiceChain-d2tavcvid3zd-FirewallRules-gmmv5tynwktm','state changed','OS::Heat::Value',NULL,330),(624,'5c2f31c3-ce01-4f8d-ae34-499dea4c67da','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-NetworkerServiceChain-d2tavcvid3zd-DockerConfig-x2yys64uqsho','state changed','OS::Heat::Value',NULL,334),(625,'ffbc87b4-d57e-46c2-a31e-a822650f6d5b','54bfb66c-f0e3-4aa0-817a-5442413fba85','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceServerMetadataHook-izw5zbol5siu','54bfb66c-f0e3-4aa0-817a-5442413fba85','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(626,'53394644-7870-4acc-8c42-8d0fcd0f6beb','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:00',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-DeployStepsTasks-k2hrkg4s257f','state changed','OS::Heat::Value',NULL,335),(627,'0061c43b-8a8d-4419-a121-a77c6d0034b7','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:00',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-NetworkerServiceChain-d2tavcvid3zd-DockerConfig-x2yys64uqsho','state changed','OS::Heat::Value',NULL,334),(628,'cecfa2e4-e55c-41d2-ad45-b44a85fa38f3','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-DeployStepsTasks-k2hrkg4s257f','state changed','OS::Heat::Value',NULL,335),(629,'3fd43d57-3516-49a1-bcd3-706fb4fec97c','54bfb66c-f0e3-4aa0-817a-5442413fba85','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceServerMetadataHook-izw5zbol5siu-IncomingMetadataSettings-qy5ha5p4dt2n','state changed','OS::Heat::Value',NULL,336),(630,'8c45ac43-abb4-4a0e-93b8-6f7124fb37c6','54bfb66c-f0e3-4aa0-817a-5442413fba85','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceServerMetadataHook-izw5zbol5siu-IncomingMetadataSettings-qy5ha5p4dt2n','state changed','OS::Heat::Value',NULL,336),(631,'8177e535-1cf2-43dd-804a-d4fcd55a73ac','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','BlockStorageServiceChain','4a3a30bc-3a99-4d78-ba1f-b7bc93457c25','state changed','OS::TripleO::BlockStorageServices',NULL,87),(632,'72d9346e-901e-4767-833d-2293be2e36bd','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-HostPrepTasks-54phafru5f5c','state changed','OS::Heat::Value',NULL,340),(633,'ee2f9305-04ab-472d-9f06-c7351a493342','54bfb66c-f0e3-4aa0-817a-5442413fba85','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceServerMetadataHook-izw5zbol5siu-IndividualServices-tlihndhykhxs','state changed','OS::Heat::Value',NULL,341),(634,'91736142-e741-4607-8d66-2328b81ca0c3','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CephStorageServiceChain-xrxptjyr46zi-HostPrepTasks-54phafru5f5c','state changed','OS::Heat::Value',NULL,340),(635,'d9a0e374-6258-4d18-af6d-0d37e28d107f','54bfb66c-f0e3-4aa0-817a-5442413fba85','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceServerMetadataHook-izw5zbol5siu-CompactServices-r6axd6vvubh4','state changed','OS::Heat::Value',NULL,342),(636,'cbdc0f25-bc12-430e-809c-5e32330721be','54bfb66c-f0e3-4aa0-817a-5442413fba85','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceServerMetadataHook-izw5zbol5siu-IndividualServices-tlihndhykhxs','state changed','OS::Heat::Value',NULL,341),(637,'72499de3-e2dc-4dde-8268-b61460e11fd1','54bfb66c-f0e3-4aa0-817a-5442413fba85','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceServerMetadataHook-izw5zbol5siu-CompactServices-r6axd6vvubh4','state changed','OS::Heat::Value',NULL,342),(638,'c1fd88d0-ccb2-4b17-8a1f-92dbbe7df14f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-7rxer4mevgz4','state changed','OS::Heat::Value',NULL,337),(639,'4710ef1f-9efc-47a9-baca-d17f260be56a','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','929dd4f1-d14f-45d2-9cc6-218484a7f826','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,134),(640,'8cbb63a0-0d95-452c-a302-84a7ac7d7744','54bfb66c-f0e3-4aa0-817a-5442413fba85','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-xrxptjyr46zi-ServiceServerMetadataHook-izw5zbol5siu','54bfb66c-f0e3-4aa0-817a-5442413fba85','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(641,'8a50e050-39d3-46a1-9486-108e13198f84','c6c3e473-c847-4e69-8abb-80576875bdd6','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceServerMetadataHook-o7k5yvaewc3b','c6c3e473-c847-4e69-8abb-80576875bdd6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(642,'e6c5b3a2-a0d2-4c65-8a12-f2e0f5c36c53','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-NetworkerServiceChain-d2tavcvid3zd-FirewallRules-gmmv5tynwktm','state changed','OS::Heat::Value',NULL,330),(643,'2604b8f2-5ac5-48ca-8cbc-c857250bce37','8b545d52-6830-4d13-aa0b-16c0b652cece','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-2-gm36g76o45qa-ContainersCommon-ywlzyb6enqsh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(644,'756f54ed-8076-4636-971e-7fb7e4fb55e5','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','3','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,343),(645,'ac1ddc4f-9980-457d-9e21-467944e33290','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChain','0ff63522-48f8-4fcd-a882-eb3249febb04','state changed','OS::TripleO::CellControllerComputeServices',NULL,80),(646,'02297d2c-485d-4b9a-a0dc-0d08a5f53b6a','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-PostUpgradeTasks-riilput7ifed','state changed','OS::Heat::Value',NULL,345),(647,'e297c2e6-8355-4543-9589-46873afd8f56','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-7rxer4mevgz4','state changed','OS::Heat::Value',NULL,337),(648,'98d65a78-8037-4740-a7a6-742543ac9cb1','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceNames-j3kivnzlxfl6','state changed','OS::Heat::Value',NULL,347),(649,'f98e5392-d92f-4277-9b79-426761bab5fb','a3d97bbf-a96b-4cc7-a0ff-63a9fd6d3aaf','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-2-gm36g76o45qa-ContainersCommon-ywlzyb6enqsh','a3d97bbf-a96b-4cc7-a0ff-63a9fd6d3aaf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(650,'a870e13a-e34a-4e96-b363-8c587711531e','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceNames-j3kivnzlxfl6','state changed','OS::Heat::Value',NULL,347),(651,'1c984a92-8453-4c56-913b-cd6a07f24fae','a3d97bbf-a96b-4cc7-a0ff-63a9fd6d3aaf','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-2-gm36g76o45qa-ContainersCommon-ywlzyb6enqsh','a3d97bbf-a96b-4cc7-a0ff-63a9fd6d3aaf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(652,'d4589727-f7ee-46bb-a3b7-c32230694310','e8726d51-214b-4ea9-ae78-805ee8f97794','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-bmfxdpyutifu','e8726d51-214b-4ea9-ae78-805ee8f97794','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(653,'c52f2b04-5817-4a81-86e0-0ab57683a24a','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-UpdateTasks-45wh46cyecjj','state changed','OS::Heat::Value',NULL,351),(654,'06f60e18-e986-47ed-ae23-af3ced751ad3','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-PostUpgradeTasks-riilput7ifed','state changed','OS::Heat::Value',NULL,345),(655,'bddb6841-d7a3-4a30-9fb5-1c82f1db49de','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-UpdateTasks-45wh46cyecjj','state changed','OS::Heat::Value',NULL,351),(656,'d2cf1009-7a51-49af-83b5-383e38141334','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-NetworkerServiceChain-d2tavcvid3zd-PuppetStepConfig-v6xhh2zvvmyu','state changed','OS::Heat::Value',NULL,362),(657,'7282d4f5-c82f-48b9-b221-30154906d157','03b08889-9c0e-4c91-baae-ba2039ff1d00','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu','03b08889-9c0e-4c91-baae-ba2039ff1d00','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(658,'048a84d5-a6f9-4aad-9ff2-b7c99c795b87','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceConfigSettings-rx24itejculj','state changed','OS::Heat::Value',NULL,375),(659,'dc7fbdff-8534-493a-a1a8-59a6f00c50b8','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-d2tavcvid3zd-MonitoringSubscriptionsConfig-zyu4r3dv3gew','state changed','OS::Heat::Value',NULL,377),(660,'95640026-1623-4427-a8b1-c22533c18227','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceConfigSettings-rx24itejculj','state changed','OS::Heat::Value',NULL,375),(661,'1941fac5-eaad-417b-a74c-b45aef99308f','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-d2tavcvid3zd-MonitoringSubscriptionsConfig-zyu4r3dv3gew','state changed','OS::Heat::Value',NULL,377),(662,'c36a44c1-d7e0-456e-8ab8-122defcb102e','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-DockerPuppetTasks-ninuwzoi4xeh','state changed','OS::Heat::Value',NULL,384),(663,'feea50bb-38b4-48d0-8c13-3cc50e8ebd06','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-NetworkerServiceChain-d2tavcvid3zd-PuppetStepConfig-v6xhh2zvvmyu','state changed','OS::Heat::Value',NULL,362),(664,'b633160a-9e0c-4ff1-896b-40fc885108c5','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-NetworkerServiceChain-d2tavcvid3zd-DockerPuppetTasks-ninuwzoi4xeh','state changed','OS::Heat::Value',NULL,384),(665,'b9775d6c-e0ec-4e54-bd0e-d7e3031021f8','c6c3e473-c847-4e69-8abb-80576875bdd6','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceServerMetadataHook-o7k5yvaewc3b-IncomingMetadataSettings-7eeie6hmkwzz','state changed','OS::Heat::Value',NULL,404),(666,'01832bd5-fa90-4320-a858-63492ec02b7c','c6c3e473-c847-4e69-8abb-80576875bdd6','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceServerMetadataHook-o7k5yvaewc3b-IncomingMetadataSettings-7eeie6hmkwzz','state changed','OS::Heat::Value',NULL,404),(667,'ea0dd805-08f8-464d-813d-113f9dfb0d2f','03b08889-9c0e-4c91-baae-ba2039ff1d00','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu-RoleParametersValue-fbp64dnpugd4','state changed','OS::Heat::Value',NULL,417),(668,'9ff79540-da44-4484-ad06-26fd18369a6b','c6c3e473-c847-4e69-8abb-80576875bdd6','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceServerMetadataHook-o7k5yvaewc3b-IndividualServices-mjagnbjjsmcf','state changed','OS::Heat::Value',NULL,419),(669,'f4fa9f1d-e85d-42de-ab5a-850de3c6b4fc','03b08889-9c0e-4c91-baae-ba2039ff1d00','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu-RoleParametersValue-fbp64dnpugd4','state changed','OS::Heat::Value',NULL,417),(670,'2e7bc1ae-ad85-4b1c-8fb8-3fc4b0596bef','c6c3e473-c847-4e69-8abb-80576875bdd6','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceServerMetadataHook-o7k5yvaewc3b-IndividualServices-mjagnbjjsmcf','state changed','OS::Heat::Value',NULL,419),(671,'eac557b1-6e4c-4f37-886a-a637a6441425','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-3vcpyfuqjexl','state changed','OS::Heat::Value',NULL,426),(672,'36c87991-0b9d-465b-8f96-4780dee725e1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNames','overcloud-CellControllerServiceNames-fyfi2zu635jc','state changed','OS::Heat::Value',NULL,427),(673,'31dc5fdb-3e4b-455e-bcfe-ecc5d3f29d86','c6c3e473-c847-4e69-8abb-80576875bdd6','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceServerMetadataHook-o7k5yvaewc3b-CompactServices-paol6wqdspig','state changed','OS::Heat::Value',NULL,428),(674,'f7c05810-5943-43a3-b618-782463822d4e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-3vcpyfuqjexl','state changed','OS::Heat::Value',NULL,426),(675,'0dfe60bc-148d-4ae0-9527-6a20767530ce','c6c3e473-c847-4e69-8abb-80576875bdd6','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','CompactServices','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceServerMetadataHook-o7k5yvaewc3b-CompactServices-paol6wqdspig','state changed','OS::Heat::Value',NULL,428),(676,'018abcaa-2a26-40b1-a74e-9767c6a29420','c6c3e473-c847-4e69-8abb-80576875bdd6','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-d2tavcvid3zd-ServiceServerMetadataHook-o7k5yvaewc3b','c6c3e473-c847-4e69-8abb-80576875bdd6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(677,'6099435c-3a31-4194-a206-53dbae5d2de5','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','CellControllerServiceNames','overcloud-CellControllerServiceNames-fyfi2zu635jc','state changed','OS::Heat::Value',NULL,427),(678,'44350b58-4f2e-43c1-8b7a-8527fe20df2c','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:01',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-uwxngt6ikts4','state changed','OS::Heat::Value',NULL,429),(679,'45ec61a3-efc1-4380-b9a5-ddcbeee1675b','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:01',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-uwxngt6ikts4','state changed','OS::Heat::Value',NULL,429),(680,'5327bf62-bf0e-456c-8ce3-538ab71c1cf7','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','CellController','overcloud-CellController-jx2wuauzgukb','state changed','OS::Heat::ResourceGroup',NULL,433),(681,'e0b2caec-8bc9-42d8-81f6-aedb97560df9','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','54bfb66c-f0e3-4aa0-817a-5442413fba85','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,332),(682,'9fcb64aa-67d2-40bc-8730-c6f60147593f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-c7vcb5efvbab','state changed','OS::Heat::Value',NULL,434),(683,'1fc62c05-e22d-4509-aa32-99ffec0c5cfc','a5716f06-aedc-46dd-b08c-db1fb66fce30','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-xrxptjyr46zi','a5716f06-aedc-46dd-b08c-db1fb66fce30','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(684,'6836eb5a-c57c-4ebb-9337-05dee2b64eec','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-c7vcb5efvbab','state changed','OS::Heat::Value',NULL,434),(685,'acb4ee16-a7e1-4a0d-b9fb-788b8f391762','fdab1b30-c47d-423d-bfb5-e2ca22572966','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','overcloud-CellController-jx2wuauzgukb','fdab1b30-c47d-423d-bfb5-e2ca22572966','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(686,'27b5d31c-c2d3-40ee-a835-29db3e65724f','fdab1b30-c47d-423d-bfb5-e2ca22572966','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','overcloud-CellController-jx2wuauzgukb','fdab1b30-c47d-423d-bfb5-e2ca22572966','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(687,'0da86d16-d704-49d8-9f0d-65679bc59a25','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','1','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-1-hnftcqwqymc3','state changed','OS::TripleO::Services::CACerts',NULL,435),(688,'c6971425-28e9-42b2-8600-00d3b7ff9245','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-4dsaurt4i7pp','state changed','OS::Heat::Value',NULL,436),(689,'2b91c55a-24e4-471e-a083-0ecfb42e941c','8b545d52-6830-4d13-aa0b-16c0b652cece','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-2-gm36g76o45qa-RoleParametersValue-3lk4l4eppjdd','state changed','OS::Heat::Value',NULL,438),(690,'5c2878ff-811d-4a6a-a193-47b878032b76','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-4dsaurt4i7pp','state changed','OS::Heat::Value',NULL,436),(691,'b2f4816b-72c3-4810-9ea9-8e2d7c1a6dc9','8b545d52-6830-4d13-aa0b-16c0b652cece','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-2-gm36g76o45qa-RoleParametersValue-3lk4l4eppjdd','state changed','OS::Heat::Value',NULL,438),(692,'4d47aa80-1140-4e2c-a824-a317d96e7441','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','ObjectStorageServiceChain','e8726d51-214b-4ea9-ae78-805ee8f97794','state changed','OS::TripleO::ObjectStorageServices',NULL,79),(693,'d6e18b0f-9c28-480a-b2ad-db5c1b68a901','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','BlockStorage','overcloud-BlockStorage-bi5aeey522za','state changed','OS::Heat::ResourceGroup',NULL,439),(694,'18915aa1-6154-4069-b4c0-43ae59fad22d','f454b763-a860-4242-89a2-3b7076acd0b4','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-1-hnftcqwqymc3','f454b763-a860-4242-89a2-3b7076acd0b4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(695,'7fa7194c-0f20-4db1-844a-dd76ef17e5ee','f454b763-a860-4242-89a2-3b7076acd0b4','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-1-hnftcqwqymc3','f454b763-a860-4242-89a2-3b7076acd0b4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(696,'5ff4e84f-f065-4684-a48d-3f30fe80d755','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','c6c3e473-c847-4e69-8abb-80576875bdd6','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,310),(697,'08011b32-53d0-421f-9652-ab9562b945f5','8b545d52-6830-4d13-aa0b-16c0b652cece','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','ContainersCommon','a3d97bbf-a96b-4cc7-a0ff-63a9fd6d3aaf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(698,'123e9655-6c22-4dde-9c8b-5c4b57134a8a','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','CellControllerCompute','overcloud-CellControllerCompute-dgtvinskucgs','state changed','OS::Heat::ResourceGroup',NULL,445),(699,'833537e5-46af-4fb6-bbb7-81340140f377','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-d2tavcvid3zd','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(700,'e877701a-d39d-4221-85b7-3523e65a5fd5','d35da1e2-1d1b-4fee-b1e5-e094f43d217f','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorage-bi5aeey522za','d35da1e2-1d1b-4fee-b1e5-e094f43d217f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(701,'9fd04b3b-b5df-4b04-8ae5-47083c6f1d0c','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','1','f454b763-a860-4242-89a2-3b7076acd0b4','state changed','OS::TripleO::Services::CACerts',NULL,435),(702,'9fec61ac-0d57-4f45-be2a-2ff6a723db19','8b545d52-6830-4d13-aa0b-16c0b652cece','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-2-gm36g76o45qa','8b545d52-6830-4d13-aa0b-16c0b652cece','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(703,'a160ab80-af5a-4c75-b208-afee6418f0c7','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','CephStorageServiceChain','a5716f06-aedc-46dd-b08c-db1fb66fce30','state changed','OS::TripleO::CephStorageServices',NULL,84),(704,'696cb403-66fc-4051-ae27-c34f13861674','a036a9ae-9c90-47f6-8743-52095a72fb5a','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerCompute-dgtvinskucgs','a036a9ae-9c90-47f6-8743-52095a72fb5a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(705,'c2c29c0d-0ee0-46ae-a3de-501abe1b6947','d35da1e2-1d1b-4fee-b1e5-e094f43d217f','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','overcloud-BlockStorage-bi5aeey522za','d35da1e2-1d1b-4fee-b1e5-e094f43d217f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(706,'d3bf3bf4-5422-41be-a5cc-7d8b27b110fc','a036a9ae-9c90-47f6-8743-52095a72fb5a','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','overcloud-CellControllerCompute-dgtvinskucgs','a036a9ae-9c90-47f6-8743-52095a72fb5a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(707,'b2e93113-6bbf-4ae3-813b-b16570e63cea','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','CellControllerCompute','a036a9ae-9c90-47f6-8743-52095a72fb5a','state changed','OS::Heat::ResourceGroup',NULL,445),(708,'37f2aff4-6a7f-4213-9086-c30ef30a8943','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','5','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-5-o4v75xfbggy3','state changed','OS::TripleO::Services::IpaClient',NULL,472),(709,'b0b7668b-4fd0-4de6-b0c6-88a745af97a2','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','2','8b545d52-6830-4d13-aa0b-16c0b652cece','state changed','OS::TripleO::Services::Collectd',NULL,271),(710,'c3b213bf-571d-45c6-8bdf-b954f27620e4','03b08889-9c0e-4c91-baae-ba2039ff1d00','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu-CeilometerServiceBase-fdzg3eicwqoi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,483),(711,'1029036e-1196-4f41-bdd4-752aacfcc812','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-emthrl2kjtq3','state changed','OS::Heat::Value',NULL,489),(712,'b5bd282a-cb77-4186-ad5f-3d5c28359af4','c882d66c-22de-4fed-82a5-5bd2c462619c','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu-CeilometerServiceBase-fdzg3eicwqoi','c882d66c-22de-4fed-82a5-5bd2c462619c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(713,'4ee45fc9-9942-4dac-a3be-173896452afd','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServers','overcloud-CellControllerComputeServers-wqkvnxa5heev','state changed','OS::Heat::Value',NULL,493),(714,'af6ea20f-1fa5-4fd1-b47a-282dcd75443d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','CellControllerComputeServers','overcloud-CellControllerComputeServers-wqkvnxa5heev','state changed','OS::Heat::Value',NULL,493),(715,'24798e37-f4dd-481f-b173-ee6c22c541e6','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-emthrl2kjtq3','state changed','OS::Heat::Value',NULL,489),(716,'b13df793-306d-4af9-9c02-69d3da715a0f','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:02',NULL,'CREATE','IN_PROGRESS','3','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,502),(717,'ff690f9a-0372-4243-85b6-fb72e18cc2d8','c882d66c-22de-4fed-82a5-5bd2c462619c','2026-06-13 07:57:02',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu-CeilometerServiceBase-fdzg3eicwqoi','c882d66c-22de-4fed-82a5-5bd2c462619c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(718,'a7c557e0-64ef-445b-bfc2-f5b7b9577fe8','69386965-ee2e-418c-aa6a-af8c30f74b2a','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-5-o4v75xfbggy3','69386965-ee2e-418c-aa6a-af8c30f74b2a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(719,'7d6a4a0a-4b75-45fa-acb9-82a9593618b2','e84e2039-a1fb-4d14-aae6-677f604f36a4','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7','e84e2039-a1fb-4d14-aae6-677f604f36a4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(720,'a4e81dad-e979-43ee-b668-2e68d55a5fd5','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','6','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-6-kh7tk7wfbizg','state changed','OS::TripleO::Services::Iscsid',NULL,523),(721,'c75b62ec-b175-4ef3-8581-05e7d5371b6b','e84e2039-a1fb-4d14-aae6-677f604f36a4','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7-ContainersCommon-xa27abibwzz6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(722,'39e5d41d-2db0-4d9d-9fa7-bd9cfb57af2c','9a15ca39-a021-4d79-97e6-12b99d59e39e','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-6-kh7tk7wfbizg','9a15ca39-a021-4d79-97e6-12b99d59e39e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(723,'93a69ada-9027-4900-b592-c3b074d06af7','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','NetworkerServiceChain','8e6aa83e-de28-41bd-834f-7d2ed100bc8b','state changed','OS::TripleO::NetworkerServices',NULL,81),(724,'b49d1c32-3cdc-473d-806b-a8516616b7b2','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','CellController','fdab1b30-c47d-423d-bfb5-e2ca22572966','state changed','OS::Heat::ResourceGroup',NULL,433),(725,'a1ef2f86-1bac-48d0-89cc-3a08eb56fa63','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','CellControllerComputeIpListMap','overcloud-CellControllerComputeIpListMap-t24ziif2qyhd','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,524),(726,'5492833e-268f-48d3-87cb-9421abfb1200','9a15ca39-a021-4d79-97e6-12b99d59e39e','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-6-kh7tk7wfbizg-ContainersCommon-c5oqfear7f6o','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(727,'4a9e7980-f8e1-4a7f-9ae8-e90a76a071d1','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','0','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-0-pni5f2ktvo3t','state changed','OS::TripleO::Services::BootParams',NULL,526),(728,'5cc14599-2d02-4f73-ae65-d45ce46e7f8d','8ecb59de-2e5b-43d7-a0ba-46d8443a6089','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7-ContainersCommon-xa27abibwzz6','8ecb59de-2e5b-43d7-a0ba-46d8443a6089','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(729,'53a55491-8472-4670-a6d0-7088474af976','70d69b07-a1cc-4be3-a00d-9309daa4f554','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-0-pni5f2ktvo3t','70d69b07-a1cc-4be3-a00d-9309daa4f554','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(730,'38aec19a-2acf-4120-a47d-7ccc2ed99a59','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-vwjybhvxvgep','state changed','OS::Heat::Value',NULL,527),(731,'5d48483a-73f9-4596-9c0f-b8c3fac03776','69386965-ee2e-418c-aa6a-af8c30f74b2a','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-5-o4v75xfbggy3','69386965-ee2e-418c-aa6a-af8c30f74b2a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(732,'e2462328-266e-4fcd-ad81-eaf2e9f69336','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-vwjybhvxvgep','state changed','OS::Heat::Value',NULL,527),(733,'4a77cd01-9b98-4185-9f0e-d1aab078d191','08d1cd68-3e43-45be-94a0-10173b05e80e','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-6-kh7tk7wfbizg-ContainersCommon-c5oqfear7f6o','08d1cd68-3e43-45be-94a0-10173b05e80e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(734,'0f2e6b07-b592-4740-8420-8617bcac4cc9','8ecb59de-2e5b-43d7-a0ba-46d8443a6089','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7-ContainersCommon-xa27abibwzz6','8ecb59de-2e5b-43d7-a0ba-46d8443a6089','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(735,'baaa7830-a100-442f-b8cf-944622f293df','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-zs6ksvn3hz7i','state changed','OS::Heat::Value',NULL,528),(736,'23731c95-ca2b-4ed7-901d-78fc382190b0','70d69b07-a1cc-4be3-a00d-9309daa4f554','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-0-pni5f2ktvo3t-RoleParametersValue-nr5gr7evjbzw','state changed','OS::Heat::Value',NULL,530),(737,'55ce16d4-b07c-48ee-9ed9-6eea272020f0','70d69b07-a1cc-4be3-a00d-9309daa4f554','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-0-pni5f2ktvo3t-RoleParametersValue-nr5gr7evjbzw','state changed','OS::Heat::Value',NULL,530),(738,'a0b07b24-bc42-403d-a204-03bc76f000f9','70d69b07-a1cc-4be3-a00d-9309daa4f554','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-0-pni5f2ktvo3t','70d69b07-a1cc-4be3-a00d-9309daa4f554','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(739,'0b5ff08d-776d-4ab4-8799-fe5cdb81f6ac','08d1cd68-3e43-45be-94a0-10173b05e80e','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-6-kh7tk7wfbizg-ContainersCommon-c5oqfear7f6o','08d1cd68-3e43-45be-94a0-10173b05e80e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(740,'f45ee6b3-b2d1-4759-9e38-b38214b0b8c7','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','BlockStorage','d35da1e2-1d1b-4fee-b1e5-e094f43d217f','state changed','OS::Heat::ResourceGroup',NULL,439),(741,'5f70658d-703c-4d47-860d-c3849274143a','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-rh2gdxmdmcbv','state changed','OS::Heat::Value',NULL,534),(742,'ed60e53c-38d3-427e-b7e8-73511b10d1a7','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-zs6ksvn3hz7i','state changed','OS::Heat::Value',NULL,528),(743,'83ac0dac-4b5c-45e8-b735-36dd496eeab6','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','CellControllerServers','overcloud-CellControllerServers-c4suvbwlwz5m','state changed','OS::Heat::Value',NULL,535),(744,'1d3dbbea-5549-4a34-910f-144d71ddc366','cabb5156-7752-43ca-8cb0-1498d71c719b','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeIpListMap-t24ziif2qyhd','cabb5156-7752-43ca-8cb0-1498d71c719b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(745,'e792cbaf-b899-467c-b1a0-ad49684d51bf','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNames','overcloud-CephStorageServiceNames-253ptgx62v6s','state changed','OS::Heat::Value',NULL,536),(746,'4d3731a9-5dfb-440b-9b6f-cd3db52863de','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-rh2gdxmdmcbv','state changed','OS::Heat::Value',NULL,534),(747,'a74242a1-bee3-483c-ab92-171e216484a4','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','CephStorageServiceNames','overcloud-CephStorageServiceNames-253ptgx62v6s','state changed','OS::Heat::Value',NULL,536),(748,'d0e49e7a-2440-4fc0-8c67-2d4aab626fe4','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','CellControllerServers','overcloud-CellControllerServers-c4suvbwlwz5m','state changed','OS::Heat::Value',NULL,535),(749,'c0b7e6fd-dc4f-4132-ad10-bd5ff26f11eb','03b08889-9c0e-4c91-baae-ba2039ff1d00','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu-ContainersCommon-l6epdvyrawjp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(750,'0e88882b-daf7-4a31-8903-ee8f7e313ef1','cf9e1e88-8545-4983-be47-daf6dbab845a','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu-ContainersCommon-l6epdvyrawjp','cf9e1e88-8545-4983-be47-daf6dbab845a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(751,'160f1262-c3ce-47e2-8422-0628836dd959','cf9e1e88-8545-4983-be47-daf6dbab845a','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu-ContainersCommon-l6epdvyrawjp','cf9e1e88-8545-4983-be47-daf6dbab845a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(752,'032a9c6b-364d-4493-b51a-0825af7a3c06','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','CellControllerIpListMap','overcloud-CellControllerIpListMap-ttruf7auvpq3','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,542),(753,'4361aede-8b86-44af-bada-4821139c483e','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','2','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,544),(754,'1c9ca970-a889-41cf-a029-fc65e858e505','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','CephStorage','overcloud-CephStorage-4kgvwchfgs4m','state changed','OS::Heat::ResourceGroup',NULL,546),(755,'4d392f0d-887a-450c-ab26-c95489d5c7a1','03b08889-9c0e-4c91-baae-ba2039ff1d00','2026-06-13 07:57:03',NULL,'CREATE','COMPLETE','CeilometerServiceBase','c882d66c-22de-4fed-82a5-5bd2c462619c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,483),(756,'19d11797-b4ac-4673-a5aa-d22fad0b95c7','c5c0834b-8295-4366-9077-ffe7ae593adf','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerIpListMap-ttruf7auvpq3','c5c0834b-8295-4366-9077-ffe7ae593adf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(757,'0a8f1350-c114-4a3b-8b79-7bc92a350e98','cabb5156-7752-43ca-8cb0-1498d71c719b','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerComputeIpListMap-t24ziif2qyhd-NetIpMapValue-6dtjuytokrmb','state changed','OS::Heat::Value',NULL,551),(758,'a216e9be-0e6c-40ad-91e9-3ab06ea7d0e1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:03',NULL,'CREATE','IN_PROGRESS','BlockStorageServers','overcloud-BlockStorageServers-36335epx7psj','state changed','OS::Heat::Value',NULL,553),(759,'ed99a369-2c5e-4703-8d15-d2b54b817638','9e3e6751-5f82-47dc-9285-d729a3c2d83f','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7','9e3e6751-5f82-47dc-9285-d729a3c2d83f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(760,'02ca4f66-eec7-4a6d-8e4f-62152255e1e6','27710f36-02c3-46ee-897e-e044b5271930','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorage-4kgvwchfgs4m','27710f36-02c3-46ee-897e-e044b5271930','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(761,'b81b2ea8-7eff-45be-8fd6-3f3e8f2e8d65','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','BlockStorageServers','overcloud-BlockStorageServers-36335epx7psj','state changed','OS::Heat::Value',NULL,553),(762,'900282b6-e31c-4d66-863a-a08e76686f1d','cabb5156-7752-43ca-8cb0-1498d71c719b','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerComputeIpListMap-t24ziif2qyhd-NetIpMapValue-6dtjuytokrmb','state changed','OS::Heat::Value',NULL,551),(763,'2cba8e6a-ca36-4d2b-83d5-1ba90b3ccd18','27710f36-02c3-46ee-897e-e044b5271930','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','overcloud-CephStorage-4kgvwchfgs4m','27710f36-02c3-46ee-897e-e044b5271930','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(764,'ec252bf1-fc0e-4a20-bf3c-ba6598274c20','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-2rzvqfs4z3ls','state changed','OS::Heat::Value',NULL,559),(765,'ef65a7be-63b3-43cf-aeb8-df82c098fca5','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','CephStorage','27710f36-02c3-46ee-897e-e044b5271930','state changed','OS::Heat::ResourceGroup',NULL,546),(766,'9460c9bb-837f-4d56-a109-7855e0cf2233','e84e2039-a1fb-4d14-aae6-677f604f36a4','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7-CeilometerServiceBase-vevprff4k3tl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,567),(767,'4cb2851e-ce53-45cb-ac33-b35e48b3b406','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-2rzvqfs4z3ls','state changed','OS::Heat::Value',NULL,559),(768,'2ccd2089-fca4-499f-a4a0-85c878c59ee4','c5c0834b-8295-4366-9077-ffe7ae593adf','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerIpListMap-ttruf7auvpq3-EnabledServicesValue-j4zl3accoxda','state changed','OS::Heat::Value',NULL,572),(769,'71faf785-a4ff-4cf6-b4eb-74efe4f257be','9e3e6751-5f82-47dc-9285-d729a3c2d83f','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7-ContainersCommon-qqwabb74pcpf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(770,'18b58d42-6e4a-48a9-9e84-740e922db68c','a433f2e1-f733-4922-9cb9-f6d1310d3aa1','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7-CeilometerServiceBase-vevprff4k3tl','a433f2e1-f733-4922-9cb9-f6d1310d3aa1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(771,'68228899-bc97-4503-867e-e8019e37f5f7','c5c0834b-8295-4366-9077-ffe7ae593adf','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerIpListMap-ttruf7auvpq3-EnabledServicesValue-j4zl3accoxda','state changed','OS::Heat::Value',NULL,572),(772,'d98485fb-d3f5-4ebc-ac81-dab050a59a43','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-w2vc6anb52nj','state changed','OS::Heat::Value',NULL,574),(773,'29f53057-c158-4ea8-8111-0d71764909b8','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','BlockStorageIpListMap','overcloud-BlockStorageIpListMap-vhaxpownd7qw','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,581),(774,'48b6986c-9033-4d86-a88b-b0f6e1021d3c','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-w2vc6anb52nj','state changed','OS::Heat::Value',NULL,574),(775,'9fc9e8e3-53cd-45bf-9f47-904dc26a6865','9a15ca39-a021-4d79-97e6-12b99d59e39e','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-6-kh7tk7wfbizg-RoleParametersValue-zoeju4ll2tur','state changed','OS::Heat::Value',NULL,582),(776,'030cdb70-116b-4780-84e0-1cbd57a31926','9a15ca39-a021-4d79-97e6-12b99d59e39e','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-6-kh7tk7wfbizg-RoleParametersValue-zoeju4ll2tur','state changed','OS::Heat::Value',NULL,582),(777,'ebdeeaf4-cea3-4f09-bd20-be12deeb4c25','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-5spykwkpcm3s','state changed','OS::Heat::Value',NULL,583),(778,'91f22d95-8052-4349-be6f-c3fd03036b16','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','5','69386965-ee2e-418c-aa6a-af8c30f74b2a','state changed','OS::TripleO::Services::IpaClient',NULL,472),(779,'8a2ff478-1f6d-44b2-8855-c3ae06fdfa3a','a433f2e1-f733-4922-9cb9-f6d1310d3aa1','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7-CeilometerServiceBase-vevprff4k3tl','a433f2e1-f733-4922-9cb9-f6d1310d3aa1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(780,'24f3ff70-7639-4ec6-80dd-090919e0c4b5','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','CephStorageServers','overcloud-CephStorageServers-64j4kacd3mjw','state changed','OS::Heat::Value',NULL,584),(781,'0933aecd-398c-471a-bed0-d7c481c61088','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','CephStorageServers','overcloud-CephStorageServers-64j4kacd3mjw','state changed','OS::Heat::Value',NULL,584),(782,'7b2fb98c-15b2-4f9c-8c56-57de0202f258','87c8cf05-7aba-4d5e-892f-afc281eeda46','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7-ContainersCommon-qqwabb74pcpf','87c8cf05-7aba-4d5e-892f-afc281eeda46','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(783,'9f8ee59c-a221-4f0b-be7c-ede68aa82d11','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-5spykwkpcm3s','state changed','OS::Heat::Value',NULL,583),(784,'44a1468d-a008-48b6-9b60-6ad92e978b82','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','0','70d69b07-a1cc-4be3-a00d-9309daa4f554','state changed','OS::TripleO::Services::BootParams',NULL,526),(785,'c9e1b791-7579-444e-87f9-d4f2cad917cd','7f42a2a6-1bad-406d-9588-853a848d52f1','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageIpListMap-vhaxpownd7qw','7f42a2a6-1bad-406d-9588-853a848d52f1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(786,'b5489a84-59c7-430f-ad35-f97495b4fe1c','9a15ca39-a021-4d79-97e6-12b99d59e39e','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','ContainersCommon','08d1cd68-3e43-45be-94a0-10173b05e80e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(787,'b94e5f73-98e3-45d7-9a8e-ccdcc04f817b','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','9','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-9-y2ivqchkq2fj','state changed','OS::TripleO::Services::MySQLClient',NULL,595),(788,'716647e3-d7f8-4275-afb8-6d1c0381b2fe','e84e2039-a1fb-4d14-aae6-677f604f36a4','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','ContainersCommon','8ecb59de-2e5b-43d7-a0ba-46d8443a6089','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(789,'04c2ad97-318e-4824-8017-20dbf9ecaecc','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','ObjectStorage','overcloud-ObjectStorage-j73va6pgikqs','state changed','OS::Heat::ResourceGroup',NULL,594),(790,'d33eba7f-b42c-432f-b28f-a9e1e58373e3','87c8cf05-7aba-4d5e-892f-afc281eeda46','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7-ContainersCommon-qqwabb74pcpf','87c8cf05-7aba-4d5e-892f-afc281eeda46','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(791,'3bfbae96-56a4-41ea-a8dd-d186fb7aa25e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','CephStorageIpListMap','overcloud-CephStorageIpListMap-hmsg7nujauu2','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,597),(792,'ab9a7475-3eac-4f0b-9809-ec5fc609a85c','542cb3d4-9944-4f61-92ea-b2ab21f3c7d6','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-9-y2ivqchkq2fj','542cb3d4-9944-4f61-92ea-b2ab21f3c7d6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(793,'a027f065-f13a-4ec5-b43c-f0180e9e61f6','542cb3d4-9944-4f61-92ea-b2ab21f3c7d6','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-9-y2ivqchkq2fj','542cb3d4-9944-4f61-92ea-b2ab21f3c7d6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(794,'078bcf11-3ed0-42e0-abaf-beac1debf9aa','9a15ca39-a021-4d79-97e6-12b99d59e39e','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-6-kh7tk7wfbizg','9a15ca39-a021-4d79-97e6-12b99d59e39e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(795,'3b8dac15-6b1e-4290-87d4-d28ba7869b81','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','4','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,601),(796,'17cda28b-308d-466b-9231-9f2ee3099363','2602450e-d5d7-4282-a76e-98b67a3d781b','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorage-j73va6pgikqs','2602450e-d5d7-4282-a76e-98b67a3d781b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(797,'806176a2-4786-44de-8f2e-206bf73d6b23','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-cebfpxdzh4jm','state changed','OS::Heat::Value',NULL,602),(798,'d7c1bd88-68a6-41a8-be73-266d040d21fb','2602450e-d5d7-4282-a76e-98b67a3d781b','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','overcloud-ObjectStorage-j73va6pgikqs','2602450e-d5d7-4282-a76e-98b67a3d781b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(799,'6e0bebfe-3771-446b-bc50-0c60f7606b4c','c4e5833d-42de-4b69-a787-a53a1d5ade91','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageIpListMap-hmsg7nujauu2','c4e5833d-42de-4b69-a787-a53a1d5ade91','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(800,'de1f175d-5fb4-4986-9ecd-d9c12ffd48c8','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-cebfpxdzh4jm','state changed','OS::Heat::Value',NULL,602),(801,'522afd44-a2fa-4238-a2f4-5bc2cb321b27','7f42a2a6-1bad-406d-9588-853a848d52f1','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-BlockStorageIpListMap-vhaxpownd7qw-EnabledServicesValue-rgvs5u62c532','state changed','OS::Heat::Value',NULL,603),(802,'217c3c3f-bab9-441a-8306-667ba24a6194','f9ec53be-5ffa-4972-a5b4-35aea93afa31','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb','f9ec53be-5ffa-4972-a5b4-35aea93afa31','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(803,'51c70414-0287-4387-9b6b-aa9c0a3da002','7f42a2a6-1bad-406d-9588-853a848d52f1','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-BlockStorageIpListMap-vhaxpownd7qw-EnabledServicesValue-rgvs5u62c532','state changed','OS::Heat::Value',NULL,603),(804,'a3ffeac4-f052-4cfd-886f-27fcd253df9f','03b08889-9c0e-4c91-baae-ba2039ff1d00','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','ContainersCommon','cf9e1e88-8545-4983-be47-daf6dbab845a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(805,'df2bcf44-e6fc-43b5-80a7-931a61f84a4a','03b08889-9c0e-4c91-baae-ba2039ff1d00','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-3-s7dlern4triu','03b08889-9c0e-4c91-baae-ba2039ff1d00','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(806,'8efa64f0-3b05-4886-9db2-41bd0422a767','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','1','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-1-3rztb74vxtna','state changed','OS::TripleO::Services::CACerts',NULL,604),(807,'8fe40206-9964-4f9a-8db1-a02c32f8ed4c','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNames','overcloud-NetworkerServiceNames-s6lid3pfya4l','state changed','OS::Heat::Value',NULL,605),(808,'8c74dd0d-cc33-42bb-bb8e-f38a6ce1ead0','c4e5833d-42de-4b69-a787-a53a1d5ade91','2026-06-13 07:57:04',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CephStorageIpListMap-hmsg7nujauu2-EnabledServicesValue-vklyeom7df2n','state changed','OS::Heat::Value',NULL,606),(809,'734f3b37-b544-4b2a-b94e-6ebf39a83ce2','c4e5833d-42de-4b69-a787-a53a1d5ade91','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CephStorageIpListMap-hmsg7nujauu2-EnabledServicesValue-vklyeom7df2n','state changed','OS::Heat::Value',NULL,606),(810,'63c7085a-9855-4281-89a5-d11658c2bde5','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:04',NULL,'CREATE','COMPLETE','NetworkerServiceNames','overcloud-NetworkerServiceNames-s6lid3pfya4l','state changed','OS::Heat::Value',NULL,605),(811,'3df62a67-fd49-4fe6-9d0f-43bcd8758aaa','cabb5156-7752-43ca-8cb0-1498d71c719b','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-t24ziif2qyhd-EnabledServicesValue-ia267rvguj76','state changed','OS::Heat::Value',NULL,607),(812,'3dc43539-d01e-487a-917d-b68150f4e717','8fa8cc9a-3cc5-47ed-a515-9d8ee67464d4','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-1-3rztb74vxtna','8fa8cc9a-3cc5-47ed-a515-9d8ee67464d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(813,'e3ceb8df-1766-4f0d-bbb8-a33e6ad45824','f9ec53be-5ffa-4972-a5b4-35aea93afa31','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','CeilometerAgentCentralBase','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,608),(814,'edf61efc-73d6-4b3f-96e9-23e63e082862','cabb5156-7752-43ca-8cb0-1498d71c719b','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-t24ziif2qyhd-EnabledServicesValue-ia267rvguj76','state changed','OS::Heat::Value',NULL,607),(815,'759fe3bf-a628-42f7-a3cb-aad167052ea5','8fa8cc9a-3cc5-47ed-a515-9d8ee67464d4','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-1-3rztb74vxtna','8fa8cc9a-3cc5-47ed-a515-9d8ee67464d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(816,'4dc08d2f-11e2-46ba-8bf6-42e0a2496084','cabb5156-7752-43ca-8cb0-1498d71c719b','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeIpListMap-t24ziif2qyhd','cabb5156-7752-43ca-8cb0-1498d71c719b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(817,'329f0a08-3ee9-432a-91a8-6343c247a338','9772f262-f152-49ed-b7e6-30873e193250','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye','9772f262-f152-49ed-b7e6-30873e193250','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(818,'29688a63-d510-4435-afd7-5fb808ec1de2','e84e2039-a1fb-4d14-aae6-677f604f36a4','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7-RoleParametersValue-4vhbglolea7b','state changed','OS::Heat::Value',NULL,610),(819,'4cb6211d-1a77-4c01-bfc4-f11788159a40','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','Networker','overcloud-Networker-6ixhueqo7kbg','state changed','OS::Heat::ResourceGroup',NULL,609),(820,'64cc2078-4ead-4825-8af5-558b3b0d12f7','e84e2039-a1fb-4d14-aae6-677f604f36a4','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7-RoleParametersValue-4vhbglolea7b','state changed','OS::Heat::Value',NULL,610),(821,'436a93dc-8050-4c17-ae6e-1284e6e61e3e','c5c0834b-8295-4366-9077-ffe7ae593adf','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerIpListMap-ttruf7auvpq3-NetIpMapValue-sryel2zv4ito','state changed','OS::Heat::Value',NULL,611),(822,'7f512aff-cc58-446b-ba39-c0684bd6fc7f','c5c0834b-8295-4366-9077-ffe7ae593adf','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerIpListMap-ttruf7auvpq3-NetIpMapValue-sryel2zv4ito','state changed','OS::Heat::Value',NULL,611),(823,'c9268d36-f40c-41fb-bd71-d980dc151efa','9772f262-f152-49ed-b7e6-30873e193250','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye-ContainersCommon-vzswe3ucs3ke','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(824,'ca90bc33-ad6a-4516-a83d-baf418e43c6f','9e3e6751-5f82-47dc-9285-d729a3c2d83f','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7-CeilometerServiceBase-irjs3qgtdixl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,613),(825,'61c4f038-4c72-49c0-a90f-d9613be2da5d','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','6','9a15ca39-a021-4d79-97e6-12b99d59e39e','state changed','OS::TripleO::Services::Iscsid',NULL,523),(826,'f2ebae59-afd0-43c2-98d7-94f24a37733d','99c88317-0fd3-44b9-819f-eb518be0f2ae','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','overcloud-Networker-6ixhueqo7kbg','99c88317-0fd3-44b9-819f-eb518be0f2ae','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(827,'c069e42b-b30f-4d55-8dc1-7a680700a558','c5c0834b-8295-4366-9077-ffe7ae593adf','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','overcloud-CellControllerIpListMap-ttruf7auvpq3','c5c0834b-8295-4366-9077-ffe7ae593adf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(828,'59823483-66ad-454a-be1c-6d8b3c6c7db2','99c88317-0fd3-44b9-819f-eb518be0f2ae','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','overcloud-Networker-6ixhueqo7kbg','99c88317-0fd3-44b9-819f-eb518be0f2ae','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(829,'a758dc54-358f-4900-a2c9-f77c7d927ae5','c6a34ff1-e53a-4b29-b6fd-065b332ea7f9','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye-ContainersCommon-vzswe3ucs3ke','c6a34ff1-e53a-4b29-b6fd-065b332ea7f9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(830,'f8ba537a-e56c-47f7-a0f6-fc8625b29e82','a4428fb9-26ba-4ced-bde3-60a7fd5da309','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7-CeilometerServiceBase-irjs3qgtdixl','a4428fb9-26ba-4ced-bde3-60a7fd5da309','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(831,'92c2999c-9fc9-48df-b05c-dc4de925d769','e84e2039-a1fb-4d14-aae6-677f604f36a4','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','CeilometerServiceBase','a433f2e1-f733-4922-9cb9-f6d1310d3aa1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,567),(832,'0b014e4e-d13f-4f79-aaf6-27b5037d5b68','c6a34ff1-e53a-4b29-b6fd-065b332ea7f9','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye-ContainersCommon-vzswe3ucs3ke','c6a34ff1-e53a-4b29-b6fd-065b332ea7f9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(833,'66d9be91-7c24-4b58-817d-5c845fc68952','e84e2039-a1fb-4d14-aae6-677f604f36a4','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-3-xhblxdamayk7','e84e2039-a1fb-4d14-aae6-677f604f36a4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(834,'65e5e771-3e89-4c41-892f-98ab4f38a2a6','a4428fb9-26ba-4ced-bde3-60a7fd5da309','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7-CeilometerServiceBase-irjs3qgtdixl','a4428fb9-26ba-4ced-bde3-60a7fd5da309','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(835,'83bf177d-6718-4eb6-9ade-1d88460b166c','9772f262-f152-49ed-b7e6-30873e193250','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','ContainersCommon','c6a34ff1-e53a-4b29-b6fd-065b332ea7f9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(836,'5f45b682-8cb0-45e2-a74c-ef935a1117cf','9e3e6751-5f82-47dc-9285-d729a3c2d83f','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','ContainersCommon','87c8cf05-7aba-4d5e-892f-afc281eeda46','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(837,'4a418c4c-92fe-425d-bb5b-29aa0969f828','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','10','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc','state changed','OS::TripleO::Services::NovaCompute',NULL,618),(838,'4122fb5b-a722-49aa-8c94-e366aab2beba','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(839,'c218055c-5457-414b-9d45-e1c409a31db5','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','9','542cb3d4-9944-4f61-92ea-b2ab21f3c7d6','state changed','OS::TripleO::Services::MySQLClient',NULL,595),(840,'ec15fc5a-f158-4ac9-8c92-56a906925381','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','3','03b08889-9c0e-4c91-baae-ba2039ff1d00','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,343),(841,'87ee38b9-a9a9-4dea-8720-22aa33cd911d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','ObjectStorage','2602450e-d5d7-4282-a76e-98b67a3d781b','state changed','OS::Heat::ResourceGroup',NULL,594),(842,'98d84c0b-6c99-4bf4-b188-2f8ba46bfafa','7f42a2a6-1bad-406d-9588-853a848d52f1','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-BlockStorageIpListMap-vhaxpownd7qw-NetIpMapValue-sckuie76qhbj','state changed','OS::Heat::Value',NULL,619),(843,'1bc30a4d-4ae5-41eb-8241-9d8a7f8e8d02','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','CellControllerComputeIpListMap','cabb5156-7752-43ca-8cb0-1498d71c719b','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,524),(844,'9ec9e158-516d-4d33-9e75-2e3212457276','7f42a2a6-1bad-406d-9588-853a848d52f1','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-BlockStorageIpListMap-vhaxpownd7qw-NetIpMapValue-sckuie76qhbj','state changed','OS::Heat::Value',NULL,619),(845,'92de0324-3815-4b9d-b9fe-e90f5e12fd5b','7f42a2a6-1bad-406d-9588-853a848d52f1','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','overcloud-BlockStorageIpListMap-vhaxpownd7qw','7f42a2a6-1bad-406d-9588-853a848d52f1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(846,'c8bb1a41-06ed-485a-9c45-b0c276bbe9a6','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','0','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-0-hhmfn3z6foza','state changed','OS::TripleO::Services::BootParams',NULL,621),(847,'30651016-5a39-41ba-8ed5-13241db3bc6e','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','13','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,623),(848,'13058d76-5b9c-430e-b5b9-45abeb67bb6e','c93b5334-abed-4f24-96da-6cf219ae8570','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s','c93b5334-abed-4f24-96da-6cf219ae8570','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(849,'c27ee0a8-d9ec-4662-a8cc-b23758603666','c4e5833d-42de-4b69-a787-a53a1d5ade91','2026-06-13 07:57:05',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CephStorageIpListMap-hmsg7nujauu2-NetIpMapValue-gmbubsgwasg4','state changed','OS::Heat::Value',NULL,625),(850,'d09f282d-3d0b-42a2-a96c-936f1a5ffabc','c4e5833d-42de-4b69-a787-a53a1d5ade91','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CephStorageIpListMap-hmsg7nujauu2-NetIpMapValue-gmbubsgwasg4','state changed','OS::Heat::Value',NULL,625),(851,'9c5cbf34-69eb-4994-a1eb-cafbdc203ef6','c4e5833d-42de-4b69-a787-a53a1d5ade91','2026-06-13 07:57:05',NULL,'CREATE','COMPLETE','overcloud-CephStorageIpListMap-hmsg7nujauu2','c4e5833d-42de-4b69-a787-a53a1d5ade91','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(852,'a2e1f9f0-1051-4435-a173-5b87e82c52b3','6840501f-1caf-4024-9e9b-40714578afed','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-0-hhmfn3z6foza','6840501f-1caf-4024-9e9b-40714578afed','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(853,'67b0c332-2712-46dd-88d5-b62691c538a7','f9ec53be-5ffa-4972-a5b4-35aea93afa31','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-RoleParametersValue-butuwz4q6the','state changed','OS::Heat::Value',NULL,626),(854,'b5abe4ac-8e74-4b87-a872-a478eab904c0','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-bv6gmhelnvop','state changed','OS::Heat::Value',NULL,627),(855,'a6aa4eef-f884-4dce-8082-f5397cdb88f2','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','CellControllerIpListMap','c5c0834b-8295-4366-9077-ffe7ae593adf','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,542),(856,'0fca475c-b312-47c5-8764-65d7ab9cc570','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','1','8fa8cc9a-3cc5-47ed-a515-9d8ee67464d4','state changed','OS::TripleO::Services::CACerts',NULL,604),(857,'dad3fa50-cca4-4117-b910-866e0849514a','f9ec53be-5ffa-4972-a5b4-35aea93afa31','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-RoleParametersValue-butuwz4q6the','state changed','OS::Heat::Value',NULL,626),(858,'60efa609-1210-46a5-94ba-625e2b2fcba7','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-bv6gmhelnvop','state changed','OS::Heat::Value',NULL,627),(859,'49078e22-3c59-4f7e-afe5-b16de47ab086','c93b5334-abed-4f24-96da-6cf219ae8570','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s-ContainersCommon-iuq36qoqqhfw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(860,'f10ec718-48fc-45a6-b017-91ebe388af88','6840501f-1caf-4024-9e9b-40714578afed','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-0-hhmfn3z6foza-RoleParametersValue-vngtv47kcehe','state changed','OS::Heat::Value',NULL,631),(861,'996825be-b43f-4e4e-ab7b-89230f8f8fb5','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaBase-vicwwraajsjy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,630),(862,'8f1904d0-bf16-48f4-8372-d9d6d33ad599','6840501f-1caf-4024-9e9b-40714578afed','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-0-hhmfn3z6foza-RoleParametersValue-vngtv47kcehe','state changed','OS::Heat::Value',NULL,631),(863,'02ce0e66-8426-43f0-9832-8055efab7b91','6840501f-1caf-4024-9e9b-40714578afed','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-0-hhmfn3z6foza','6840501f-1caf-4024-9e9b-40714578afed','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(864,'8a94c1e4-5e7d-4473-b85a-b6a435dd9047','443248e5-9a09-47b2-ba6e-b7e2d1fb8a13','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s-ContainersCommon-iuq36qoqqhfw','443248e5-9a09-47b2-ba6e-b7e2d1fb8a13','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(865,'3b6ee33d-1486-4128-98e0-82a64e328853','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','7','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-7-tyhmrgkmwkda','state changed','OS::TripleO::Services::Kernel',NULL,634),(866,'268e6daf-bb35-48f7-b161-530bd777c963','9e3e6751-5f82-47dc-9285-d729a3c2d83f','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7-RoleParametersValue-vdmvm7ukytet','state changed','OS::Heat::Value',NULL,637),(867,'a3f026dc-d65a-4e55-a773-0bc4d12685a5','9e3e6751-5f82-47dc-9285-d729a3c2d83f','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7-RoleParametersValue-vdmvm7ukytet','state changed','OS::Heat::Value',NULL,637),(868,'90dc997b-d199-468b-9c61-18b938cd9ab5','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','ObjectStorageServers','overcloud-ObjectStorageServers-6b4doytyu3mc','state changed','OS::Heat::Value',NULL,638),(869,'b2dec099-9cae-4a8f-95d1-103dc25cee92','443248e5-9a09-47b2-ba6e-b7e2d1fb8a13','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s-ContainersCommon-iuq36qoqqhfw','443248e5-9a09-47b2-ba6e-b7e2d1fb8a13','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(870,'8bad48ae-3654-4990-8ebe-fd192fc31aa1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','ObjectStorageServers','overcloud-ObjectStorageServers-6b4doytyu3mc','state changed','OS::Heat::Value',NULL,638),(871,'d33fe250-d156-4b83-80b1-ea1027f6ff99','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','ObjectStorageIpListMap','overcloud-ObjectStorageIpListMap-sfx7zeywgslu','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,636),(872,'d1b5c96a-5d31-4cc3-99d3-6f9061ae62dc','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','Networker','99c88317-0fd3-44b9-819f-eb518be0f2ae','state changed','OS::Heat::ResourceGroup',NULL,609),(873,'4f477ffd-8d01-46fa-9b7b-de9a9df5d4db','26df407a-1278-4321-acf0-54ffb4fa44f9','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaBase-vicwwraajsjy','26df407a-1278-4321-acf0-54ffb4fa44f9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(874,'17517b89-502b-40cd-ae4f-cfbbb7db7f9e','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','5','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y','state changed','OS::TripleO::Services::CinderBackup',NULL,640),(875,'ed5b5652-bd8a-402b-987d-9ec5ec72cc01','c93b5334-abed-4f24-96da-6cf219ae8570','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','ContainersCommon','443248e5-9a09-47b2-ba6e-b7e2d1fb8a13','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(876,'ba156074-5f18-4405-8937-4c371fd2cb91','9772f262-f152-49ed-b7e6-30873e193250','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye-CeilometerServiceBase-pqgdcdxstj5l','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,641),(877,'a743e457-50c7-4c8c-8d20-9b122e11e713','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','3','e84e2039-a1fb-4d14-aae6-677f604f36a4','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,502),(878,'5dc53ca2-35c9-413e-ac88-545689d5c849','9e3e6751-5f82-47dc-9285-d729a3c2d83f','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','CeilometerServiceBase','a4428fb9-26ba-4ced-bde3-60a7fd5da309','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,613),(879,'e68b0504-deca-4782-b947-6f4e1b8ba988','255b2652-a788-4de0-b3c0-176cad10d45d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageIpListMap-sfx7zeywgslu','255b2652-a788-4de0-b3c0-176cad10d45d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(880,'69a71ab5-43f3-4d3f-b80d-69fb978a9202','59a69d9c-f605-4084-8a0b-70749ca36c80','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-7-tyhmrgkmwkda','59a69d9c-f605-4084-8a0b-70749ca36c80','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(881,'761de994-0953-4a45-9a51-7ec6c3664851','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y','5e499b71-33b0-4411-8974-230c16fa3fd6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(882,'0fa575c5-15fe-42ad-985e-f33a1f4c7825','9e3e6751-5f82-47dc-9285-d729a3c2d83f','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-2-aeznsxuregx7','9e3e6751-5f82-47dc-9285-d729a3c2d83f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(883,'cc650950-fd6c-4651-b80f-f5b5711dbea6','550b666c-cf46-4773-86c0-a8ef45130ebd','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye-CeilometerServiceBase-pqgdcdxstj5l','550b666c-cf46-4773-86c0-a8ef45130ebd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(884,'f7d6df4e-91e1-4cca-ad39-2a0612116ac6','550b666c-cf46-4773-86c0-a8ef45130ebd','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye-CeilometerServiceBase-pqgdcdxstj5l','550b666c-cf46-4773-86c0-a8ef45130ebd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(885,'19f9f0c3-de7a-4dc5-8247-427930f328d8','26df407a-1278-4321-acf0-54ffb4fa44f9','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaBase-vicwwraajsjy-RoleParametersValue-yqbg5azke5eq','state changed','OS::Heat::Value',NULL,642),(886,'3825505e-2bd1-4676-a460-d17b73f3a05b','26df407a-1278-4321-acf0-54ffb4fa44f9','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaBase-vicwwraajsjy-RoleParametersValue-yqbg5azke5eq','state changed','OS::Heat::Value',NULL,642),(887,'2593f269-b365-4393-895a-aeddc7c3dd4f','59a69d9c-f605-4084-8a0b-70749ca36c80','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-7-tyhmrgkmwkda-RoleParametersValue-yjsx467lefwa','state changed','OS::Heat::Value',NULL,645),(888,'81d81a72-5469-4a4b-a8d3-1c0e1eeff40e','26df407a-1278-4321-acf0-54ffb4fa44f9','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaBase-vicwwraajsjy','26df407a-1278-4321-acf0-54ffb4fa44f9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(889,'6d6eadfc-c2ad-4d9f-bba4-a08e4e5ffcf2','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','NetworkerServers','overcloud-NetworkerServers-l6cvvuh2zdfn','state changed','OS::Heat::Value',NULL,643),(890,'7cefafaa-aecc-4116-b824-1ab08abd87ed','59a69d9c-f605-4084-8a0b-70749ca36c80','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-7-tyhmrgkmwkda-RoleParametersValue-yjsx467lefwa','state changed','OS::Heat::Value',NULL,645),(891,'2e2b5a1b-fec7-4038-9e53-d7dbe0ad8c0b','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','BlockStorageIpListMap','7f42a2a6-1bad-406d-9588-853a848d52f1','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,581),(892,'0414b9ad-ff7c-4457-9566-0771a1e66b5a','255b2652-a788-4de0-b3c0-176cad10d45d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ObjectStorageIpListMap-sfx7zeywgslu-EnabledServicesValue-ggsxfxakkklp','state changed','OS::Heat::Value',NULL,648),(893,'4f5b25ef-6b16-4c32-852e-7f84d7fc9a53','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','NetworkerServers','overcloud-NetworkerServers-l6cvvuh2zdfn','state changed','OS::Heat::Value',NULL,643),(894,'5560fe32-19ca-4df7-b931-0de89b4bb69b','59a69d9c-f605-4084-8a0b-70749ca36c80','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-7-tyhmrgkmwkda','59a69d9c-f605-4084-8a0b-70749ca36c80','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(895,'59540baa-a655-41d8-999d-be98d22105e0','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-yuuvouebz7my','state changed','OS::Heat::Value',NULL,649),(896,'cbe7e2cb-e4a9-49ef-822b-a7f172003f89','255b2652-a788-4de0-b3c0-176cad10d45d','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ObjectStorageIpListMap-sfx7zeywgslu-EnabledServicesValue-ggsxfxakkklp','state changed','OS::Heat::Value',NULL,648),(897,'74bba156-43c1-4cc7-bc99-bcf2328a722e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-yuuvouebz7my','state changed','OS::Heat::Value',NULL,649),(898,'c6b1e4d7-f58d-4882-81c2-821b0904c2de','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderCommon-mhsouy7wxvf7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(899,'c7438a2c-419b-400c-a7ec-d7ea32caebfa','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','NetworkerIpListMap','overcloud-NetworkerIpListMap-yvfwwoijojle','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,654),(900,'7d36a0d4-e0df-4586-ab7b-eceb420823d4','2622bbfd-4611-4881-b113-5da00e9a3e4d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderCommon-mhsouy7wxvf7','2622bbfd-4611-4881-b113-5da00e9a3e4d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(901,'6e298425-0099-48d0-9180-fc69c1761e82','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','7','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf','state changed','OS::TripleO::Services::CinderVolume',NULL,655),(902,'426b263d-118e-4441-a2c6-37a334f8c106','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:06',NULL,'CREATE','COMPLETE','CephStorageIpListMap','c4e5833d-42de-4b69-a787-a53a1d5ade91','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,597),(903,'70782a7b-64ec-48d7-9550-64ee716d0639','331f97aa-cbeb-41a7-9503-7b9151ba972d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerIpListMap-yvfwwoijojle','331f97aa-cbeb-41a7-9503-7b9151ba972d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(904,'86c55461-6cd3-490b-9c38-4f8be3e18d95','2622bbfd-4611-4881-b113-5da00e9a3e4d','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderCommon-mhsouy7wxvf7-CinderNVMeOF-t3dr57z67om6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(905,'dd3fd7bc-e9e6-42b9-a4bd-cc281d6e00ae','f9ec53be-5ffa-4972-a5b4-35aea93afa31','2026-06-13 07:57:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-ContainersCommon-2ltor7dfkqoo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(906,'5b1b7322-669d-4b6f-adb9-75a39760768e','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','0','6840501f-1caf-4024-9e9b-40714578afed','state changed','OS::TripleO::Services::BootParams',NULL,621),(907,'8af57900-a098-4764-9daf-4d5aaccdd78a','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf','f43914ad-07b9-4540-9d93-bd897b8f190e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(908,'0d8d5973-a979-47e2-968b-a844d5bbace3','331f97aa-cbeb-41a7-9503-7b9151ba972d','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-NetworkerIpListMap-yvfwwoijojle-EnabledServicesValue-bogamatm4iuy','state changed','OS::Heat::Value',NULL,656),(909,'164681c9-d2fe-4327-b76e-5093703c940a','6935a716-4513-4e61-a8d5-44bcf30f252f','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-ContainersCommon-2ltor7dfkqoo','6935a716-4513-4e61-a8d5-44bcf30f252f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(910,'267863ad-090a-472d-907b-05bef4f53b1f','c93b5334-abed-4f24-96da-6cf219ae8570','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s-RoleParametersValue-qi7ve3itswcy','state changed','OS::Heat::Value',NULL,657),(911,'3be9204a-5deb-435f-aa77-7fcc00c7e073','83f4159f-2bca-440c-8126-7a2142941df6','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderCommon-mhsouy7wxvf7-CinderNVMeOF-t3dr57z67om6','83f4159f-2bca-440c-8126-7a2142941df6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(912,'d1b85a55-bbeb-4f22-aa5c-41f19dbcf6db','331f97aa-cbeb-41a7-9503-7b9151ba972d','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-NetworkerIpListMap-yvfwwoijojle-EnabledServicesValue-bogamatm4iuy','state changed','OS::Heat::Value',NULL,656),(913,'395b3e92-63e3-4916-a2a9-7b39d94ed6fd','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','NovaComputeCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaComputeCommon-6hnjl6xcuefk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,658),(914,'b3912e53-fd8f-4ce5-980f-5023c68d60e1','6935a716-4513-4e61-a8d5-44bcf30f252f','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-ContainersCommon-2ltor7dfkqoo','6935a716-4513-4e61-a8d5-44bcf30f252f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(915,'e15efc2f-ff94-48a9-81a8-5716184878f9','c93b5334-abed-4f24-96da-6cf219ae8570','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s-RoleParametersValue-qi7ve3itswcy','state changed','OS::Heat::Value',NULL,657),(916,'1d56dee2-f79c-44fa-836e-6676fb06cb41','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','2','9e3e6751-5f82-47dc-9285-d729a3c2d83f','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,544),(917,'b571dc40-7bc2-4772-8638-f93294a1b811','f9ec53be-5ffa-4972-a5b4-35aea93afa31','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','ContainersCommon','6935a716-4513-4e61-a8d5-44bcf30f252f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(918,'e549c325-8609-4bf8-bd85-e66632c3477c','83f4159f-2bca-440c-8126-7a2142941df6','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderCommon-mhsouy7wxvf7-CinderNVMeOF-t3dr57z67om6','83f4159f-2bca-440c-8126-7a2142941df6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(919,'067fd139-cf37-4672-9127-2b7d07bac060','2622bbfd-4611-4881-b113-5da00e9a3e4d','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','CinderNVMeOF','83f4159f-2bca-440c-8126-7a2142941df6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(920,'d201dcbf-e053-4aef-99e8-e5af16cbcac1','6d6050e3-1417-48aa-824b-07d8addfae4f','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaComputeCommon-6hnjl6xcuefk','6d6050e3-1417-48aa-824b-07d8addfae4f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(921,'7d024695-fdb6-43c1-ab8c-2e13d1f49257','6d6050e3-1417-48aa-824b-07d8addfae4f','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaComputeCommon-6hnjl6xcuefk','6d6050e3-1417-48aa-824b-07d8addfae4f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(922,'b07fd0d1-5432-4308-9985-38b5371468a2','9772f262-f152-49ed-b7e6-30873e193250','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye-RoleParametersValue-rccqkt5gucww','state changed','OS::Heat::Value',NULL,661),(923,'6ced6763-8b6b-4da1-b5a0-7a7eab870fe4','9772f262-f152-49ed-b7e6-30873e193250','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye-RoleParametersValue-rccqkt5gucww','state changed','OS::Heat::Value',NULL,661),(924,'4bf344cc-fe1d-44f8-899d-9c09844f5e0e','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderCommon-k2xlnphdkm66','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(925,'a832edc6-46a1-45cf-91f7-ac02d07bc423','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','4','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv','state changed','OS::TripleO::Services::CinderApi',NULL,664),(926,'4a905a06-1019-4d1b-92ce-fdee10549b17','2d1eafbc-5242-4579-8cbe-db76edb2143c','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderCommon-k2xlnphdkm66','2d1eafbc-5242-4579-8cbe-db76edb2143c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(927,'30cc44c1-00ea-4482-addc-0bf5c831c890','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','NovaBase','26df407a-1278-4321-acf0-54ffb4fa44f9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,630),(928,'c27bab5c-ac2a-4066-a959-639e42173131','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv','6863ec1b-ef8c-404d-94e8-60edf0df97d5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(929,'fe2b77bb-398f-4dc6-a9d1-46e6700d89a1','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','7','59a69d9c-f605-4084-8a0b-70749ca36c80','state changed','OS::TripleO::Services::Kernel',NULL,634),(930,'785e4774-e804-4e14-92f6-6ce5ad7cf65e','9772f262-f152-49ed-b7e6-30873e193250','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','CeilometerServiceBase','550b666c-cf46-4773-86c0-a8ef45130ebd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,641),(931,'c3ee2bd7-a9ab-4373-b57d-6b15768fd162','9772f262-f152-49ed-b7e6-30873e193250','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerAgentCentralBase-p4psykgqs3ye','9772f262-f152-49ed-b7e6-30873e193250','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(932,'9b651aa7-39f6-431d-841e-a6d4017bd812','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','6','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y','state changed','OS::TripleO::Services::CinderScheduler',NULL,667),(933,'5b347d18-03c3-4da8-b825-db41434d37c8','255b2652-a788-4de0-b3c0-176cad10d45d','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ObjectStorageIpListMap-sfx7zeywgslu-NetIpMapValue-ztszohmv5qy6','state changed','OS::Heat::Value',NULL,668),(934,'ad424104-5ced-41d2-b61b-dceab915ed3d','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-MySQLClient-ur2lcbpxdfuo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(935,'f14a21c8-6234-4b7f-8555-1bd1967fa543','255b2652-a788-4de0-b3c0-176cad10d45d','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ObjectStorageIpListMap-sfx7zeywgslu-NetIpMapValue-ztszohmv5qy6','state changed','OS::Heat::Value',NULL,668),(936,'0b18fa5d-203b-4609-b19c-f3dca3dff9a6','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y','9460b4b7-515e-4776-a5e8-6f6054fae830','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(937,'b22513f5-b0e3-4d6d-9526-6b3d06644206','2d1eafbc-5242-4579-8cbe-db76edb2143c','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderCommon-k2xlnphdkm66-ContainersCommon-5z3ijho26bab','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(938,'2d9119c6-dd0d-4577-85a0-6ed1109d0683','255b2652-a788-4de0-b3c0-176cad10d45d','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageIpListMap-sfx7zeywgslu','255b2652-a788-4de0-b3c0-176cad10d45d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(939,'c4f2227d-3a63-48c3-8db1-d69bbdd8c085','c7eca1f7-3186-40bf-97e4-118c2484b59e','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderCommon-k2xlnphdkm66-ContainersCommon-5z3ijho26bab','c7eca1f7-3186-40bf-97e4-118c2484b59e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(940,'2b1e574c-22d6-4352-b6cc-84cb2d3ab32e','c7eca1f7-3186-40bf-97e4-118c2484b59e','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderCommon-k2xlnphdkm66-ContainersCommon-5z3ijho26bab','c7eca1f7-3186-40bf-97e4-118c2484b59e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(941,'45aa320a-e193-4b2d-a447-6129d6a8f240','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','CinderBackupBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,671),(942,'7ca50709-800b-4a15-8ad4-4dc99e745fa6','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','11','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui','state changed','OS::TripleO::Services::NovaLibvirt',NULL,672),(943,'b65261d5-dd07-4452-a633-2c5b14a00436','62c64a1f-9b9d-4336-891b-a72e254290e6','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-MySQLClient-ur2lcbpxdfuo','62c64a1f-9b9d-4336-891b-a72e254290e6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(944,'6b192c13-3352-461d-8609-466b4cb36918','62c64a1f-9b9d-4336-891b-a72e254290e6','2026-06-13 07:57:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-MySQLClient-ur2lcbpxdfuo','62c64a1f-9b9d-4336-891b-a72e254290e6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(945,'e5b8f2e4-e75b-4b3a-b95f-3268608f91e5','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm','d057787c-75ca-442f-b924-1c97460854a4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(946,'af245612-b5f5-4152-96f3-1fa1384f088b','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui','4f0331e8-f204-4623-b1ea-dfdbebe864bb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(947,'5c159125-4cb7-49a6-8772-77a8554c3222','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderBase-qe3cli7rjsix','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,673),(948,'f50ac22d-9ed8-42b8-a85c-4d396f4bfc4f','2622bbfd-4611-4881-b113-5da00e9a3e4d','2026-06-13 07:57:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderCommon-mhsouy7wxvf7-ContainersCommon-2dgixuii3rt4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(949,'41a650ae-9a27-4a87-8591-472af0217c70','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-ContainersCommon-j7kejqkvvvgb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(950,'4173a691-ed05-4c0b-b6c4-dc84d735ec25','940636e0-949a-4891-b553-fccdcd491409','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderCommon-mhsouy7wxvf7-ContainersCommon-2dgixuii3rt4','940636e0-949a-4891-b553-fccdcd491409','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(951,'711a6b40-7d09-44bd-8d39-0c93a41972a9','f9ec53be-5ffa-4972-a5b4-35aea93afa31','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerServiceBase-eza2ytsvcfud','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,674),(952,'4bffd46e-d14f-47b3-a9b4-3af2517b3481','0173bf51-9dd8-4129-be1d-1a733b491796','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderBase-qe3cli7rjsix','0173bf51-9dd8-4129-be1d-1a733b491796','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(953,'f943fa19-edff-4d4c-a929-c1b7cc212d0a','331f97aa-cbeb-41a7-9503-7b9151ba972d','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-NetworkerIpListMap-yvfwwoijojle-NetIpMapValue-r6kogidvyw35','state changed','OS::Heat::Value',NULL,675),(954,'8c4730b7-13b1-45c1-908f-0aa1fd8761bb','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-RoleParametersValue-tkz3zjehqbo3','state changed','OS::Heat::Value',NULL,676),(955,'d6407bf1-048e-44c4-b70b-18a9c9e0f66d','6c0cb3b2-6e34-408a-b30a-bd0fd22b28d4','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerServiceBase-eza2ytsvcfud','6c0cb3b2-6e34-408a-b30a-bd0fd22b28d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(956,'612c0cf8-2a11-4eb5-a44a-c22fe86f561e','91482750-c269-4a5d-8ff6-b6d45022133b','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-ContainersCommon-j7kejqkvvvgb','91482750-c269-4a5d-8ff6-b6d45022133b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(957,'085cb22e-b7ad-4ee7-9ca7-42dbb9765ad1','0173bf51-9dd8-4129-be1d-1a733b491796','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderBase-qe3cli7rjsix','0173bf51-9dd8-4129-be1d-1a733b491796','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(958,'df7877db-5609-48ca-942f-930cc3f8c7a7','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-RoleParametersValue-tkz3zjehqbo3','state changed','OS::Heat::Value',NULL,676),(959,'a05aa422-cc1d-48b2-8438-2020ab1e3ee0','6c0cb3b2-6e34-408a-b30a-bd0fd22b28d4','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb-CeilometerServiceBase-eza2ytsvcfud','6c0cb3b2-6e34-408a-b30a-bd0fd22b28d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(960,'887b40c9-344b-403a-a298-f89d3f46e459','940636e0-949a-4891-b553-fccdcd491409','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderCommon-mhsouy7wxvf7-ContainersCommon-2dgixuii3rt4','940636e0-949a-4891-b553-fccdcd491409','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(961,'50ce47c5-0b0d-460e-89eb-0d56c92105ee','c93b5334-abed-4f24-96da-6cf219ae8570','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','SshdBase','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s-SshdBase-smfjuijc5aty','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,677),(962,'6b7289ec-b90d-448d-bda3-39e26d014211','331f97aa-cbeb-41a7-9503-7b9151ba972d','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-NetworkerIpListMap-yvfwwoijojle-NetIpMapValue-r6kogidvyw35','state changed','OS::Heat::Value',NULL,675),(963,'78be0e79-145d-499d-a664-1a4c968ea92d','f9ec53be-5ffa-4972-a5b4-35aea93afa31','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','CeilometerAgentCentralBase','9772f262-f152-49ed-b7e6-30873e193250','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,608),(964,'2e798326-dc4a-4b42-a5d2-4e63a0e711c9','91482750-c269-4a5d-8ff6-b6d45022133b','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-ContainersCommon-j7kejqkvvvgb','91482750-c269-4a5d-8ff6-b6d45022133b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(965,'7a75c867-fdb6-4915-a0e9-0f6c2a8b85db','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaLogging-ehwlagleuryn','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,679),(966,'8b26906a-62e6-4a08-a250-02a33ef93085','331f97aa-cbeb-41a7-9503-7b9151ba972d','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-NetworkerIpListMap-yvfwwoijojle','331f97aa-cbeb-41a7-9503-7b9151ba972d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(967,'dd2ee092-c54e-4daf-ab53-bded649b7767','53f2c8f5-f48f-4454-8e5d-0e66eb53d891','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s-SshdBase-smfjuijc5aty','53f2c8f5-f48f-4454-8e5d-0e66eb53d891','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(968,'71737ac8-9d19-4718-887c-48c7594ba521','53f2c8f5-f48f-4454-8e5d-0e66eb53d891','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s-SshdBase-smfjuijc5aty','53f2c8f5-f48f-4454-8e5d-0e66eb53d891','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(969,'cafcb6c2-1512-4e07-97d0-22f3b5ac4960','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','NovaComputeCommon','6d6050e3-1417-48aa-824b-07d8addfae4f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,658),(970,'e399bb9b-d1fd-4d53-b82b-ad5cb921ee39','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-MySQLClient-m52anukgolnw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(971,'b4b64d78-2b1b-4ac9-80d5-6165aeaf27b1','a317cf8a-0c0e-48f3-805e-daeb47e5481e','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaLogging-ehwlagleuryn','a317cf8a-0c0e-48f3-805e-daeb47e5481e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(972,'2969d879-6d6f-4309-bb95-bfd3e756175b','c93b5334-abed-4f24-96da-6cf219ae8570','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','SshdBase','53f2c8f5-f48f-4454-8e5d-0e66eb53d891','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,677),(973,'3ae523fd-4dae-47e9-a8e4-f02f55037658','c93b5334-abed-4f24-96da-6cf219ae8570','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-13-fkg5vrifuw5s','c93b5334-abed-4f24-96da-6cf219ae8570','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(974,'ab11f8ac-c0cd-4f00-bf61-73a6a5516684','fa76d3bb-6326-4e51-961b-46ce9c3c2600','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-MySQLClient-m52anukgolnw','fa76d3bb-6326-4e51-961b-46ce9c3c2600','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(975,'b135992e-2acd-4ab0-9b81-0184233b535e','fa76d3bb-6326-4e51-961b-46ce9c3c2600','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-MySQLClient-m52anukgolnw','fa76d3bb-6326-4e51-961b-46ce9c3c2600','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(976,'e207f102-654c-4d2b-a79d-a2364ef157fd','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-ContainersCommon-cpksvy5623vx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(977,'65b2d8a6-471f-4557-9c04-d588c72f07fa','5f05c929-7c61-4bb7-aca1-7294c339ea67','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-ContainersCommon-cpksvy5623vx','5f05c929-7c61-4bb7-aca1-7294c339ea67','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(978,'f24329a0-0d34-46fd-8fb4-48f344a525d4','a317cf8a-0c0e-48f3-805e-daeb47e5481e','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaLogging-ehwlagleuryn-InitLogContainerName-cq5sxccduq54','state changed','OS::Heat::Value',NULL,680),(979,'1aa5e7e9-44e1-4522-a720-45ce3569630c','a317cf8a-0c0e-48f3-805e-daeb47e5481e','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaLogging-ehwlagleuryn-InitLogContainerName-cq5sxccduq54','state changed','OS::Heat::Value',NULL,680),(980,'a78a9828-3b5c-4a53-95d1-4ece57e75824','5f05c929-7c61-4bb7-aca1-7294c339ea67','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-ContainersCommon-cpksvy5623vx','5f05c929-7c61-4bb7-aca1-7294c339ea67','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(981,'4485a7cd-5723-482f-8779-51b3479ed6f1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','ObjectStorageIpListMap','255b2652-a788-4de0-b3c0-176cad10d45d','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,636),(982,'f9aeb821-7955-4b25-9a35-f4b2cb016196','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderCommon-pjpsqaqcmasg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(983,'16e4a7bb-0643-4938-8cc6-51d5eb55cf32','2d1eafbc-5242-4579-8cbe-db76edb2143c','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderCommon-k2xlnphdkm66-CinderNVMeOF-rqshckoqpei2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(984,'5265bfa0-0aeb-4108-9d91-9527e67e2cda','2f789de0-51e1-45d1-b016-c984cc2d5e17','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderCommon-pjpsqaqcmasg','2f789de0-51e1-45d1-b016-c984cc2d5e17','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(985,'ccf2323f-3784-4593-9bb5-0abcc1f0e2a5','2d1eafbc-5242-4579-8cbe-db76edb2143c','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','ContainersCommon','c7eca1f7-3186-40bf-97e4-118c2484b59e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(986,'89722c6c-a6fe-4cf8-b43f-6e3590ca244a','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-ContainersCommon-3bb6oh6t2mmm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(987,'d49eb03a-fc45-4f9c-a445-1dce59faab27','c123c7a9-1bc1-454a-804a-74e55660ea05','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderCommon-k2xlnphdkm66-CinderNVMeOF-rqshckoqpei2','c123c7a9-1bc1-454a-804a-74e55660ea05','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(988,'05c457bb-234b-4ec2-baa5-80c5d3d34108','2f789de0-51e1-45d1-b016-c984cc2d5e17','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderCommon-pjpsqaqcmasg-ContainersCommon-et5n4lqgp4er','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(989,'fad9386f-9b3f-4f59-bd09-f42a96aff960','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','MySQLClient','62c64a1f-9b9d-4336-891b-a72e254290e6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(990,'5b84b70b-01fc-4d14-b681-708684c2c753','c123c7a9-1bc1-454a-804a-74e55660ea05','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderCommon-k2xlnphdkm66-CinderNVMeOF-rqshckoqpei2','c123c7a9-1bc1-454a-804a-74e55660ea05','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(991,'304fd60d-d5a7-494b-877e-79bf316f90d6','d0cd7518-aa29-43de-aeaa-670b3a84c4be','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-ContainersCommon-3bb6oh6t2mmm','d0cd7518-aa29-43de-aeaa-670b3a84c4be','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(992,'d8848171-746c-479d-a5d0-e5d2a2d4b1fa','d0cd7518-aa29-43de-aeaa-670b3a84c4be','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-ContainersCommon-3bb6oh6t2mmm','d0cd7518-aa29-43de-aeaa-670b3a84c4be','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(993,'a0c07777-bc55-4ed8-ac74-779f5d0a256d','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-MySQLClient-pp7bsfqc4yti','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(994,'71ce8136-d52c-4566-af6c-bc40e5c7c296','29f3d338-6a3b-4817-9af4-898b4681edda','2026-06-13 07:57:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderCommon-pjpsqaqcmasg-ContainersCommon-et5n4lqgp4er','29f3d338-6a3b-4817-9af4-898b4681edda','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(995,'ff258bcc-ad34-41ea-8857-5c9e6185a790','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','13','c93b5334-abed-4f24-96da-6cf219ae8570','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,623),(996,'4ccf2664-cd0a-4042-aa90-b8f1e6061355','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:08',NULL,'CREATE','COMPLETE','NetworkerIpListMap','331f97aa-cbeb-41a7-9503-7b9151ba972d','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,654),(997,'1b13339b-b38d-49f6-bc12-026dc2567413','29f3d338-6a3b-4817-9af4-898b4681edda','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderCommon-pjpsqaqcmasg-ContainersCommon-et5n4lqgp4er','29f3d338-6a3b-4817-9af4-898b4681edda','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(998,'fdc32017-6edc-4362-b1e5-75221f2cf229','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaBase-pgqnqvtd45bi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,681),(999,'22cd7d21-b586-4f5b-a354-57c5b11bca2c','2f789de0-51e1-45d1-b016-c984cc2d5e17','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','ContainersCommon','29f3d338-6a3b-4817-9af4-898b4681edda','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1000,'2f45ffcd-a83c-44cd-a4e4-bf8414a4e8aa','6161155d-9196-44ad-aba6-c3a8fb83a48b','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-MySQLClient-pp7bsfqc4yti','6161155d-9196-44ad-aba6-c3a8fb83a48b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1001,'93383dc9-7d3e-42db-98cb-d58c45e854a6','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-CinderNVMeOF-6tj5wd6xrdu7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1002,'367338e1-1562-4bbc-b84e-ef8fd31cd9f6','6161155d-9196-44ad-aba6-c3a8fb83a48b','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-MySQLClient-pp7bsfqc4yti','6161155d-9196-44ad-aba6-c3a8fb83a48b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1003,'480eef5b-6cd5-4732-8a6e-e18d05d788dc','72125eb5-af60-4e53-9bb4-c4fa4d2c822d','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaBase-pgqnqvtd45bi','72125eb5-af60-4e53-9bb4-c4fa4d2c822d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1004,'3f22a2d8-57ce-49e9-8704-9264623674a3','2622bbfd-4611-4881-b113-5da00e9a3e4d','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','ContainersCommon','940636e0-949a-4891-b553-fccdcd491409','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1005,'9ef9e352-78ae-4dce-aab8-361dc562b3b3','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','CinderBase','0173bf51-9dd8-4129-be1d-1a733b491796','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,673),(1006,'e976709c-dcd5-4c00-b269-37f8f4ed6248','f9ec53be-5ffa-4972-a5b4-35aea93afa31','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','CeilometerServiceBase','6c0cb3b2-6e34-408a-b30a-bd0fd22b28d4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,674),(1007,'b3e160f5-2d73-4ae0-a95b-b52fe9e14f10','1c01737c-1a75-4412-97ef-7f954f75efeb','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-CinderNVMeOF-6tj5wd6xrdu7','1c01737c-1a75-4412-97ef-7f954f75efeb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1008,'f95ff83c-1ba9-4fb6-a91d-801bb64a399c','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','ContainersCommon','91482750-c269-4a5d-8ff6-b6d45022133b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1009,'887ab29a-85d8-4c31-8841-9f4c23a9ca81','2622bbfd-4611-4881-b113-5da00e9a3e4d','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderCommon-mhsouy7wxvf7','2622bbfd-4611-4881-b113-5da00e9a3e4d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1010,'c855b387-fbaa-450e-ae1c-f0824a62a629','f9ec53be-5ffa-4972-a5b4-35aea93afa31','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-4-6pfaiyopjemb','f9ec53be-5ffa-4972-a5b4-35aea93afa31','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1011,'2507e381-7177-434c-9897-81c7d61799e0','1c01737c-1a75-4412-97ef-7f954f75efeb','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-CinderNVMeOF-6tj5wd6xrdu7','1c01737c-1a75-4412-97ef-7f954f75efeb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1012,'808c6946-b220-42e1-8ecf-20e8884605d5','72125eb5-af60-4e53-9bb4-c4fa4d2c822d','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaBase-pgqnqvtd45bi-RoleParametersValue-j75j554zeysp','state changed','OS::Heat::Value',NULL,686),(1013,'1b72d68a-370b-44ad-bff3-e0de724c3ca8','72125eb5-af60-4e53-9bb4-c4fa4d2c822d','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaBase-pgqnqvtd45bi-RoleParametersValue-j75j554zeysp','state changed','OS::Heat::Value',NULL,686),(1014,'775c0c85-b97d-4da2-a2a5-b646e91d8ef4','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderCommon-5ncvaih3uezv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1015,'84068a60-16c6-43e8-a8f0-12015c4c6651','72125eb5-af60-4e53-9bb4-c4fa4d2c822d','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaBase-pgqnqvtd45bi','72125eb5-af60-4e53-9bb4-c4fa4d2c822d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1016,'2b75a47c-3789-4eb6-9ab0-6844330071f7','267070e3-fd2c-45c1-901b-9cb984d2226a','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderCommon-5ncvaih3uezv','267070e3-fd2c-45c1-901b-9cb984d2226a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1017,'ccb80744-5852-43d6-b014-2a7a0df15a3b','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','17','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-17-pbyq4odb5nme','state changed','OS::TripleO::Services::Snmp',NULL,687),(1018,'39258d92-659e-4790-82ee-f399aa846a34','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','MySQLClient','fa76d3bb-6326-4e51-961b-46ce9c3c2600','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1019,'202a3060-7eb1-48ec-af72-12a8eab40ccd','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-RoleParametersValue-oqoa54dqerlu','state changed','OS::Heat::Value',NULL,688),(1020,'ea627785-80a1-4604-bdc8-8a07c5d368c6','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-RoleParametersValue-oqoa54dqerlu','state changed','OS::Heat::Value',NULL,688),(1021,'63bb9827-4b4a-4c8b-b5e2-15ed6b4515a0','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','ContainersCommon','5f05c929-7c61-4bb7-aca1-7294c339ea67','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1022,'5ca5fa91-e1c1-4bee-9660-bda497f9b693','a317cf8a-0c0e-48f3-805e-daeb47e5481e','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaLogging-ehwlagleuryn-RoleParametersValue-dtq352viumei','state changed','OS::Heat::Value',NULL,689),(1023,'b874a22a-3b05-479f-916c-35e17bfcc4b5','a317cf8a-0c0e-48f3-805e-daeb47e5481e','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaLogging-ehwlagleuryn-RoleParametersValue-dtq352viumei','state changed','OS::Heat::Value',NULL,689),(1024,'f53dfd13-5fac-45db-8e7f-6032e3c00f11','a317cf8a-0c0e-48f3-805e-daeb47e5481e','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-NovaLogging-ehwlagleuryn','a317cf8a-0c0e-48f3-805e-daeb47e5481e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1025,'482d1526-94f2-45fc-ab36-ad9d624777ee','267070e3-fd2c-45c1-901b-9cb984d2226a','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderCommon-5ncvaih3uezv-CinderNVMeOF-iyck4t2nysou','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1026,'2c2521cb-afde-4b64-b5db-41d5e422177e','1f71d64a-553a-4d91-bab3-8b49398bcab3','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-17-pbyq4odb5nme','1f71d64a-553a-4d91-bab3-8b49398bcab3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1027,'e5ce4105-1b7a-4679-b8b5-dd9f5d0d17c6','1f71d64a-553a-4d91-bab3-8b49398bcab3','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-17-pbyq4odb5nme','1f71d64a-553a-4d91-bab3-8b49398bcab3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1028,'62b1c2e5-d367-492e-8878-0bd1758636b4','b6d42f07-8df0-45b9-b717-516800150d6c','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderCommon-5ncvaih3uezv-CinderNVMeOF-iyck4t2nysou','b6d42f07-8df0-45b9-b717-516800150d6c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1029,'02b94a29-41e2-4639-823b-2219e4eef463','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','17','1f71d64a-553a-4d91-bab3-8b49398bcab3','state changed','OS::TripleO::Services::Snmp',NULL,687),(1030,'f0a27d8e-abef-4786-9162-04ed6f84eb99','b6d42f07-8df0-45b9-b717-516800150d6c','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderCommon-5ncvaih3uezv-CinderNVMeOF-iyck4t2nysou','b6d42f07-8df0-45b9-b717-516800150d6c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1031,'70efe9f6-17ba-4c31-bbc0-9642ae16cc8a','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','21','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-21-y3sl7wqskwwc','state changed','OS::TripleO::Services::TripleoFirewall',NULL,691),(1032,'3a561ae3-7d21-4aad-9c81-c169d8ca033a','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-RoleParametersValue-kt3iyxd6njt5','state changed','OS::Heat::Value',NULL,692),(1033,'bcc44184-77b3-414c-9ce9-7ede934a499a','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-RoleParametersValue-kt3iyxd6njt5','state changed','OS::Heat::Value',NULL,692),(1034,'cedb6740-b7e8-430e-87d2-10bebc203c75','48538d19-2567-47f1-8c27-4fbf49ac9607','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-21-y3sl7wqskwwc','48538d19-2567-47f1-8c27-4fbf49ac9607','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1035,'6aa10392-ae47-4b46-bdce-fd1dcca7f153','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-RoleParametersValue-ksvoqeta5qap','state changed','OS::Heat::Value',NULL,693),(1036,'9e712515-f481-47f0-8ea4-cb5966efa69f','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-RoleParametersValue-ksvoqeta5qap','state changed','OS::Heat::Value',NULL,693),(1037,'7b35d970-d81c-46ec-9640-243574336312','48538d19-2567-47f1-8c27-4fbf49ac9607','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-21-y3sl7wqskwwc-RoleParametersValue-iw5ofnxwe3eh','state changed','OS::Heat::Value',NULL,694),(1038,'75a83ba8-ef7d-42e0-a403-94b00a61356a','2f789de0-51e1-45d1-b016-c984cc2d5e17','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderCommon-pjpsqaqcmasg-CinderNVMeOF-r4vjn2s6auo2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1039,'1602c405-5529-4722-a59e-e6d8dc96cd05','48538d19-2567-47f1-8c27-4fbf49ac9607','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-21-y3sl7wqskwwc-RoleParametersValue-iw5ofnxwe3eh','state changed','OS::Heat::Value',NULL,694),(1040,'62619d39-21f3-4cfc-8aa4-52dce4f9d385','2d1eafbc-5242-4579-8cbe-db76edb2143c','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','CinderNVMeOF','c123c7a9-1bc1-454a-804a-74e55660ea05','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1041,'b0a7e775-780c-4e52-9b83-fab3d626461f','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','4','f9ec53be-5ffa-4972-a5b4-35aea93afa31','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,601),(1042,'8e085c99-6e52-4860-b540-23e57c3d6997','48538d19-2567-47f1-8c27-4fbf49ac9607','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-21-y3sl7wqskwwc','48538d19-2567-47f1-8c27-4fbf49ac9607','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1043,'e6375d0e-03b1-4eb0-af44-c8d2a3cb4de8','2d1eafbc-5242-4579-8cbe-db76edb2143c','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderCommon-k2xlnphdkm66','2d1eafbc-5242-4579-8cbe-db76edb2143c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1044,'00a27a74-c9aa-4467-af57-f8e2358a0497','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','CinderCommon','2622bbfd-4611-4881-b113-5da00e9a3e4d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1045,'0af56b08-ef4a-479a-8097-cb9146742ee3','7a2ab782-ed1e-4a39-af34-9a84ff4591a8','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderCommon-pjpsqaqcmasg-CinderNVMeOF-r4vjn2s6auo2','7a2ab782-ed1e-4a39-af34-9a84ff4591a8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1046,'ffe12f05-e1f0-4ae6-ae6c-2bb15161f58c','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-RoleParametersValue-blkuqrzjhwwp','state changed','OS::Heat::Value',NULL,695),(1047,'8ddd8c7e-3c1b-4c10-9ee2-46737b5e5d3c','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:09',NULL,'CREATE','COMPLETE','ContainersCommon','d0cd7518-aa29-43de-aeaa-670b3a84c4be','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1048,'efe092f4-00fb-43e5-a8e4-40ef88690974','7a2ab782-ed1e-4a39-af34-9a84ff4591a8','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderCommon-pjpsqaqcmasg-CinderNVMeOF-r4vjn2s6auo2','7a2ab782-ed1e-4a39-af34-9a84ff4591a8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1049,'b80b15ed-efce-4d25-b841-599facb356b1','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-RoleParametersValue-blkuqrzjhwwp','state changed','OS::Heat::Value',NULL,695),(1050,'e2ba43f9-5fbb-452b-bd31-8814f700e76b','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-ContainersCommon-fmocxzn44rkj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1051,'aabba363-a67f-4435-a6e2-d830e1ac0611','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','NovaLibvirtLogging','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaLibvirtLogging-csavd5icah5x','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1052,'584781a3-f68f-409a-b952-c746421be688','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','MySQLClient','6161155d-9196-44ad-aba6-c3a8fb83a48b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1053,'49d633ab-7963-48b3-8a0f-f9032bec2f18','54ecc52f-fff2-4c59-a2aa-147c2d29ce8b','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-ContainersCommon-fmocxzn44rkj','54ecc52f-fff2-4c59-a2aa-147c2d29ce8b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1054,'108127de-c297-45b8-8cbc-8823effe0f3c','54ecc52f-fff2-4c59-a2aa-147c2d29ce8b','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc-ContainersCommon-fmocxzn44rkj','54ecc52f-fff2-4c59-a2aa-147c2d29ce8b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1055,'6c77ce66-dfdf-407f-ac08-4ad178edd15e','c4fe8e80-1e48-485b-9e81-f8959ad70773','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaLibvirtLogging-csavd5icah5x','c4fe8e80-1e48-485b-9e81-f8959ad70773','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1056,'a9b69e9c-6caf-4a4c-ab44-c9a2ee2de5db','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','CinderNVMeOF','1c01737c-1a75-4412-97ef-7f954f75efeb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1057,'4eb7c1ec-ab34-4ac6-8b4b-e94f1ae7f1ad','c4fe8e80-1e48-485b-9e81-f8959ad70773','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaLibvirtLogging-csavd5icah5x','c4fe8e80-1e48-485b-9e81-f8959ad70773','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1058,'27d0e8fc-65dc-4a8d-bfbd-7adba3713b37','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','NovaBase','72125eb5-af60-4e53-9bb4-c4fa4d2c822d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,681),(1059,'be6acc10-33c1-429c-8864-c7a36c42298e','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','8','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-8-2bwlihnng66l','state changed','OS::TripleO::Services::MetricsQdr',NULL,701),(1060,'b679c866-5a8c-4748-9bd7-3682eeacd446','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','NovaLogging','a317cf8a-0c0e-48f3-805e-daeb47e5481e','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,679),(1061,'f74b6b85-37cf-4337-9801-4df068c7b3fc','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-ContainersCommon-yonqcuzapc7l','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1062,'cb2b9e61-7d3b-4213-bd2e-fded4fcf73c8','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,702),(1063,'67169b43-7d2f-4b79-8c95-0187c2fcbbec','77719ee2-f6b4-4394-ad98-8767019fc248','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-8-2bwlihnng66l','77719ee2-f6b4-4394-ad98-8767019fc248','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1064,'ee30534d-9295-4007-bdf0-6f650c15f711','a9800d97-b528-4c33-8da4-bc48f61c2780','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-ContainersCommon-yonqcuzapc7l','a9800d97-b528-4c33-8da4-bc48f61c2780','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1065,'b2e02a3f-dabb-45e7-9070-6d363722e433','a9800d97-b528-4c33-8da4-bc48f61c2780','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-ContainersCommon-yonqcuzapc7l','a9800d97-b528-4c33-8da4-bc48f61c2780','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1066,'f938510e-8744-48e1-86c8-3e68f7d49ca8','267070e3-fd2c-45c1-901b-9cb984d2226a','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderCommon-5ncvaih3uezv-ContainersCommon-jqdaa6v6g76s','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1067,'e3266093-e264-4ca2-8fac-cd39c0bc077b','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','CinderCommon','2d1eafbc-5242-4579-8cbe-db76edb2143c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1068,'a4a5e110-9cb5-4c71-8c4b-cd77d7f2e240','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l','584058a3-fafe-40e8-b089-bd58f3869d88','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1069,'ad86e431-85cb-46e5-99e7-346c45315b83','77719ee2-f6b4-4394-ad98-8767019fc248','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-8-2bwlihnng66l-RoleParametersValue-qxfwp6rcwoty','state changed','OS::Heat::Value',NULL,703),(1070,'1a4a91f5-cacd-499a-925f-707a7b997b69','77719ee2-f6b4-4394-ad98-8767019fc248','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-8-2bwlihnng66l-RoleParametersValue-qxfwp6rcwoty','state changed','OS::Heat::Value',NULL,703),(1071,'8a8fae6a-25b0-4866-b525-2cadc62bd166','7e3bf47a-a693-440e-9ef6-987d9515c3b4','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderCommon-5ncvaih3uezv-ContainersCommon-jqdaa6v6g76s','7e3bf47a-a693-440e-9ef6-987d9515c3b4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1072,'8efa9ae6-d239-42be-aca7-2d58d0a4c5d6','7e3bf47a-a693-440e-9ef6-987d9515c3b4','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderCommon-5ncvaih3uezv-ContainersCommon-jqdaa6v6g76s','7e3bf47a-a693-440e-9ef6-987d9515c3b4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1073,'463db669-538a-4d43-8214-e29a32c7428d','267070e3-fd2c-45c1-901b-9cb984d2226a','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','CinderNVMeOF','b6d42f07-8df0-45b9-b717-516800150d6c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1074,'2e34d94d-f4b1-4690-bd13-1e7d12c1bfcb','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderBase-yekkuohix44i','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,704),(1075,'3475242e-969e-496c-870b-c6b18838956b','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-ContainersCommon-wujdllrsygqi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1076,'837965df-b19a-40a8-8e07-943ac1c21cc8','85c56f27-5caa-4648-8f1e-141155c0b6ed','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderBase-yekkuohix44i','85c56f27-5caa-4648-8f1e-141155c0b6ed','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1077,'c799a6f7-3046-4b52-a0f0-cbda28349b3d','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','21','48538d19-2567-47f1-8c27-4fbf49ac9607','state changed','OS::TripleO::Services::TripleoFirewall',NULL,691),(1078,'87fa3459-90bf-4314-a828-a22dd0910a38','85c56f27-5caa-4648-8f1e-141155c0b6ed','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderBase-yekkuohix44i','85c56f27-5caa-4648-8f1e-141155c0b6ed','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1079,'8fc91bcd-bc62-4d33-a800-00689dca5431','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-MySQLClient-bmhmizczr3vb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1080,'b7baef43-58c9-4add-ae36-9a6b09e6d7f9','07cf4a95-ac3b-4a91-accf-653ff90ab829','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-ContainersCommon-wujdllrsygqi','07cf4a95-ac3b-4a91-accf-653ff90ab829','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1081,'74b78101-18df-43cd-bfce-a5c7f3fc8499','07cf4a95-ac3b-4a91-accf-653ff90ab829','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-ContainersCommon-wujdllrsygqi','07cf4a95-ac3b-4a91-accf-653ff90ab829','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1082,'6683acd9-5bce-4279-9270-61b7bb213159','2714b87f-782f-4475-8268-450ab280c541','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-MySQLClient-bmhmizczr3vb','2714b87f-782f-4475-8268-450ab280c541','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1083,'25ad43b4-8351-4da1-bd80-1f53fbc520a3','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','ContainersCommon','07cf4a95-ac3b-4a91-accf-653ff90ab829','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1084,'faa6ef93-d1b5-492c-b621-e96ed3c0f2e2','2714b87f-782f-4475-8268-450ab280c541','2026-06-13 07:57:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-MySQLClient-bmhmizczr3vb','2714b87f-782f-4475-8268-450ab280c541','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1085,'3b21930b-8ca2-4dac-9ea9-a7ba405aaae3','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:10',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderCommon-aajsqpris5dg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1086,'c3e9221d-99b4-482e-919b-958a4ed50197','2f789de0-51e1-45d1-b016-c984cc2d5e17','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','CinderNVMeOF','7a2ab782-ed1e-4a39-af34-9a84ff4591a8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1087,'b6ea1026-5bf9-46e3-b527-7b9dff523bb4','ab506063-523a-420c-bbf2-ce2eb0360c58','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderCommon-aajsqpris5dg','ab506063-523a-420c-bbf2-ce2eb0360c58','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1088,'7586596f-e0d8-4c38-bff5-3c953935250f','2f789de0-51e1-45d1-b016-c984cc2d5e17','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderCommon-pjpsqaqcmasg','2f789de0-51e1-45d1-b016-c984cc2d5e17','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1089,'bbff133c-2381-4730-b67b-9905386c29f3','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-RoleParametersValue-zqtozw73rfmq','state changed','OS::Heat::Value',NULL,707),(1090,'8607a475-21b7-4565-bdb0-ae3687a140d0','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-RoleParametersValue-zqtozw73rfmq','state changed','OS::Heat::Value',NULL,707),(1091,'b0a9c015-5200-4628-999b-c39ada5b61eb','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','25','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,708),(1092,'e6d166c4-d5e2-4453-8790-3b1119cec54e','ab506063-523a-420c-bbf2-ce2eb0360c58','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderCommon-aajsqpris5dg-ContainersCommon-grva4jq4ecrm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1093,'02febf5c-e8ec-45db-b149-d6e57d4bc85b','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','ContainersCommon','54ecc52f-fff2-4c59-a2aa-147c2d29ce8b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1094,'9cc006e1-5446-44f2-99fc-a21777c61dd0','49815be1-ca41-4366-9fd2-ffdc688493b8','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf','49815be1-ca41-4366-9fd2-ffdc688493b8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1095,'4b6c1540-4c58-45cb-9e95-d10091d17157','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','NovaLibvirtLogging','c4fe8e80-1e48-485b-9e81-f8959ad70773','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1096,'0ecdb6b4-a96d-4d93-b952-67ae4186db20','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-10-cj4wwgzt4cwc','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1097,'2d24d4cb-324a-4c6a-9989-e3bd3acb8ce2','6f51554c-c598-465f-9927-837c55d75c43','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderCommon-aajsqpris5dg-ContainersCommon-grva4jq4ecrm','6f51554c-c598-465f-9927-837c55d75c43','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1098,'29fd467c-3e3d-42a6-be5b-201aadf966cf','6f51554c-c598-465f-9927-837c55d75c43','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderCommon-aajsqpris5dg-ContainersCommon-grva4jq4ecrm','6f51554c-c598-465f-9927-837c55d75c43','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1099,'35a5224e-2c9c-4101-af69-3f937b9396fe','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-RoleParametersValue-l36aenfvqp74','state changed','OS::Heat::Value',NULL,709),(1100,'105f1423-fca9-44a9-92fb-f3020d6f84aa','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-RoleParametersValue-l36aenfvqp74','state changed','OS::Heat::Value',NULL,709),(1101,'680ad24e-444e-435e-a20e-87893a1f406e','ab506063-523a-420c-bbf2-ce2eb0360c58','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','ContainersCommon','6f51554c-c598-465f-9927-837c55d75c43','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1102,'4c07ffef-26c5-4165-aa26-55d35c636d7f','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-MySQLClient-btpfpvfhkrdi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1103,'f3608c15-7e7b-4d9b-acd0-8793657e1677','c3b5787c-90e6-4f8f-afb9-3b81a41bfffe','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-MySQLClient-btpfpvfhkrdi','c3b5787c-90e6-4f8f-afb9-3b81a41bfffe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1104,'88628821-5bf7-48b6-a214-878006eeeb1e','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','ContainersCommon','a9800d97-b528-4c33-8da4-bc48f61c2780','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1105,'c345714c-e1f3-49cc-ad36-a6bf3246a980','c3b5787c-90e6-4f8f-afb9-3b81a41bfffe','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-MySQLClient-btpfpvfhkrdi','c3b5787c-90e6-4f8f-afb9-3b81a41bfffe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1106,'820b4ad0-6154-4693-b3e5-efe426e8b39d','49815be1-ca41-4366-9fd2-ffdc688493b8','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-NeutronBase-onrgh22uk37m','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,710),(1107,'30e3e5fa-4986-4852-b5f9-fd6b91b2b617','77719ee2-f6b4-4394-ad98-8767019fc248','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-8-2bwlihnng66l-ContainersCommon-33fpaddqveun','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1108,'31719ee1-390d-492c-9be5-05a5c4f32d9e','5933717f-d0b0-4d28-96c0-2892b1e14324','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-NeutronBase-onrgh22uk37m','5933717f-d0b0-4d28-96c0-2892b1e14324','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1109,'644e1e8a-c73a-4d4e-b156-8c5186b8fd94','267070e3-fd2c-45c1-901b-9cb984d2226a','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','ContainersCommon','7e3bf47a-a693-440e-9ef6-987d9515c3b4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1110,'cc643594-f0ea-4bd4-b7fe-1aeabdce0e0f','751908d7-054b-4c85-b7bc-d4e13654457a','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-8-2bwlihnng66l-ContainersCommon-33fpaddqveun','751908d7-054b-4c85-b7bc-d4e13654457a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1111,'ecfe45a5-dca3-4319-85c5-e6fb344c9d9c','5933717f-d0b0-4d28-96c0-2892b1e14324','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-NeutronBase-onrgh22uk37m','5933717f-d0b0-4d28-96c0-2892b1e14324','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1112,'19967e47-d844-408f-ba5d-ef48fa410778','267070e3-fd2c-45c1-901b-9cb984d2226a','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderCommon-5ncvaih3uezv','267070e3-fd2c-45c1-901b-9cb984d2226a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1113,'55064bbe-fe1b-4d6d-bd0e-24d23a454411','751908d7-054b-4c85-b7bc-d4e13654457a','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-8-2bwlihnng66l-ContainersCommon-33fpaddqveun','751908d7-054b-4c85-b7bc-d4e13654457a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1114,'de425bf3-5806-4f3f-9bcf-91a8d93ad6bd','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-ContainersCommon-abdenkneo3ds','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1115,'02e6036b-9373-4b06-8314-6798d61280a0','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderBase-i6zlnf2ylf2s','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,711),(1116,'4338ce93-1253-4073-b4bb-9b9e48d70a3e','d2822cbe-478a-4822-8bcd-cf0ca8348652','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-ContainersCommon-abdenkneo3ds','d2822cbe-478a-4822-8bcd-cf0ca8348652','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1117,'0fe8fa02-f35b-49ac-8238-99aced378c9c','d2822cbe-478a-4822-8bcd-cf0ca8348652','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-ContainersCommon-abdenkneo3ds','d2822cbe-478a-4822-8bcd-cf0ca8348652','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1118,'45affba3-c2b5-4379-ad10-8fd44f8e6d3d','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','CinderCommon','2f789de0-51e1-45d1-b016-c984cc2d5e17','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1119,'9e93793a-a21e-43b0-9091-7c09fa072f6f','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','10','99cfc7f7-d2d5-4f81-85f7-b4e5319fa328','state changed','OS::TripleO::Services::NovaCompute',NULL,618),(1120,'e189d54b-bb49-460c-a88d-091185d43734','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','CinderBase','85c56f27-5caa-4648-8f1e-141155c0b6ed','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,704),(1121,'f52aac69-86e5-4ee1-a731-40d83f41902e','5ec895a1-d48e-4d9c-b76a-bcb5bbfb5958','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderBase-i6zlnf2ylf2s','5ec895a1-d48e-4d9c-b76a-bcb5bbfb5958','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1122,'6df05b0c-238b-4d6a-bdb9-cfa53c6b975e','5ec895a1-d48e-4d9c-b76a-bcb5bbfb5958','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-CinderBase-i6zlnf2ylf2s','5ec895a1-d48e-4d9c-b76a-bcb5bbfb5958','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1123,'e3e50e49-3640-4769-ad16-b397536b792b','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:11',NULL,'CREATE','COMPLETE','MySQLClient','2714b87f-782f-4475-8268-450ab280c541','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1124,'e5cdc29c-aa4e-4518-8572-a5da46ad9f59','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:11',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-ContainersCommon-mubwsfoz4o7k','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1125,'459d1747-c05a-43ed-a1ad-70d0ea8a7c2b','ec83c00e-7fdc-4e72-a807-7cbe44044ca9','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-ContainersCommon-mubwsfoz4o7k','ec83c00e-7fdc-4e72-a807-7cbe44044ca9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1126,'78caceb6-afd3-44f6-a31b-706e07a0f198','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','NovaLibvirtCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaLibvirtCommon-eivnypfsrigu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(1127,'182a6e94-1c17-45b5-ae2f-0d7844392cca','ec83c00e-7fdc-4e72-a807-7cbe44044ca9','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-ContainersCommon-mubwsfoz4o7k','ec83c00e-7fdc-4e72-a807-7cbe44044ca9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1128,'08889d37-f03e-4afd-8d41-0302acf50ab7','ab506063-523a-420c-bbf2-ce2eb0360c58','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderCommon-aajsqpris5dg-CinderNVMeOF-asen2fqxkb7n','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1129,'edc20bfe-0ddb-46b2-a531-5d61da123e77','ce505687-a6b1-448d-8625-af796b90e569','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaLibvirtCommon-eivnypfsrigu','ce505687-a6b1-448d-8625-af796b90e569','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1130,'eae6037a-b43a-4e99-855b-76993b08d36d','39d6d70d-4f63-4a34-8af6-a42ade544b66','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderCommon-aajsqpris5dg-CinderNVMeOF-asen2fqxkb7n','39d6d70d-4f63-4a34-8af6-a42ade544b66','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1131,'5269f2cf-649a-4ac1-94e3-0548760bbff5','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderBase-mhzv4l73yyzi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,718),(1132,'630803b5-80e6-4c01-8814-2fb90ff8189a','ce505687-a6b1-448d-8625-af796b90e569','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaLibvirtCommon-eivnypfsrigu-RoleParametersValue-r6ytyn6x7zfy','state changed','OS::Heat::Value',NULL,719),(1133,'bfa311e3-8be8-495b-883f-e2cc4c826d68','39d6d70d-4f63-4a34-8af6-a42ade544b66','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderCommon-aajsqpris5dg-CinderNVMeOF-asen2fqxkb7n','39d6d70d-4f63-4a34-8af6-a42ade544b66','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1134,'f6779770-f01c-48d9-bf9b-245faf69646f','ce505687-a6b1-448d-8625-af796b90e569','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaLibvirtCommon-eivnypfsrigu-RoleParametersValue-r6ytyn6x7zfy','state changed','OS::Heat::Value',NULL,719),(1135,'a449e1a2-d5e2-4d57-a4b4-763b68ea6228','ce505687-a6b1-448d-8625-af796b90e569','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui-NovaLibvirtCommon-eivnypfsrigu','ce505687-a6b1-448d-8625-af796b90e569','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1136,'56f3f934-dca1-4adf-80bc-f4645f4a7dee','a8056cc2-137d-47e9-8a67-3a8737b10f55','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderBase-mhzv4l73yyzi','a8056cc2-137d-47e9-8a67-3a8737b10f55','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1137,'d1e7c3ff-c9e9-4736-94d2-29169e5af59d','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','CinderCommon','267070e3-fd2c-45c1-901b-9cb984d2226a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1138,'100acf63-4d3b-4f9c-bd36-791c39a43a65','a8056cc2-137d-47e9-8a67-3a8737b10f55','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm-CinderBase-mhzv4l73yyzi','a8056cc2-137d-47e9-8a67-3a8737b10f55','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1139,'1f83a03f-fa44-4ec0-a1f0-07e8b8cb1127','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','MySQLClient','c3b5787c-90e6-4f8f-afb9-3b81a41bfffe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1140,'9d05e3ef-e73d-4392-bbf1-b29a9702da31','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','14','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-14-lm44kjfwvcar','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,723),(1141,'8e4d9b41-e532-4521-aa62-c7a8ec190de7','49815be1-ca41-4366-9fd2-ffdc688493b8','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-RoleParametersValue-yrmfq7qbucen','state changed','OS::Heat::Value',NULL,724),(1142,'ffc4aad6-7936-455c-9055-fff0329f63c3','49815be1-ca41-4366-9fd2-ffdc688493b8','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','NeutronBase','5933717f-d0b0-4d28-96c0-2892b1e14324','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,710),(1143,'249df6c3-580b-468c-8995-ca792fe983bb','b85552d0-d3ba-4de9-8d85-fa9ad7a3e2c6','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-14-lm44kjfwvcar','b85552d0-d3ba-4de9-8d85-fa9ad7a3e2c6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1144,'1e8e02a7-54ab-4dee-8da2-da26121c1b84','49815be1-ca41-4366-9fd2-ffdc688493b8','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-RoleParametersValue-yrmfq7qbucen','state changed','OS::Heat::Value',NULL,724),(1145,'82d81856-3ae3-442f-b23c-324666325247','77719ee2-f6b4-4394-ad98-8767019fc248','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','ContainersCommon','751908d7-054b-4c85-b7bc-d4e13654457a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1146,'67d4a734-2cf6-4a9b-ab5a-54dd392bca06','77719ee2-f6b4-4394-ad98-8767019fc248','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-8-2bwlihnng66l','77719ee2-f6b4-4394-ad98-8767019fc248','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1147,'95e6de75-71f6-4f85-83e8-5a3f4629ef26','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderCommon-h7k2zlsbptjx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1148,'fe25b73c-c2ca-4727-9303-427e5a81a0c2','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-ApacheServiceBase-txoickxa5bx3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,725),(1149,'f119e863-ef70-4005-9570-31db9bde0528','b85552d0-d3ba-4de9-8d85-fa9ad7a3e2c6','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-14-lm44kjfwvcar-RoleParametersValue-jv3ny2aawaaf','state changed','OS::Heat::Value',NULL,726),(1150,'e29a63c0-b6d1-43fe-ad3e-739f19867074','a9a626ce-17cf-42e0-9805-67622760b80f','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderCommon-h7k2zlsbptjx','a9a626ce-17cf-42e0-9805-67622760b80f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1151,'d5d25511-9560-48f8-bf1c-4696f37ed479','b85552d0-d3ba-4de9-8d85-fa9ad7a3e2c6','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-14-lm44kjfwvcar-RoleParametersValue-jv3ny2aawaaf','state changed','OS::Heat::Value',NULL,726),(1152,'fbe39a0d-1949-4728-89d0-b71f6a3f9cbb','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','ContainersCommon','d2822cbe-478a-4822-8bcd-cf0ca8348652','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1153,'e03dbf6f-8dcf-45a7-bcda-c801b283eaf8','100ad260-260e-456c-9fa3-a71debf9ac93','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-ApacheServiceBase-txoickxa5bx3','100ad260-260e-456c-9fa3-a71debf9ac93','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1154,'a22a8efe-341f-43af-8966-b4ef535ad1b1','100ad260-260e-456c-9fa3-a71debf9ac93','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-ApacheServiceBase-txoickxa5bx3-ApacheNetworks-urth7e7xzcjy','state changed','OS::Heat::Value',NULL,727),(1155,'99692d6e-cf00-4e4c-9c3c-dd5f43d5027e','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','CinderBase','5ec895a1-d48e-4d9c-b76a-bcb5bbfb5958','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,711),(1156,'56f55678-b830-417d-929d-39e742ac7ff9','100ad260-260e-456c-9fa3-a71debf9ac93','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-ApacheServiceBase-txoickxa5bx3-ApacheNetworks-urth7e7xzcjy','state changed','OS::Heat::Value',NULL,727),(1157,'7282720f-9635-4bb8-9017-2d9658bfbcf3','100ad260-260e-456c-9fa3-a71debf9ac93','2026-06-13 07:57:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv-ApacheServiceBase-txoickxa5bx3','100ad260-260e-456c-9fa3-a71debf9ac93','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1158,'6daf05ae-283e-4101-915d-a22f83952721','a9a626ce-17cf-42e0-9805-67622760b80f','2026-06-13 07:57:12',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderCommon-h7k2zlsbptjx-CinderNVMeOF-kunoqxmps2lo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1159,'6c2a8bc9-fb0b-48a7-af18-19c46d16ca2f','a0e71c8c-a1f6-4b6d-bed8-4a530de3b2f9','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderCommon-h7k2zlsbptjx-CinderNVMeOF-kunoqxmps2lo','a0e71c8c-a1f6-4b6d-bed8-4a530de3b2f9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1160,'5745c0e1-9563-4c60-85e2-f644a0bd1bad','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','ContainersCommon','ec83c00e-7fdc-4e72-a807-7cbe44044ca9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1161,'00603fac-937e-4c36-acc6-e004f9c40ec5','a0e71c8c-a1f6-4b6d-bed8-4a530de3b2f9','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderCommon-h7k2zlsbptjx-CinderNVMeOF-kunoqxmps2lo','a0e71c8c-a1f6-4b6d-bed8-4a530de3b2f9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1162,'63fd6957-488e-4ce2-906e-ae86d4214a1e','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','NovaLibvirtCommon','ce505687-a6b1-448d-8625-af796b90e569','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(1163,'f6e9e13c-b84a-42c2-ba3d-b47eb3aa2a01','4f0331e8-f204-4623-b1ea-dfdbebe864bb','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-11-jzlwuss4tiui','4f0331e8-f204-4623-b1ea-dfdbebe864bb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1164,'f78705c3-ab21-4b00-99a3-5fa03a126882','ab506063-523a-420c-bbf2-ce2eb0360c58','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','CinderNVMeOF','39d6d70d-4f63-4a34-8af6-a42ade544b66','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1165,'e2012260-6b46-4ea6-b297-e984afd73995','ab506063-523a-420c-bbf2-ce2eb0360c58','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y-CinderCommon-aajsqpris5dg','ab506063-523a-420c-bbf2-ce2eb0360c58','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1166,'e567cd0b-5ebd-43a0-b0ac-2ce83aac99e4','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','8','77719ee2-f6b4-4394-ad98-8767019fc248','state changed','OS::TripleO::Services::MetricsQdr',NULL,701),(1167,'4ecc611b-d532-447e-8a30-c1db675207b1','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','CinderBase','a8056cc2-137d-47e9-8a67-3a8737b10f55','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,718),(1168,'c3d2f508-682e-4f88-bcee-75bf8f64815e','d057787c-75ca-442f-b924-1c97460854a4','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y-CinderBackupBase-wun2wkbouavm','d057787c-75ca-442f-b924-1c97460854a4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1169,'2817ea2e-568c-47c8-a5e4-b3a1ae9e3649','49815be1-ca41-4366-9fd2-ffdc688493b8','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-ContainersCommon-aochzcm37azp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1170,'c351d04c-db74-454d-8d1f-a45988dd3431','7c6d729d-d8b4-45b2-b2e9-3a1b54295b4b','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-ContainersCommon-aochzcm37azp','7c6d729d-d8b4-45b2-b2e9-3a1b54295b4b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1171,'765f2160-9480-490d-bf21-8b5c635bb607','7c6d729d-d8b4-45b2-b2e9-3a1b54295b4b','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-ContainersCommon-aochzcm37azp','7c6d729d-d8b4-45b2-b2e9-3a1b54295b4b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1172,'593f46cc-abb4-499f-8fd5-ed7d627b1d1c','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','12','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-12-wjri62lhcbdp','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,731),(1173,'33d3fd72-13de-46a4-8212-7bbca81ae610','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-MySQLClient-2edag63ljija','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1174,'9318038d-1973-43bf-bb4d-559608b915cf','b85552d0-d3ba-4de9-8d85-fa9ad7a3e2c6','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-14-lm44kjfwvcar-ContainersCommon-sslne2xprtzu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1175,'50904c56-bfa4-478c-8d99-e2fb583d38bc','78b0d31c-9a9f-4849-8648-8ae8ce4f9f3c','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-12-wjri62lhcbdp','78b0d31c-9a9f-4849-8648-8ae8ce4f9f3c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1176,'edda3740-f102-41f1-adfe-a37772bd5db5','2507bd60-7ce0-475a-9062-0098bc70d6e2','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-MySQLClient-2edag63ljija','2507bd60-7ce0-475a-9062-0098bc70d6e2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1177,'a3b38acd-c3c4-46d2-9ee0-d168798b9707','2507bd60-7ce0-475a-9062-0098bc70d6e2','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-MySQLClient-2edag63ljija','2507bd60-7ce0-475a-9062-0098bc70d6e2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1178,'5a2032e0-b55b-4a17-8a37-7435fc352c89','f3a22dfd-7375-423a-9575-2cbd73933063','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-14-lm44kjfwvcar-ContainersCommon-sslne2xprtzu','f3a22dfd-7375-423a-9575-2cbd73933063','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1179,'3a1e9151-db30-4378-8b4d-276cf2bc859f','f3a22dfd-7375-423a-9575-2cbd73933063','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-14-lm44kjfwvcar-ContainersCommon-sslne2xprtzu','f3a22dfd-7375-423a-9575-2cbd73933063','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1180,'70c27ba9-a59e-4833-90c5-dfd197f449bb','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','ApacheServiceBase','100ad260-260e-456c-9fa3-a71debf9ac93','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,725),(1181,'f9e0bd72-9942-4df6-9216-1c476f11181f','78b0d31c-9a9f-4849-8648-8ae8ce4f9f3c','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-12-wjri62lhcbdp-RoleParametersValue-tszotrmixvie','state changed','OS::Heat::Value',NULL,732),(1182,'49310ac0-d11a-4c2f-ad86-cb34fa3d0f08','6863ec1b-ef8c-404d-94e8-60edf0df97d5','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-4-aq2fqde6cbqv','6863ec1b-ef8c-404d-94e8-60edf0df97d5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1183,'c57a1a1f-e825-460e-9a7e-c90c2b0c4b82','78b0d31c-9a9f-4849-8648-8ae8ce4f9f3c','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-12-wjri62lhcbdp-RoleParametersValue-tszotrmixvie','state changed','OS::Heat::Value',NULL,732),(1184,'ac7aaf6f-eaab-45fa-a3c5-9a6646898dae','78b0d31c-9a9f-4849-8648-8ae8ce4f9f3c','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-12-wjri62lhcbdp','78b0d31c-9a9f-4849-8648-8ae8ce4f9f3c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1185,'9ac51315-8fd7-43ec-bc04-1dea8ecfe0fd','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','11','4f0331e8-f204-4623-b1ea-dfdbebe864bb','state changed','OS::TripleO::Services::NovaLibvirt',NULL,672),(1186,'5dafa80e-5cc8-4a00-b183-b1ca74b72e37','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:13',NULL,'CREATE','COMPLETE','CinderBackupBase','d057787c-75ca-442f-b924-1c97460854a4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,671),(1187,'7191388a-94e4-4337-bcc2-85396fc21087','a9a626ce-17cf-42e0-9805-67622760b80f','2026-06-13 07:57:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderCommon-h7k2zlsbptjx-ContainersCommon-22qemqcwrnbb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1188,'756370de-9a73-40c8-b61f-d5753f26dedd','5e499b71-33b0-4411-8974-230c16fa3fd6','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-5-uwp42hiiau3y','5e499b71-33b0-4411-8974-230c16fa3fd6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1189,'a2f24198-1d2c-4f7a-8587-60193d2e132f','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','CinderCommon','ab506063-523a-420c-bbf2-ce2eb0360c58','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1190,'13d024e6-8efc-4606-b25e-c96a5e9869d0','ea30a966-461d-4cf5-a9cb-9de8e08f63d4','2026-06-13 07:57:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderCommon-h7k2zlsbptjx-ContainersCommon-22qemqcwrnbb','ea30a966-461d-4cf5-a9cb-9de8e08f63d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1191,'2406f254-9e74-4b44-9bf2-4990e8dc23e3','a9a626ce-17cf-42e0-9805-67622760b80f','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','CinderNVMeOF','a0e71c8c-a1f6-4b6d-bed8-4a530de3b2f9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1192,'e0e5f81e-b3d9-46b7-b304-4f0582b0ecdf','ea30a966-461d-4cf5-a9cb-9de8e08f63d4','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderCommon-h7k2zlsbptjx-ContainersCommon-22qemqcwrnbb','ea30a966-461d-4cf5-a9cb-9de8e08f63d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1193,'57c68e05-dd43-4e86-be8e-937ae380875d','9460b4b7-515e-4776-a5e8-6f6054fae830','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-6-rhact7um337y','9460b4b7-515e-4776-a5e8-6f6054fae830','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1194,'6aedac06-8321-4ee7-8db2-007f54ef6ae0','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:14',NULL,'CREATE','IN_PROGRESS','15','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-15-dssmgdhemh3u','state changed','OS::TripleO::Services::Podman',NULL,741),(1195,'ad7d36c9-f12e-4943-a3c7-aefde71ee88c','ac8a6972-36ea-42b6-9dd4-90fac23fbe9d','2026-06-13 07:57:14',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-15-dssmgdhemh3u','ac8a6972-36ea-42b6-9dd4-90fac23fbe9d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1196,'d0927d1b-ae22-4efb-9a54-45c45b25d26b','ac8a6972-36ea-42b6-9dd4-90fac23fbe9d','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-15-dssmgdhemh3u','ac8a6972-36ea-42b6-9dd4-90fac23fbe9d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1197,'8c851259-f93c-4bf0-a067-065dedec9e9d','49815be1-ca41-4366-9fd2-ffdc688493b8','2026-06-13 07:57:14',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-NeutronLogging-6qmiha6t4u6n','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,742),(1198,'5b5e4bd5-f3f2-4f3d-b6d9-5efc646d900a','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','4','6863ec1b-ef8c-404d-94e8-60edf0df97d5','state changed','OS::TripleO::Services::CinderApi',NULL,664),(1199,'434e4af0-4a13-4905-8dfa-58bc2175b7b3','49815be1-ca41-4366-9fd2-ffdc688493b8','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','ContainersCommon','7c6d729d-d8b4-45b2-b2e9-3a1b54295b4b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1200,'76121909-b200-4c37-bc80-0a966565f664','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','5','5e499b71-33b0-4411-8974-230c16fa3fd6','state changed','OS::TripleO::Services::CinderBackup',NULL,640),(1201,'cd4ee034-e298-464d-91f1-bd7e03d9a443','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-RoleParametersValue-d4smdg3nlnsc','state changed','OS::Heat::Value',NULL,744),(1202,'c422354d-721a-432a-a20b-15d1109bcdb8','c8e7ed68-e96d-427d-a17e-9920db0c3feb','2026-06-13 07:57:14',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-NeutronLogging-6qmiha6t4u6n','c8e7ed68-e96d-427d-a17e-9920db0c3feb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1203,'3cdc61a0-3c96-4f7e-8125-81a0488a82a2','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-RoleParametersValue-d4smdg3nlnsc','state changed','OS::Heat::Value',NULL,744),(1204,'9867303f-6ed6-45ba-ae3c-5e478d2e73aa','c8e7ed68-e96d-427d-a17e-9920db0c3feb','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf-NeutronLogging-6qmiha6t4u6n','c8e7ed68-e96d-427d-a17e-9920db0c3feb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1205,'fa947f1a-4a1a-48bd-ab70-073cd341095d','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','MySQLClient','2507bd60-7ce0-475a-9062-0098bc70d6e2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1206,'34199217-2454-4560-a798-7b3a80da99ce','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','12','78b0d31c-9a9f-4849-8648-8ae8ce4f9f3c','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,731),(1207,'2d5bbf3b-b385-4518-ac54-806cdf930528','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','6','9460b4b7-515e-4776-a5e8-6f6054fae830','state changed','OS::TripleO::Services::CinderScheduler',NULL,667),(1208,'0402ce43-f7ec-4870-b0f7-399c7d9eba17','b85552d0-d3ba-4de9-8d85-fa9ad7a3e2c6','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','ContainersCommon','f3a22dfd-7375-423a-9575-2cbd73933063','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1209,'86ca615f-7c31-4a5f-bcb2-8492b1c7355b','b85552d0-d3ba-4de9-8d85-fa9ad7a3e2c6','2026-06-13 07:57:14',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-14-lm44kjfwvcar','b85552d0-d3ba-4de9-8d85-fa9ad7a3e2c6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1210,'f679fa37-9449-4d03-91f2-e677704c6933','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','16','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-16-ixrirjppi6sm','state changed','OS::TripleO::Services::Rsyslog',NULL,757),(1211,'d82ab37e-9689-4746-901d-a2c411ac26ee','a9a626ce-17cf-42e0-9805-67622760b80f','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','ContainersCommon','ea30a966-461d-4cf5-a9cb-9de8e08f63d4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1212,'c38188a6-479e-482b-bf88-40d29ef60249','d9eeb44a-c56b-4ed8-8f24-1868f2a3e4fe','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-16-ixrirjppi6sm','d9eeb44a-c56b-4ed8-8f24-1868f2a3e4fe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1213,'e69428f2-4b91-424f-b8c7-1a9b270d148d','a9a626ce-17cf-42e0-9805-67622760b80f','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l-CinderCommon-h7k2zlsbptjx','a9a626ce-17cf-42e0-9805-67622760b80f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1214,'1dbc97e3-e7ca-4f54-ac3c-bbaab7cb5d05','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','8','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb','state changed','OS::TripleO::Services::Clustercheck',NULL,763),(1215,'37296f8d-5486-4c64-9a49-5e63edb0ec4c','d9eeb44a-c56b-4ed8-8f24-1868f2a3e4fe','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-16-ixrirjppi6sm-RoleParametersValue-wn6r7ltlrlfq','state changed','OS::Heat::Value',NULL,764),(1216,'0234af70-b496-42e3-a928-fc13bbe76af4','5938a572-c684-4833-93a1-7d84924d0a60','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb','5938a572-c684-4833-93a1-7d84924d0a60','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1217,'144f941a-b007-4bd0-880b-d7f111e12548','d9eeb44a-c56b-4ed8-8f24-1868f2a3e4fe','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-16-ixrirjppi6sm-RoleParametersValue-wn6r7ltlrlfq','state changed','OS::Heat::Value',NULL,764),(1218,'74879e94-21d7-43b7-b966-a32b5a0d9597','5938a572-c684-4833-93a1-7d84924d0a60','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-ContainersCommon-265kmkywcxkk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1219,'a8b2c828-7e80-465e-bfe5-5d88d47fb986','37f6cfc5-210e-4316-aa5b-8c28e0eba141','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-ContainersCommon-265kmkywcxkk','37f6cfc5-210e-4316-aa5b-8c28e0eba141','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1220,'d3d2c31d-4378-44e1-a3ac-fa610c19092a','37f6cfc5-210e-4316-aa5b-8c28e0eba141','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-ContainersCommon-265kmkywcxkk','37f6cfc5-210e-4316-aa5b-8c28e0eba141','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1221,'36e06f54-6320-4a9a-bf25-941b4579db3f','5938a572-c684-4833-93a1-7d84924d0a60','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','ContainersCommon','37f6cfc5-210e-4316-aa5b-8c28e0eba141','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1222,'61e4895b-fbb0-43ea-9bd7-52c3b53c3aa4','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','15','ac8a6972-36ea-42b6-9dd4-90fac23fbe9d','state changed','OS::TripleO::Services::Podman',NULL,741),(1223,'aa8e9110-85f1-4755-becb-2a670cf765e0','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','10','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-10-lsacif63fo7w','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,773),(1224,'86094a3f-a315-49f1-b6cb-b98c78936e0a','1255561f-7376-4d6b-ad34-9596184ab09d','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-10-lsacif63fo7w','1255561f-7376-4d6b-ad34-9596184ab09d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1225,'3cb908c2-5272-418e-8a92-55733cf1e3f1','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','14','b85552d0-d3ba-4de9-8d85-fa9ad7a3e2c6','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,723),(1226,'adb5f59a-465f-4f92-b730-b354ccf2a4fe','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','19','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-19-auiw6pdxsqz6','state changed','OS::TripleO::Services::Timesync',NULL,779),(1227,'9cd9fea6-0c1c-47ed-a6ed-0c9b33feb247','1255561f-7376-4d6b-ad34-9596184ab09d','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-10-lsacif63fo7w','1255561f-7376-4d6b-ad34-9596184ab09d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1228,'09954dd3-69d6-4473-9121-3a1f892d0dc1','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','10','1255561f-7376-4d6b-ad34-9596184ab09d','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,773),(1229,'d5f0abbc-ea42-4956-ab4b-9ac6d6d69b19','49815be1-ca41-4366-9fd2-ffdc688493b8','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','NeutronLogging','c8e7ed68-e96d-427d-a17e-9920db0c3feb','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,742),(1230,'55c89e07-6130-4514-8359-51372b483003','c6c4ad3a-d408-45d2-bd24-6fca3f5d4b66','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-19-auiw6pdxsqz6','c6c4ad3a-d408-45d2-bd24-6fca3f5d4b66','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1231,'d7f96d58-2d6d-47b3-af32-aae681ebf99c','49815be1-ca41-4366-9fd2-ffdc688493b8','2026-06-13 07:57:15',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-25-selj3jkn4jqf','49815be1-ca41-4366-9fd2-ffdc688493b8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1232,'b8049f5a-f11e-4c91-bbf8-d15ca9b637e3','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:15',NULL,'CREATE','IN_PROGRESS','18','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-18-wzo7sx2ylmwf','state changed','OS::TripleO::Services::Sshd',NULL,787),(1233,'72b9f99a-15c0-41b8-abfe-ecf8fae1b0a2','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','14','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf','state changed','OS::TripleO::Services::HeatApi',NULL,788),(1234,'05108c03-aee6-4350-8262-9cc74c1838f1','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','CinderCommon','a9a626ce-17cf-42e0-9805-67622760b80f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1235,'369c53c3-5ff1-449c-abba-99d140e2f3bd','c6c4ad3a-d408-45d2-bd24-6fca3f5d4b66','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-19-auiw6pdxsqz6','c6c4ad3a-d408-45d2-bd24-6fca3f5d4b66','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1236,'ea5ec177-0d3b-4d8d-a9db-34f07ffbf789','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','9','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-9-jsupnm6bqijn','state changed','OS::TripleO::Services::Collectd',NULL,789),(1237,'5943c417-0f95-4a4b-ad57-b0343d925c92','584058a3-fafe-40e8-b089-bd58f3869d88','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf-CinderBase-6bzrev3z7c4l','584058a3-fafe-40e8-b089-bd58f3869d88','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1238,'c3a42835-4a8d-41dd-82c8-035f5d17a61c','5b098c56-d4d0-4416-90fb-ca2064eb385a','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-18-wzo7sx2ylmwf','5b098c56-d4d0-4416-90fb-ca2064eb385a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1239,'61607285-4a49-4c1a-b923-d5563d3c7ebe','5b098c56-d4d0-4416-90fb-ca2064eb385a','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-18-wzo7sx2ylmwf','5b098c56-d4d0-4416-90fb-ca2064eb385a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1240,'66c98987-284b-4b21-a5d1-134d3f1507bb','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1241,'58c0a566-d8eb-4599-a533-dffdd6974a16','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','18','5b098c56-d4d0-4416-90fb-ca2064eb385a','state changed','OS::TripleO::Services::Sshd',NULL,787),(1242,'1886e2a9-b5be-48ac-8924-9c4cb127e0e7','a15fcfc5-3f85-45b7-b696-2fca51e86bef','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-9-jsupnm6bqijn','a15fcfc5-3f85-45b7-b696-2fca51e86bef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1243,'45c9a8f0-8f02-4565-b181-879cc7ca15cf','d9eeb44a-c56b-4ed8-8f24-1868f2a3e4fe','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-16-ixrirjppi6sm-ContainersCommon-dcwi2sus2xt6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1244,'40be9341-a08c-434a-8705-7bc8a965d1c4','06c7cb6b-96af-4763-a31d-d47f33025cf8','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-16-ixrirjppi6sm-ContainersCommon-dcwi2sus2xt6','06c7cb6b-96af-4763-a31d-d47f33025cf8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1245,'85b07729-676f-4a65-90f4-6e9fa25f8aac','a15fcfc5-3f85-45b7-b696-2fca51e86bef','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-9-jsupnm6bqijn-ContainersCommon-or2tayqmgycq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1246,'8482d3b0-651b-4b06-bf90-4f4e0e535af0','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','22','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-22-dhusoirw3ryo','state changed','OS::TripleO::Services::TripleoPackages',NULL,791),(1247,'c52a2116-96bf-420b-b277-818a4b43d5ed','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-ContainersCommon-4h4qncvys3hk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1248,'fd36caa5-186e-4796-b780-1b00072fec78','06c7cb6b-96af-4763-a31d-d47f33025cf8','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-16-ixrirjppi6sm-ContainersCommon-dcwi2sus2xt6','06c7cb6b-96af-4763-a31d-d47f33025cf8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1249,'3f058e31-8576-4392-b469-d2878b839565','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','25','49815be1-ca41-4366-9fd2-ffdc688493b8','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,708),(1250,'c1267c79-4e18-4570-a530-39b8df1d1d69','ba8d1158-edd6-4358-971b-4cf1939d7e6e','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-9-jsupnm6bqijn-ContainersCommon-or2tayqmgycq','ba8d1158-edd6-4358-971b-4cf1939d7e6e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1251,'660e3074-1b68-42ae-9fcf-49d9e8594073','ec2c4c9d-87e2-4ac2-ac8c-5782a5a2a529','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-ContainersCommon-4h4qncvys3hk','ec2c4c9d-87e2-4ac2-ac8c-5782a5a2a529','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1252,'2ddacc9f-90c8-4978-bf1f-aa3e7f2e2615','ba8d1158-edd6-4358-971b-4cf1939d7e6e','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-9-jsupnm6bqijn-ContainersCommon-or2tayqmgycq','ba8d1158-edd6-4358-971b-4cf1939d7e6e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1253,'6736fa3f-5afc-415a-8a9e-dafa88a80be0','a15fcfc5-3f85-45b7-b696-2fca51e86bef','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','ContainersCommon','ba8d1158-edd6-4358-971b-4cf1939d7e6e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1254,'88fbabcd-6f17-4efe-a332-c2d46d80df01','ec2c4c9d-87e2-4ac2-ac8c-5782a5a2a529','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-ContainersCommon-4h4qncvys3hk','ec2c4c9d-87e2-4ac2-ac8c-5782a5a2a529','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1255,'b8e83a74-7569-4ce1-9579-d5d6ec9b4e52','a41040b1-2fae-41a4-98c7-d1754aa391a0','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-22-dhusoirw3ryo','a41040b1-2fae-41a4-98c7-d1754aa391a0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1256,'1aeedf72-342a-48f6-a235-cafa105e1692','5938a572-c684-4833-93a1-7d84924d0a60','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-RoleParametersValue-lltt6qgxkxed','state changed','OS::Heat::Value',NULL,792),(1257,'78429c68-4504-4e93-944b-f98c6dabbc8e','5938a572-c684-4833-93a1-7d84924d0a60','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-RoleParametersValue-lltt6qgxkxed','state changed','OS::Heat::Value',NULL,792),(1258,'ec0ccbee-b4b4-4d0e-9060-587cbfc70122','a41040b1-2fae-41a4-98c7-d1754aa391a0','2026-06-13 07:57:16',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-22-dhusoirw3ryo-RoleParametersValue-vffw57zmkdms','state changed','OS::Heat::Value',NULL,793),(1259,'79d5c194-3f1b-49c3-8004-8e656469b23a','a41040b1-2fae-41a4-98c7-d1754aa391a0','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-22-dhusoirw3ryo-RoleParametersValue-vffw57zmkdms','state changed','OS::Heat::Value',NULL,793),(1260,'afea254f-ccf0-4cf2-b64e-e1cfea7d6688','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','CinderBase','584058a3-fafe-40e8-b089-bd58f3869d88','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,702),(1261,'565964da-820a-4d51-ae6f-fe9d385c7c7c','f43914ad-07b9-4540-9d93-bd897b8f190e','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-7-qgpwlayid5mf','f43914ad-07b9-4540-9d93-bd897b8f190e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1262,'e7521328-c624-43b7-ab56-46519a14a77a','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:16',NULL,'CREATE','COMPLETE','19','c6c4ad3a-d408-45d2-bd24-6fca3f5d4b66','state changed','OS::TripleO::Services::Timesync',NULL,779),(1263,'5b80bc0e-3318-443f-af37-2868c6e6e41e','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:17',NULL,'CREATE','IN_PROGRESS','23','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-23-ugutovpnyvbm','state changed','OS::TripleO::Services::Tuned',NULL,795),(1264,'68c06252-79fa-4beb-b0c7-b8d04eac5e5c','2463de1c-606d-42b1-8188-8cb2d52623d2','2026-06-13 07:57:17',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-23-ugutovpnyvbm','2463de1c-606d-42b1-8188-8cb2d52623d2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1265,'faf91f4e-1644-4d41-9909-cc31131d6045','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','7','f43914ad-07b9-4540-9d93-bd897b8f190e','state changed','OS::TripleO::Services::CinderVolume',NULL,655),(1266,'e96aca1c-4aa7-4e8e-8730-14c30e162dde','d9eeb44a-c56b-4ed8-8f24-1868f2a3e4fe','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','ContainersCommon','06c7cb6b-96af-4763-a31d-d47f33025cf8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1267,'3a9642a4-7897-4ea0-bfaf-edce22170f9c','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:17',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-RoleParametersValue-prgkxdt3cci4','state changed','OS::Heat::Value',NULL,796),(1268,'dd0aaddd-d7e0-4b6e-8a9c-db0b0e12be38','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-RoleParametersValue-prgkxdt3cci4','state changed','OS::Heat::Value',NULL,796),(1269,'2b4578b6-1476-41aa-92e5-53cfce4e0761','a15fcfc5-3f85-45b7-b696-2fca51e86bef','2026-06-13 07:57:17',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-9-jsupnm6bqijn-RoleParametersValue-votrr5dq5bne','state changed','OS::Heat::Value',NULL,797),(1270,'1dfd67c1-6868-4625-b75b-3029a266b7bf','d9eeb44a-c56b-4ed8-8f24-1868f2a3e4fe','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-16-ixrirjppi6sm','d9eeb44a-c56b-4ed8-8f24-1868f2a3e4fe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1271,'600ef546-bff1-4d4f-8889-bf2b0bac15b4','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','ContainersCommon','ec2c4c9d-87e2-4ac2-ac8c-5782a5a2a529','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1272,'6a89b641-5ed2-4fb8-980e-f7e9f441e3ec','a15fcfc5-3f85-45b7-b696-2fca51e86bef','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-9-jsupnm6bqijn-RoleParametersValue-votrr5dq5bne','state changed','OS::Heat::Value',NULL,797),(1273,'25449a76-5bc3-4065-af33-839d6afbdf9b','5938a572-c684-4833-93a1-7d84924d0a60','2026-06-13 07:57:17',NULL,'CREATE','IN_PROGRESS','MysqlPuppetBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,799),(1274,'5f815b14-d6c8-487f-87f4-f28b6c0f2776','a15fcfc5-3f85-45b7-b696-2fca51e86bef','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-9-jsupnm6bqijn','a15fcfc5-3f85-45b7-b696-2fca51e86bef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1275,'16d058a7-6121-46cc-956c-05a47b757f2c','2463de1c-606d-42b1-8188-8cb2d52623d2','2026-06-13 07:57:17',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-23-ugutovpnyvbm-RoleParametersValue-oqh7j7q7hzmz','state changed','OS::Heat::Value',NULL,800),(1276,'1537f4ee-c1c3-4f0c-b1f6-7be43d452ccf','2463de1c-606d-42b1-8188-8cb2d52623d2','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-23-ugutovpnyvbm-RoleParametersValue-oqh7j7q7hzmz','state changed','OS::Heat::Value',NULL,800),(1277,'48aea2fb-5431-40d9-bed7-05ab56fce55e','503db8a0-2583-494c-893b-bc0f39e83aed','2026-06-13 07:57:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok','503db8a0-2583-494c-893b-bc0f39e83aed','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1278,'93f96ea2-2862-4c93-a695-48b2c19ed3ef','2463de1c-606d-42b1-8188-8cb2d52623d2','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-23-ugutovpnyvbm','2463de1c-606d-42b1-8188-8cb2d52623d2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1279,'c69d1ac6-3875-40a0-9c0b-9d34030d3da3','a41040b1-2fae-41a4-98c7-d1754aa391a0','2026-06-13 07:57:17',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-22-dhusoirw3ryo-Podman-4l5qstdip4nw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,803),(1280,'79f5bb95-6206-4cb2-991d-82af40f1e43d','9c69b912-657c-4c6e-99cb-51f8384974d2','2026-06-13 07:57:17',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-22-dhusoirw3ryo-Podman-4l5qstdip4nw','9c69b912-657c-4c6e-99cb-51f8384974d2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1281,'7f357881-1524-4e42-b1cc-c1cc7c1f0f01','9c69b912-657c-4c6e-99cb-51f8384974d2','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-22-dhusoirw3ryo-Podman-4l5qstdip4nw','9c69b912-657c-4c6e-99cb-51f8384974d2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1282,'7badf980-0d6d-4444-bfab-a68f25a79427','503db8a0-2583-494c-893b-bc0f39e83aed','2026-06-13 07:57:17',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok-RoleParametersValue-ylvbzylvhzlo','state changed','OS::Heat::Value',NULL,806),(1283,'255ce7b6-a1a9-4b5f-abba-7182fa136048','503db8a0-2583-494c-893b-bc0f39e83aed','2026-06-13 07:57:17',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok-RoleParametersValue-ylvbzylvhzlo','state changed','OS::Heat::Value',NULL,806),(1284,'11a2b858-8f9a-4701-91a5-543e69618ce3','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','11','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn','state changed','OS::TripleO::Services::GlanceApi',NULL,817),(1285,'5f747803-61a9-4078-b6a5-09e7c257567f','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','23','2463de1c-606d-42b1-8188-8cb2d52623d2','state changed','OS::TripleO::Services::Tuned',NULL,795),(1286,'d82fcee0-f4e6-427d-ab4e-8119115d63fb','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','16','d9eeb44a-c56b-4ed8-8f24-1868f2a3e4fe','state changed','OS::TripleO::Services::Rsyslog',NULL,757),(1287,'a5f1b7fe-7b8e-424f-9e24-e09cf1e6a97b','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','9','a15fcfc5-3f85-45b7-b696-2fca51e86bef','state changed','OS::TripleO::Services::Collectd',NULL,789),(1288,'f1575195-bc4f-414b-b4d8-4894a525851c','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn','8aa2b506-019f-497d-b7b0-a778e81a7ef0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1289,'d7d456f6-ba1c-4f98-87c6-97decb6d6e2a','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-ApacheServiceBase-axe2ocbobqzu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,820),(1290,'9c0f40c9-c6df-43ae-bb35-2b9e2d9c2033','8b74b976-54e8-4b21-a721-98c6d2a61929','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-ApacheServiceBase-axe2ocbobqzu','8b74b976-54e8-4b21-a721-98c6d2a61929','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1291,'a0efa3c1-c67f-45bc-b963-526636ae25c2','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','20','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-20-4aow6sfbjugo','state changed','OS::TripleO::Services::Timezone',NULL,824),(1292,'c4293658-1af7-46b9-8c60-2b5707b23177','8e663ff9-0092-4af8-9720-ca6611e4ea09','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-20-4aow6sfbjugo','8e663ff9-0092-4af8-9720-ca6611e4ea09','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1293,'70fd469a-dc6b-4a71-b86d-d99ebd4cdcee','8e663ff9-0092-4af8-9720-ca6611e4ea09','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-20-4aow6sfbjugo','8e663ff9-0092-4af8-9720-ca6611e4ea09','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1294,'1c62b198-4d3e-4f28-8cdd-0fae6c65a97c','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-CinderNVMeOF-7kj5u76frlob','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1295,'c027ecd8-8597-4a36-ad06-65f12b9408d6','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','13','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm','state changed','OS::TripleO::Services::HAproxy',NULL,826),(1296,'987ce80d-5049-46d8-af5c-d18759abc1a3','a41040b1-2fae-41a4-98c7-d1754aa391a0','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','Podman','9c69b912-657c-4c6e-99cb-51f8384974d2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,803),(1297,'eb1d935b-cdb6-4987-9a29-ce5076b2b113','42a49c31-ee49-4c67-a145-2b41c62ea3ed','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-CinderNVMeOF-7kj5u76frlob','42a49c31-ee49-4c67-a145-2b41c62ea3ed','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1298,'56efc411-f6e9-4bfd-a0cb-2bd21bd7ae24','a41040b1-2fae-41a4-98c7-d1754aa391a0','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-22-dhusoirw3ryo','a41040b1-2fae-41a4-98c7-d1754aa391a0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1299,'7b69660e-e94a-414d-b757-0e00f41ce3b4','503db8a0-2583-494c-893b-bc0f39e83aed','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok-MysqlBase-2k3ao2z7fhhk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,827),(1300,'8b5ec02c-5a42-4f8d-ab65-53d6186672f1','42a49c31-ee49-4c67-a145-2b41c62ea3ed','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-CinderNVMeOF-7kj5u76frlob','42a49c31-ee49-4c67-a145-2b41c62ea3ed','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1301,'510d20b5-1648-4268-8615-e317096cd883','8b74b976-54e8-4b21-a721-98c6d2a61929','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-ApacheServiceBase-axe2ocbobqzu-ApacheNetworks-bwx2iosflkkd','state changed','OS::Heat::Value',NULL,828),(1302,'a2d309ec-cbbe-40ff-ab45-8e7364d25004','8b74b976-54e8-4b21-a721-98c6d2a61929','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-ApacheServiceBase-axe2ocbobqzu-ApacheNetworks-bwx2iosflkkd','state changed','OS::Heat::Value',NULL,828),(1303,'fdfabc18-0241-461d-b4d4-dcaa9ca59f92','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1304,'d0507865-95f8-4498-9e5e-9170bbbecd03','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','CinderNVMeOF','42a49c31-ee49-4c67-a145-2b41c62ea3ed','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1305,'039845a8-0992-4810-9ace-d2b79c67fb81','8b74b976-54e8-4b21-a721-98c6d2a61929','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-ApacheServiceBase-axe2ocbobqzu','8b74b976-54e8-4b21-a721-98c6d2a61929','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1306,'2bcf0a5b-95e5-4cd8-ba32-0ebab2b2e63b','62f61cfe-4958-4bdf-bdb3-f11f13c2413e','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok-MysqlBase-2k3ao2z7fhhk','62f61cfe-4958-4bdf-bdb3-f11f13c2413e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1307,'c0dacc7e-b8f2-418a-8620-c6981ea511b0','62f61cfe-4958-4bdf-bdb3-f11f13c2413e','2026-06-13 07:57:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok-MysqlBase-2k3ao2z7fhhk','62f61cfe-4958-4bdf-bdb3-f11f13c2413e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1308,'2de2f478-e55e-4b73-b647-bbd4a1c0fb39','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:18',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyPublicTLS-nbm5lrsky4po','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,829),(1309,'57f16195-777a-4946-b2cd-74d5c6fd81c7','decdbad1-4563-43fe-b7d2-e5e9e8a409fc','2026-06-13 07:57:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyPublicTLS-nbm5lrsky4po','decdbad1-4563-43fe-b7d2-e5e9e8a409fc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1310,'01fe1b38-ecf8-45d5-9368-b549bab71525','decdbad1-4563-43fe-b7d2-e5e9e8a409fc','2026-06-13 07:57:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyPublicTLS-nbm5lrsky4po','decdbad1-4563-43fe-b7d2-e5e9e8a409fc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1311,'d2a49b07-8e85-4f68-9cf2-9bfc8e308585','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:19',NULL,'CREATE','IN_PROGRESS','HeatApiLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-HeatApiLogging-huvwmq3h6wg7','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1312,'0faaebdc-201e-4d8c-825a-d1809dc0c9d1','1a6c4812-92dc-4dd7-aaf9-70e9f2f0598d','2026-06-13 07:57:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-HeatApiLogging-huvwmq3h6wg7','1a6c4812-92dc-4dd7-aaf9-70e9f2f0598d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1313,'b307ff59-073e-4b27-bb76-5c3efbf34090','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:19',NULL,'CREATE','COMPLETE','22','a41040b1-2fae-41a4-98c7-d1754aa391a0','state changed','OS::TripleO::Services::TripleoPackages',NULL,791),(1314,'cd8c0d43-3ed4-40da-a901-25a4a4bd46c3','1a6c4812-92dc-4dd7-aaf9-70e9f2f0598d','2026-06-13 07:57:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-HeatApiLogging-huvwmq3h6wg7','1a6c4812-92dc-4dd7-aaf9-70e9f2f0598d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1315,'d92dc68e-ab8a-4ce6-94d2-3d364f2c23f4','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:19',NULL,'CREATE','COMPLETE','20','8e663ff9-0092-4af8-9720-ca6611e4ea09','state changed','OS::TripleO::Services::Timezone',NULL,824),(1316,'1e25c4dd-60c2-469f-b9e8-97abe711476e','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:19',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-ContainersCommon-authhm76oxg5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1317,'cf606d5a-478f-44b0-b81b-0981ae4db1ae','bc29e564-eb60-41fe-a4c1-6334a96b0b93','2026-06-13 07:57:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-ContainersCommon-authhm76oxg5','bc29e564-eb60-41fe-a4c1-6334a96b0b93','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1318,'a02d8c52-69d7-44f4-bda5-6f32a1ce503a','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:19',NULL,'CREATE','COMPLETE','ApacheServiceBase','8b74b976-54e8-4b21-a721-98c6d2a61929','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,820),(1319,'d663c46a-7a3b-46ef-b5fc-b43ed11e6d4a','503db8a0-2583-494c-893b-bc0f39e83aed','2026-06-13 07:57:19',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok-ContainersCommon-fwnpj6h67h5b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1320,'a81f0675-12ae-411a-922b-3ea236ef5d7a','bc29e564-eb60-41fe-a4c1-6334a96b0b93','2026-06-13 07:57:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-ContainersCommon-authhm76oxg5','bc29e564-eb60-41fe-a4c1-6334a96b0b93','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1321,'fee06816-0067-45fc-b354-cc97330428fd','78d68a06-60ac-443b-8acc-b9495b6a644d','2026-06-13 07:57:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok-ContainersCommon-fwnpj6h67h5b','78d68a06-60ac-443b-8acc-b9495b6a644d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1322,'c5faf22a-dab8-4cd1-b6b2-ddbaf83992d3','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:19',NULL,'CREATE','IN_PROGRESS','24','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-24-4m6jcdiofdbc','state changed','OS::TripleO::Services::OVNController',NULL,831),(1323,'76fba2fb-a3ed-49f7-9e72-2a37bba87260','503db8a0-2583-494c-893b-bc0f39e83aed','2026-06-13 07:57:19',NULL,'CREATE','COMPLETE','MysqlBase','62f61cfe-4958-4bdf-bdb3-f11f13c2413e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,827),(1324,'42a2b417-a46d-4cdf-8cda-56d9f55db5cc','78d68a06-60ac-443b-8acc-b9495b6a644d','2026-06-13 07:57:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok-ContainersCommon-fwnpj6h67h5b','78d68a06-60ac-443b-8acc-b9495b6a644d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1325,'0b2a64be-43aa-4e81-a901-a5c9b55b68d0','c4cae5a2-34bc-4410-a7f2-2228c949264a','2026-06-13 07:57:19',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-24-4m6jcdiofdbc','c4cae5a2-34bc-4410-a7f2-2228c949264a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1326,'044a10d5-6626-480e-8686-dc976fb16edb','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:19',NULL,'CREATE','IN_PROGRESS','HAProxyBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,832),(1327,'fc058159-2769-4eeb-a558-5cf48d06592b','c4cae5a2-34bc-4410-a7f2-2228c949264a','2026-06-13 07:57:20',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-24-4m6jcdiofdbc-ContainersCommon-tyayu2zzss4y','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1328,'6332bf50-81dd-4af7-b23b-5acf0b643e8b','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:20',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','decdbad1-4563-43fe-b7d2-e5e9e8a409fc','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,829),(1329,'777f3caf-653a-4989-864f-3dba999c3b16','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45','2f549a05-4c46-4ab5-8220-c8a597631246','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1330,'36b57851-b93c-4527-ba74-093233dc000d','a15ae63c-2adb-4a8d-abff-e5a15149b147','2026-06-13 07:57:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-24-4m6jcdiofdbc-ContainersCommon-tyayu2zzss4y','a15ae63c-2adb-4a8d-abff-e5a15149b147','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1331,'6139bba7-c228-4b0b-87db-f4efe8e4da95','a15ae63c-2adb-4a8d-abff-e5a15149b147','2026-06-13 07:57:20',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-24-4m6jcdiofdbc-ContainersCommon-tyayu2zzss4y','a15ae63c-2adb-4a8d-abff-e5a15149b147','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1332,'55bace8f-4446-42a0-a996-e85cdf411a7e','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:20',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-ContainersCommon-km27m3cdgu3x','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1333,'582be7af-79e5-4413-a850-7f3250e6d825','68c6d382-7604-4646-ac67-c0f559dcd2d4','2026-06-13 07:57:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-ContainersCommon-km27m3cdgu3x','68c6d382-7604-4646-ac67-c0f559dcd2d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1334,'f1114c90-5f48-4166-85bf-a054d37a6814','68c6d382-7604-4646-ac67-c0f559dcd2d4','2026-06-13 07:57:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-ContainersCommon-km27m3cdgu3x','68c6d382-7604-4646-ac67-c0f559dcd2d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1335,'19ee979d-b311-4639-9e28-8f15925ccde7','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:20',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-HeatBase-imcc6g24yexl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,833),(1336,'565771a4-8641-4fa6-95cb-cca653365c9e','532a812c-9255-498c-b80a-fb90610f914f','2026-06-13 07:57:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-HeatBase-imcc6g24yexl','532a812c-9255-498c-b80a-fb90610f914f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1337,'4e7a7bcd-6fe2-45fa-844f-ab03bed731d4','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:20',NULL,'CREATE','COMPLETE','HeatApiLogging','1a6c4812-92dc-4dd7-aaf9-70e9f2f0598d','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1338,'4093e0c7-888b-4e87-af12-8b933eebe2b1','532a812c-9255-498c-b80a-fb90610f914f','2026-06-13 07:57:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf-HeatBase-imcc6g24yexl','532a812c-9255-498c-b80a-fb90610f914f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1339,'7581426b-393c-42f2-9907-0b640ea55986','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-RoleParametersValue-evzgjgkhchty','state changed','OS::Heat::Value',NULL,834),(1340,'7a214bd3-d6d6-422e-9248-7c01c9955fed','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:20',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-RoleParametersValue-evzgjgkhchty','state changed','OS::Heat::Value',NULL,834),(1341,'f76e4a72-cd6c-4a57-b11e-d6ff28ab5468','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:20',NULL,'CREATE','COMPLETE','ContainersCommon','bc29e564-eb60-41fe-a4c1-6334a96b0b93','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1342,'5507fe7f-ef0a-4900-b1c4-89a4a439125e','503db8a0-2583-494c-893b-bc0f39e83aed','2026-06-13 07:57:20',NULL,'CREATE','COMPLETE','ContainersCommon','78d68a06-60ac-443b-8acc-b9495b6a644d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1343,'88306ea5-1dec-4479-834d-6bf33d836cd6','503db8a0-2583-494c-893b-bc0f39e83aed','2026-06-13 07:57:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb-MysqlPuppetBase-dumcja35c7ok','503db8a0-2583-494c-893b-bc0f39e83aed','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1344,'41fee566-cf76-4ec2-9997-61d8386f44e2','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-RoleParametersValue-lrl55c3s7anw','state changed','OS::Heat::Value',NULL,835),(1345,'843bd36d-e903-4500-81c0-111d09e13151','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-RoleParametersValue-lrl55c3s7anw','state changed','OS::Heat::Value',NULL,835),(1346,'0dcbb126-e79a-41b4-991a-bc378f8289d1','c4cae5a2-34bc-4410-a7f2-2228c949264a','2026-06-13 07:57:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-24-4m6jcdiofdbc-RoleParametersValue-akapbgnkv4mt','state changed','OS::Heat::Value',NULL,836),(1347,'90165d14-24ef-467a-87fb-d1632665ba0a','c4cae5a2-34bc-4410-a7f2-2228c949264a','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-24-4m6jcdiofdbc-RoleParametersValue-akapbgnkv4mt','state changed','OS::Heat::Value',NULL,836),(1348,'99614857-35be-47de-8618-5cd8f7fc7f94','c4cae5a2-34bc-4410-a7f2-2228c949264a','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','ContainersCommon','a15ae63c-2adb-4a8d-abff-e5a15149b147','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1349,'80745013-b8a4-4cbb-9a6f-75d3478d6727','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:21',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyPublicTLS-2ac34avib2br','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,837),(1350,'9bf1f7d5-3ef5-471e-8f5f-6fd56a6d4775','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','ContainersCommon','68c6d382-7604-4646-ac67-c0f559dcd2d4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1351,'fcc403e7-90c6-4c22-80da-ffbceafbad15','80274fb5-d449-49e8-a01f-8c56379d0230','2026-06-13 07:57:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyPublicTLS-2ac34avib2br','80274fb5-d449-49e8-a01f-8c56379d0230','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1352,'9c3d3974-1ac6-483d-81b1-4737a190f643','80274fb5-d449-49e8-a01f-8c56379d0230','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyPublicTLS-2ac34avib2br','80274fb5-d449-49e8-a01f-8c56379d0230','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1353,'c2723d9b-b9d3-4192-8a8f-2f7dcc752824','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','HeatBase','532a812c-9255-498c-b80a-fb90610f914f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,833),(1354,'72039ffd-69cc-4eae-9867-9b35f8a644e1','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-14-ac7rcqrbispf','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1355,'9c745317-b2f3-4fab-8638-cc6840704aa9','5938a572-c684-4833-93a1-7d84924d0a60','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','MysqlPuppetBase','503db8a0-2583-494c-893b-bc0f39e83aed','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,799),(1356,'420cdfe5-1b07-4326-b4a6-7070146bc6fd','5938a572-c684-4833-93a1-7d84924d0a60','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-8-qz52r2jgddhb','5938a572-c684-4833-93a1-7d84924d0a60','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1357,'e1c71965-8d36-4d2f-8eaa-55fe37521170','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:21',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-TLSProxyBase-k3yt6j236uz2','state changed','OS::TripleO::Services::TLSProxyBase',NULL,838),(1358,'1e709bab-d135-4fc5-afe4-e846228eb204','f5207447-c7d2-447f-9882-a08d56dd78a6','2026-06-13 07:57:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-TLSProxyBase-k3yt6j236uz2','f5207447-c7d2-447f-9882-a08d56dd78a6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1359,'1cdf93e8-e84a-4d20-8985-4f13a75fe828','f5207447-c7d2-447f-9882-a08d56dd78a6','2026-06-13 07:57:21',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-TLSProxyBase-k3yt6j236uz2-ApacheNetworks-jkg2rx7llpsk','state changed','OS::Heat::Value',NULL,839),(1360,'36d3483a-55aa-4af5-86b2-1342d3d0ccff','f5207447-c7d2-447f-9882-a08d56dd78a6','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-TLSProxyBase-k3yt6j236uz2-ApacheNetworks-jkg2rx7llpsk','state changed','OS::Heat::Value',NULL,839),(1361,'4ef26f41-f5f5-42b1-83ee-225b878d05d5','f5207447-c7d2-447f-9882-a08d56dd78a6','2026-06-13 07:57:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-TLSProxyBase-k3yt6j236uz2','f5207447-c7d2-447f-9882-a08d56dd78a6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1362,'25e91dbc-1d27-4a5c-bbfb-5c2da5d6b4ec','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:21',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-ContainersCommon-ehfdngp736av','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1363,'b8f3d96d-fdc8-4a1c-8889-de0c28a8c5e6','c4cae5a2-34bc-4410-a7f2-2228c949264a','2026-06-13 07:57:22',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-24-4m6jcdiofdbc-OVNBridgeMappingsValue-or4unprdcp45','state changed','OS::Heat::Value',NULL,840),(1364,'dc04ce67-ede1-48f4-8660-086d7fa4e69c','6b9d0d5f-e609-46f6-98d3-4050a8157d4b','2026-06-13 07:57:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-ContainersCommon-ehfdngp736av','6b9d0d5f-e609-46f6-98d3-4050a8157d4b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1365,'9a406b24-a24a-40ea-beae-86233f8addeb','c4cae5a2-34bc-4410-a7f2-2228c949264a','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-24-4m6jcdiofdbc-OVNBridgeMappingsValue-or4unprdcp45','state changed','OS::Heat::Value',NULL,840),(1366,'5c18a04e-ad04-40a7-aec3-ec6e33cd3cf8','c4cae5a2-34bc-4410-a7f2-2228c949264a','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld-24-4m6jcdiofdbc','c4cae5a2-34bc-4410-a7f2-2228c949264a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1367,'9ce12f27-9849-4000-b514-b4814e2267de','6b9d0d5f-e609-46f6-98d3-4050a8157d4b','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-ContainersCommon-ehfdngp736av','6b9d0d5f-e609-46f6-98d3-4050a8157d4b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1368,'926501a3-d1c1-4048-b752-7604b42b88d2','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','14','43ea71b8-fbdc-4b2f-b2e0-bf3428937ac0','state changed','OS::TripleO::Services::HeatApi',NULL,788),(1369,'00336c96-fc1b-4183-91fa-60910d256920','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:22',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyInternalTLS-ze7vcropmaok','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,841),(1370,'e789613a-d917-44bc-b540-785e1c044e0b','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','8','5938a572-c684-4833-93a1-7d84924d0a60','state changed','OS::TripleO::Services::Clustercheck',NULL,763),(1371,'e22445fa-153d-446e-a0c7-8d6ecd39c3e3','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','80274fb5-d449-49e8-a01f-8c56379d0230','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,837),(1372,'f6123fa5-2732-49f9-bb6c-0058fce9ca9d','2e260738-6406-43a0-9f80-87d7684ae5e9','2026-06-13 07:57:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyInternalTLS-ze7vcropmaok','2e260738-6406-43a0-9f80-87d7684ae5e9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1373,'d0c8c40b-4da9-4f1f-aa05-0e2c79442d36','2e260738-6406-43a0-9f80-87d7684ae5e9','2026-06-13 07:57:22',NULL,'CREATE','IN_PROGRESS','HAProxyNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyInternalTLS-ze7vcropmaok-HAProxyNetworks-xpwzik3fk7ej','state changed','OS::Heat::Value',NULL,848),(1374,'a5c706ab-5bdf-4879-9c68-675b71290f14','2e260738-6406-43a0-9f80-87d7684ae5e9','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','HAProxyNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyInternalTLS-ze7vcropmaok-HAProxyNetworks-xpwzik3fk7ej','state changed','OS::Heat::Value',NULL,848),(1375,'8fb9f44e-2ac6-47ab-a94e-c0408014380b','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:22',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-MySQLClient-4nzn4cin2l5u','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1376,'685aa531-fc16-4e55-9e68-753ace11c08f','2e260738-6406-43a0-9f80-87d7684ae5e9','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyInternalTLS-ze7vcropmaok','2e260738-6406-43a0-9f80-87d7684ae5e9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1377,'9283736c-a267-460e-96b1-8dc3ea8c7a1e','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','TLSProxyBase','f5207447-c7d2-447f-9882-a08d56dd78a6','state changed','OS::TripleO::Services::TLSProxyBase',NULL,838),(1378,'c951b94d-6a05-457e-b61f-59750c60dda2','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:22',NULL,'CREATE','IN_PROGRESS','18','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-18-t5rzigpcwqux','state changed','OS::TripleO::Services::Horizon',NULL,856),(1379,'deeb44c2-c91c-424a-b970-b73bb9ac34f8','9aa0ae7e-5d1b-45c7-b6d8-4a26f0c579e4','2026-06-13 07:57:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-MySQLClient-4nzn4cin2l5u','9aa0ae7e-5d1b-45c7-b6d8-4a26f0c579e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1380,'f34d63f9-338b-46d4-aa32-681ebbca0202','9aa0ae7e-5d1b-45c7-b6d8-4a26f0c579e4','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-MySQLClient-4nzn4cin2l5u','9aa0ae7e-5d1b-45c7-b6d8-4a26f0c579e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1381,'402ef733-0f39-474c-940d-3e8d21a3bfab','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','24','c4cae5a2-34bc-4410-a7f2-2228c949264a','state changed','OS::TripleO::Services::OVNController',NULL,831),(1382,'d7ca8719-5562-447a-8922-7be1b1d2d252','58400164-6682-49a5-8096-1c79361644a9','2026-06-13 07:57:22',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceChain-uwffiijkhcld','58400164-6682-49a5-8096-1c79361644a9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1383,'7247888e-7c45-483d-85a1-b555a3609ca2','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','12','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,858),(1384,'3c115047-10d5-4ed5-8a6b-1951f1452a3c','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyInternalTLS-anidtcywbutp','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,859),(1385,'737c5794-c16e-403d-abe9-09e2cd875a61','27919d02-086d-43ee-8297-f52eecef5cf3','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-18-t5rzigpcwqux','27919d02-086d-43ee-8297-f52eecef5cf3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1386,'0a3093eb-f2c8-4aee-b3bd-6577574d3d6e','0cea53d9-46ed-4dcb-a194-8d1c077af517','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7','0cea53d9-46ed-4dcb-a194-8d1c077af517','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1387,'c6b5fb7f-16fd-4ed2-a71d-44d243e5de49','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','ContainersCommon','6b9d0d5f-e609-46f6-98d3-4050a8157d4b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1388,'5957a621-7f64-4d26-a8bd-e0c56da95eaa','27919d02-086d-43ee-8297-f52eecef5cf3','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-18-t5rzigpcwqux-RoleParametersValue-omsvcrdxnmi6','state changed','OS::Heat::Value',NULL,860),(1389,'be60c073-06da-40eb-9a85-ff31e590d896','e50f9445-5840-4fdb-955e-6ad92b50cca5','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyInternalTLS-anidtcywbutp','e50f9445-5840-4fdb-955e-6ad92b50cca5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1390,'e9029ddc-37ef-499e-8b08-92af8bdc8e4e','27919d02-086d-43ee-8297-f52eecef5cf3','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-18-t5rzigpcwqux-RoleParametersValue-omsvcrdxnmi6','state changed','OS::Heat::Value',NULL,860),(1391,'8932592f-14c0-45aa-ae5b-b7dfdfd5c25a','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-RoleParametersValue-dpwdoej664a3','state changed','OS::Heat::Value',NULL,861),(1392,'a68131a4-b253-4a9f-8d5c-ae60a27d8223','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-RoleParametersValue-dpwdoej664a3','state changed','OS::Heat::Value',NULL,861),(1393,'a1f865e3-3250-4cdf-9f07-5e02c3828b60','0cea53d9-46ed-4dcb-a194-8d1c077af517','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','GlanceApi','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,862),(1394,'445726e2-e133-47f8-a111-40a45c07463d','e50f9445-5840-4fdb-955e-6ad92b50cca5','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','HAProxyNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyInternalTLS-anidtcywbutp-HAProxyNetworks-ywj53dpu4the','state changed','OS::Heat::Value',NULL,863),(1395,'c73f1b71-a65d-452e-b7a5-65cc68f69dcc','e50f9445-5840-4fdb-955e-6ad92b50cca5','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','HAProxyNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyInternalTLS-anidtcywbutp-HAProxyNetworks-ywj53dpu4the','state changed','OS::Heat::Value',NULL,863),(1396,'da101b4c-2f33-4dc9-b989-3ce86ca9fca2','e50f9445-5840-4fdb-955e-6ad92b50cca5','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyInternalTLS-anidtcywbutp','e50f9445-5840-4fdb-955e-6ad92b50cca5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1397,'403b5aba-f10c-47ed-9e1f-d0b763accda3','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3','dad991d0-b878-4e35-a348-c7fbc4bf4d73','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1398,'5d80f7cf-e06f-4e05-82f8-40e38a7e3b63','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','2e260738-6406-43a0-9f80-87d7684ae5e9','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,841),(1399,'4283d8db-5bc1-43b0-9808-ca3af9d10d3e','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-GlanceLogging-fpv4bmc5y43a','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1400,'950b2f68-c292-4d97-9bc5-cc84e626c6c6','fe391fbf-abe0-462b-bc6f-3a893606d38f','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-GlanceLogging-fpv4bmc5y43a','fe391fbf-abe0-462b-bc6f-3a893606d38f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1401,'f4523ba3-1d66-4a80-9213-fa9db8c93d06','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-TLSProxyBase-d5mmcbopcm5t','state changed','OS::TripleO::Services::TLSProxyBase',NULL,864),(1402,'d05b0753-340e-43f7-89aa-71fce9fc9823','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','ServiceChain','58400164-6682-49a5-8096-1c79361644a9','state changed','OS::Heat::ResourceChain',NULL,93),(1403,'183e1019-5140-4b12-b838-ca472149340e','e3a0e825-e1c4-4f78-9bd3-be3e02792036','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-TLSProxyBase-d5mmcbopcm5t','e3a0e825-e1c4-4f78-9bd3-be3e02792036','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1404,'a59f726c-065e-4478-a6fc-a0f4bc9e8e17','fe391fbf-abe0-462b-bc6f-3a893606d38f','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-GlanceLogging-fpv4bmc5y43a-RoleParametersValue-nsofw6zmwmjm','state changed','OS::Heat::Value',NULL,865),(1405,'255bfdac-1134-45b4-aced-ec167e231369','fe391fbf-abe0-462b-bc6f-3a893606d38f','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-GlanceLogging-fpv4bmc5y43a-RoleParametersValue-nsofw6zmwmjm','state changed','OS::Heat::Value',NULL,865),(1406,'5090206b-fe2f-4d3e-8e08-28a3404ab498','fe391fbf-abe0-462b-bc6f-3a893606d38f','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn-GlanceLogging-fpv4bmc5y43a','fe391fbf-abe0-462b-bc6f-3a893606d38f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1407,'cf1bef5d-3a87-4161-a1ff-0a29e1e0a8d0','e3a0e825-e1c4-4f78-9bd3-be3e02792036','2026-06-13 07:57:23',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-TLSProxyBase-d5mmcbopcm5t-ApacheNetworks-3vrwwsnnipeu','state changed','OS::Heat::Value',NULL,866),(1408,'1f3a1bab-ed85-4a7e-a3b9-11d21f50488b','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','MySQLClient','9aa0ae7e-5d1b-45c7-b6d8-4a26f0c579e4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1409,'6cd69eea-d216-4725-bb43-cda6c51609cd','e3a0e825-e1c4-4f78-9bd3-be3e02792036','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-TLSProxyBase-d5mmcbopcm5t-ApacheNetworks-3vrwwsnnipeu','state changed','OS::Heat::Value',NULL,866),(1410,'937d5372-a2ab-41df-a0fe-469b127849c0','e3a0e825-e1c4-4f78-9bd3-be3e02792036','2026-06-13 07:57:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-TLSProxyBase-d5mmcbopcm5t','e3a0e825-e1c4-4f78-9bd3-be3e02792036','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1411,'d2e378c7-e872-4ced-a402-b7ea15d40521','27919d02-086d-43ee-8297-f52eecef5cf3','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-18-t5rzigpcwqux-ContainersCommon-lng7owxwimad','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1412,'b8f32d83-26aa-4bf0-b30c-aabb6b4b2abe','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:24',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','e50f9445-5840-4fdb-955e-6ad92b50cca5','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,859),(1413,'cc31b9aa-52fc-40ac-b4d2-c670d7d09df8','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','HAProxyLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyLogging-ngkscvi5gjz5','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(1414,'b31aff3e-5193-49b3-8b01-909dda2fa584','5ed3f467-6646-418e-8be9-9a46fbda0c54','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-18-t5rzigpcwqux-ContainersCommon-lng7owxwimad','5ed3f467-6646-418e-8be9-9a46fbda0c54','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1415,'c7d5e972-2727-4e9f-a4f4-6bbd9397494b','4f16bbd9-d228-489d-9285-9b2d57fde6c4','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyLogging-ngkscvi5gjz5','4f16bbd9-d228-489d-9285-9b2d57fde6c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1416,'7dde219a-6b40-413f-91f0-308c53bd16e0','0cea53d9-46ed-4dcb-a194-8d1c077af517','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceLogging-p7jtigjtp6ge','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1417,'08526e43-1a7a-4f72-916f-0d7fc3102eab','4f16bbd9-d228-489d-9285-9b2d57fde6c4','2026-06-13 07:57:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45-HAProxyLogging-ngkscvi5gjz5','4f16bbd9-d228-489d-9285-9b2d57fde6c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1418,'55932a88-9e6e-4a6d-9f13-204d284ba5ba','a74fed6b-401e-4b91-9cf7-0e06d52c7908','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceLogging-p7jtigjtp6ge','a74fed6b-401e-4b91-9cf7-0e06d52c7908','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1419,'1cef0a69-359c-42b1-8005-f15259994c85','5ed3f467-6646-418e-8be9-9a46fbda0c54','2026-06-13 07:57:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-18-t5rzigpcwqux-ContainersCommon-lng7owxwimad','5ed3f467-6646-418e-8be9-9a46fbda0c54','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1420,'7e14d9d4-1d8c-40e8-881c-cbe271421d49','a74fed6b-401e-4b91-9cf7-0e06d52c7908','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceLogging-p7jtigjtp6ge-RoleParametersValue-z3uk5hbo4uvz','state changed','OS::Heat::Value',NULL,877),(1421,'dcc3e9a8-e163-464d-b8ba-943aa230fea4','a74fed6b-401e-4b91-9cf7-0e06d52c7908','2026-06-13 07:57:24',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceLogging-p7jtigjtp6ge-RoleParametersValue-z3uk5hbo4uvz','state changed','OS::Heat::Value',NULL,877),(1422,'3a2d2532-b3bd-4dfe-973a-ce00a5bf4be3','a74fed6b-401e-4b91-9cf7-0e06d52c7908','2026-06-13 07:57:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceLogging-p7jtigjtp6ge','a74fed6b-401e-4b91-9cf7-0e06d52c7908','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1423,'ce440bd3-5a1f-41c9-8dac-197c1c3180da','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-GlanceLogging-p5wnrobfa4m6','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1424,'a72134e8-6d0e-40d0-affe-3ee0450faa5d','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:24',NULL,'CREATE','COMPLETE','GlanceLogging','fe391fbf-abe0-462b-bc6f-3a893606d38f','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1425,'0f96f52b-3e02-4453-aa52-21ae8ce97cc6','8aa2b506-019f-497d-b7b0-a778e81a7ef0','2026-06-13 07:57:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-11-t22zzjvhtrvn','8aa2b506-019f-497d-b7b0-a778e81a7ef0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1426,'7a25cac5-e70a-4da0-a66b-f087adf0e595','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:24',NULL,'CREATE','COMPLETE','TLSProxyBase','e3a0e825-e1c4-4f78-9bd3-be3e02792036','state changed','OS::TripleO::Services::TLSProxyBase',NULL,864),(1427,'986b9ead-0e03-4535-8bb7-422c23102728','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ExternalUpgradeTasks-ymkejskmgkmg','state changed','OS::Heat::Value',NULL,882),(1428,'e59d5c0b-fd57-4651-ae0f-df13efc4d53c','b63d908b-85c1-41ee-8f64-3df1ff737afa','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-GlanceLogging-p5wnrobfa4m6','b63d908b-85c1-41ee-8f64-3df1ff737afa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1429,'b1c08a9c-8852-4808-9a7b-831a841581ec','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:24',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ExternalUpgradeTasks-ymkejskmgkmg','state changed','OS::Heat::Value',NULL,882),(1430,'f66467be-ab42-488e-befe-77d5998cfa87','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:24',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ComputeServiceChain-wgl7ydi5ubp5-GlobalConfigSettings-rib7odlpj6d3','state changed','OS::Heat::Value',NULL,883),(1431,'a53ba00c-f58b-45bc-980c-c09ab29e8269','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:24',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ComputeServiceChain-wgl7ydi5ubp5-GlobalConfigSettings-rib7odlpj6d3','state changed','OS::Heat::Value',NULL,883),(1432,'e5b4c7c7-7261-4e0e-8692-10c1a4a17197','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ScaleTasks-5w7ngngm5byf','state changed','OS::Heat::Value',NULL,884),(1433,'299158b2-a4e2-4cc2-bc2e-ddc51830f6d1','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ScaleTasks-5w7ngngm5byf','state changed','OS::Heat::Value',NULL,884),(1434,'a65b62f6-d4fa-41cb-8889-db3f7bdaa5d2','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PreUpgradeRollingTasks-ookey6shob5o','state changed','OS::Heat::Value',NULL,885),(1435,'2ef5c759-0dc8-424a-b1f8-8e54b6ead18e','b63d908b-85c1-41ee-8f64-3df1ff737afa','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-GlanceLogging-p5wnrobfa4m6-RoleParametersValue-ctrmtctizzsx','state changed','OS::Heat::Value',NULL,886),(1436,'3c83bd98-3dae-4110-913e-5976c0557533','b63d908b-85c1-41ee-8f64-3df1ff737afa','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-GlanceLogging-p5wnrobfa4m6-RoleParametersValue-ctrmtctizzsx','state changed','OS::Heat::Value',NULL,886),(1437,'392be233-a103-40ea-b52b-7e359443bca4','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ComputeServiceChain-wgl7ydi5ubp5-DockerConfig-t66eh2gqvvdk','state changed','OS::Heat::Value',NULL,887),(1438,'f3b721c0-1c12-4f48-ba1a-dadc0f75e28c','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PreUpgradeRollingTasks-ookey6shob5o','state changed','OS::Heat::Value',NULL,885),(1439,'71a5e441-ef26-4eff-af87-2cf43c2bcd85','b63d908b-85c1-41ee-8f64-3df1ff737afa','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-GlanceLogging-p5wnrobfa4m6','b63d908b-85c1-41ee-8f64-3df1ff737afa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1440,'15e42050-0814-4bc1-8f4e-9dc9a0c89687','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ComputeServiceChain-wgl7ydi5ubp5-DockerConfig-t66eh2gqvvdk','state changed','OS::Heat::Value',NULL,887),(1441,'87f360c4-3e64-4c41-bd74-ae35fda9ff15','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PreDeployStepTasks-wvi7hlydsog2','state changed','OS::Heat::Value',NULL,888),(1442,'9a61aa3a-f796-4595-ac5e-30c8d96d6543','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceNames-ymhh4jmfw72e','state changed','OS::Heat::Value',NULL,889),(1443,'ac4e4dfa-92d0-416a-a756-bcf02b8e8d70','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','HAProxyLogging','4f16bbd9-d228-489d-9285-9b2d57fde6c4','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(1444,'c31f4fb1-035d-4c2f-948d-7da816e11b01','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceNames-ymhh4jmfw72e','state changed','OS::Heat::Value',NULL,889),(1445,'e4bb6e60-de20-4710-bbfa-1da284310079','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PreDeployStepTasks-wvi7hlydsog2','state changed','OS::Heat::Value',NULL,888),(1446,'f4db7666-ce29-4025-8363-8f6080a60ff5','2f549a05-4c46-4ab5-8220-c8a597631246','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm-HAProxyBase-ryryrmeg6e45','2f549a05-4c46-4ab5-8220-c8a597631246','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1447,'7488c5be-3ea8-45b3-9863-c4a3ce63748f','0cea53d9-46ed-4dcb-a194-8d1c077af517','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-MySQLClient-hwzbkofzevkg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1448,'43d239c4-db74-4866-8763-faae6fa60fff','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','11','8aa2b506-019f-497d-b7b0-a778e81a7ef0','state changed','OS::TripleO::Services::GlanceApi',NULL,817),(1449,'cbd6c806-fa94-4299-b9b5-733caf91d83d','0cea53d9-46ed-4dcb-a194-8d1c077af517','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','GlanceLogging','a74fed6b-401e-4b91-9cf7-0e06d52c7908','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1450,'7656ca19-b57f-4814-b65f-482d3dd6f8fe','27919d02-086d-43ee-8297-f52eecef5cf3','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','ContainersCommon','5ed3f467-6646-418e-8be9-9a46fbda0c54','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1451,'aa871049-6596-4c3e-8ce9-d0343b237c62','27919d02-086d-43ee-8297-f52eecef5cf3','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-18-t5rzigpcwqux','27919d02-086d-43ee-8297-f52eecef5cf3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1452,'1705c649-6f18-4715-b1d3-d098b371b55d','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PuppetConfig-uqswlndflsya','state changed','OS::Heat::Value',NULL,891),(1453,'cd4e5b65-33d2-4f2d-9a5d-46f47c5c7b3b','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-UpgradeTasks-fir3lv5flqmh','state changed','OS::Heat::Value',NULL,890),(1454,'6692824f-214e-43ea-906a-7786075c975a','a1300fab-c775-4417-9e1d-ffdcfd8d6ead','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-MySQLClient-hwzbkofzevkg','a1300fab-c775-4417-9e1d-ffdcfd8d6ead','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1455,'b0b066c3-bdac-4038-87b5-358667994d55','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PuppetConfig-uqswlndflsya','state changed','OS::Heat::Value',NULL,891),(1456,'96c74428-1538-4284-b7e4-2335c11722b4','a1300fab-c775-4417-9e1d-ffdcfd8d6ead','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-MySQLClient-hwzbkofzevkg','a1300fab-c775-4417-9e1d-ffdcfd8d6ead','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1457,'e2f9b1df-ed2f-48f5-862c-6ca858959100','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceServerMetadataHook-fwa4ox6dj3nf','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,893),(1458,'b527a199-6b75-4355-bb9a-8444a9cc2f55','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-CinderNVMeOF-ac4zzwp3ilot','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1459,'b6619b94-91c0-46eb-8c5b-91112f3f0a54','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-UpgradeTasks-fir3lv5flqmh','state changed','OS::Heat::Value',NULL,890),(1460,'9210122f-3d02-48dc-bde0-c10f13151362','0cea53d9-46ed-4dcb-a194-8d1c077af517','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','MySQLClient','a1300fab-c775-4417-9e1d-ffdcfd8d6ead','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1461,'47df64d7-48cc-4db1-9176-c46392dbee9d','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PostUpgradeTasks-lvopqrvlbbyv','state changed','OS::Heat::Value',NULL,894),(1462,'306cb533-58e4-49f8-aa5c-0d055741759a','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PostUpgradeTasks-lvopqrvlbbyv','state changed','OS::Heat::Value',NULL,894),(1463,'2b733fc7-1a70-48e0-987c-0bae8ce6dc00','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-DeployStepsTasks-u5nnvznu473p','state changed','OS::Heat::Value',NULL,896),(1464,'ac0a148b-74ce-4a65-a5f4-b208d6d6e7c2','b15c0149-04cf-4408-a316-277f1fb84495','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceServerMetadataHook-fwa4ox6dj3nf','b15c0149-04cf-4408-a316-277f1fb84495','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1465,'f55fda88-bbe7-42af-8a5c-9276b519df9e','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-DeployStepsTasks-u5nnvznu473p','state changed','OS::Heat::Value',NULL,896),(1466,'6098e8f9-528e-447a-bab8-3015de7f78c3','5f3c6634-b995-474d-b293-7f57ef57cb3b','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-CinderNVMeOF-ac4zzwp3ilot','5f3c6634-b995-474d-b293-7f57ef57cb3b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1467,'467d52c7-1e52-41e0-b909-a1301321d887','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:25',NULL,'CREATE','COMPLETE','GlanceLogging','b63d908b-85c1-41ee-8f64-3df1ff737afa','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1468,'8c680b01-5f0f-4621-8294-fe5441a21b2a','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:25',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ComputeServiceChain-wgl7ydi5ubp5-KollaConfig-xkz5roblkxrp','state changed','OS::Heat::Value',NULL,901),(1469,'22619a2c-2bc6-4e7a-8301-04ef3217a8f7','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PuppetStepConfig-sifeobbgvg4e','state changed','OS::Heat::Value',NULL,903),(1470,'222263cd-117b-4164-9a08-fb13abaac5dd','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PuppetStepConfig-sifeobbgvg4e','state changed','OS::Heat::Value',NULL,903),(1471,'1047a1fc-137a-47f1-9b13-e7f10b97808a','b15c0149-04cf-4408-a316-277f1fb84495','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceServerMetadataHook-fwa4ox6dj3nf-IncomingMetadataSettings-wbg5xkarzabj','state changed','OS::Heat::Value',NULL,904),(1472,'b16243ea-fbad-41ed-bdc0-9a687f92df35','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ComputeServiceChain-wgl7ydi5ubp5-KollaConfig-xkz5roblkxrp','state changed','OS::Heat::Value',NULL,901),(1473,'28e477bd-4813-4503-80a3-d984cea2872d','5f3c6634-b995-474d-b293-7f57ef57cb3b','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-CinderNVMeOF-ac4zzwp3ilot','5f3c6634-b995-474d-b293-7f57ef57cb3b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1474,'f174d249-0478-4d57-a639-72f3705152dc','b15c0149-04cf-4408-a316-277f1fb84495','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceServerMetadataHook-fwa4ox6dj3nf-IncomingMetadataSettings-wbg5xkarzabj','state changed','OS::Heat::Value',NULL,904),(1475,'dccad373-8711-4804-9790-5a2b25d1cd65','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ExternalPostDeployTasks-nglpxsdui5gx','state changed','OS::Heat::Value',NULL,907),(1476,'2b596ef1-85f6-4d2e-8626-3b96326cfd67','b15c0149-04cf-4408-a316-277f1fb84495','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceServerMetadataHook-fwa4ox6dj3nf-IndividualServices-2vgw7r3otmmo','state changed','OS::Heat::Value',NULL,909),(1477,'e9516f2d-f139-4aa1-9e29-c009722d0ae0','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','18','27919d02-086d-43ee-8297-f52eecef5cf3','state changed','OS::TripleO::Services::Horizon',NULL,856),(1478,'4f1cef27-4406-456b-b915-cb3c24a68fa0','b15c0149-04cf-4408-a316-277f1fb84495','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceServerMetadataHook-fwa4ox6dj3nf-CompactServices-6m7u7hheje6r','state changed','OS::Heat::Value',NULL,910),(1479,'c2768810-f9d4-41db-81c7-e852a67fab44','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ExternalPostDeployTasks-nglpxsdui5gx','state changed','OS::Heat::Value',NULL,907),(1480,'81cf9ae7-cfd6-42e7-9d64-b750e092d7a5','b15c0149-04cf-4408-a316-277f1fb84495','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceServerMetadataHook-fwa4ox6dj3nf-IndividualServices-2vgw7r3otmmo','state changed','OS::Heat::Value',NULL,909),(1481,'e6331fe9-ac76-474f-92f1-1b1e6559fb69','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','HAProxyBase','2f549a05-4c46-4ab5-8220-c8a597631246','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,832),(1482,'5a7af135-c4f7-45b2-8d7b-61426d06a06e','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-DockerPuppetTasks-xxtfdo4mqr6h','state changed','OS::Heat::Value',NULL,911),(1483,'9c35db40-fb1b-47aa-b489-715f4b4b8b04','b15c0149-04cf-4408-a316-277f1fb84495','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceServerMetadataHook-fwa4ox6dj3nf-CompactServices-6m7u7hheje6r','state changed','OS::Heat::Value',NULL,910),(1484,'e5960fb9-10c8-43ed-802b-a1b56faa1803','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-13-ipl2wds3fwxm','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1485,'05d31505-106d-43e1-a4c9-b6f28c93ba15','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-DockerPuppetTasks-xxtfdo4mqr6h','state changed','OS::Heat::Value',NULL,911),(1486,'bdf0b257-efb4-481b-9326-77f99995d6af','b15c0149-04cf-4408-a316-277f1fb84495','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceServerMetadataHook-fwa4ox6dj3nf','b15c0149-04cf-4408-a316-277f1fb84495','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1487,'869a2738-4aab-472b-a483-5019ede2edd7','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','15','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-15-feau3pddfjwr','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,913),(1488,'fdf337f7-acb4-47eb-b588-0e121a289382','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceConfigSettings-qxvopiawxikm','state changed','OS::Heat::Value',NULL,916),(1489,'42b2572e-ec6c-4231-b4b5-3d20140df9eb','0cea53d9-46ed-4dcb-a194-8d1c077af517','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-RoleParametersValue-jii2lq4klaon','state changed','OS::Heat::Value',NULL,915),(1490,'2ccbb03b-8ebb-4113-ba3d-86d12615f471','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ServiceConfigSettings-qxvopiawxikm','state changed','OS::Heat::Value',NULL,916),(1491,'11da42fc-2b0f-4bfa-b843-3cd8413727b5','0cea53d9-46ed-4dcb-a194-8d1c077af517','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-RoleParametersValue-jii2lq4klaon','state changed','OS::Heat::Value',NULL,915),(1492,'dfa2e179-83c0-41fd-926a-ba8ed121fe1b','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ComputeServiceChain-wgl7ydi5ubp5-DockerConfigScripts-e5b2lwilnxwp','state changed','OS::Heat::Value',NULL,918),(1493,'74a85eae-077b-48d7-a7d5-106b7e263ac5','c657adfb-fe0c-463e-af3e-be26aa8b8a04','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-15-feau3pddfjwr','c657adfb-fe0c-463e-af3e-be26aa8b8a04','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1494,'289a5f2a-cbee-486a-8978-68593d19ef26','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ComputeServiceChain-wgl7ydi5ubp5-DockerConfigScripts-e5b2lwilnxwp','state changed','OS::Heat::Value',NULL,918),(1495,'7260266c-fff6-44fd-9792-f47723068328','c657adfb-fe0c-463e-af3e-be26aa8b8a04','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-15-feau3pddfjwr','c657adfb-fe0c-463e-af3e-be26aa8b8a04','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1496,'96f2aa49-b21a-4f87-9773-0b7969cc5b3d','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','22','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa','state changed','OS::TripleO::Services::Keystone',NULL,919),(1497,'3481a89e-864b-4a79-ba36-3f10df2ee937','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-HostPrepTasks-tfh56pdxptwp','state changed','OS::Heat::Value',NULL,920),(1498,'6a156568-3697-4fd1-9d85-8aa1d098fb69','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','15','c657adfb-fe0c-463e-af3e-be26aa8b8a04','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,913),(1499,'22e7c3c3-e13e-440b-9d1b-fe80a17eda12','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-MySQLClient-lgbmnvphvrev','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1500,'90318ba1-5ad6-423a-bfb8-a61e5c95e5da','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa','9fe9d7df-2814-4c88-bb39-36bb7317476b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1501,'6bce1974-3d78-4c0f-8db2-0a6e508d7d95','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ComputeServiceChain-wgl7ydi5ubp5-AnsibleGroupVars-isc3hwlbxgql','state changed','OS::Heat::Value',NULL,921),(1502,'c7baa0da-1b39-4174-9329-e68396cae243','606334c4-836b-41b8-8835-74533a521f62','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-MySQLClient-lgbmnvphvrev','606334c4-836b-41b8-8835-74533a521f62','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1503,'a8a34a4a-27ac-428a-9763-d8182e24364b','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ComputeServiceChain-wgl7ydi5ubp5-AnsibleGroupVars-isc3hwlbxgql','state changed','OS::Heat::Value',NULL,921),(1504,'5b733575-8c24-4201-bc56-eeac3ff24902','606334c4-836b-41b8-8835-74533a521f62','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-MySQLClient-lgbmnvphvrev','606334c4-836b-41b8-8835-74533a521f62','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1505,'d35de652-0998-4115-bdab-6b6c5791d55b','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-HostPrepTasks-tfh56pdxptwp','state changed','OS::Heat::Value',NULL,920),(1506,'a885b4a7-32bf-477f-a575-0c6e54f319a5','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ExternalUpdateTasks-xsiwt3ccpnx4','state changed','OS::Heat::Value',NULL,922),(1507,'40e0691a-d627-4e88-935e-71ee7d15f441','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','13','ccbd9fbd-d456-43f8-a16c-54893ca56d3d','state changed','OS::TripleO::Services::HAproxy',NULL,826),(1508,'066b7a09-167e-4fe5-a40d-ee2072e73d76','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ExternalUpdateTasks-xsiwt3ccpnx4','state changed','OS::Heat::Value',NULL,922),(1509,'290eab2a-c01d-4b53-a257-6a1db22703ee','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-RoleParametersValue-bxkj4ohg7mcz','state changed','OS::Heat::Value',NULL,923),(1510,'281402f8-4e53-4c4b-b64b-eaa0f69b8783','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-RoleParametersValue-bxkj4ohg7mcz','state changed','OS::Heat::Value',NULL,923),(1511,'721653f4-15ed-412c-9d0c-0119fca8eb59','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-HostFirewallTasks-fbgwycucjseq','state changed','OS::Heat::Value',NULL,925),(1512,'a3bb7944-f494-4b12-a958-3cac4c92dffc','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','b15c0149-04cf-4408-a316-277f1fb84495','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,893),(1513,'a7977967-9664-4599-90ac-6ab8ec1388ad','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-IpaRegistrationTasks-lpmr3tpa5f63','state changed','OS::Heat::Value',NULL,926),(1514,'4c8a000d-cfc0-4914-805d-d80a435a6489','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-HostFirewallTasks-fbgwycucjseq','state changed','OS::Heat::Value',NULL,925),(1515,'0da21637-538e-412e-893f-d0bd0a56bbc1','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-IpaRegistrationTasks-lpmr3tpa5f63','state changed','OS::Heat::Value',NULL,926),(1516,'73f81d88-368b-4548-b947-560c571b0277','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','CinderNVMeOF','5f3c6634-b995-474d-b293-7f57ef57cb3b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1517,'03a6cba5-bbae-46c7-a674-86ada4102483','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','19','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-19-36knz56oq7zc','state changed','OS::TripleO::Services::IpaClient',NULL,927),(1518,'efcd02ea-9914-4ab1-987d-4cfcdd29ee87','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ContainerPuppetTasks-47uxko3dqvgu','state changed','OS::Heat::Value',NULL,929),(1519,'46d4cdc9-4cdb-4138-ae6d-22b7eab762cb','91f29e9f-4130-40ec-960c-14b88c5c727b','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-19-36knz56oq7zc','91f29e9f-4130-40ec-960c-14b88c5c727b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1520,'f802bdd6-a8ef-4b6e-bd06-2738f883ace4','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-UpdateTasks-h3hqgn6nmwnu','state changed','OS::Heat::Value',NULL,933),(1521,'267b51a7-0367-418e-94cf-103a21f12103','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ContainerPuppetTasks-47uxko3dqvgu','state changed','OS::Heat::Value',NULL,929),(1522,'ef6fddb8-21e5-4950-9307-787774bc02cb','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-UpdateTasks-h3hqgn6nmwnu','state changed','OS::Heat::Value',NULL,933),(1523,'bb4531ca-82ae-44ac-9532-b6422840c3ba','91f29e9f-4130-40ec-960c-14b88c5c727b','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-19-36knz56oq7zc','91f29e9f-4130-40ec-960c-14b88c5c727b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1524,'25a4b812-d4ad-47bc-ac83-e5a1e491e4f9','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-wgl7ydi5ubp5-MonitoringSubscriptionsConfig-erezqfe3untl','state changed','OS::Heat::Value',NULL,934),(1525,'38557934-a73f-4b1e-ae41-012f4f21e21c','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','19','91f29e9f-4130-40ec-960c-14b88c5c727b','state changed','OS::TripleO::Services::IpaClient',NULL,927),(1526,'7c854337-212c-4b9a-9f6d-afa9b2aedb99','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-wgl7ydi5ubp5-MonitoringSubscriptionsConfig-erezqfe3untl','state changed','OS::Heat::Value',NULL,934),(1527,'d3fdbc2f-6b6e-4175-9468-c73e112e2e11','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ComputeServiceChain-wgl7ydi5ubp5-FirewallFrontendRules-znqnbtaualu5','state changed','OS::Heat::Value',NULL,937),(1528,'a09b2dfe-35f7-47e5-b26c-8554bff5ac0d','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-wgl7ydi5ubp5-KeystoneResourcesConfigs-ui3wsnotidxz','state changed','OS::Heat::Value',NULL,938),(1529,'7f304fd3-7278-4af0-882c-4fe63ffef6d6','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ComputeServiceChain-wgl7ydi5ubp5-FirewallRules-i3ujhyxea47p','state changed','OS::Heat::Value',NULL,941),(1530,'392e7366-28fd-4150-a648-0b6586ad5125','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ComputeServiceChain-wgl7ydi5ubp5-FirewallFrontendRules-znqnbtaualu5','state changed','OS::Heat::Value',NULL,937),(1531,'2b7b83a9-e9f1-4573-b817-183d62a65ea2','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ComputeServiceChain-wgl7ydi5ubp5-FirewallRules-i3ujhyxea47p','state changed','OS::Heat::Value',NULL,941),(1532,'9550cfb0-4a1f-49c2-85db-cc9ce23388c4','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-wgl7ydi5ubp5-KeystoneResourcesConfigs-ui3wsnotidxz','state changed','OS::Heat::Value',NULL,938),(1533,'f6766603-c574-4a78-8e72-90c2c2c28b9e','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','23','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha','state changed','OS::TripleO::Services::ManilaApi',NULL,943),(1534,'82855406-0ed6-4bf7-8468-3ea5d85900dd','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PostUpdateTasks-c7hk5gc6pfpr','state changed','OS::Heat::Value',NULL,944),(1535,'1e0e0640-8198-4c4f-addb-2941864a6a56','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-PostUpdateTasks-c7hk5gc6pfpr','state changed','OS::Heat::Value',NULL,944),(1536,'1024bc5c-574a-4a24-a1bc-4026a2d59fb1','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-ContainersCommon-ymu3taulr4zr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1537,'9116e847-7b83-4ea1-86e8-dc87bfb5052d','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-UpgradeBatchTasks-bn6zoolbjpvw','state changed','OS::Heat::Value',NULL,946),(1538,'6deca857-94a0-4347-8313-28eff2ccd693','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha','73ae34e8-084b-4611-9590-864726aac969','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1539,'03ede088-a62b-41fa-a5cc-f3a47fe8d5a0','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-UpgradeBatchTasks-bn6zoolbjpvw','state changed','OS::Heat::Value',NULL,946),(1540,'fc54c837-d00b-4867-978d-2ff076b6786a','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:27',NULL,'CREATE','COMPLETE','MySQLClient','606334c4-836b-41b8-8835-74533a521f62','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1541,'4ef08ba4-9212-4a26-8a75-45dbe18de89c','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:27',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ExternalDeployTasks-m3n77kpsthj4','state changed','OS::Heat::Value',NULL,951),(1542,'af56608f-cab9-40b7-9147-bddc09bc69c0','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-ApacheServiceBase-7etfwpvs3ybg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,953),(1543,'3f0513c7-0336-4389-9bea-4f9ebbfa1869','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','17','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo','state changed','OS::TripleO::Services::HeatEngine',NULL,954),(1544,'938f29c6-bfb7-4d2d-a0d8-a2fce0b208a6','8d963a66-969f-4f6d-8c07-7b706c81cdef','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-ContainersCommon-ymu3taulr4zr','8d963a66-969f-4f6d-8c07-7b706c81cdef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1545,'3eac8154-e343-4263-bdad-9721414087bf','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:28',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ComputeServiceChain-wgl7ydi5ubp5-ExternalDeployTasks-m3n77kpsthj4','state changed','OS::Heat::Value',NULL,951),(1546,'e1b181a0-aecf-4f49-be06-5550f53d986c','3153c3bb-fb87-49ec-a7e5-cb3900022196','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-ApacheServiceBase-7etfwpvs3ybg','3153c3bb-fb87-49ec-a7e5-cb3900022196','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1547,'26b33e98-2e3f-4e64-b09d-b71161a42f99','8d963a66-969f-4f6d-8c07-7b706c81cdef','2026-06-13 07:57:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-ContainersCommon-ymu3taulr4zr','8d963a66-969f-4f6d-8c07-7b706c81cdef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1548,'50158392-10e7-4e1d-97c4-6fc24ecb748b','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo','68b3daa4-a2f1-49dc-ac89-40f3441e8510','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1549,'81d7b4f7-952b-404e-b822-cb56b5b7f9f5','ff12385a-9ac7-4e5c-bc33-073b021ba451','2026-06-13 07:57:28',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-wgl7ydi5ubp5','ff12385a-9ac7-4e5c-bc33-073b021ba451','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1550,'c89047b9-777f-4e88-953d-e9cf147293e7','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-RoleParametersValue-ntu6iqiq6ykw','state changed','OS::Heat::Value',NULL,955),(1551,'015b01ec-cac5-443d-9d65-da0e364849ff','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-RoleParametersValue-ntu6iqiq6ykw','state changed','OS::Heat::Value',NULL,955),(1552,'19e7d18e-c28f-425b-be79-76f3e63f6786','3153c3bb-fb87-49ec-a7e5-cb3900022196','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-ApacheServiceBase-7etfwpvs3ybg-ApacheNetworks-u2p3ndmjt57g','state changed','OS::Heat::Value',NULL,956),(1553,'87f5a2cd-3a70-43b7-828d-92ad8fa239ec','3153c3bb-fb87-49ec-a7e5-cb3900022196','2026-06-13 07:57:28',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-ApacheServiceBase-7etfwpvs3ybg-ApacheNetworks-u2p3ndmjt57g','state changed','OS::Heat::Value',NULL,956),(1554,'54cdd294-ed31-4747-b533-0531d564bfe2','3153c3bb-fb87-49ec-a7e5-cb3900022196','2026-06-13 07:57:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-ApacheServiceBase-7etfwpvs3ybg','3153c3bb-fb87-49ec-a7e5-cb3900022196','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1555,'f1e6ac87-95ed-4ff0-a466-24465d857fa5','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-ContainersCommon-rcpcu5vn5e54','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1556,'9a3b1700-15d3-46ae-9fda-c2e96c0d03c2','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:28',NULL,'CREATE','COMPLETE','ComputeServiceChain','ff12385a-9ac7-4e5c-bc33-073b021ba451','state changed','OS::TripleO::ComputeServices',NULL,82),(1557,'05631c81-0819-4ea1-adcd-a419ed26f8e0','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-RoleParametersValue-izkccg32stav','state changed','OS::Heat::Value',NULL,957),(1558,'69079749-697d-4eac-a089-78c389991f2b','802d2054-490c-441b-9e4a-48c56aaab7cb','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-ContainersCommon-rcpcu5vn5e54','802d2054-490c-441b-9e4a-48c56aaab7cb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1559,'0b765449-bea4-4e63-879e-485d292a0a9f','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3-RoleParametersValue-izkccg32stav','state changed','OS::Heat::Value',NULL,957),(1560,'1598b2ea-fc14-4d6a-9b2d-3c17508905ea','802d2054-490c-441b-9e4a-48c56aaab7cb','2026-06-13 07:57:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-ContainersCommon-rcpcu5vn5e54','802d2054-490c-441b-9e4a-48c56aaab7cb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1561,'d2095201-fd53-4597-818e-d5d174a49b3b','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:28',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-ContainersCommon-y7rxpmptxpcm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1562,'073df2fd-398f-42b6-953e-d3121545589f','486d7374-051e-44bc-926c-ded75ad149c5','2026-06-13 07:57:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-ContainersCommon-y7rxpmptxpcm','486d7374-051e-44bc-926c-ded75ad149c5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1563,'fd78e7fa-e136-4a0f-9255-ee2fd4ec8ce2','486d7374-051e-44bc-926c-ded75ad149c5','2026-06-13 07:57:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-ContainersCommon-y7rxpmptxpcm','486d7374-051e-44bc-926c-ded75ad149c5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1564,'5fd74add-8a56-4371-9bc5-a7307e2aea23','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:29',NULL,'CREATE','COMPLETE','ContainersCommon','8d963a66-969f-4f6d-8c07-7b706c81cdef','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1565,'04993dfd-932b-4b54-8139-f0484376da4e','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:29',NULL,'CREATE','COMPLETE','ApacheServiceBase','3153c3bb-fb87-49ec-a7e5-cb3900022196','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,953),(1566,'98503565-3315-471f-9850-3515df6c72e3','dad991d0-b878-4e35-a348-c7fbc4bf4d73','2026-06-13 07:57:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7-GlanceApi-lhq3m2ak5ee3','dad991d0-b878-4e35-a348-c7fbc4bf4d73','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1567,'52703e87-0862-482f-9008-6dbd947e7389','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:29',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ManilaBase-6yj4tjrgoznc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,993),(1568,'9752c2f4-098b-4c75-86ee-9be92ea78620','011c41e9-aaa4-4318-b0f7-662f6204fe7f','2026-06-13 07:57:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ManilaBase-6yj4tjrgoznc','011c41e9-aaa4-4318-b0f7-662f6204fe7f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1569,'f3f9cde0-f914-494c-bb93-456c61c5ae21','011c41e9-aaa4-4318-b0f7-662f6204fe7f','2026-06-13 07:57:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ManilaBase-6yj4tjrgoznc','011c41e9-aaa4-4318-b0f7-662f6204fe7f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1570,'f0e7f8f9-6ac6-48c6-acc9-223b3d7dadb5','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:29',NULL,'CREATE','IN_PROGRESS','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-gxf57pwfmy52','state changed','OS::Heat::Value',NULL,994),(1571,'79b21146-726b-42a2-8053-86d70f493ab2','0cea53d9-46ed-4dcb-a194-8d1c077af517','2026-06-13 07:57:29',NULL,'CREATE','COMPLETE','GlanceApi','dad991d0-b878-4e35-a348-c7fbc4bf4d73','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,862),(1572,'e56c44fd-84a0-40d2-8aeb-dbbe6edf68f1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:29',NULL,'CREATE','COMPLETE','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-gxf57pwfmy52','state changed','OS::Heat::Value',NULL,994),(1573,'11bec3bf-684e-4687-a429-52434a84937b','0cea53d9-46ed-4dcb-a194-8d1c077af517','2026-06-13 07:57:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-12-biepft4jt2r7','0cea53d9-46ed-4dcb-a194-8d1c077af517','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1574,'7edc6aef-ca73-4b73-923a-ae5a0dccd106','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:29',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-HeatBase-xceb3aq33ces','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,995),(1575,'97021b40-7372-4bb5-b05a-a6446d311f74','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:29',NULL,'CREATE','COMPLETE','ContainersCommon','802d2054-490c-441b-9e4a-48c56aaab7cb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1576,'29f31862-48eb-4df8-b9bc-77dd153464f6','512dc555-9cd1-4446-8efc-3939c99c757f','2026-06-13 07:57:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-HeatBase-xceb3aq33ces','512dc555-9cd1-4446-8efc-3939c99c757f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1577,'da45b213-c129-4ed2-ac2c-aed741465b6c','512dc555-9cd1-4446-8efc-3939c99c757f','2026-06-13 07:57:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-HeatBase-xceb3aq33ces','512dc555-9cd1-4446-8efc-3939c99c757f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1578,'788f12a4-6215-4c63-b538-321d4c45d66f','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:29',NULL,'CREATE','IN_PROGRESS','KeystoneLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-KeystoneLogging-vgajzjbhucdg','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(1579,'5b809292-1113-4c26-9290-7f098ec2d42f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:29',NULL,'CREATE','IN_PROGRESS','ComputeServiceNames','overcloud-ComputeServiceNames-idn2npgxvlmw','state changed','OS::Heat::Value',NULL,996),(1580,'cd4ab218-e96b-41cd-82a9-88d0dc5847c7','20d5818a-6ec3-493c-a02f-2348bc4cd6ef','2026-06-13 07:57:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-KeystoneLogging-vgajzjbhucdg','20d5818a-6ec3-493c-a02f-2348bc4cd6ef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1581,'c464aa57-cd06-41f3-a1c6-b9eb1cb7c72e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','ComputeServiceNames','overcloud-ComputeServiceNames-idn2npgxvlmw','state changed','OS::Heat::Value',NULL,996),(1582,'40c83185-c067-4975-b62c-1a38027923c6','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','ContainersCommon','486d7374-051e-44bc-926c-ded75ad149c5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1583,'496cb7eb-da8c-44d4-8fb9-a7dc95ba8e1e','20d5818a-6ec3-493c-a02f-2348bc4cd6ef','2026-06-13 07:57:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-KeystoneLogging-vgajzjbhucdg-RoleParametersValue-pk2oxqs5v5zb','state changed','OS::Heat::Value',NULL,998),(1584,'bb25a422-1d2a-4ec6-9447-fc8c1fed4759','20d5818a-6ec3-493c-a02f-2348bc4cd6ef','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-KeystoneLogging-vgajzjbhucdg-RoleParametersValue-pk2oxqs5v5zb','state changed','OS::Heat::Value',NULL,998),(1585,'e9bf3e8f-bd41-4408-b6a3-6d6069d11fb7','20d5818a-6ec3-493c-a02f-2348bc4cd6ef','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-KeystoneLogging-vgajzjbhucdg','20d5818a-6ec3-493c-a02f-2348bc4cd6ef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1586,'a3a4ee2f-e177-4a07-8a12-9e775dd6e8f3','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:30',NULL,'CREATE','IN_PROGRESS','Compute','overcloud-Compute-ajofa4bwgzle','state changed','OS::Heat::ResourceGroup',NULL,999),(1587,'a15a1650-ac98-4c92-afd0-227e54304408','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','12','0cea53d9-46ed-4dcb-a194-8d1c077af517','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,858),(1588,'09adbbb4-7dd7-4982-96c0-3eeca03db5b1','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','2026-06-13 07:57:30',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1589,'3ee4ac25-0b9d-4ed5-a96c-cf7cf5781135','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1590,'413202bd-2246-43a3-9148-85d13969ed5b','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:30',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ApacheServiceBase-h5l2zkz57g4w','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1002),(1591,'7afaa741-56f2-48fa-9bda-c5d5c8ae97bd','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','ManilaBase','011c41e9-aaa4-4318-b0f7-662f6204fe7f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,993),(1592,'28f2f5c4-869f-479a-b019-be09fe8bea5a','fddab522-539c-4a80-af18-7565b391fc87','2026-06-13 07:57:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ApacheServiceBase-h5l2zkz57g4w','fddab522-539c-4a80-af18-7565b391fc87','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1593,'0ca01610-d559-40e9-b1cd-28721384d34c','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-RoleParametersValue-rljxccd4r6ev','state changed','OS::Heat::Value',NULL,1006),(1594,'38dcbfd4-9f8a-4ab5-899f-2a7c580b767a','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-RoleParametersValue-rljxccd4r6ev','state changed','OS::Heat::Value',NULL,1006),(1595,'1608d1c2-5fa9-4d47-a126-a139b51bbaf9','fddab522-539c-4a80-af18-7565b391fc87','2026-06-13 07:57:30',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ApacheServiceBase-h5l2zkz57g4w-ApacheNetworks-eapkzinlplir','state changed','OS::Heat::Value',NULL,1009),(1596,'08a7d155-68b3-40a1-96c4-7dc47739644c','fddab522-539c-4a80-af18-7565b391fc87','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ApacheServiceBase-h5l2zkz57g4w-ApacheNetworks-eapkzinlplir','state changed','OS::Heat::Value',NULL,1009),(1597,'fbab7af8-cb1d-4f73-ad35-c7db4fc27aef','fddab522-539c-4a80-af18-7565b391fc87','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ApacheServiceBase-h5l2zkz57g4w','fddab522-539c-4a80-af18-7565b391fc87','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1598,'5dd1f981-56b9-4fcc-b924-273c41c1e7a9','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:30',NULL,'CREATE','COMPLETE','HeatBase','512dc555-9cd1-4446-8efc-3939c99c757f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,995),(1599,'196991ab-3a59-40bb-9822-f1caa55c0307','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:30',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-MySQLClient-e4f3a532udcf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1600,'870b4878-76f6-4530-9a1a-34d84d14ca8c','914f95ff-37cd-4224-ab66-74bc4c47c6f8','2026-06-13 07:57:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-MySQLClient-e4f3a532udcf','914f95ff-37cd-4224-ab66-74bc4c47c6f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1601,'eea10e70-284b-474a-9cf4-b9a0d498eb5b','914f95ff-37cd-4224-ab66-74bc4c47c6f8','2026-06-13 07:57:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa-MySQLClient-e4f3a532udcf','914f95ff-37cd-4224-ab66-74bc4c47c6f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1602,'772ee3f2-8306-444a-b978-a201830e5e6b','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:31',NULL,'CREATE','COMPLETE','KeystoneLogging','20d5818a-6ec3-493c-a02f-2348bc4cd6ef','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(1603,'a5cda084-e092-4f57-b49c-e70bedd80c1a','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','16','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e','state changed','OS::TripleO::Services::HeatApiCfn',NULL,1018),(1604,'e0a75066-8f4b-44f4-935d-ae23d332a300','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1605,'ab9fb536-fa37-4126-9070-a06e4efbb50e','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-MySQLClient-i6sfidlnatjj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1606,'8906dd0a-acce-47df-b490-dc329d7b68b7','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','2026-06-13 07:57:31',NULL,'UPDATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(1607,'2dd8619b-ba26-49e6-9277-ec479de44ad3','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-ApacheServiceBase-shu6nzy7yy3r','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1019),(1608,'f7095ece-bef5-4c71-8dfd-6c0297826101','3c978477-e163-4437-ba01-2d39ebfd44b1','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-MySQLClient-i6sfidlnatjj','3c978477-e163-4437-ba01-2d39ebfd44b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1609,'0ca832a7-206c-40de-b71c-1797b4cca644','3c978477-e163-4437-ba01-2d39ebfd44b1','2026-06-13 07:57:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-MySQLClient-i6sfidlnatjj','3c978477-e163-4437-ba01-2d39ebfd44b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1610,'45c901da-7971-45f2-8de8-a93995413373','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-MySQLClient-k672dvb57u4l','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1611,'732e9fac-7ee9-425f-8055-0a1205b2fd0e','0462bdd6-71f0-4fe7-8efd-e137d0f3297d','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-ApacheServiceBase-shu6nzy7yy3r','0462bdd6-71f0-4fe7-8efd-e137d0f3297d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1612,'7e5c983d-f9ba-40eb-ae9a-0ceea9b86ee6','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:31',NULL,'CREATE','COMPLETE','ApacheServiceBase','fddab522-539c-4a80-af18-7565b391fc87','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1002),(1613,'6b0a4ebd-c913-4700-8ff2-f25d780bf2e8','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','1','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a','state changed','OS::TripleO::Compute',NULL,1020),(1614,'4c91d881-7cc1-4e7c-b64d-89a26946aa82','fe89c7ea-165c-4344-9554-4d132dc90e86','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-MySQLClient-k672dvb57u4l','fe89c7ea-165c-4344-9554-4d132dc90e86','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1615,'009ee0a9-1379-4607-aa67-0ef8da7d8886','fe89c7ea-165c-4344-9554-4d132dc90e86','2026-06-13 07:57:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-MySQLClient-k672dvb57u4l','fe89c7ea-165c-4344-9554-4d132dc90e86','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1616,'1b411e92-a13c-46ca-bf12-7401537f1069','0462bdd6-71f0-4fe7-8efd-e137d0f3297d','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-ApacheServiceBase-shu6nzy7yy3r-ApacheNetworks-2v6emmv4kotd','state changed','OS::Heat::Value',NULL,1021),(1617,'3e2bad2a-1443-40c3-88a0-f18400bd3878','0462bdd6-71f0-4fe7-8efd-e137d0f3297d','2026-06-13 07:57:31',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-ApacheServiceBase-shu6nzy7yy3r-ApacheNetworks-2v6emmv4kotd','state changed','OS::Heat::Value',NULL,1021),(1618,'888860d6-136f-4906-9836-baf54510e686','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:31',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a','02e417f5-77e0-4b7d-99c1-64f5383fc66a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1619,'19c9b87f-e154-46ea-ac3b-ab09e0854d24','0462bdd6-71f0-4fe7-8efd-e137d0f3297d','2026-06-13 07:57:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-ApacheServiceBase-shu6nzy7yy3r','0462bdd6-71f0-4fe7-8efd-e137d0f3297d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1620,'7d63ecf8-9a12-42f4-ab14-eba5d8879fd4','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','MySQLClient','914f95ff-37cd-4224-ab66-74bc4c47c6f8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1621,'5c0c6bbf-1a92-4849-bdce-df562832fbd3','9fe9d7df-2814-4c88-bb39-36bb7317476b','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-22-4t5ftydlaxfa','9fe9d7df-2814-4c88-bb39-36bb7317476b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1622,'f124ca60-e9cb-43d8-b4e1-1837c06522da','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:32',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-DeploymentActions-6234nw4lkhff','state changed','OS::Heat::Value',NULL,1022),(1623,'c98dcaae-bf24-4685-9a26-a73a029d56b3','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-DeploymentActions-6234nw4lkhff','state changed','OS::Heat::Value',NULL,1022),(1624,'656f4127-5c9c-4086-b8ad-3457a05b301f','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:32',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ContainersCommon-bkwzmiociryz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1625,'8112a0ef-7cdb-4696-8991-95db9535aa47','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:32',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-HeatBase-tsffmvlbvn5d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1024),(1626,'bd959168-0206-411f-b5a9-21c5f33d5bf5','2691a82d-74c1-4c5f-be59-27410cf8533d','2026-06-13 07:57:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ContainersCommon-bkwzmiociryz','2691a82d-74c1-4c5f-be59-27410cf8533d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1627,'95dd2310-39b6-4115-a4f1-e8c44580f176','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','MySQLClient','3c978477-e163-4437-ba01-2d39ebfd44b1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1628,'f112c28c-b019-4a18-9e93-261d6c5ba5b6','2691a82d-74c1-4c5f-be59-27410cf8533d','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha-ContainersCommon-bkwzmiociryz','2691a82d-74c1-4c5f-be59-27410cf8533d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1629,'f08641de-cf81-4e1d-9e5f-ec78fe2f9ac1','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:32',NULL,'CREATE','IN_PROGRESS','HeatEngineLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-HeatEngineLogging-mndxfkeawl6b','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(1630,'938014bd-1550-4dff-b8c9-86b698d26e36','837c6591-2493-4e9a-9424-d20b063bb663','2026-06-13 07:57:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-HeatBase-tsffmvlbvn5d','837c6591-2493-4e9a-9424-d20b063bb663','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1631,'9afc3516-9b10-4d27-a822-643e9bc82723','837c6591-2493-4e9a-9424-d20b063bb663','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-HeatBase-tsffmvlbvn5d','837c6591-2493-4e9a-9424-d20b063bb663','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1632,'d86fc5f0-3ab1-4969-a195-7eec12ea87e8','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','2026-06-13 07:57:32',NULL,'CREATE','IN_PROGRESS','0','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26','state changed','OS::TripleO::Compute',NULL,1025),(1633,'d268735c-9b9e-436d-8357-91afaa1e087d','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','ApacheServiceBase','0462bdd6-71f0-4fe7-8efd-e137d0f3297d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1019),(1634,'c16561b0-376e-4a28-80d4-79d9797cd79a','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','MySQLClient','fe89c7ea-165c-4344-9554-4d132dc90e86','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1635,'d29e1f39-70df-4b02-8b9c-4698c03ab6d4','7b52c250-a0ab-4b49-8d20-d793a01c6179','2026-06-13 07:57:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-HeatEngineLogging-mndxfkeawl6b','7b52c250-a0ab-4b49-8d20-d793a01c6179','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1636,'35f821d3-590e-446a-a270-054ea721a1e5','7b52c250-a0ab-4b49-8d20-d793a01c6179','2026-06-13 07:57:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-HeatEngineLogging-mndxfkeawl6b-RoleParametersValue-g25btntbv6ir','state changed','OS::Heat::Value',NULL,1026),(1637,'cd992a7e-e3a5-491e-9c6b-822843cfb705','7b52c250-a0ab-4b49-8d20-d793a01c6179','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-HeatEngineLogging-mndxfkeawl6b-RoleParametersValue-g25btntbv6ir','state changed','OS::Heat::Value',NULL,1026),(1638,'7bda963a-8497-4cff-96e3-e21870614c0a','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','22','9fe9d7df-2814-4c88-bb39-36bb7317476b','state changed','OS::TripleO::Services::Keystone',NULL,919),(1639,'060b6423-33f9-4888-83a3-3efd6202beed','7b52c250-a0ab-4b49-8d20-d793a01c6179','2026-06-13 07:57:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo-HeatEngineLogging-mndxfkeawl6b','7b52c250-a0ab-4b49-8d20-d793a01c6179','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1640,'7bffc549-dcd7-4d68-9b22-8d37b28fbdd0','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:32',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1641,'9b694df2-d2c4-4ea9-b6be-0289074cfc3d','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NovaCompute-oypjfkae5uhd','state changed','OS::TripleO::ComputeServer',NULL,1031),(1642,'5927197d-4985-4772-8fd2-ce063d2580e5','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NovaCompute-n3vey5xlhbde','state changed','OS::TripleO::ComputeServer',NULL,1034),(1643,'e122fd09-87a3-432f-9cda-65c78963741d','03e35313-e91f-4876-9a79-2d3eef21f8fa','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NovaCompute-oypjfkae5uhd','03e35313-e91f-4876-9a79-2d3eef21f8fa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1644,'9655d5ac-f36d-45e3-ba66-75567d721e09','a730d77c-7e57-4af1-9dbc-ab0231f988d2','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NovaCompute-n3vey5xlhbde','a730d77c-7e57-4af1-9dbc-ab0231f988d2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1645,'74328323-453a-41e5-b854-f803e7978144','03e35313-e91f-4876-9a79-2d3eef21f8fa','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-oypjfkae5uhd-deployed-server-aulljvzlmm3k','state changed','OS::Heat::DeployedServer',NULL,1037),(1646,'bc09b978-5e72-43a7-9fba-5a2e56b72230','03e35313-e91f-4876-9a79-2d3eef21f8fa','2026-06-13 07:57:33',NULL,'CREATE','COMPLETE','deployed-server','72b6336a-6b4d-4051-a48d-e3be42ba8565','state changed','OS::Heat::DeployedServer',NULL,1037),(1647,'19058d96-7ba7-46a8-8b42-4ffe5270d0ef','a730d77c-7e57-4af1-9dbc-ab0231f988d2','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NovaCompute-n3vey5xlhbde-ControlPlanePort-elclaolgznta','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1038),(1648,'d7057248-da87-4ac3-b8c4-7f013a27eb84','ddec5e3b-4d2d-4f11-90a6-f8b8153004d9','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NovaCompute-n3vey5xlhbde-ControlPlanePort-elclaolgznta','ddec5e3b-4d2d-4f11-90a6-f8b8153004d9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1649,'d50559e8-ed16-4b04-b711-992f33b7dd91','ddec5e3b-4d2d-4f11-90a6-f8b8153004d9','2026-06-13 07:57:33',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NovaCompute-n3vey5xlhbde-ControlPlanePort-elclaolgznta','ddec5e3b-4d2d-4f11-90a6-f8b8153004d9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1650,'2e786155-9473-4f53-81fa-b553d3482028','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','26','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq','state changed','OS::TripleO::Services::ManilaShare',NULL,1039),(1651,'b3b7728b-4875-4921-b4dd-26ea24fd259b','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-ContainersCommon-wofsdice2bx2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1652,'01052f5c-51d0-4cef-9dea-942cfc97f496','44ccc59f-a013-4957-8a76-9780fefb6b58','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-ContainersCommon-wofsdice2bx2','44ccc59f-a013-4957-8a76-9780fefb6b58','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1653,'9b873bdc-c70e-4c20-84cc-c5424081ab80','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq','dfd13fee-4eee-4928-a0ed-367277d95429','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1654,'04d20b52-4050-4e87-81b0-e13f04a2cf21','44ccc59f-a013-4957-8a76-9780fefb6b58','2026-06-13 07:57:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-ContainersCommon-wofsdice2bx2','44ccc59f-a013-4957-8a76-9780fefb6b58','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1655,'00638e13-68c5-42f2-9619-652cbdb37389','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:33',NULL,'CREATE','COMPLETE','ContainersCommon','2691a82d-74c1-4c5f-be59-27410cf8533d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1656,'956052df-8b9f-4309-b15a-201f8bef77bd','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','2','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g','state changed','OS::TripleO::Compute',NULL,1040),(1657,'aea7e614-a849-45d2-9f88-a64391b6530a','73ae34e8-084b-4611-9590-864726aac969','2026-06-13 07:57:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-23-3hyeeamfipha','73ae34e8-084b-4611-9590-864726aac969','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1658,'60de581f-1a9d-4918-96c3-2421ce454996','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:33',NULL,'CREATE','COMPLETE','HeatBase','837c6591-2493-4e9a-9424-d20b063bb663','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1024),(1659,'0e76e3c5-5147-4167-a07c-04516b7318fc','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-MySQLClient-jmbj2lkkn7i2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1660,'a7a5e3f3-f1fa-47e4-9e4c-ce4ec587f041','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g','6c27444a-c396-4268-b71c-9036fba94480','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1661,'dea42750-f112-4f76-9cb5-d48b897f3b10','d8b8c42c-ea6e-497a-94c3-2cc9c01d15fd','2026-06-13 07:57:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-MySQLClient-jmbj2lkkn7i2','d8b8c42c-ea6e-497a-94c3-2cc9c01d15fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1662,'be0d2d54-a83a-4f84-acda-02f52827297c','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:33',NULL,'CREATE','COMPLETE','HeatEngineLogging','7b52c250-a0ab-4b49-8d20-d793a01c6179','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(1663,'2138d802-cb8a-49f0-b6fd-ab8f5046b4f4','d8b8c42c-ea6e-497a-94c3-2cc9c01d15fd','2026-06-13 07:57:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-MySQLClient-jmbj2lkkn7i2','d8b8c42c-ea6e-497a-94c3-2cc9c01d15fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1664,'23e8c85c-45f2-4a76-b8d6-f9231931c970','68b3daa4-a2f1-49dc-ac89-40f3441e8510','2026-06-13 07:57:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-17-osgsc7vimrwo','68b3daa4-a2f1-49dc-ac89-40f3441e8510','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1665,'dfd09372-2183-4a0a-bff4-902b79112917','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','23','73ae34e8-084b-4611-9590-864726aac969','state changed','OS::TripleO::Services::ManilaApi',NULL,943),(1666,'385d254b-42b8-4903-a1dd-12d84c2c47cd','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NovaCompute-kzegc7sxb5q5','state changed','OS::TripleO::ComputeServer',NULL,1041),(1667,'162e681a-aaf3-4952-8b52-a3b015afbb17','b46a18d9-13bf-4d0b-917e-744f41fa8400','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NovaCompute-kzegc7sxb5q5','b46a18d9-13bf-4d0b-917e-744f41fa8400','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1668,'ad4772a5-4ff1-4595-a6ad-bfb98d9007e1','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-DeploymentActions-xuwngufp77au','state changed','OS::Heat::Value',NULL,1044),(1669,'6ba07353-de3a-4afd-8488-78053fa76264','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-DeploymentActions-xuwngufp77au','state changed','OS::Heat::Value',NULL,1044),(1670,'2f793087-d853-4a96-b02a-779e05a6c77c','b46a18d9-13bf-4d0b-917e-744f41fa8400','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NovaCompute-kzegc7sxb5q5-ControlPlanePort-vvtlag4vlbv6','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1049),(1671,'570e823a-a944-4b2a-9668-7337a4e6967b','03e35313-e91f-4876-9a79-2d3eef21f8fa','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NovaCompute-oypjfkae5uhd-ControlPlanePort-sjryepnu4byq','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1051),(1672,'31d03543-fe3d-4414-8d07-5f9c24218e9a','6765f146-e011-40c4-b177-01b47ff6e833','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NovaCompute-kzegc7sxb5q5-ControlPlanePort-vvtlag4vlbv6','6765f146-e011-40c4-b177-01b47ff6e833','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1673,'6eca7d92-fc13-40dd-9eda-f803f151056d','a730d77c-7e57-4af1-9dbc-ab0231f988d2','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-n3vey5xlhbde-deployed-server-6s3zcxzmqupy','state changed','OS::Heat::DeployedServer',NULL,1052),(1674,'7940eb78-53b0-4513-a544-0f090853a580','a730d77c-7e57-4af1-9dbc-ab0231f988d2','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','ControlPlanePort','ddec5e3b-4d2d-4f11-90a6-f8b8153004d9','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1038),(1675,'1540c7af-18cf-4ff5-b29d-258f21dd5b2d','c642c009-fd4e-4564-8e07-14fa0548bc47','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NovaCompute-oypjfkae5uhd-ControlPlanePort-sjryepnu4byq','c642c009-fd4e-4564-8e07-14fa0548bc47','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1676,'1af02052-49d8-4659-9042-d45555d90404','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','17','68b3daa4-a2f1-49dc-ac89-40f3441e8510','state changed','OS::TripleO::Services::HeatEngine',NULL,954),(1677,'3e8f32d5-0151-4c7a-b573-a52f1bc9183d','c642c009-fd4e-4564-8e07-14fa0548bc47','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NovaCompute-oypjfkae5uhd-ControlPlanePort-sjryepnu4byq','c642c009-fd4e-4564-8e07-14fa0548bc47','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1678,'659fc214-9565-4076-a457-5234b802bc1e','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-RoleParametersValue-qs653m5bo6pt','state changed','OS::Heat::Value',NULL,1054),(1679,'beb74038-09e9-47ca-a6ea-627de5e4de5b','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-RoleParametersValue-qs653m5bo6pt','state changed','OS::Heat::Value',NULL,1054),(1680,'4667bfb1-0c23-4012-8090-77deb89ac6dd','a730d77c-7e57-4af1-9dbc-ab0231f988d2','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','deployed-server','f2c851f8-7915-4f4b-944d-ec651de8c933','state changed','OS::Heat::DeployedServer',NULL,1052),(1681,'c216c160-df3f-49ef-b1c5-96ade1569dbe','a730d77c-7e57-4af1-9dbc-ab0231f988d2','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NovaCompute-n3vey5xlhbde','a730d77c-7e57-4af1-9dbc-ab0231f988d2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1682,'6a7de118-a0c1-44ee-93d3-d202e4452fc6','6765f146-e011-40c4-b177-01b47ff6e833','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NovaCompute-kzegc7sxb5q5-ControlPlanePort-vvtlag4vlbv6','6765f146-e011-40c4-b177-01b47ff6e833','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1683,'79a638fe-4f1b-4468-b6db-fe8e86d2adb3','03e35313-e91f-4876-9a79-2d3eef21f8fa','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','ControlPlanePort','c642c009-fd4e-4564-8e07-14fa0548bc47','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1051),(1684,'3384516e-acd7-47af-ab26-d16a434ca0f4','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','27','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-27-35acnq63o64b','state changed','OS::TripleO::Services::Memcached',NULL,1055),(1685,'fb5107b1-2443-4fc9-8caa-4555da8aeb7f','03e35313-e91f-4876-9a79-2d3eef21f8fa','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NovaCompute-oypjfkae5uhd','03e35313-e91f-4876-9a79-2d3eef21f8fa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1686,'c661e825-fff2-4f48-b5f4-7ada83973feb','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','ContainersCommon','44ccc59f-a013-4957-8a76-9780fefb6b58','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1687,'54faaf5d-19aa-4e9f-bb6b-1a7217202449','35a0f192-3141-4e6b-b91e-f9ace0f4d6bc','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-27-35acnq63o64b','35a0f192-3141-4e6b-b91e-f9ace0f4d6bc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1688,'4df99c88-9fb6-470b-86dd-5a364923572d','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','ManilaCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaCommon-zjv67vu5temx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1689,'70ada51d-51f8-4add-a1aa-19d576392c21','35a0f192-3141-4e6b-b91e-f9ace0f4d6bc','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-27-35acnq63o64b-RoleParametersValue-lpxakkvlkqcq','state changed','OS::Heat::Value',NULL,1063),(1690,'5d053942-ec1f-45af-8ffe-4bc47ff48fc2','35a0f192-3141-4e6b-b91e-f9ace0f4d6bc','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-27-35acnq63o64b-RoleParametersValue-lpxakkvlkqcq','state changed','OS::Heat::Value',NULL,1063),(1691,'bd1c3799-11cc-4f07-87e8-3ff761aedce2','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:34',NULL,'CREATE','COMPLETE','MySQLClient','d8b8c42c-ea6e-497a-94c3-2cc9c01d15fd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1692,'7571e61a-0aa8-478c-9a75-d96f65df0cfc','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:34',NULL,'CREATE','IN_PROGRESS','21','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-21-d6did6jayxi5','state changed','OS::TripleO::Services::Kernel',NULL,1064),(1693,'2b56e937-993d-40db-b06f-7050b93a0dc3','188698ca-ecde-40bd-8cef-25570cf0eede','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaCommon-zjv67vu5temx','188698ca-ecde-40bd-8cef-25570cf0eede','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1694,'cb31d05f-fca8-4c8d-97dc-cabcfd46594e','3c19fbdc-eaa2-438f-a903-59dd0de75fe7','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-21-d6did6jayxi5','3c19fbdc-eaa2-438f-a903-59dd0de75fe7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1695,'0bd86b57-2178-4371-b53a-6e4ec12bef26','188698ca-ecde-40bd-8cef-25570cf0eede','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaCommon-zjv67vu5temx-ContainersCommon-dn56gqyuzbeh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1696,'eafc16ef-8abf-4287-b01f-08a16b168f10','3c19fbdc-eaa2-438f-a903-59dd0de75fe7','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-21-d6did6jayxi5-RoleParametersValue-how52wg2hunz','state changed','OS::Heat::Value',NULL,1066),(1697,'55eb2d72-aba0-4ca1-a68c-cfdc05330725','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-DeploymentActions-hxikmm62miqn','state changed','OS::Heat::Value',NULL,1065),(1698,'eb6f9b69-2c3c-43af-83d4-e882fe2dea69','3c19fbdc-eaa2-438f-a903-59dd0de75fe7','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-21-d6did6jayxi5-RoleParametersValue-how52wg2hunz','state changed','OS::Heat::Value',NULL,1066),(1699,'531e370e-868a-47d8-986a-96ea9ef37a82','3c19fbdc-eaa2-438f-a903-59dd0de75fe7','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-21-d6did6jayxi5','3c19fbdc-eaa2-438f-a903-59dd0de75fe7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1700,'eff7ee4e-caa9-4c35-998a-11b36b299151','d202a4ff-0a71-417e-b877-d2cd4064dfa7','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaCommon-zjv67vu5temx-ContainersCommon-dn56gqyuzbeh','d202a4ff-0a71-417e-b877-d2cd4064dfa7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1701,'bba2ec85-8192-46c7-be47-7e2d0ffa3853','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-DeploymentActions-hxikmm62miqn','state changed','OS::Heat::Value',NULL,1065),(1702,'01170875-53cc-4e75-9b1e-5ebc9a6bb835','d202a4ff-0a71-417e-b877-d2cd4064dfa7','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaCommon-zjv67vu5temx-ContainersCommon-dn56gqyuzbeh','d202a4ff-0a71-417e-b877-d2cd4064dfa7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1703,'342ce26a-5cfb-4f47-9aa8-cb6f35e8e9c2','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','NovaCompute','03e35313-e91f-4876-9a79-2d3eef21f8fa','state changed','OS::TripleO::ComputeServer',NULL,1031),(1704,'19e117a7-174b-4521-add4-65d6ded63337','b46a18d9-13bf-4d0b-917e-744f41fa8400','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-kzegc7sxb5q5-deployed-server-cfiuurwz4ifi','state changed','OS::Heat::DeployedServer',NULL,1068),(1705,'7a1d822c-c5a8-4104-89a9-74a33ef9a9c0','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','NovaCompute','a730d77c-7e57-4af1-9dbc-ab0231f988d2','state changed','OS::TripleO::ComputeServer',NULL,1034),(1706,'f4d021b7-81b4-4da8-848c-6e3b57f366b2','b46a18d9-13bf-4d0b-917e-744f41fa8400','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','deployed-server','6d9e20a8-14a4-4115-a134-e8065bee088a','state changed','OS::Heat::DeployedServer',NULL,1068),(1707,'36789cbb-2b83-4b12-9533-63cec4f94d06','b46a18d9-13bf-4d0b-917e-744f41fa8400','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','ControlPlanePort','6765f146-e011-40c4-b177-01b47ff6e833','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1049),(1708,'d7f548b5-af7d-441f-9ca0-5b294a974471','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-PreNetworkConfig-rvf4jbso5adp','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1709,'8476b671-9616-4ab1-834c-1171151d4f2a','b46a18d9-13bf-4d0b-917e-744f41fa8400','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NovaCompute-kzegc7sxb5q5','b46a18d9-13bf-4d0b-917e-744f41fa8400','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1710,'3647ad03-9995-426c-818c-3dbb27235af3','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-TenantPort-3qzt5zoqraj5','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1072),(1711,'306d771f-d643-46e5-ba27-0f0619187845','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-InternalApiPort-doc456cwlnmt','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1071),(1712,'32c352b1-9f4d-498e-bbc8-7b8f43941e59','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NodeTLSCAData-2rpzji3qby3z','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1713,'36a25525-4f72-4379-9dd3-eb97ba2be220','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','HeatApiCfnLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-HeatApiCfnLogging-mqmyaufpjmfe','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1714,'ed355aeb-614b-4865-9286-7278c3dfc3d3','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-ComputeExtraConfigPre-gpdibvwxle2l','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1073),(1715,'29ab3cdc-acc8-4d03-8489-eced2e906572','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-PreNetworkConfig-jbssjtu5ge6n','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1716,'85c3d7b3-e822-4413-9eb4-78b0e0322fd5','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NetHostMap-igv7s56munc6','state changed','OS::Heat::Value',NULL,1074),(1717,'85562c53-375a-4c47-9601-0fc82a4c39bd','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NetHostMap-arssbqokc2c2','state changed','OS::Heat::Value',NULL,1076),(1718,'0e41abf0-7201-4f64-9369-8fbb7756e228','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-StoragePort-4sntms2aockp','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1077),(1719,'ebf14cad-7881-4d52-aacc-69af36eb021a','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NodeTLSCAData-q56mhfq2asnk','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1720,'6c0133d0-51c6-4fc8-9e3c-2c929fcf51ee','de315a59-df88-4ae5-9405-4a492636cc75','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-InternalApiPort-doc456cwlnmt','de315a59-df88-4ae5-9405-4a492636cc75','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1721,'81b39ddc-84c0-48b0-a865-76d3910cc34f','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','PreNetworkConfig','babf96d9-1ee2-40af-9df6-643af9e0e87e','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1722,'41d693ed-394d-4c76-a365-b17c983b7c51','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','PreNetworkConfig','da2df4bb-9060-4200-8f1e-61e11d492367','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1723,'e1d226ba-897b-48d4-b79f-9018d093117f','133cbaa7-7dce-46c3-8e75-778e21fecaa5','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-TenantPort-3qzt5zoqraj5','133cbaa7-7dce-46c3-8e75-778e21fecaa5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1724,'3f5f437b-e075-44f5-9708-9f73f572e8b2','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-StoragePort-4tcu7m6odtx5','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1078),(1725,'8a3dafcc-58d0-4253-b96d-fc1576923e47','7a050f94-0fed-4e09-906d-20701978ee11','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-ComputeExtraConfigPre-gpdibvwxle2l','7a050f94-0fed-4e09-906d-20701978ee11','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1726,'22311caa-c021-48cb-ae84-d707e350198a','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','NodeTLSCAData','4f108339-8096-4d96-9939-14221de32bbd','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1727,'393b9b1a-04c7-4756-a5dc-45af368fb95c','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NetHostMap-igv7s56munc6','state changed','OS::Heat::Value',NULL,1074),(1728,'af949edf-84d6-4104-b417-6d3efc4077e2','044d99ea-7ef8-4d39-bda7-cc0b7a72ac50','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-HeatApiCfnLogging-mqmyaufpjmfe','044d99ea-7ef8-4d39-bda7-cc0b7a72ac50','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1729,'cb5092d4-80e6-46bc-ac36-63ec92bf04d7','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','NodeTLSCAData','3d4f732d-03e2-4837-a330-5ab6e165d659','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1730,'332154f4-95ab-416b-b093-d6b3a432dcf6','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NetHostMap-arssbqokc2c2','state changed','OS::Heat::Value',NULL,1076),(1731,'61e09f7d-b558-4f22-8e36-3f55d4b422f6','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-InternalApiPort-723tnc5bzjel','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1079),(1732,'b8be9702-2e5c-4f9b-a0bc-5e160286532a','c5c4b30f-0b62-4e52-a817-5568773536a2','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-StoragePort-4tcu7m6odtx5','c5c4b30f-0b62-4e52-a817-5568773536a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1733,'bd1b9040-de55-4102-8ba5-eac51a95c619','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NovaComputeAnsibleHostVars-gv7iz52tpjoq','state changed','OS::Heat::Value',NULL,1083),(1734,'1d11d7db-d55e-4f3c-8320-d1a403701307','044d99ea-7ef8-4d39-bda7-cc0b7a72ac50','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e-HeatApiCfnLogging-mqmyaufpjmfe','044d99ea-7ef8-4d39-bda7-cc0b7a72ac50','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1735,'1d8bd446-f162-48f3-8697-e0c4bab38ba9','7a050f94-0fed-4e09-906d-20701978ee11','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-ComputeExtraConfigPre-gpdibvwxle2l','7a050f94-0fed-4e09-906d-20701978ee11','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1736,'695a8d61-d497-441e-9406-4ce9a53204d4','07ca4ae4-841c-4417-aff5-2faaf096899b','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-StoragePort-4sntms2aockp','07ca4ae4-841c-4417-aff5-2faaf096899b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1737,'eb11c2d3-f916-46b2-b301-421767896368','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-ComputeExtraConfigPre-uattz54wxujw','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1082),(1738,'e0f95216-a262-470c-9a49-44460a2df7d2','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ContainersCommon-srow3e6f7xoo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1739,'545d50f9-e3c1-44c3-9790-a01b797a8ca7','35a0f192-3141-4e6b-b91e-f9ace0f4d6bc','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-27-35acnq63o64b-ContainersCommon-6f4xn3lfxqns','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1740,'67143d84-8c65-4869-9814-5c0c6a9312f7','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-TenantPort-36gxnalfsrey','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1084),(1741,'f51b4597-d947-44eb-ab0d-83e3d216f15e','ef740b81-663b-475e-bb1a-461f98a9858d','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-InternalApiPort-723tnc5bzjel','ef740b81-663b-475e-bb1a-461f98a9858d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1742,'9872173b-d9eb-4ae4-9591-61ad48437cae','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NovaComputeAnsibleHostVars-gv7iz52tpjoq','state changed','OS::Heat::Value',NULL,1083),(1743,'38e7fa8f-dc2d-440a-8a11-125688bca4fd','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NovaComputeAnsibleHostVars-qy6hisetbi7f','state changed','OS::Heat::Value',NULL,1086),(1744,'3f392e17-d7d6-4fde-a40c-ba96568dc825','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NovaComputeAnsibleHostVars-qy6hisetbi7f','state changed','OS::Heat::Value',NULL,1086),(1745,'dd132451-19e2-4eba-a843-0b5634ad1b30','c5c4b30f-0b62-4e52-a817-5568773536a2','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-StoragePort-4tcu7m6odtx5-StorageDeployedPort-sgsmrtknr42k','state changed','OS::Heat::Value',NULL,1089),(1746,'aad936d4-0324-438d-b7de-4e35947b77c4','34e524b6-6c54-4f97-8086-a47214b0df35','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-ComputeExtraConfigPre-uattz54wxujw','34e524b6-6c54-4f97-8086-a47214b0df35','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1747,'81ece849-5418-4013-9c41-6706aa2bacc1','9b90def5-ab1c-468a-b6d4-933fcbbd0057','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ContainersCommon-srow3e6f7xoo','9b90def5-ab1c-468a-b6d4-933fcbbd0057','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1748,'a5b1dae4-36a9-4d90-9957-b136568459ae','133cbaa7-7dce-46c3-8e75-778e21fecaa5','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-TenantPort-3qzt5zoqraj5-TenantDeployedPort-ovb3agvs7rt7','state changed','OS::Heat::Value',NULL,1088),(1749,'867fba56-2374-4fe6-9966-8db4a0060caf','de315a59-df88-4ae5-9405-4a492636cc75','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-InternalApiPort-doc456cwlnmt-InternalApiDeployedPort-s3bp6f7hafzx','state changed','OS::Heat::Value',NULL,1087),(1750,'ff36b225-396b-43ae-a2c5-8d90540ce890','bdfd3e55-0f4a-4d2f-9b6f-9a7386209ffa','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-27-35acnq63o64b-ContainersCommon-6f4xn3lfxqns','bdfd3e55-0f4a-4d2f-9b6f-9a7386209ffa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1751,'48269c91-7761-48b6-a664-e59d7c66d4ae','c5c4b30f-0b62-4e52-a817-5568773536a2','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-StoragePort-4tcu7m6odtx5-StorageDeployedPort-sgsmrtknr42k','state changed','OS::Heat::Value',NULL,1089),(1752,'d4136044-9683-464c-a1cf-59bf97415288','9b90def5-ab1c-468a-b6d4-933fcbbd0057','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ContainersCommon-srow3e6f7xoo','9b90def5-ab1c-468a-b6d4-933fcbbd0057','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1753,'f6f0430a-d668-494f-8756-710d6705f4a7','34e524b6-6c54-4f97-8086-a47214b0df35','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-ComputeExtraConfigPre-uattz54wxujw','34e524b6-6c54-4f97-8086-a47214b0df35','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1754,'59c00b7b-343e-47f8-acf9-c0a952b49d30','133cbaa7-7dce-46c3-8e75-778e21fecaa5','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-TenantPort-3qzt5zoqraj5-TenantDeployedPort-ovb3agvs7rt7','state changed','OS::Heat::Value',NULL,1088),(1755,'b2da9da7-d2bb-4aed-a32a-a99d1cd9633c','c5c4b30f-0b62-4e52-a817-5568773536a2','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-StoragePort-4tcu7m6odtx5','c5c4b30f-0b62-4e52-a817-5568773536a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1756,'1484278c-7cdf-4fd3-8272-aa1a9f5dec0d','bdfd3e55-0f4a-4d2f-9b6f-9a7386209ffa','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-27-35acnq63o64b-ContainersCommon-6f4xn3lfxqns','bdfd3e55-0f4a-4d2f-9b6f-9a7386209ffa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1757,'9cd9b43b-40f7-4954-9975-1acf71ed84a3','133cbaa7-7dce-46c3-8e75-778e21fecaa5','2026-06-13 07:57:35',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-TenantPort-3qzt5zoqraj5','133cbaa7-7dce-46c3-8e75-778e21fecaa5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1758,'5a1e315e-05ed-451c-8e10-3243d2ddde89','15bd833b-9a82-42d8-a2bd-f570b6c8e9f4','2026-06-13 07:57:35',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-TenantPort-36gxnalfsrey','15bd833b-9a82-42d8-a2bd-f570b6c8e9f4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1759,'3787fb94-02aa-456f-9026-d7e022e8f466','07ca4ae4-841c-4417-aff5-2faaf096899b','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-StoragePort-4sntms2aockp-StorageDeployedPort-hzoldwxkagyu','state changed','OS::Heat::Value',NULL,1090),(1760,'67568787-0ef2-40c6-aadb-c6ebb5ccc10a','de315a59-df88-4ae5-9405-4a492636cc75','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-InternalApiPort-doc456cwlnmt-InternalApiDeployedPort-s3bp6f7hafzx','state changed','OS::Heat::Value',NULL,1087),(1761,'e0bead04-3a11-4494-83a8-40bf86adbf2b','07ca4ae4-841c-4417-aff5-2faaf096899b','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-StoragePort-4sntms2aockp-StorageDeployedPort-hzoldwxkagyu','state changed','OS::Heat::Value',NULL,1090),(1762,'598dc8c4-586f-429c-aa57-3edb3fc71d71','de315a59-df88-4ae5-9405-4a492636cc75','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-InternalApiPort-doc456cwlnmt','de315a59-df88-4ae5-9405-4a492636cc75','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1763,'734c3dde-ba54-4092-9984-b05a550e0389','07ca4ae4-841c-4417-aff5-2faaf096899b','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-StoragePort-4sntms2aockp','07ca4ae4-841c-4417-aff5-2faaf096899b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1764,'4c5b1255-3a6e-4723-b371-14a655403034','ef740b81-663b-475e-bb1a-461f98a9858d','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-InternalApiPort-723tnc5bzjel-InternalApiDeployedPort-s3lxt3gppmzs','state changed','OS::Heat::Value',NULL,1091),(1765,'7b68abb0-178f-430e-a597-32b34a82c730','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','21','3c19fbdc-eaa2-438f-a903-59dd0de75fe7','state changed','OS::TripleO::Services::Kernel',NULL,1064),(1766,'610f30c8-070f-404c-957b-26c508ad1149','ef740b81-663b-475e-bb1a-461f98a9858d','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-InternalApiPort-723tnc5bzjel-InternalApiDeployedPort-s3lxt3gppmzs','state changed','OS::Heat::Value',NULL,1091),(1767,'a248a7b7-07b7-44b3-92a9-aeba66744cce','15bd833b-9a82-42d8-a2bd-f570b6c8e9f4','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-TenantPort-36gxnalfsrey-TenantDeployedPort-n3beawfo45hy','state changed','OS::Heat::Value',NULL,1092),(1768,'57ee4628-d5b0-4724-97f1-f4dcf30e324a','15bd833b-9a82-42d8-a2bd-f570b6c8e9f4','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-TenantPort-36gxnalfsrey-TenantDeployedPort-n3beawfo45hy','state changed','OS::Heat::Value',NULL,1092),(1769,'c8f95af6-33c0-444c-8db7-2ccab3f3a8f7','15bd833b-9a82-42d8-a2bd-f570b6c8e9f4','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-TenantPort-36gxnalfsrey','15bd833b-9a82-42d8-a2bd-f570b6c8e9f4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1770,'7e5d106b-0730-41e2-b5b7-f93c8d563a4b','ef740b81-663b-475e-bb1a-461f98a9858d','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-InternalApiPort-723tnc5bzjel','ef740b81-663b-475e-bb1a-461f98a9858d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1771,'7ce4b642-1269-45e2-a2d6-9717d7791cf2','188698ca-ecde-40bd-8cef-25570cf0eede','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','ContainersCommon','d202a4ff-0a71-417e-b877-d2cd4064dfa7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1772,'05cb2a7f-eeec-4a6d-86f5-246532383ce6','188698ca-ecde-40bd-8cef-25570cf0eede','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaCommon-zjv67vu5temx','188698ca-ecde-40bd-8cef-25570cf0eede','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1773,'3effb08d-0933-4c3c-b4df-6a7a8221c841','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','NovaCompute','b46a18d9-13bf-4d0b-917e-744f41fa8400','state changed','OS::TripleO::ComputeServer',NULL,1041),(1774,'67f08e60-3fcd-4331-9488-8286ba8e0d73','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','25','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn','state changed','OS::TripleO::Services::ManilaScheduler',NULL,1096),(1775,'d2dbd314-1bc9-43b4-ac8f-2583b49ccbfe','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-ComputeExtraConfigPre-zz6pj3b4b5pt','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1097),(1776,'bd51f014-4243-4dd3-861b-f2d4dd3038a8','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-TenantPort-mpdsivmc3evt','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1098),(1777,'3ddc4b8c-77a2-436b-89c5-e419a2bab844','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-PreNetworkConfig-jm6vcwcpr6io','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1778,'e66fe50b-3f74-4b45-9a02-496c0ab1131b','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NetHostMap-fgfmfdezqgbt','state changed','OS::Heat::Value',NULL,1099),(1779,'84b86179-7cc6-40d2-b5fc-f30c84216af4','d63cced9-269c-438f-ba16-046684db51e9','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn','d63cced9-269c-438f-ba16-046684db51e9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1780,'9c299826-7053-4d0b-9736-8ab5ae1e6472','96ee0382-b65c-45e8-97bc-39be70aed6b5','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-ComputeExtraConfigPre-zz6pj3b4b5pt','96ee0382-b65c-45e8-97bc-39be70aed6b5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1781,'db5eac8d-1e05-4b7f-84c0-a6e30df29eb8','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','PreNetworkConfig','ce0cce01-2894-411f-83bc-36b33f299521','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1782,'a896c175-d594-4313-9150-c340d5cb5c5c','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NetHostMap-fgfmfdezqgbt','state changed','OS::Heat::Value',NULL,1099),(1783,'eb6273a9-9811-4477-af56-d779ac84a10d','96ee0382-b65c-45e8-97bc-39be70aed6b5','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-ComputeExtraConfigPre-zz6pj3b4b5pt','96ee0382-b65c-45e8-97bc-39be70aed6b5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1784,'50dced0e-c1c5-4b83-8d7c-0c06a4c53925','28ef4f05-a350-46ad-9ed7-795f6dd54cb4','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-TenantPort-mpdsivmc3evt','28ef4f05-a350-46ad-9ed7-795f6dd54cb4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1785,'5cf7e298-b8c1-45a3-b943-4d25c8588dd2','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NovaComputeAnsibleHostVars-kwxzia6vq3sx','state changed','OS::Heat::Value',NULL,1102),(1786,'7e5a0506-f07b-403b-8b69-a9863f9b7985','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-StoragePort-xt5ls6las37j','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1101),(1787,'63ff5029-2c34-4bbe-af71-056feed22793','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NodeTLSCAData-jhio7tqmh62c','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1788,'a4a2c182-5910-4dc9-9f37-206d1b2bc2fc','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','96ee0382-b65c-45e8-97bc-39be70aed6b5','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1097),(1789,'2f2550f8-4aad-4a88-8e3f-2a25c691a632','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NovaComputeAnsibleHostVars-kwxzia6vq3sx','state changed','OS::Heat::Value',NULL,1102),(1790,'0c44af21-3402-47a7-bcce-576bbad0cb62','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-InternalApiPort-dlxx5at62iv2','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1104),(1791,'59e46005-b699-472f-a019-4a44026e3c88','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','NodeTLSCAData','070d8b97-2ccf-4d1b-82fc-6b2d5e5d5d94','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1792,'bce1620d-708c-4c66-ad5b-648e8bbcab36','28ef4f05-a350-46ad-9ed7-795f6dd54cb4','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-TenantPort-mpdsivmc3evt-TenantDeployedPort-qdsbtr4lzxuc','state changed','OS::Heat::Value',NULL,1106),(1793,'7960fa96-804b-41dc-b283-73bf388da490','28ef4f05-a350-46ad-9ed7-795f6dd54cb4','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-TenantPort-mpdsivmc3evt-TenantDeployedPort-qdsbtr4lzxuc','state changed','OS::Heat::Value',NULL,1106),(1794,'0f5e45e3-d878-4c05-96ac-d955692c0672','5e592afc-921c-4f2a-b0d5-230cf1a15d86','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-StoragePort-xt5ls6las37j','5e592afc-921c-4f2a-b0d5-230cf1a15d86','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1795,'3bf3b042-4aa7-465c-a47d-ed233e158e07','bd4bb4b0-a2ed-4d68-9005-f50f9462d876','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-InternalApiPort-dlxx5at62iv2','bd4bb4b0-a2ed-4d68-9005-f50f9462d876','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1796,'d913ab7a-7017-4fca-9a88-5dac0a3841da','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NodeExtraConfig-z7frknbk56la','state changed','OS::TripleO::NodeExtraConfig',NULL,1107),(1797,'8596bdc0-6af1-4211-9134-9a8630624898','28ef4f05-a350-46ad-9ed7-795f6dd54cb4','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-TenantPort-mpdsivmc3evt','28ef4f05-a350-46ad-9ed7-795f6dd54cb4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1798,'a515990e-8825-4912-94bf-a1b57ad11374','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','7a050f94-0fed-4e09-906d-20701978ee11','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1073),(1799,'1270515b-b074-4211-8098-e529224922f7','d63cced9-269c-438f-ba16-046684db51e9','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-ContainersCommon-r32cdu7gpldr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1800,'8a880f23-3660-494d-ae0c-8302540ae0e4','5e592afc-921c-4f2a-b0d5-230cf1a15d86','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-StoragePort-xt5ls6las37j-StorageDeployedPort-4m6z5tjyad27','state changed','OS::Heat::Value',NULL,1108),(1801,'7452f5d0-8167-46f2-af0b-a0290a03687b','66dc0d87-ba24-4f78-b5bd-43e45403dc35','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NodeExtraConfig-z7frknbk56la','66dc0d87-ba24-4f78-b5bd-43e45403dc35','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1802,'57085056-dd46-4095-97d7-511950247f7d','bd4bb4b0-a2ed-4d68-9005-f50f9462d876','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-InternalApiPort-dlxx5at62iv2-InternalApiDeployedPort-segylcq6qo5j','state changed','OS::Heat::Value',NULL,1109),(1803,'dd999631-9c97-4466-aabe-8cb29a4aeb75','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','TenantPort','133cbaa7-7dce-46c3-8e75-778e21fecaa5','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1072),(1804,'489b5d05-3696-46cc-830a-caaaf9c63549','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','InternalApiPort','de315a59-df88-4ae5-9405-4a492636cc75','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1071),(1805,'d56dc584-1ce9-4c28-a96b-83917ed5baa0','bd4bb4b0-a2ed-4d68-9005-f50f9462d876','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-InternalApiPort-dlxx5at62iv2-InternalApiDeployedPort-segylcq6qo5j','state changed','OS::Heat::Value',NULL,1109),(1806,'ce05ab94-d66c-425c-807e-f67417875e25','66dc0d87-ba24-4f78-b5bd-43e45403dc35','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NodeExtraConfig-z7frknbk56la','66dc0d87-ba24-4f78-b5bd-43e45403dc35','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1807,'49551847-86b7-48f5-b9dc-6d57decf409f','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','HeatApiCfnLogging','044d99ea-7ef8-4d39-bda7-cc0b7a72ac50','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1808,'554c03e8-804f-4058-a149-ddf812f0bf21','bd4bb4b0-a2ed-4d68-9005-f50f9462d876','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-InternalApiPort-dlxx5at62iv2','bd4bb4b0-a2ed-4d68-9005-f50f9462d876','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1809,'0663edbb-b0e4-42a8-ba7c-fc4c755a5862','5e592afc-921c-4f2a-b0d5-230cf1a15d86','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-StoragePort-xt5ls6las37j-StorageDeployedPort-4m6z5tjyad27','state changed','OS::Heat::Value',NULL,1108),(1810,'270ebd40-39c0-453c-8938-b65b644a3157','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NodeExtraConfig-7u7ix3bbdjj2','state changed','OS::TripleO::NodeExtraConfig',NULL,1114),(1811,'d9b75e3c-82cc-4053-b353-f22177436c64','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-RoleParametersValue-udnzgkomuxbf','state changed','OS::Heat::Value',NULL,1111),(1812,'67323fa3-2422-438b-b728-545daf3d8447','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-16-koxqfym5tg5e','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1813,'bf5f79e7-aff8-4f48-b3d1-d994f7ab5b77','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','NodeExtraConfig','66dc0d87-ba24-4f78-b5bd-43e45403dc35','state changed','OS::TripleO::NodeExtraConfig',NULL,1107),(1814,'b31c319a-c8da-43b8-91fc-0b3e50b40d12','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','StoragePort','07ca4ae4-841c-4417-aff5-2faaf096899b','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1077),(1815,'79ead52d-5a65-4da7-a380-5507498455b0','6f33d2e5-5c46-4757-857a-b7283fbc9289','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-ContainersCommon-r32cdu7gpldr','6f33d2e5-5c46-4757-857a-b7283fbc9289','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1816,'ea9ecffd-62a4-411f-99fc-63bfad98844d','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','StoragePort','c5c4b30f-0b62-4e52-a817-5568773536a2','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1078),(1817,'9330408f-bf8b-4a76-9780-3005529acafb','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-RoleParametersValue-udnzgkomuxbf','state changed','OS::Heat::Value',NULL,1111),(1818,'161a3b11-2089-48ce-8fc8-8814af6168c3','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','34e524b6-6c54-4f97-8086-a47214b0df35','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1082),(1819,'9f1015e2-e87d-4500-96dc-1489e7a605be','5e592afc-921c-4f2a-b0d5-230cf1a15d86','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-StoragePort-xt5ls6las37j','5e592afc-921c-4f2a-b0d5-230cf1a15d86','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1820,'30cc2cfc-9a4e-48d9-b3d0-26401c828f6e','6f33d2e5-5c46-4757-857a-b7283fbc9289','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-ContainersCommon-r32cdu7gpldr','6f33d2e5-5c46-4757-857a-b7283fbc9289','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1821,'46c7d857-5630-4d34-a0aa-6511aa302f37','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','InternalApiPort','ef740b81-663b-475e-bb1a-461f98a9858d','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1079),(1822,'4438603f-08ee-42b8-87b8-6086d32d37ec','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','ContainersCommon','9b90def5-ab1c-468a-b6d4-933fcbbd0057','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1823,'b944e97a-5132-436b-8842-2c7174207a2b','35a0f192-3141-4e6b-b91e-f9ace0f4d6bc','2026-06-13 07:57:36',NULL,'CREATE','COMPLETE','ContainersCommon','bdfd3e55-0f4a-4d2f-9b6f-9a7386209ffa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1824,'af5c3eda-0a44-480a-ae45-885824060d19','270ddb9f-b5fe-4ba0-9723-251791740c71','2026-06-13 07:57:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NodeExtraConfig-7u7ix3bbdjj2','270ddb9f-b5fe-4ba0-9723-251791740c71','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1825,'3e948788-8ed0-49ab-8fa6-bdd6afad17f8','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NodeExtraConfig-uhyde2g6m6dz','state changed','OS::TripleO::NodeExtraConfig',NULL,1122),(1826,'d33bf74d-858a-4284-be92-0e5a73da0b04','270ddb9f-b5fe-4ba0-9723-251791740c71','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NodeExtraConfig-7u7ix3bbdjj2','270ddb9f-b5fe-4ba0-9723-251791740c71','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1827,'1881cdab-c92e-4090-a494-9ce5898a8ef8','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','TenantPort','15bd833b-9a82-42d8-a2bd-f570b6c8e9f4','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1084),(1828,'adf08e9f-8a91-42ae-a1b2-8f9bcb5e6914','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NetIpMap-f5hb5uwl7ep3','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1123),(1829,'09bd576d-9538-4020-88f2-36888c36cd01','35a0f192-3141-4e6b-b91e-f9ace0f4d6bc','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-27-35acnq63o64b','35a0f192-3141-4e6b-b91e-f9ace0f4d6bc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1830,'ea31d8b9-8cd1-4d1e-b027-c2f290d9e33a','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','ManilaCommon','188698ca-ecde-40bd-8cef-25570cf0eede','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1831,'5b80508f-ca51-4717-8ea7-5892a2655894','148bdc7d-c24c-40fc-aad1-75df778be6fd','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NodeExtraConfig-uhyde2g6m6dz','148bdc7d-c24c-40fc-aad1-75df778be6fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1832,'407271d9-1461-49a3-9ca7-69e3112ecaa5','148bdc7d-c24c-40fc-aad1-75df778be6fd','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NodeExtraConfig-uhyde2g6m6dz','148bdc7d-c24c-40fc-aad1-75df778be6fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1833,'1a0f2c93-daaf-424f-aff6-476fc9709ab4','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','NodeExtraConfig','148bdc7d-c24c-40fc-aad1-75df778be6fd','state changed','OS::TripleO::NodeExtraConfig',NULL,1122),(1834,'07025d5d-1268-4d4e-8c01-a8a4df5cee2d','843edffe-e4c5-4c13-b177-c51f844389ee','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NetIpMap-f5hb5uwl7ep3','843edffe-e4c5-4c13-b177-c51f844389ee','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1835,'6264a2f2-a422-404c-8e62-132624f28e77','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NetIpMap-yq65swrxe6ps','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1128),(1836,'12ce644a-e1b5-46a3-8d72-c6b00a25fd57','2cbb0f3f-4fa5-4bd2-97b3-7a5fb2f9c71e','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NetIpMap-yq65swrxe6ps','2cbb0f3f-4fa5-4bd2-97b3-7a5fb2f9c71e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1837,'47d2de75-d6cb-40a4-8cb4-7f6a88b9fb4f','843edffe-e4c5-4c13-b177-c51f844389ee','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NetIpMap-f5hb5uwl7ep3-NetIpMapValue-ck5jmiuspgue','state changed','OS::Heat::Value',NULL,1129),(1838,'70efcf83-799a-4908-a363-e738e65965c6','843edffe-e4c5-4c13-b177-c51f844389ee','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NetIpMap-f5hb5uwl7ep3-NetIpMapValue-ck5jmiuspgue','state changed','OS::Heat::Value',NULL,1129),(1839,'926212bd-9191-4a96-a714-cc94b34c2910','843edffe-e4c5-4c13-b177-c51f844389ee','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26-NetIpMap-f5hb5uwl7ep3','843edffe-e4c5-4c13-b177-c51f844389ee','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1840,'6c9ecd3f-e448-4633-b4b6-d758e8f7fbcc','2cbb0f3f-4fa5-4bd2-97b3-7a5fb2f9c71e','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NetIpMap-yq65swrxe6ps-NetIpMapValue-fw7pydzlr7jw','state changed','OS::Heat::Value',NULL,1130),(1841,'78dcb09c-fcc8-4109-b602-969646de91c7','2cbb0f3f-4fa5-4bd2-97b3-7a5fb2f9c71e','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NetIpMap-yq65swrxe6ps-NetIpMapValue-fw7pydzlr7jw','state changed','OS::Heat::Value',NULL,1130),(1842,'51599e01-08a8-46ae-b7f9-50e006b67939','2cbb0f3f-4fa5-4bd2-97b3-7a5fb2f9c71e','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a-NetIpMap-yq65swrxe6ps','2cbb0f3f-4fa5-4bd2-97b3-7a5fb2f9c71e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1843,'83be3f9b-d444-45a2-8b43-1594cf5a6801','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','16','2a7fad8d-cc6e-466d-a3a3-4bd5a2a0f10f','state changed','OS::TripleO::Services::HeatApiCfn',NULL,1018),(1844,'44dfb363-541f-4ed9-a465-a673234df252','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','TenantPort','28ef4f05-a350-46ad-9ed7-795f6dd54cb4','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1098),(1845,'13f84f29-6b2d-4e4d-9416-a556504a7258','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','InternalApiPort','bd4bb4b0-a2ed-4d68-9005-f50f9462d876','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1104),(1846,'e35d7994-d5fd-4693-92bd-d877fea6e74f','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','StoragePort','5e592afc-921c-4f2a-b0d5-230cf1a15d86','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1101),(1847,'9d20af4c-efb3-4313-bb37-c9aebcab50f5','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','27','35a0f192-3141-4e6b-b91e-f9ace0f4d6bc','state changed','OS::TripleO::Services::Memcached',NULL,1055),(1848,'cab6240a-d379-40df-9106-7b8689d93beb','d63cced9-269c-438f-ba16-046684db51e9','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-RoleParametersValue-4i5fsj5wctcx','state changed','OS::Heat::Value',NULL,1142),(1849,'766a6621-d8c7-46e2-a4f7-dee9fb839330','d63cced9-269c-438f-ba16-046684db51e9','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-RoleParametersValue-4i5fsj5wctcx','state changed','OS::Heat::Value',NULL,1142),(1850,'ae3030f9-9a3e-4d3b-b234-5d8f82d3a8aa','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NetIpMap-r6shpfefvzkk','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1145),(1851,'7083a86b-20c7-43cd-adad-5b5dd10aa754','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','ManilaShareContainerBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,1146),(1852,'add12ec1-2d1f-43df-bc02-814d8d5ed8ac','9d9923c8-d706-4d48-bdd2-023ac78ab0a4','2026-06-13 07:57:37',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NetIpMap-r6shpfefvzkk','9d9923c8-d706-4d48-bdd2-023ac78ab0a4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1853,'f5cc15d2-3ee0-4347-8673-5ba608f7fe68','d63cced9-269c-438f-ba16-046684db51e9','2026-06-13 07:57:37',NULL,'CREATE','COMPLETE','ContainersCommon','6f33d2e5-5c46-4757-857a-b7283fbc9289','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1854,'edaf752b-a9ce-4e69-9f15-9a6251108d49','9d9923c8-d706-4d48-bdd2-023ac78ab0a4','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NetIpMap-r6shpfefvzkk-NetIpMapValue-i52vp56wp7j3','state changed','OS::Heat::Value',NULL,1149),(1855,'dc5c7b5f-f5b6-4c21-b2ab-d71b01cf0034','9d9923c8-d706-4d48-bdd2-023ac78ab0a4','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NetIpMap-r6shpfefvzkk-NetIpMapValue-i52vp56wp7j3','state changed','OS::Heat::Value',NULL,1149),(1856,'22dcf4ed-4ae2-4c51-91f6-c087de7f9d32','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','NodeExtraConfig','270ddb9f-b5fe-4ba0-9723-251791740c71','state changed','OS::TripleO::NodeExtraConfig',NULL,1114),(1857,'42e0c831-17bf-4815-b16a-4961f70369d6','9d9923c8-d706-4d48-bdd2-023ac78ab0a4','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g-NetIpMap-r6shpfefvzkk','9d9923c8-d706-4d48-bdd2-023ac78ab0a4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1858,'4fed4d3f-241f-47b9-bd9c-cab7069ff66a','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','20','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-20-e32d2a4xzptn','state changed','OS::TripleO::Services::Iscsid',NULL,1151),(1859,'d1da83f2-174b-4923-98c6-84ce6d7e216d','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1860,'4bfc0689-e563-4d36-9802-b8c44ae5fea6','81555c93-2d9c-4692-8814-783f876c0424','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-20-e32d2a4xzptn','81555c93-2d9c-4692-8814-783f876c0424','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1861,'372d3cf1-9617-485b-8010-4f41c069f67b','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','NetIpMap','843edffe-e4c5-4c13-b177-c51f844389ee','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1123),(1862,'ec7a458b-1a3b-470b-a1c1-45490fef99b7','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-0-jdarimczow26','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1863,'663c6310-f3b2-4c12-9362-3044bf6dfb44','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','31','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza','state changed','OS::TripleO::Services::NeutronApi',NULL,1152),(1864,'d887ba31-0cf3-4930-94e6-6ef916dec552','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','NetIpMap','2cbb0f3f-4fa5-4bd2-97b3-7a5fb2f9c71e','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1128),(1865,'de8d39d9-2e89-4840-918b-6c0969ada01f','81555c93-2d9c-4692-8814-783f876c0424','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-20-e32d2a4xzptn-ContainersCommon-r4hcmm6g3okm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1866,'e7ce78e8-ff9e-4af3-999f-07e0e0733025','02e417f5-77e0-4b7d-99c1-64f5383fc66a','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-1-64qzoc4tm44a','02e417f5-77e0-4b7d-99c1-64f5383fc66a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1867,'9fef546e-ed57-45ac-8c38-2e6f8af60418','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ManilaBase-y6bls4yxzlbt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1153),(1868,'9c254a21-8780-492f-aa3f-1d06d482a94f','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza','6431ff66-a2fa-4a58-95c7-0a74c61461b0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1869,'34314040-5955-4e6c-a097-bfcb29baa60e','183d93d9-7632-4360-a54a-a316759fb5ed','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-20-e32d2a4xzptn-ContainersCommon-r4hcmm6g3okm','183d93d9-7632-4360-a54a-a316759fb5ed','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1870,'b0caddb5-3e56-4bef-8169-3ab1900d283f','183d93d9-7632-4360-a54a-a316759fb5ed','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-20-e32d2a4xzptn-ContainersCommon-r4hcmm6g3okm','183d93d9-7632-4360-a54a-a316759fb5ed','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1871,'bb57b3a9-e280-4550-8dc1-8de0d76401c6','568a1575-0211-4905-b753-e475dd42815f','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ManilaBase-y6bls4yxzlbt','568a1575-0211-4905-b753-e475dd42815f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1872,'f392a455-fd39-43d5-944c-483df41117f6','568a1575-0211-4905-b753-e475dd42815f','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ManilaBase-y6bls4yxzlbt','568a1575-0211-4905-b753-e475dd42815f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1873,'531d5ba2-2cb8-4f0b-8aee-adc9ae3e5aa6','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-ContainersCommon-6phh6h3bydns','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1874,'0bbbb066-5bb8-422c-a251-a931bc57ccad','e89a87b6-b31d-4d5c-814a-d2a2cde347e2','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-ContainersCommon-6phh6h3bydns','e89a87b6-b31d-4d5c-814a-d2a2cde347e2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1875,'7d2d217a-3e0f-4ca9-b327-8efa2fa1966c','e89a87b6-b31d-4d5c-814a-d2a2cde347e2','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-ContainersCommon-6phh6h3bydns','e89a87b6-b31d-4d5c-814a-d2a2cde347e2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1876,'c8dffd2b-7123-409b-95f5-7140094dfdfb','d63cced9-269c-438f-ba16-046684db51e9','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-MySQLClient-arjnuc23x55n','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1877,'37596d2a-1c00-4ff6-bfbb-7490785af18f','91df8955-e8ff-4547-8f68-03809742a593','2026-06-13 07:57:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-MySQLClient-arjnuc23x55n','91df8955-e8ff-4547-8f68-03809742a593','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1878,'c9d5fa50-6b5b-4419-ba91-c43683e000fb','91df8955-e8ff-4547-8f68-03809742a593','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-MySQLClient-arjnuc23x55n','91df8955-e8ff-4547-8f68-03809742a593','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1879,'69d32eb7-0ace-42a6-984c-02f66bcf5937','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','2026-06-13 07:57:38',NULL,'CREATE','COMPLETE','1','02e417f5-77e0-4b7d-99c1-64f5383fc66a','state changed','OS::TripleO::Compute',NULL,1020),(1880,'52114575-1418-4583-a03f-94886aec486b','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','NetIpMap','9d9923c8-d706-4d48-bdd2-023ac78ab0a4','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1145),(1881,'df9ac67f-e4c3-4506-a255-998b0e4f5a29','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','0','3351f4b5-b6d2-4cf5-bb40-c1931670f1c4','state changed','OS::TripleO::Compute',NULL,1025),(1882,'fb3014e5-16aa-4a23-92b7-27380506f6e1','6c27444a-c396-4268-b71c-9036fba94480','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','overcloud-Compute-ajofa4bwgzle-2-v6vtvo5i5b5g','6c27444a-c396-4268-b71c-9036fba94480','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1883,'9d372e44-ace2-466f-aeef-373e30e8232f','81555c93-2d9c-4692-8814-783f876c0424','2026-06-13 07:57:39',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-20-e32d2a4xzptn-RoleParametersValue-m27noxu2wf6r','state changed','OS::Heat::Value',NULL,1154),(1884,'293e862f-03e7-4e84-ac1b-de9509d261ba','81555c93-2d9c-4692-8814-783f876c0424','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-20-e32d2a4xzptn-RoleParametersValue-m27noxu2wf6r','state changed','OS::Heat::Value',NULL,1154),(1885,'fb1db023-683a-4563-a2e8-304e0110bb0a','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:39',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-RoleParametersValue-rsgwtjr7y5q6','state changed','OS::Heat::Value',NULL,1155),(1886,'8848eae2-c3aa-4e4c-8174-aabba45eeb5f','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-RoleParametersValue-rsgwtjr7y5q6','state changed','OS::Heat::Value',NULL,1155),(1887,'314c56b3-f112-4121-8c47-14e8465da158','81555c93-2d9c-4692-8814-783f876c0424','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','ContainersCommon','183d93d9-7632-4360-a54a-a316759fb5ed','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1888,'ba31f0da-3a34-4441-a8ea-27a0f62e422b','81555c93-2d9c-4692-8814-783f876c0424','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-20-e32d2a4xzptn','81555c93-2d9c-4692-8814-783f876c0424','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1889,'a79fb940-da5c-4f6c-a8d9-2c5a54b9330d','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','ManilaBase','568a1575-0211-4905-b753-e475dd42815f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1153),(1890,'a2577e36-2726-4aa1-a1b0-464b60a00c06','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:39',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-RoleParametersValue-dqlrpdyjwqfu','state changed','OS::Heat::Value',NULL,1156),(1891,'418f5486-d49a-4a0d-a9c3-81f4f5587b37','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-RoleParametersValue-dqlrpdyjwqfu','state changed','OS::Heat::Value',NULL,1156),(1892,'dad262a7-0797-4980-90a0-58fe6111da15','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','ContainersCommon','e89a87b6-b31d-4d5c-814a-d2a2cde347e2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1893,'9b8236c1-47b4-4b00-bbf4-85a987dc5bf2','d63cced9-269c-438f-ba16-046684db51e9','2026-06-13 07:57:39',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-ManilaBase-7qj5v2jrtt25','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1157),(1894,'b22984f3-5491-4051-9c71-0e12d9e0f4fd','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','2','6c27444a-c396-4268-b71c-9036fba94480','state changed','OS::TripleO::Compute',NULL,1040),(1895,'51966e82-dd7e-4155-aa0f-b29492175b31','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','2026-06-13 07:57:39',NULL,'UPDATE','COMPLETE','overcloud-Compute-ajofa4bwgzle','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(1896,'4ee8a233-f2f5-4c16-9db8-4bde7b78b0b3','1c67fcf3-dbce-4476-8fbb-10710fa68509','2026-06-13 07:57:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-ManilaBase-7qj5v2jrtt25','1c67fcf3-dbce-4476-8fbb-10710fa68509','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1897,'eea12de7-394d-4b80-9694-dbcd8a247be6','d63cced9-269c-438f-ba16-046684db51e9','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','MySQLClient','91df8955-e8ff-4547-8f68-03809742a593','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1898,'28122b42-0620-402b-acaa-f5bc46693ce9','1c67fcf3-dbce-4476-8fbb-10710fa68509','2026-06-13 07:57:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn-ManilaBase-7qj5v2jrtt25','1c67fcf3-dbce-4476-8fbb-10710fa68509','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1899,'4a5f0a72-78e8-441b-a527-d8d1509d0e4b','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:40',NULL,'CREATE','COMPLETE','20','81555c93-2d9c-4692-8814-783f876c0424','state changed','OS::TripleO::Services::Iscsid',NULL,1151),(1900,'e5cd3a49-3272-424c-ac2e-56097466e0d6','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:40',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-MySQLClient-ubq3z7ftoarr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1901,'7f325b34-4029-42f3-8cf4-9ea71d587965','76f451bd-0121-4e74-a225-7648b16db3de','2026-06-13 07:57:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-MySQLClient-ubq3z7ftoarr','76f451bd-0121-4e74-a225-7648b16db3de','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1902,'b8fe110d-5db4-4673-8bd7-763a7d6e86db','76f451bd-0121-4e74-a225-7648b16db3de','2026-06-13 07:57:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-MySQLClient-ubq3z7ftoarr','76f451bd-0121-4e74-a225-7648b16db3de','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1903,'95a9572e-ef8e-4b12-8a81-d620fe95f390','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:40',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-NeutronLogging-r3cch5hscwax','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,1161),(1904,'1bab543c-4726-4ca3-ae6b-7e0bd1d08d1c','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:40',NULL,'CREATE','IN_PROGRESS','24','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-24-d3puserq3yqc','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,1162),(1905,'9aa1ec5d-c851-4690-abd9-a5e57345f129','c82deb14-6380-496d-b836-206b9154c6e4','2026-06-13 07:57:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-NeutronLogging-r3cch5hscwax','c82deb14-6380-496d-b836-206b9154c6e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1906,'0b8bdcf7-3f5c-44b2-8804-7855da56c8ff','7a7070f3-32a5-47f5-8099-0ed3e19ffa88','2026-06-13 07:57:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-24-d3puserq3yqc','7a7070f3-32a5-47f5-8099-0ed3e19ffa88','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1907,'ed4a1b5b-9a14-4c6f-ae67-b5b0460a0d92','7a7070f3-32a5-47f5-8099-0ed3e19ffa88','2026-06-13 07:57:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-24-d3puserq3yqc','7a7070f3-32a5-47f5-8099-0ed3e19ffa88','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1908,'676961e7-802a-4243-a516-192526067979','c82deb14-6380-496d-b836-206b9154c6e4','2026-06-13 07:57:40',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-NeutronLogging-r3cch5hscwax-RoleParametersValue-vzl4z5imsnwm','state changed','OS::Heat::Value',NULL,1163),(1909,'c3caf408-94a9-4941-b1d1-5072503f2682','c82deb14-6380-496d-b836-206b9154c6e4','2026-06-13 07:57:40',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-NeutronLogging-r3cch5hscwax-RoleParametersValue-vzl4z5imsnwm','state changed','OS::Heat::Value',NULL,1163),(1910,'1b8ae758-fafd-4eef-b68f-5e6ccd97f207','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:40',NULL,'CREATE','COMPLETE','Compute','bbf5a9a1-619e-48a8-b7f1-09726a3a5de8','state changed','OS::Heat::ResourceGroup',NULL,999),(1911,'7e08602a-cf3e-4d01-8af6-eb7efd4aa7da','c82deb14-6380-496d-b836-206b9154c6e4','2026-06-13 07:57:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-NeutronLogging-r3cch5hscwax','c82deb14-6380-496d-b836-206b9154c6e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1912,'778b6218-d9da-4f49-8aff-ed3f38b8db7d','d63cced9-269c-438f-ba16-046684db51e9','2026-06-13 07:57:41',NULL,'CREATE','COMPLETE','ManilaBase','1c67fcf3-dbce-4476-8fbb-10710fa68509','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1157),(1913,'3d0e16c2-297b-407c-af44-dd81de692801','d63cced9-269c-438f-ba16-046684db51e9','2026-06-13 07:57:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-25-wchspizahlmn','d63cced9-269c-438f-ba16-046684db51e9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1914,'8c943f20-87f8-447f-9b55-72daa0ddfa43','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:41',NULL,'CREATE','IN_PROGRESS','ManilaShareCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ManilaShareCommon-pgy5iwolwloj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1915,'e8b96db2-e4db-420e-9b9f-bdf9621c4fa1','a12b186d-497b-4fb0-a0a8-55f41eea4983','2026-06-13 07:57:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ManilaShareCommon-pgy5iwolwloj','a12b186d-497b-4fb0-a0a8-55f41eea4983','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1916,'e426ed25-a841-4224-85fc-f490d4b46996','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:41',NULL,'CREATE','COMPLETE','MySQLClient','76f451bd-0121-4e74-a225-7648b16db3de','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1917,'0b0a98c7-4d09-4d32-9514-1ad547c4e0a1','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:41',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-MySQLClient-d2l4ahzlme55','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1918,'aefb3264-ab8b-42fe-bc1f-c50ec8e9198f','3252d974-3229-4fa9-8946-051dfed0b05b','2026-06-13 07:57:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-MySQLClient-d2l4ahzlme55','3252d974-3229-4fa9-8946-051dfed0b05b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1919,'e0911ec9-22d6-4246-ae5d-5725fa558fe9','3252d974-3229-4fa9-8946-051dfed0b05b','2026-06-13 07:57:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-MySQLClient-d2l4ahzlme55','3252d974-3229-4fa9-8946-051dfed0b05b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1920,'1ffbb136-c240-4384-aa6f-193f27f25c8a','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:41',NULL,'CREATE','COMPLETE','25','d63cced9-269c-438f-ba16-046684db51e9','state changed','OS::TripleO::Services::ManilaScheduler',NULL,1096),(1921,'1abbc64b-85d3-47bf-b51a-291cab5f4f96','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:41',NULL,'CREATE','IN_PROGRESS','ComputeServers','overcloud-ComputeServers-g2tdomxvlrz4','state changed','OS::Heat::Value',NULL,1180),(1922,'480ff927-17ac-4167-b35d-46166c786e05','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:41',NULL,'CREATE','IN_PROGRESS','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-zboa2re4lfga','state changed','OS::Heat::Value',NULL,1181),(1923,'950ee002-b11a-42e1-8d71-937c4c011ead','a12b186d-497b-4fb0-a0a8-55f41eea4983','2026-06-13 07:57:41',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ManilaShareCommon-pgy5iwolwloj-ContainersCommon-ndokngrhrlca','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1924,'82a13d48-1fdc-4e32-be57-a3c8898fca9b','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:41',NULL,'CREATE','COMPLETE','NeutronLogging','c82deb14-6380-496d-b836-206b9154c6e4','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,1161),(1925,'23ab8131-4a4c-4667-9563-40cbff1a6932','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:41',NULL,'CREATE','COMPLETE','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-zboa2re4lfga','state changed','OS::Heat::Value',NULL,1181),(1926,'cff4240d-ce73-4fdc-85ea-63b082ed9bbf','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:41',NULL,'CREATE','COMPLETE','24','7a7070f3-32a5-47f5-8099-0ed3e19ffa88','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,1162),(1927,'6d444de6-e698-4dde-b3c4-af42607dc5a8','2b9872c8-596c-4e7b-adb2-6de98fb604ef','2026-06-13 07:57:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ManilaShareCommon-pgy5iwolwloj-ContainersCommon-ndokngrhrlca','2b9872c8-596c-4e7b-adb2-6de98fb604ef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1928,'43ec1f6e-392f-48e6-9149-09da70a88824','2b9872c8-596c-4e7b-adb2-6de98fb604ef','2026-06-13 07:57:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ManilaShareCommon-pgy5iwolwloj-ContainersCommon-ndokngrhrlca','2b9872c8-596c-4e7b-adb2-6de98fb604ef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1929,'97f5edc1-1323-483b-8371-efe7d78a4af6','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:41',NULL,'CREATE','COMPLETE','ComputeServers','overcloud-ComputeServers-g2tdomxvlrz4','state changed','OS::Heat::Value',NULL,1180),(1930,'a1ed0259-8de6-4f40-939a-51638ca90047','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:41',NULL,'CREATE','IN_PROGRESS','ComputeIpListMap','overcloud-ComputeIpListMap-6n24x26xdirb','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1186),(1931,'9a6118c9-52a6-4b53-8552-5cac5b1ea687','0ad8d24c-07c3-4a7a-a4b7-6b33532ede9c','2026-06-13 07:57:41',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeIpListMap-6n24x26xdirb','0ad8d24c-07c3-4a7a-a4b7-6b33532ede9c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1932,'2ae8f312-81bb-4153-9c8e-cbcd345d4ba1','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','28','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-28-olmoazlii5ca','state changed','OS::TripleO::Services::MetricsQdr',NULL,1190),(1933,'1cbfb66c-bb01-4db4-aa15-6cfbc65f5795','0ad8d24c-07c3-4a7a-a4b7-6b33532ede9c','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ComputeIpListMap-6n24x26xdirb-EnabledServicesValue-rtxugmtbkhkc','state changed','OS::Heat::Value',NULL,1192),(1934,'ef97cd62-057e-4efd-a29c-97a4f6dbcb1d','0ad8d24c-07c3-4a7a-a4b7-6b33532ede9c','2026-06-13 07:57:42',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ComputeIpListMap-6n24x26xdirb-EnabledServicesValue-rtxugmtbkhkc','state changed','OS::Heat::Value',NULL,1192),(1935,'cf558a8d-a8d4-4fbf-a79a-035625a0238f','4b4e0119-cc5c-4056-bee3-164cb3f87921','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-28-olmoazlii5ca','4b4e0119-cc5c-4056-bee3-164cb3f87921','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1936,'9755e71c-7ed6-4e54-8a67-fbcd40ef6a8e','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','29','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5','state changed','OS::TripleO::Services::MySQL',NULL,1193),(1937,'627ccee3-9704-4d55-b00c-77b149a9c1ea','4b4e0119-cc5c-4056-bee3-164cb3f87921','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-28-olmoazlii5ca-ContainersCommon-3lpolwigtuap','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1938,'cf8e94fe-a968-4b81-bf78-f3dc1f420e2b','4eef861b-e2a8-41f8-aa46-64aaa3e3d3a2','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-28-olmoazlii5ca-ContainersCommon-3lpolwigtuap','4eef861b-e2a8-41f8-aa46-64aaa3e3d3a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1939,'6f61eb89-8b9c-4ed9-8353-859fb20fba40','4eef861b-e2a8-41f8-aa46-64aaa3e3d3a2','2026-06-13 07:57:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-28-olmoazlii5ca-ContainersCommon-3lpolwigtuap','4eef861b-e2a8-41f8-aa46-64aaa3e3d3a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1940,'b76682f2-4526-48e4-b523-493c311db286','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ContainersCommon-4ww5b4yvwjh7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1941,'305defcc-8377-4084-b1b8-0e4f057ba470','e7972d62-26c2-47e6-955a-282ebb6e0140','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5','e7972d62-26c2-47e6-955a-282ebb6e0140','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1942,'d3792e08-b622-465b-aed1-8ad97c99b70e','021a2eb8-76ed-4adf-82a7-4abbd31e588b','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ContainersCommon-4ww5b4yvwjh7','021a2eb8-76ed-4adf-82a7-4abbd31e588b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1943,'c6d5cea5-787c-4df5-9d26-d3180f9a6581','021a2eb8-76ed-4adf-82a7-4abbd31e588b','2026-06-13 07:57:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ContainersCommon-4ww5b4yvwjh7','021a2eb8-76ed-4adf-82a7-4abbd31e588b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1944,'b9a96100-df02-4224-90bc-76cb354831e2','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-NeutronBase-76pqhywzu2bm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1194),(1945,'23f03470-f930-4614-96aa-00076ac33598','e7972d62-26c2-47e6-955a-282ebb6e0140','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5-MysqlBase-w4wzti5hai6h','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,1195),(1946,'da8f588d-0325-4871-a1d5-d4b48457d32d','cab70f41-97c9-462e-bd13-8a9d301b5050','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-NeutronBase-76pqhywzu2bm','cab70f41-97c9-462e-bd13-8a9d301b5050','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1947,'88026b6f-d463-4d45-b189-4276cdb318f7','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:42',NULL,'CREATE','COMPLETE','MySQLClient','3252d974-3229-4fa9-8946-051dfed0b05b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1948,'bf6360f6-c173-4573-bc8d-c97aade96153','cab70f41-97c9-462e-bd13-8a9d301b5050','2026-06-13 07:57:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-NeutronBase-76pqhywzu2bm','cab70f41-97c9-462e-bd13-8a9d301b5050','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1949,'4ad513dc-564c-416d-ba0a-a07d2609f6fa','21a60ad2-ffdc-43c6-b1b6-032a7b3bbc52','2026-06-13 07:57:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5-MysqlBase-w4wzti5hai6h','21a60ad2-ffdc-43c6-b1b6-032a7b3bbc52','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1950,'05391d45-18f3-4521-8de8-6d31a9ba4cde','21a60ad2-ffdc-43c6-b1b6-032a7b3bbc52','2026-06-13 07:57:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5-MysqlBase-w4wzti5hai6h','21a60ad2-ffdc-43c6-b1b6-032a7b3bbc52','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1951,'9bcd0ed6-b125-4b3e-aa0e-bf59943f9977','a12b186d-497b-4fb0-a0a8-55f41eea4983','2026-06-13 07:57:42',NULL,'CREATE','COMPLETE','ContainersCommon','2b9872c8-596c-4e7b-adb2-6de98fb604ef','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1952,'da57082e-7407-46a1-8664-e733663d9b04','a12b186d-497b-4fb0-a0a8-55f41eea4983','2026-06-13 07:57:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm-ManilaShareCommon-pgy5iwolwloj','a12b186d-497b-4fb0-a0a8-55f41eea4983','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1953,'e43e49fc-6602-4047-a7b6-e5ec1e8455e6','0ad8d24c-07c3-4a7a-a4b7-6b33532ede9c','2026-06-13 07:57:43',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ComputeIpListMap-6n24x26xdirb-NetIpMapValue-3u3iav5cne3v','state changed','OS::Heat::Value',NULL,1196),(1954,'ba3933ac-a7ef-4f98-84f1-2e6c62b2a9de','0ad8d24c-07c3-4a7a-a4b7-6b33532ede9c','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ComputeIpListMap-6n24x26xdirb-NetIpMapValue-3u3iav5cne3v','state changed','OS::Heat::Value',NULL,1196),(1955,'3813a872-621f-46be-9c42-16273303c479','0ad8d24c-07c3-4a7a-a4b7-6b33532ede9c','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','overcloud-ComputeIpListMap-6n24x26xdirb','0ad8d24c-07c3-4a7a-a4b7-6b33532ede9c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1956,'db67c902-65d1-4b31-a8a5-0c5d4707bd2d','4b4e0119-cc5c-4056-bee3-164cb3f87921','2026-06-13 07:57:43',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-28-olmoazlii5ca-RoleParametersValue-yspwwjb33ci7','state changed','OS::Heat::Value',NULL,1197),(1957,'e7c41841-74a8-4a5a-83a4-88b2dad7bade','4b4e0119-cc5c-4056-bee3-164cb3f87921','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-28-olmoazlii5ca-RoleParametersValue-yspwwjb33ci7','state changed','OS::Heat::Value',NULL,1197),(1958,'b2af79fa-f817-40d9-924b-29cc5291039b','4b4e0119-cc5c-4056-bee3-164cb3f87921','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','ContainersCommon','4eef861b-e2a8-41f8-aa46-64aaa3e3d3a2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1959,'645e0576-4d9e-48c1-9446-9bfceb3b56eb','4b4e0119-cc5c-4056-bee3-164cb3f87921','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-28-olmoazlii5ca','4b4e0119-cc5c-4056-bee3-164cb3f87921','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1960,'a963dbbf-34c9-40a3-b062-7fcb654f83f6','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','ManilaShareCommon','a12b186d-497b-4fb0-a0a8-55f41eea4983','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1961,'7a3d1334-3d41-47a8-87e5-bb613be1a410','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','ContainersCommon','021a2eb8-76ed-4adf-82a7-4abbd31e588b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1962,'a634760c-17a7-41d1-9379-08aaaf993f04','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq-ManilaShareContainerBase-psbu7xqrxydm','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1963,'4351a79c-5cc2-4070-8f5c-7dd6303b888d','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:43',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-TLSProxyBase-a7nvpzm5jxyg','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1198),(1964,'17592019-8a54-4bf9-9de7-1136d67f178a','e7972d62-26c2-47e6-955a-282ebb6e0140','2026-06-13 07:57:43',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5-ContainersCommon-t3hbfa2ueiic','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1965,'e100c0a2-e437-4582-9627-5aaa621630ec','8faccb28-f2b9-4175-b1e1-192896d6b234','2026-06-13 07:57:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-TLSProxyBase-a7nvpzm5jxyg','8faccb28-f2b9-4175-b1e1-192896d6b234','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1966,'ba7dee60-1c2c-4a00-8ad0-50dc74c8801d','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','NeutronBase','cab70f41-97c9-462e-bd13-8a9d301b5050','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1194),(1967,'e1c6b41c-31dd-4b34-bb81-6b9ef225352c','dd69e14a-4563-4130-8262-b40aaee9cddb','2026-06-13 07:57:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5-ContainersCommon-t3hbfa2ueiic','dd69e14a-4563-4130-8262-b40aaee9cddb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1968,'6d304abf-3c22-48df-8566-4b0c4304aa7d','e7972d62-26c2-47e6-955a-282ebb6e0140','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','MysqlBase','21a60ad2-ffdc-43c6-b1b6-032a7b3bbc52','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,1195),(1969,'b6c0e5f5-c9c5-4a7f-a0b0-2c7a45994194','8faccb28-f2b9-4175-b1e1-192896d6b234','2026-06-13 07:57:43',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-TLSProxyBase-a7nvpzm5jxyg-ApacheNetworks-bpnh5mjr2vfj','state changed','OS::Heat::Value',NULL,1199),(1970,'fff228a4-46ef-44a4-9778-7b332661960f','dd69e14a-4563-4130-8262-b40aaee9cddb','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5-ContainersCommon-t3hbfa2ueiic','dd69e14a-4563-4130-8262-b40aaee9cddb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1971,'cbae1459-98d2-438a-8c1d-2be767757f76','8faccb28-f2b9-4175-b1e1-192896d6b234','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-TLSProxyBase-a7nvpzm5jxyg-ApacheNetworks-bpnh5mjr2vfj','state changed','OS::Heat::Value',NULL,1199),(1972,'39f722fe-4d23-4e87-ae96-a8188c53967e','8faccb28-f2b9-4175-b1e1-192896d6b234','2026-06-13 07:57:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza-TLSProxyBase-a7nvpzm5jxyg','8faccb28-f2b9-4175-b1e1-192896d6b234','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1973,'5d24dd77-02f6-4b86-aaf2-0af619b5ad2d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','ComputeIpListMap','0ad8d24c-07c3-4a7a-a4b7-6b33532ede9c','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1186),(1974,'62b2076d-1679-47ec-9316-65aecc5329ba','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','28','4b4e0119-cc5c-4056-bee3-164cb3f87921','state changed','OS::TripleO::Services::MetricsQdr',NULL,1190),(1975,'2d8b98e6-8e5c-4b36-a07c-19acea9d280f','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','ManilaShareContainerBase','8dc70112-ed4d-43c5-aa5b-c03426ea3bd5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,1146),(1976,'1cb350cb-6022-4c13-b02b-6a8f0bbdda04','dfd13fee-4eee-4928-a0ed-367277d95429','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-26-rkofyc5dikbq','dfd13fee-4eee-4928-a0ed-367277d95429','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1977,'0ed04354-42be-4178-b0c8-f47a0e3ead76','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:44',NULL,'CREATE','IN_PROGRESS','32','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,1203),(1978,'86ac10b5-fd6a-433f-ab60-83b5045e4216','e7972d62-26c2-47e6-955a-282ebb6e0140','2026-06-13 07:57:44',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5-RoleParametersValue-6v23jjm2youb','state changed','OS::Heat::Value',NULL,1204),(1979,'2781e8ef-badc-4969-99ac-60b4c4750df7','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','TLSProxyBase','8faccb28-f2b9-4175-b1e1-192896d6b234','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1198),(1980,'95286040-7810-4f6d-8349-b1cd926cfbd0','e7972d62-26c2-47e6-955a-282ebb6e0140','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5-RoleParametersValue-6v23jjm2youb','state changed','OS::Heat::Value',NULL,1204),(1981,'773833dc-3a04-474b-a9b9-4861113009f6','ada9bb67-4e51-4cbf-95b8-91e49cd9e0e7','2026-06-13 07:57:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx','ada9bb67-4e51-4cbf-95b8-91e49cd9e0e7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1982,'e7a7878e-478a-409c-b388-eeae914708ce','6431ff66-a2fa-4a58-95c7-0a74c61461b0','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-31-ydifadlplfza','6431ff66-a2fa-4a58-95c7-0a74c61461b0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1983,'f0c388c5-4481-4dee-8d96-f277fa97c8ce','e7972d62-26c2-47e6-955a-282ebb6e0140','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','ContainersCommon','dd69e14a-4563-4130-8262-b40aaee9cddb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1984,'fa417e78-0acd-48c9-9e8c-ce804a88074f','e7972d62-26c2-47e6-955a-282ebb6e0140','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-29-qb2bv5xj6sl5','e7972d62-26c2-47e6-955a-282ebb6e0140','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1985,'31adcb3c-eb4e-4480-a3c3-7f8176321eed','ada9bb67-4e51-4cbf-95b8-91e49cd9e0e7','2026-06-13 07:57:44',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-RoleParametersValue-n7antoki2wn2','state changed','OS::Heat::Value',NULL,1205),(1986,'3fe54887-9378-485f-bfdd-5ec0ae90394a','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','26','dfd13fee-4eee-4928-a0ed-367277d95429','state changed','OS::TripleO::Services::ManilaShare',NULL,1039),(1987,'254bc041-8862-4d8f-b8f8-ae421fba16c2','ada9bb67-4e51-4cbf-95b8-91e49cd9e0e7','2026-06-13 07:57:44',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-RoleParametersValue-n7antoki2wn2','state changed','OS::Heat::Value',NULL,1205),(1988,'8d3a3081-c4a9-4e0e-a6e1-d9ea285ddfb4','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:45',NULL,'CREATE','COMPLETE','31','6431ff66-a2fa-4a58-95c7-0a74c61461b0','state changed','OS::TripleO::Services::NeutronApi',NULL,1152),(1989,'90fb9057-033a-432c-8142-ce96f884b7b9','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:45',NULL,'CREATE','COMPLETE','29','e7972d62-26c2-47e6-955a-282ebb6e0140','state changed','OS::TripleO::Services::MySQL',NULL,1193),(1990,'595d5a37-5265-4016-8939-111c80db9df7','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:45',NULL,'CREATE','IN_PROGRESS','30','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-30-cavjumlml6fy','state changed','OS::TripleO::Services::MySQLClient',NULL,1226),(1991,'2f59568d-7e21-4035-8fba-2afecc9b7016','59713c33-3780-438e-bd53-f9a0c80ec517','2026-06-13 07:57:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-30-cavjumlml6fy','59713c33-3780-438e-bd53-f9a0c80ec517','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1992,'4b0ddf03-9c1b-4fc9-861a-7f091363138c','59713c33-3780-438e-bd53-f9a0c80ec517','2026-06-13 07:57:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-30-cavjumlml6fy','59713c33-3780-438e-bd53-f9a0c80ec517','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1993,'16467ed1-0a6f-43a2-ac83-537dc83e0338','ada9bb67-4e51-4cbf-95b8-91e49cd9e0e7','2026-06-13 07:57:45',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-NeutronBase-oxl6nhiwtfxx','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,1229),(1994,'27816425-b3d4-4120-b0bf-3d689b0d595d','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','33','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei','state changed','OS::TripleO::Services::NovaApi',NULL,1233),(1995,'79b16063-fe8f-4673-a1e5-c6d4a723ff4d','ba093aab-9c29-4add-a1de-7a7ea52b22c1','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-NeutronBase-oxl6nhiwtfxx','ba093aab-9c29-4add-a1de-7a7ea52b22c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1996,'b1289470-ed6a-4ef3-9f2e-da1ff657ddac','ba093aab-9c29-4add-a1de-7a7ea52b22c1','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','NeutronMl2Base','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-NeutronBase-oxl6nhiwtfxx-NeutronMl2Base-jkpz33ebxabb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,1235),(1997,'a7ef03ef-6bbb-4fb6-8f9f-71a294293617','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei','7a91c96c-32aa-45c6-a16e-9a13254b65a6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1998,'34808fb8-30ab-4e36-b16c-40a5847b840d','29c1eb7e-20f8-4a50-82d1-36d2037a2798','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-NeutronBase-oxl6nhiwtfxx-NeutronMl2Base-jkpz33ebxabb','29c1eb7e-20f8-4a50-82d1-36d2037a2798','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1999,'9f4eef2e-e464-47be-ac34-81951dd67b2e','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','35','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu','state changed','OS::TripleO::Services::NovaMetadata',NULL,1236),(2000,'a11b9acb-e8b7-4de4-8f99-90cf06d56556','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu','a9276268-4ac7-4c6b-bdba-e4a194302019','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2001,'3f679f07-fbcf-4e60-8a55-53818ee5a52d','29c1eb7e-20f8-4a50-82d1-36d2037a2798','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-NeutronBase-oxl6nhiwtfxx-NeutronMl2Base-jkpz33ebxabb-NeutronBase-t2wfmiwpb3xj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1237),(2002,'9845edcc-3ac3-4175-9d26-c0897e0c5e25','4b4afc0d-3fdf-4897-8ccc-f56e2428913c','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-NeutronBase-oxl6nhiwtfxx-NeutronMl2Base-jkpz33ebxabb-NeutronBase-t2wfmiwpb3xj','4b4afc0d-3fdf-4897-8ccc-f56e2428913c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2003,'f97dd299-e3c2-4658-b755-8a836e9eda44','4b4afc0d-3fdf-4897-8ccc-f56e2428913c','2026-06-13 07:57:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-NeutronBase-oxl6nhiwtfxx-NeutronMl2Base-jkpz33ebxabb-NeutronBase-t2wfmiwpb3xj','4b4afc0d-3fdf-4897-8ccc-f56e2428913c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2004,'003d9610-3bb7-4eba-8b71-2c4b3edfcd16','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-MySQLClient-nwc2kk2xvlnd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2005,'58056c34-d8e0-4010-9f0c-e43390a734ab','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-ContainersCommon-vl4prlwinhlr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2006,'7d25d695-0629-41bf-902f-e59edc4870e3','c2f2342e-1644-48f7-81dc-3d4c0466800d','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-MySQLClient-nwc2kk2xvlnd','c2f2342e-1644-48f7-81dc-3d4c0466800d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2007,'5627f569-d9bb-4259-a347-6eeb4440b6fb','c2f2342e-1644-48f7-81dc-3d4c0466800d','2026-06-13 07:57:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-MySQLClient-nwc2kk2xvlnd','c2f2342e-1644-48f7-81dc-3d4c0466800d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2008,'d33af8d3-25c7-49fd-850b-f6e4ac9cb785','1a9402ba-c83a-4cb9-bed5-39edc9ae1bea','2026-06-13 07:57:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-ContainersCommon-vl4prlwinhlr','1a9402ba-c83a-4cb9-bed5-39edc9ae1bea','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2009,'faa905e4-3086-4d08-a494-7be39a16d4c2','1a9402ba-c83a-4cb9-bed5-39edc9ae1bea','2026-06-13 07:57:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-ContainersCommon-vl4prlwinhlr','1a9402ba-c83a-4cb9-bed5-39edc9ae1bea','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2010,'803d2fd9-b022-4c0f-b446-2264696ac673','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:46',NULL,'CREATE','COMPLETE','30','59713c33-3780-438e-bd53-f9a0c80ec517','state changed','OS::TripleO::Services::MySQLClient',NULL,1226),(2011,'c96b9c96-e2c5-4f74-8303-8b00c5f3c124','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:47',NULL,'CREATE','IN_PROGRESS','34','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz','state changed','OS::TripleO::Services::NovaConductor',NULL,1239),(2012,'7affd052-2e56-4bfb-a275-def1fc188894','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2013,'c9249400-ffc2-425e-b80f-0e10624e7b04','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:47',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaApiDBClient-fexzuycem6r6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1240),(2014,'101d67d7-0309-4a2c-bd65-fa4dc1d88e43','e84dd26d-7acc-4ebb-83f6-b7bb34d32a3e','2026-06-13 07:57:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaApiDBClient-fexzuycem6r6','e84dd26d-7acc-4ebb-83f6-b7bb34d32a3e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2015,'0ef32b74-6556-4d44-be59-5a25ed05dfba','29c1eb7e-20f8-4a50-82d1-36d2037a2798','2026-06-13 07:57:47',NULL,'CREATE','COMPLETE','NeutronBase','4b4afc0d-3fdf-4897-8ccc-f56e2428913c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1237),(2016,'70e5a6da-11b0-4630-8883-f38e4691c515','e84dd26d-7acc-4ebb-83f6-b7bb34d32a3e','2026-06-13 07:57:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaApiDBClient-fexzuycem6r6','e84dd26d-7acc-4ebb-83f6-b7bb34d32a3e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2017,'e9ad8881-92ed-4cd7-a369-881984d36ff5','29c1eb7e-20f8-4a50-82d1-36d2037a2798','2026-06-13 07:57:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-NeutronBase-oxl6nhiwtfxx-NeutronMl2Base-jkpz33ebxabb','29c1eb7e-20f8-4a50-82d1-36d2037a2798','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2018,'20d014f2-5ff8-4231-a56d-4b305a538055','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:47',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaApiDBClient-mg4tnzslv34k','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1241),(2019,'a8c6890a-e9a3-4114-b5d7-aab3724ded21','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:47',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaDBClient-5xlztdveqson','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1242),(2020,'5f234560-62a0-4ce4-8fd4-f61694bc6c97','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:47',NULL,'CREATE','COMPLETE','MySQLClient','c2f2342e-1644-48f7-81dc-3d4c0466800d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2021,'fa67bbd5-3535-4d2d-869d-609124475f13','eb03c1de-0000-497a-b172-6498cd7a8ea9','2026-06-13 07:57:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaApiDBClient-mg4tnzslv34k','eb03c1de-0000-497a-b172-6498cd7a8ea9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2022,'388458dd-c12b-49b2-929c-421ef767a246','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:47',NULL,'CREATE','COMPLETE','ContainersCommon','1a9402ba-c83a-4cb9-bed5-39edc9ae1bea','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2023,'64cf5537-72e8-47f3-957a-763e18fa5f2a','eb03c1de-0000-497a-b172-6498cd7a8ea9','2026-06-13 07:57:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaApiDBClient-mg4tnzslv34k','eb03c1de-0000-497a-b172-6498cd7a8ea9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2024,'e5cb5709-5e2d-4bc9-adeb-352d89c81a55','02c10ad7-b460-4931-ba25-33c9795998a2','2026-06-13 07:57:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaDBClient-5xlztdveqson','02c10ad7-b460-4931-ba25-33c9795998a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2025,'1e92c4b0-b873-4308-a2ae-1ec28b736a5f','02c10ad7-b460-4931-ba25-33c9795998a2','2026-06-13 07:57:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaDBClient-5xlztdveqson','02c10ad7-b460-4931-ba25-33c9795998a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2026,'ae29b924-0240-4954-9538-69e1093edd6b','ba093aab-9c29-4add-a1de-7a7ea52b22c1','2026-06-13 07:57:48',NULL,'CREATE','COMPLETE','NeutronMl2Base','29c1eb7e-20f8-4a50-82d1-36d2037a2798','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,1235),(2027,'142f465f-1fcb-4752-aaf3-7cb1fc5a6970','ba093aab-9c29-4add-a1de-7a7ea52b22c1','2026-06-13 07:57:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx-NeutronBase-oxl6nhiwtfxx','ba093aab-9c29-4add-a1de-7a7ea52b22c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2028,'faf5c773-046b-4bf6-b06e-d857e41475dc','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:48',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaDBClient-45zfj2xuvl6h','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1243),(2029,'0000469d-26ed-4bb3-a402-ec6608f5b96f','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:48',NULL,'CREATE','COMPLETE','NovaApiDBClient','e84dd26d-7acc-4ebb-83f6-b7bb34d32a3e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1240),(2030,'cce3fdca-a205-412c-9a82-f60a8fdfd1ef','f31abc61-c311-4bb7-8d79-7f6e9e2811a8','2026-06-13 07:57:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaDBClient-45zfj2xuvl6h','f31abc61-c311-4bb7-8d79-7f6e9e2811a8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2031,'16cc5583-3b73-4e1e-8ce3-19f3b37a5eb6','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:48',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaDBClient-vnn27rd72sta','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1244),(2032,'f40a21ef-53ea-4eb9-a4e8-43040acc2404','f31abc61-c311-4bb7-8d79-7f6e9e2811a8','2026-06-13 07:57:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaDBClient-45zfj2xuvl6h','f31abc61-c311-4bb7-8d79-7f6e9e2811a8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2033,'9cafa4e3-ff35-48de-ada0-d2f69da2f299','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:48',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-ApacheServiceBase-675l6nv3vuct','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1245),(2034,'b4850569-d1c3-4e8f-be1e-309e217cb592','da490135-8ff0-4609-a772-c00ae053f464','2026-06-13 07:57:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaDBClient-vnn27rd72sta','da490135-8ff0-4609-a772-c00ae053f464','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2035,'6389fad6-3d0b-4140-9aa0-1c7bfc73cf31','da490135-8ff0-4609-a772-c00ae053f464','2026-06-13 07:57:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaDBClient-vnn27rd72sta','da490135-8ff0-4609-a772-c00ae053f464','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2036,'71bcda6a-3cc6-4e38-a2b4-d167f2b8e31e','21639122-3cf3-4df5-bdaf-2f332a074fdf','2026-06-13 07:57:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-ApacheServiceBase-675l6nv3vuct','21639122-3cf3-4df5-bdaf-2f332a074fdf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2037,'a123d711-d234-4edb-9aec-2e4f2dab70e0','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:48',NULL,'CREATE','COMPLETE','NovaApiDBClient','eb03c1de-0000-497a-b172-6498cd7a8ea9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1241),(2038,'f58f96ba-225c-433c-a46f-796ecb8b9307','21639122-3cf3-4df5-bdaf-2f332a074fdf','2026-06-13 07:57:48',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-ApacheServiceBase-675l6nv3vuct-ApacheNetworks-jyvamw3s2ppa','state changed','OS::Heat::Value',NULL,1246),(2039,'8347621b-6e18-4673-aead-6f648c0a5be8','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:48',NULL,'CREATE','COMPLETE','NovaDBClient','02c10ad7-b460-4931-ba25-33c9795998a2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1242),(2040,'f138facf-e6d6-4664-b6b3-b07cccc33293','21639122-3cf3-4df5-bdaf-2f332a074fdf','2026-06-13 07:57:48',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-ApacheServiceBase-675l6nv3vuct-ApacheNetworks-jyvamw3s2ppa','state changed','OS::Heat::Value',NULL,1246),(2041,'daac70a3-fccf-4614-979b-bf8d819bcf93','21639122-3cf3-4df5-bdaf-2f332a074fdf','2026-06-13 07:57:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-ApacheServiceBase-675l6nv3vuct','21639122-3cf3-4df5-bdaf-2f332a074fdf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2042,'aeb69edb-2bf8-40a7-836b-2dc147c7364b','ada9bb67-4e51-4cbf-95b8-91e49cd9e0e7','2026-06-13 07:57:49',NULL,'CREATE','COMPLETE','NeutronBase','ba093aab-9c29-4add-a1de-7a7ea52b22c1','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,1229),(2043,'e24f0ca0-6c88-495b-a633-2325ba173486','ada9bb67-4e51-4cbf-95b8-91e49cd9e0e7','2026-06-13 07:57:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-32-jugk24irl7nx','ada9bb67-4e51-4cbf-95b8-91e49cd9e0e7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2044,'efadaa59-4ded-46a9-b118-2d43c7b63faa','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:49',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-MySQLClient-koga3oftodyl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2045,'477628d7-f2f8-42d4-b657-774f965935be','afdf06da-2844-40c4-ab36-c3382c998298','2026-06-13 07:57:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-MySQLClient-koga3oftodyl','afdf06da-2844-40c4-ab36-c3382c998298','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2046,'d0ffcc11-824a-4e17-8d23-35157f4f51c5','afdf06da-2844-40c4-ab36-c3382c998298','2026-06-13 07:57:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-MySQLClient-koga3oftodyl','afdf06da-2844-40c4-ab36-c3382c998298','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2047,'882cea1e-d27a-46a0-97f2-636e16b03f56','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:49',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-RoleParametersValue-2qldkeey3w3s','state changed','OS::Heat::Value',NULL,1247),(2048,'8fc3cd10-7191-4c78-a1b9-85a2c8558578','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:49',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-RoleParametersValue-2qldkeey3w3s','state changed','OS::Heat::Value',NULL,1247),(2049,'5eed50ee-f704-4b8a-8399-208a79fa4ec0','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:49',NULL,'CREATE','COMPLETE','NovaDBClient','f31abc61-c311-4bb7-8d79-7f6e9e2811a8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1243),(2050,'3c259219-195b-4dd8-ad0c-76a3379ced0b','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:49',NULL,'CREATE','COMPLETE','32','ada9bb67-4e51-4cbf-95b8-91e49cd9e0e7','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,1203),(2051,'ee9b61d5-f7e1-4354-890e-e83794ba42db','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:49',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-RoleParametersValue-rgr4fevpwz6e','state changed','OS::Heat::Value',NULL,1248),(2052,'0f41637d-ea91-4db9-9fc1-f1dc3fa6b413','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:49',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-RoleParametersValue-rgr4fevpwz6e','state changed','OS::Heat::Value',NULL,1248),(2053,'2c7b3955-486a-4fb8-ae15-cb418a67c207','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:49',NULL,'CREATE','COMPLETE','NovaDBClient','da490135-8ff0-4609-a772-c00ae053f464','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1244),(2054,'17825de7-5a8d-40f6-9dc0-66dde8b04395','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:49',NULL,'CREATE','COMPLETE','ApacheServiceBase','21639122-3cf3-4df5-bdaf-2f332a074fdf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1245),(2055,'d59f50a0-dfe6-4c3f-91db-86daca5eb459','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','36','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc','state changed','OS::TripleO::Services::NovaScheduler',NULL,1254),(2056,'146022a2-d466-46c7-8fa9-fa98cd281983','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc','29634036-cc5f-4026-8d32-e8a82aa68933','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2057,'8316cf10-a0ec-46fc-bd84-d675ea2166c1','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-ContainersCommon-j4ulg6cxnw2h','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2058,'449390f1-abfc-4004-8e0c-6ed1445b3b41','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-ContainersCommon-xt6gpmhu4uny','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2059,'ac9aeeac-45b8-404e-962a-9e5fd7d65250','b2604d13-bdc6-4ee9-817d-fde74f15272d','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-ContainersCommon-j4ulg6cxnw2h','b2604d13-bdc6-4ee9-817d-fde74f15272d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2060,'f1f4cf92-e097-4edf-b957-9f7428004c51','6ca530c0-1743-4d2f-a374-87d2e02986be','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-ContainersCommon-xt6gpmhu4uny','6ca530c0-1743-4d2f-a374-87d2e02986be','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2061,'689abb99-e7a2-402a-bed2-42f084eac2c8','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:50',NULL,'CREATE','COMPLETE','MySQLClient','afdf06da-2844-40c4-ab36-c3382c998298','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2062,'89a38cd4-8aab-4bc4-acc8-49e2ab5d8d59','b2604d13-bdc6-4ee9-817d-fde74f15272d','2026-06-13 07:57:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-ContainersCommon-j4ulg6cxnw2h','b2604d13-bdc6-4ee9-817d-fde74f15272d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2063,'8997851b-06db-4eae-becb-619f32cf6d14','6ca530c0-1743-4d2f-a374-87d2e02986be','2026-06-13 07:57:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-ContainersCommon-xt6gpmhu4uny','6ca530c0-1743-4d2f-a374-87d2e02986be','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2064,'869e848e-bc2e-4f87-bff3-157d62d9b938','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-ContainersCommon-cvfxocjmtp7o','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2065,'c9b206bb-d280-417c-ba50-e96ae2db91b8','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','NovaMetadataLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaMetadataLogging-vcmpqxjanfd7','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(2066,'4bee5a12-6828-45aa-b1f3-640668f6624f','5055a969-d499-42a9-ae16-a6023f9c5ad5','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-ContainersCommon-cvfxocjmtp7o','5055a969-d499-42a9-ae16-a6023f9c5ad5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2067,'bea15aa7-e9a2-48b6-8cdf-e9b41525bbab','5055a969-d499-42a9-ae16-a6023f9c5ad5','2026-06-13 07:57:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-ContainersCommon-cvfxocjmtp7o','5055a969-d499-42a9-ae16-a6023f9c5ad5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2068,'1ad28102-d630-4b5d-884a-ef13d4bdac36','01db85e7-a9a7-4998-bfd5-67dc78b22914','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaMetadataLogging-vcmpqxjanfd7','01db85e7-a9a7-4998-bfd5-67dc78b22914','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2069,'f0aeafb2-baa5-497e-85da-4b60a0685617','01db85e7-a9a7-4998-bfd5-67dc78b22914','2026-06-13 07:57:50',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaMetadataLogging-vcmpqxjanfd7-RoleParametersValue-4ina4q6ud6bc','state changed','OS::Heat::Value',NULL,1255),(2070,'2ee36055-d79e-4bab-8cd9-3da898f1bb37','01db85e7-a9a7-4998-bfd5-67dc78b22914','2026-06-13 07:57:50',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaMetadataLogging-vcmpqxjanfd7-RoleParametersValue-4ina4q6ud6bc','state changed','OS::Heat::Value',NULL,1255),(2071,'46aff1c1-76c7-4ae8-9807-c7f40f1a1476','01db85e7-a9a7-4998-bfd5-67dc78b22914','2026-06-13 07:57:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaMetadataLogging-vcmpqxjanfd7','01db85e7-a9a7-4998-bfd5-67dc78b22914','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2072,'d090f7b7-7fcb-4eda-a413-2798cf832cd0','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaBase-cdoxo5ucyzvu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1256),(2073,'5a896dfa-2680-447d-b9a5-f7b220e5c967','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaBase-p7vsvxzjc2m5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1257),(2074,'99c60260-ea62-4f63-938d-73b86ce828cb','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','ContainersCommon','b2604d13-bdc6-4ee9-817d-fde74f15272d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2075,'1aa9f4de-eca3-4771-83b5-80c1776148a2','b84c27ad-c761-4c7b-880c-f698d3eafb59','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaBase-p7vsvxzjc2m5','b84c27ad-c761-4c7b-880c-f698d3eafb59','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2076,'2604fd55-dc96-4851-ba85-a519092d281a','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','ContainersCommon','6ca530c0-1743-4d2f-a374-87d2e02986be','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2077,'66aefbf3-8de7-4a23-bd3e-e3ec79ca82e1','c7f2b1dd-2506-4b51-be79-200f11f2dea5','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaBase-cdoxo5ucyzvu','c7f2b1dd-2506-4b51-be79-200f11f2dea5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2078,'b82a00b6-7ecd-4ffa-97ed-70e5ad0635f6','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-ApacheServiceBase-ohoueqsdcsy2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1258),(2079,'7a3a349b-53f5-4bf3-9b5b-2c44cdda92bd','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaBase-gtrhfg3xru35','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1259),(2080,'26aa4596-8708-46d5-bc4a-fecfdc5fb255','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','ContainersCommon','5055a969-d499-42a9-ae16-a6023f9c5ad5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2081,'bd9a8b99-63bb-4c8e-91e4-5d05749d215f','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','NovaMetadataLogging','01db85e7-a9a7-4998-bfd5-67dc78b22914','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(2082,'5efb963d-eb97-4b01-ad60-05bbd6ed01c8','b84c27ad-c761-4c7b-880c-f698d3eafb59','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaBase-p7vsvxzjc2m5-RoleParametersValue-5dyugjafwabp','state changed','OS::Heat::Value',NULL,1260),(2083,'23172b0b-b1d6-4b4b-85d8-6493a6fdb7b0','9e49383a-e634-4601-b625-5bacf9bb9ef1','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaBase-gtrhfg3xru35','9e49383a-e634-4601-b625-5bacf9bb9ef1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2084,'b0b60211-253c-47f9-9fd8-4b1b8d40e306','2c2c7295-735a-4a28-aa42-961225e0f7ed','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-ApacheServiceBase-ohoueqsdcsy2','2c2c7295-735a-4a28-aa42-961225e0f7ed','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2085,'66d2a4ae-8169-430c-ac64-7788640b245a','c7f2b1dd-2506-4b51-be79-200f11f2dea5','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaBase-cdoxo5ucyzvu-RoleParametersValue-lqicemjdqanu','state changed','OS::Heat::Value',NULL,1261),(2086,'807a769b-5c82-4e2e-a557-8f564276e604','b84c27ad-c761-4c7b-880c-f698d3eafb59','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaBase-p7vsvxzjc2m5-RoleParametersValue-5dyugjafwabp','state changed','OS::Heat::Value',NULL,1260),(2087,'ccea67cf-8fdc-46f6-8c0c-8b86dc63e356','c7f2b1dd-2506-4b51-be79-200f11f2dea5','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaBase-cdoxo5ucyzvu-RoleParametersValue-lqicemjdqanu','state changed','OS::Heat::Value',NULL,1261),(2088,'2ee2357b-c79c-4407-b4f4-9f1d56e34d0e','b84c27ad-c761-4c7b-880c-f698d3eafb59','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaBase-p7vsvxzjc2m5','b84c27ad-c761-4c7b-880c-f698d3eafb59','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2089,'ea1add53-e41b-4c4f-916e-53cda9d7df4e','c7f2b1dd-2506-4b51-be79-200f11f2dea5','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaBase-cdoxo5ucyzvu','c7f2b1dd-2506-4b51-be79-200f11f2dea5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2090,'d39a0d86-90e9-427a-8e7b-2d6535683d48','9e49383a-e634-4601-b625-5bacf9bb9ef1','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaBase-gtrhfg3xru35-RoleParametersValue-vjwb6cxah6zv','state changed','OS::Heat::Value',NULL,1262),(2091,'32dc57ec-faa0-4fd7-95eb-1f2926bfede6','2c2c7295-735a-4a28-aa42-961225e0f7ed','2026-06-13 07:57:51',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-ApacheServiceBase-ohoueqsdcsy2-ApacheNetworks-pztagyqzbu2j','state changed','OS::Heat::Value',NULL,1263),(2092,'1eda68e8-c80c-47e3-a96d-7aaf5b8461c1','9e49383a-e634-4601-b625-5bacf9bb9ef1','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaBase-gtrhfg3xru35-RoleParametersValue-vjwb6cxah6zv','state changed','OS::Heat::Value',NULL,1262),(2093,'d9aa9571-9424-4f75-861a-ffdfaadaabdc','9e49383a-e634-4601-b625-5bacf9bb9ef1','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaBase-gtrhfg3xru35','9e49383a-e634-4601-b625-5bacf9bb9ef1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2094,'06708a82-2d05-47a2-bd6e-a6913b43d75f','2c2c7295-735a-4a28-aa42-961225e0f7ed','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-ApacheServiceBase-ohoueqsdcsy2-ApacheNetworks-pztagyqzbu2j','state changed','OS::Heat::Value',NULL,1263),(2095,'b3c67dd4-c21f-4b93-9231-216573b55615','2c2c7295-735a-4a28-aa42-961225e0f7ed','2026-06-13 07:57:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-ApacheServiceBase-ohoueqsdcsy2','2c2c7295-735a-4a28-aa42-961225e0f7ed','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2096,'72ff4934-7b72-4f70-bd71-161f73ecdd9c','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-RoleParametersValue-dui6arb23ge4','state changed','OS::Heat::Value',NULL,1264),(2097,'a50da68d-866f-49f0-9690-4ded7c07a42b','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-RoleParametersValue-2wlgzs2ukvke','state changed','OS::Heat::Value',NULL,1265),(2098,'3bf69c32-e102-4b79-a089-cf614de086ab','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-RoleParametersValue-dui6arb23ge4','state changed','OS::Heat::Value',NULL,1264),(2099,'6b6a235b-55d4-45a5-96d6-c4d4fa511784','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-RoleParametersValue-2wlgzs2ukvke','state changed','OS::Heat::Value',NULL,1265),(2100,'5823b198-8752-4f13-944b-914b64917778','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaLogging-sa76ggqnmyqz','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1268),(2101,'3a17ad46-2c82-4f42-947b-87da402bf00a','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaLogging-5vdvw7senv6m','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1269),(2102,'2694311b-851d-4cf2-8e50-b98db2be7d1c','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaBase-2ytygotgcxez','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1270),(2103,'a1c4a0ef-303f-4c32-ac78-0779fb34d10e','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','NovaBase','b84c27ad-c761-4c7b-880c-f698d3eafb59','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1257),(2104,'fdb92c11-152a-4bf4-8e1a-d11be7083a46','23a0bf6d-63fe-4751-ae15-6a70c9272dd6','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaLogging-sa76ggqnmyqz','23a0bf6d-63fe-4751-ae15-6a70c9272dd6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2105,'63717dad-e7e1-4c28-93ee-b6eb1432d9a2','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-MySQLClient-sxo6kc5qphl4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2106,'907550ab-a884-4d5b-8e26-1ddaabb3b48d','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','NovaBase','c7f2b1dd-2506-4b51-be79-200f11f2dea5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1256),(2107,'42d93039-cf35-456b-ad25-a65a934ef28a','01bdb8ae-ba3a-4449-abdb-dceee3c0c09b','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaLogging-5vdvw7senv6m','01bdb8ae-ba3a-4449-abdb-dceee3c0c09b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2108,'d5312972-1867-4fe5-84b3-5a3228758013','bc2690a8-5c8a-43da-bc08-55a31681af5b','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaBase-2ytygotgcxez','bc2690a8-5c8a-43da-bc08-55a31681af5b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2109,'1fc79ac6-203a-40a0-afef-7621515704e6','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','ApacheServiceBase','2c2c7295-735a-4a28-aa42-961225e0f7ed','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1258),(2110,'87db42d3-0282-4f08-ac3d-8f7ef6ea5ff8','23a0bf6d-63fe-4751-ae15-6a70c9272dd6','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaLogging-sa76ggqnmyqz-RoleParametersValue-vxqwpp7qsk54','state changed','OS::Heat::Value',NULL,1271),(2111,'5c0e7151-7c37-44c7-a215-5eede2377be7','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','NovaBase','9e49383a-e634-4601-b625-5bacf9bb9ef1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1259),(2112,'3486ffab-1ca1-4419-8c7c-3a1cc2190712','55d6603f-e6ac-4b8a-8f0f-6f3e70abb173','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-MySQLClient-sxo6kc5qphl4','55d6603f-e6ac-4b8a-8f0f-6f3e70abb173','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2113,'c0fe85c0-75dc-4e53-ae40-0ac3f12cacc2','23a0bf6d-63fe-4751-ae15-6a70c9272dd6','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaLogging-sa76ggqnmyqz-RoleParametersValue-vxqwpp7qsk54','state changed','OS::Heat::Value',NULL,1271),(2114,'33489476-0902-46bc-81da-a201db8dd0d7','bc2690a8-5c8a-43da-bc08-55a31681af5b','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaBase-2ytygotgcxez-RoleParametersValue-qp2c2b37spvd','state changed','OS::Heat::Value',NULL,1272),(2115,'b0d619b7-e138-473d-91c2-6e16747c5f37','bc2690a8-5c8a-43da-bc08-55a31681af5b','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaBase-2ytygotgcxez-RoleParametersValue-qp2c2b37spvd','state changed','OS::Heat::Value',NULL,1272),(2116,'377119c7-4ebd-4022-b623-da5a27880996','01bdb8ae-ba3a-4449-abdb-dceee3c0c09b','2026-06-13 07:57:52',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaLogging-5vdvw7senv6m-InitLogContainerName-67cvnxkv2u5k','state changed','OS::Heat::Value',NULL,1273),(2117,'e8c91945-4d92-47f2-977c-a7f4fd7dc3ed','bc2690a8-5c8a-43da-bc08-55a31681af5b','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaBase-2ytygotgcxez','bc2690a8-5c8a-43da-bc08-55a31681af5b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2118,'51345b2d-68e5-427a-b72e-024041fa900a','55d6603f-e6ac-4b8a-8f0f-6f3e70abb173','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-MySQLClient-sxo6kc5qphl4','55d6603f-e6ac-4b8a-8f0f-6f3e70abb173','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2119,'06c1973d-b897-4265-a8c9-be054060a202','01bdb8ae-ba3a-4449-abdb-dceee3c0c09b','2026-06-13 07:57:52',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaLogging-5vdvw7senv6m-InitLogContainerName-67cvnxkv2u5k','state changed','OS::Heat::Value',NULL,1273),(2120,'76862766-321f-478b-824e-4ad58862d5f5','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:53',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaApiDBClient-lllvn7i7lsu4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1274),(2121,'d68b70b8-2a17-4fe4-9ab5-6a031b42be41','d2592099-dc73-427d-ad69-0b57b12a21a0','2026-06-13 07:57:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaApiDBClient-lllvn7i7lsu4','d2592099-dc73-427d-ad69-0b57b12a21a0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2122,'34b837db-5e62-4928-8383-8410eefd1a67','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:53',NULL,'CREATE','IN_PROGRESS','NovaApiLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaApiLogging-ri2dgrhz7zsp','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(2123,'af786dca-3651-4c3a-8878-2f63970a1b25','d2592099-dc73-427d-ad69-0b57b12a21a0','2026-06-13 07:57:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaApiDBClient-lllvn7i7lsu4','d2592099-dc73-427d-ad69-0b57b12a21a0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2124,'2108ce2e-75ba-4908-8c7f-3f917bfa0bec','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:53',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaApiDBClient-ctk5kcvpov4p','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1275),(2125,'3a0fa93e-2865-41df-899c-822e677ebb42','98ff8c6c-bf46-489d-879c-01523fa6954b','2026-06-13 07:57:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaApiLogging-ri2dgrhz7zsp','98ff8c6c-bf46-489d-879c-01523fa6954b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2126,'4810f8d9-6474-43b6-b813-68c62d3558dd','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:53',NULL,'CREATE','COMPLETE','NovaBase','bc2690a8-5c8a-43da-bc08-55a31681af5b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1270),(2127,'4aed178c-d849-4c41-9237-75f8729afe54','16c59dcb-b329-413f-bfd9-d02df560cf43','2026-06-13 07:57:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaApiDBClient-ctk5kcvpov4p','16c59dcb-b329-413f-bfd9-d02df560cf43','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2128,'1f76ace9-a72e-4273-88f8-d21246da821c','23a0bf6d-63fe-4751-ae15-6a70c9272dd6','2026-06-13 07:57:53',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaLogging-sa76ggqnmyqz-InitLogContainerName-zzyagfeqft3z','state changed','OS::Heat::Value',NULL,1276),(2129,'4b01b49a-1fd7-438c-ba8d-7301bc56c345','23a0bf6d-63fe-4751-ae15-6a70c9272dd6','2026-06-13 07:57:53',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaLogging-sa76ggqnmyqz-InitLogContainerName-zzyagfeqft3z','state changed','OS::Heat::Value',NULL,1276),(2130,'2e6b6668-a2d0-4968-93c2-b81ddc6140fc','01bdb8ae-ba3a-4449-abdb-dceee3c0c09b','2026-06-13 07:57:53',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaLogging-5vdvw7senv6m-RoleParametersValue-xcbngzgo7jgl','state changed','OS::Heat::Value',NULL,1277),(2131,'72a21b02-052e-4877-ac3c-7bfdccddfd2e','98ff8c6c-bf46-489d-879c-01523fa6954b','2026-06-13 07:57:53',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaApiLogging-ri2dgrhz7zsp-RoleParametersValue-3lyca4msrylv','state changed','OS::Heat::Value',NULL,1278),(2132,'30c6a850-145d-4f97-99fe-42417422d29e','16c59dcb-b329-413f-bfd9-d02df560cf43','2026-06-13 07:57:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu-NovaApiDBClient-ctk5kcvpov4p','16c59dcb-b329-413f-bfd9-d02df560cf43','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2133,'9f027aaf-067c-460f-9b41-8420eee42b32','23a0bf6d-63fe-4751-ae15-6a70c9272dd6','2026-06-13 07:57:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz-NovaLogging-sa76ggqnmyqz','23a0bf6d-63fe-4751-ae15-6a70c9272dd6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2134,'bc1a4e89-02f6-4e9a-8042-47d520a75e57','98ff8c6c-bf46-489d-879c-01523fa6954b','2026-06-13 07:57:53',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaApiLogging-ri2dgrhz7zsp-RoleParametersValue-3lyca4msrylv','state changed','OS::Heat::Value',NULL,1278),(2135,'035c5a59-339d-41a3-b026-872187d4c73c','01bdb8ae-ba3a-4449-abdb-dceee3c0c09b','2026-06-13 07:57:53',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaLogging-5vdvw7senv6m-RoleParametersValue-xcbngzgo7jgl','state changed','OS::Heat::Value',NULL,1277),(2136,'2318ada1-f90f-456f-a9d3-db9507ee6cee','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:53',NULL,'CREATE','COMPLETE','MySQLClient','55d6603f-e6ac-4b8a-8f0f-6f3e70abb173','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2137,'d21ce59d-2361-453a-ba35-47b8e6e07b3b','98ff8c6c-bf46-489d-879c-01523fa6954b','2026-06-13 07:57:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei-NovaApiLogging-ri2dgrhz7zsp','98ff8c6c-bf46-489d-879c-01523fa6954b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2138,'30686781-edc3-4390-a618-39920f5db556','01bdb8ae-ba3a-4449-abdb-dceee3c0c09b','2026-06-13 07:57:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaLogging-5vdvw7senv6m','01bdb8ae-ba3a-4449-abdb-dceee3c0c09b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2139,'c747b59f-3224-4172-bdad-fec1fa6473b2','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:54',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaDBClient-vdmitw4lcdx3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1279),(2140,'756fc93f-701e-4491-ac66-71c4b2f075f8','989dc94b-1e82-4d5c-887f-9d9e774418ba','2026-06-13 07:57:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaDBClient-vdmitw4lcdx3','989dc94b-1e82-4d5c-887f-9d9e774418ba','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2141,'a251f18c-f674-467b-979e-c076cf603c0c','989dc94b-1e82-4d5c-887f-9d9e774418ba','2026-06-13 07:57:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-NovaDBClient-vdmitw4lcdx3','989dc94b-1e82-4d5c-887f-9d9e774418ba','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2142,'8d9584bb-53df-4c76-8a21-d26328bc56ef','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:54',NULL,'CREATE','COMPLETE','NovaApiDBClient','d2592099-dc73-427d-ad69-0b57b12a21a0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1274),(2143,'257f675c-c8c1-4267-af23-addc8146169f','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:54',NULL,'CREATE','COMPLETE','NovaLogging','23a0bf6d-63fe-4751-ae15-6a70c9272dd6','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1268),(2144,'3c818c7f-ae7e-4122-befd-f0e2aaa0ef26','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','2026-06-13 07:57:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-34-hesefgyqj6vz','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2145,'3436c1f7-af62-4363-9fd4-22534f61cd4b','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:54',NULL,'CREATE','COMPLETE','NovaApiLogging','98ff8c6c-bf46-489d-879c-01523fa6954b','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(2146,'f9782f03-be9b-4a9b-a0ac-2736a62982d2','7a91c96c-32aa-45c6-a16e-9a13254b65a6','2026-06-13 07:57:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-33-r6e5phengnei','7a91c96c-32aa-45c6-a16e-9a13254b65a6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2147,'a755e59c-65b6-4151-8d98-d3183f621023','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:54',NULL,'CREATE','COMPLETE','NovaLogging','01bdb8ae-ba3a-4449-abdb-dceee3c0c09b','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1269),(2148,'434d8fb4-a13d-4669-bb5a-64c277e99a95','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:54',NULL,'CREATE','COMPLETE','NovaApiDBClient','16c59dcb-b329-413f-bfd9-d02df560cf43','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1275),(2149,'d24432d0-722b-4404-8aca-bf669d5290d1','a9276268-4ac7-4c6b-bdba-e4a194302019','2026-06-13 07:57:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-35-l3nmo7am3ksu','a9276268-4ac7-4c6b-bdba-e4a194302019','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2150,'356b9ddf-54e3-44a1-aba1-a49757f74192','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:55',NULL,'CREATE','COMPLETE','34','07b7b405-a6f5-4eea-8f3e-4e8c7886c461','state changed','OS::TripleO::Services::NovaConductor',NULL,1239),(2151,'b5acae00-e1b2-4104-bef8-2b0d681dd852','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:55',NULL,'CREATE','COMPLETE','33','7a91c96c-32aa-45c6-a16e-9a13254b65a6','state changed','OS::TripleO::Services::NovaApi',NULL,1233),(2152,'f06ccf60-93db-4733-ab37-7320e6fa830f','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:55',NULL,'CREATE','COMPLETE','35','a9276268-4ac7-4c6b-bdba-e4a194302019','state changed','OS::TripleO::Services::NovaMetadata',NULL,1236),(2153,'dc832641-797a-4345-a825-9f8c0011a541','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:55',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-MySQLClient-v4bkeuwlr47g','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2154,'b41d48ac-590c-4017-b360-ee5ddabecc89','bf077f31-304f-43b2-a975-d605cb4fd553','2026-06-13 07:57:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-MySQLClient-v4bkeuwlr47g','bf077f31-304f-43b2-a975-d605cb4fd553','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2155,'b75e97ef-49c6-4a20-9b8d-b07a4ce71921','bf077f31-304f-43b2-a975-d605cb4fd553','2026-06-13 07:57:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc-MySQLClient-v4bkeuwlr47g','bf077f31-304f-43b2-a975-d605cb4fd553','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2156,'820cc400-7a78-4174-b229-6168fb531b86','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:55',NULL,'CREATE','COMPLETE','MySQLClient','bf077f31-304f-43b2-a975-d605cb4fd553','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2157,'1554c6f3-52dd-420c-8c94-c25e649003fb','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:55',NULL,'CREATE','COMPLETE','NovaDBClient','989dc94b-1e82-4d5c-887f-9d9e774418ba','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1279),(2158,'6de12f8d-bc40-48b3-8f4e-870bcdbd9d56','29634036-cc5f-4026-8d32-e8a82aa68933','2026-06-13 07:57:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-36-6wd4cxanvvqc','29634036-cc5f-4026-8d32-e8a82aa68933','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2159,'df6e46a5-2599-48d2-b4c4-88170e644c91','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','37','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1312),(2160,'d1c22f09-fc49-4841-b8cc-8089cdf4d447','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','38','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-38-v6prz4qx67ds','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1313),(2161,'4d4a2901-2cb3-4624-aeab-595465cdb521','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z','91cc2fe5-a1be-4e47-9141-80087855f516','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2162,'d5858ac4-a59c-4c4c-8494-18144ce9434b','dda532d3-118a-408b-94ff-95da89aca73a','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-38-v6prz4qx67ds','dda532d3-118a-408b-94ff-95da89aca73a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2163,'6f252705-cde6-4e19-a14a-6d5187e31ccc','dda532d3-118a-408b-94ff-95da89aca73a','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-38-v6prz4qx67ds-ContainersCommon-wgzwycol5chc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2164,'853c9b6f-5ab4-4e16-bedb-083bb7bb88cc','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','39','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-39-hflyzjwmle4x','state changed','OS::TripleO::Services::OVNDBs',NULL,1316),(2165,'d21184cb-ded3-4b3a-8211-1c5d395c5414','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-MySQLClient-v6uxcpnytiqe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2166,'b53675e8-68e9-4091-8e58-c0bdea77752e','25dcfa2f-8d94-488b-979b-0a42c14eb32d','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-38-v6prz4qx67ds-ContainersCommon-wgzwycol5chc','25dcfa2f-8d94-488b-979b-0a42c14eb32d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2167,'fb5df9e7-1f0a-47b6-913d-d5e2c7601870','3eb34d32-7708-4a27-84a6-6e69165d111a','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-MySQLClient-v6uxcpnytiqe','3eb34d32-7708-4a27-84a6-6e69165d111a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2168,'9b859ae5-7daf-4a9e-997c-ea3a2ad329f2','25dcfa2f-8d94-488b-979b-0a42c14eb32d','2026-06-13 07:57:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-38-v6prz4qx67ds-ContainersCommon-wgzwycol5chc','25dcfa2f-8d94-488b-979b-0a42c14eb32d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2169,'78bb5bb3-211a-4fcc-af79-0147180e85f2','3eb34d32-7708-4a27-84a6-6e69165d111a','2026-06-13 07:57:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-MySQLClient-v6uxcpnytiqe','3eb34d32-7708-4a27-84a6-6e69165d111a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2170,'99e7f12e-7378-431e-8cb0-0967175237eb','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:56',NULL,'CREATE','COMPLETE','36','29634036-cc5f-4026-8d32-e8a82aa68933','state changed','OS::TripleO::Services::NovaScheduler',NULL,1254),(2171,'f97f72da-fc26-425a-850f-0321d457c4ac','4d90d585-767b-414e-ad74-7d504ecb2b99','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-39-hflyzjwmle4x','4d90d585-767b-414e-ad74-7d504ecb2b99','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2172,'855dcbc9-03e8-4e0d-ac70-5ea33a75edd6','4d90d585-767b-414e-ad74-7d504ecb2b99','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-39-hflyzjwmle4x-ContainersCommon-kdbxdael5gac','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2173,'bf170b53-747f-42c9-944c-76d4358e2584','766e5e61-c302-4e3d-9680-d6879029f0b6','2026-06-13 07:57:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-39-hflyzjwmle4x-ContainersCommon-kdbxdael5gac','766e5e61-c302-4e3d-9680-d6879029f0b6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2174,'af0fab32-cea2-44be-b360-8ca8833f0b9d','766e5e61-c302-4e3d-9680-d6879029f0b6','2026-06-13 07:57:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-39-hflyzjwmle4x-ContainersCommon-kdbxdael5gac','766e5e61-c302-4e3d-9680-d6879029f0b6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2175,'df1e7c87-a63f-4e4c-bd48-3e776e0caab5','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:57',NULL,'CREATE','IN_PROGRESS','40','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-40-cqrpvcdb7rai','state changed','OS::TripleO::Services::OVNController',NULL,1327),(2176,'eb6740a7-a614-4aba-8888-80e59710956a','a33c18f2-769c-434a-803b-e4f04dc048e2','2026-06-13 07:57:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-40-cqrpvcdb7rai','a33c18f2-769c-434a-803b-e4f04dc048e2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2177,'c98f3b7c-fa21-45ae-b500-071c540984fd','a33c18f2-769c-434a-803b-e4f04dc048e2','2026-06-13 07:57:57',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-40-cqrpvcdb7rai-OVNBridgeMappingsValue-c4sjqmu7yamv','state changed','OS::Heat::Value',NULL,1328),(2178,'910272ff-11db-4001-8ebc-20e0267352c9','a33c18f2-769c-434a-803b-e4f04dc048e2','2026-06-13 07:57:57',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-40-cqrpvcdb7rai-OVNBridgeMappingsValue-c4sjqmu7yamv','state changed','OS::Heat::Value',NULL,1328),(2179,'8e272fc6-5f39-4341-89fd-7ae71c6fc9fa','dda532d3-118a-408b-94ff-95da89aca73a','2026-06-13 07:57:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-38-v6prz4qx67ds-RoleParametersValue-uy3eophzne7n','state changed','OS::Heat::Value',NULL,1329),(2180,'c5deea83-321b-469d-a02f-65f0f3fd9b2c','dda532d3-118a-408b-94ff-95da89aca73a','2026-06-13 07:57:57',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-38-v6prz4qx67ds-RoleParametersValue-uy3eophzne7n','state changed','OS::Heat::Value',NULL,1329),(2181,'d1d98066-aaf9-4f8b-b9c0-6b6641337bc3','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:57:57',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaDBClient-znm3pxmtjgfs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1330),(2182,'8d5087be-ec9f-4afd-966b-f41fe97b0339','dda532d3-118a-408b-94ff-95da89aca73a','2026-06-13 07:57:57',NULL,'CREATE','COMPLETE','ContainersCommon','25dcfa2f-8d94-488b-979b-0a42c14eb32d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2183,'f60069cb-227d-4ead-8411-9a0f1d70aaf6','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:57:57',NULL,'CREATE','COMPLETE','MySQLClient','3eb34d32-7708-4a27-84a6-6e69165d111a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2184,'cf53fa86-24d9-4781-ab81-dcd759594f91','dda532d3-118a-408b-94ff-95da89aca73a','2026-06-13 07:57:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-38-v6prz4qx67ds','dda532d3-118a-408b-94ff-95da89aca73a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2185,'5171c413-58f3-4f6c-81b9-6d12b9236818','0a01ed7c-1cb9-490f-a593-dffc8faf6c69','2026-06-13 07:57:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaDBClient-znm3pxmtjgfs','0a01ed7c-1cb9-490f-a593-dffc8faf6c69','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2186,'ddd17443-0466-4088-b86f-78552d8a83f0','0a01ed7c-1cb9-490f-a593-dffc8faf6c69','2026-06-13 07:57:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaDBClient-znm3pxmtjgfs','0a01ed7c-1cb9-490f-a593-dffc8faf6c69','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2187,'43375e14-058b-4e92-8f40-c648d42801cf','4d90d585-767b-414e-ad74-7d504ecb2b99','2026-06-13 07:57:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-39-hflyzjwmle4x-RoleParametersValue-ene5ipeoja3z','state changed','OS::Heat::Value',NULL,1331),(2188,'e2101e08-1ea8-444a-b251-d06d7ff30ce0','4d90d585-767b-414e-ad74-7d504ecb2b99','2026-06-13 07:57:57',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-39-hflyzjwmle4x-RoleParametersValue-ene5ipeoja3z','state changed','OS::Heat::Value',NULL,1331),(2189,'82947c86-580c-4efb-805a-819e636ad671','4d90d585-767b-414e-ad74-7d504ecb2b99','2026-06-13 07:57:57',NULL,'CREATE','COMPLETE','ContainersCommon','766e5e61-c302-4e3d-9680-d6879029f0b6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2190,'dde9b0bc-f49e-4ffe-8498-6b69240eb56e','4d90d585-767b-414e-ad74-7d504ecb2b99','2026-06-13 07:57:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-39-hflyzjwmle4x','4d90d585-767b-414e-ad74-7d504ecb2b99','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2191,'7131d971-6e5e-48b2-98c7-d627e08565a8','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:58',NULL,'CREATE','COMPLETE','38','dda532d3-118a-408b-94ff-95da89aca73a','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1313),(2192,'9e071c26-c3b8-4223-bdf6-39f9c94cb894','a33c18f2-769c-434a-803b-e4f04dc048e2','2026-06-13 07:57:58',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-40-cqrpvcdb7rai-ContainersCommon-kakftr5cnnls','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2193,'13346ed4-6fca-4c17-8bdb-14c7cbb503c5','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:57:58',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-ContainersCommon-6jjvkwebjamw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2194,'2d571449-2bd0-4ce3-b254-6626f4419fc8','eca21759-b5d2-4dab-9ff3-ed3a7572584e','2026-06-13 07:57:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-40-cqrpvcdb7rai-ContainersCommon-kakftr5cnnls','eca21759-b5d2-4dab-9ff3-ed3a7572584e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2195,'779e4fb5-e620-4f14-803b-d6eb6f99b618','eca21759-b5d2-4dab-9ff3-ed3a7572584e','2026-06-13 07:57:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-40-cqrpvcdb7rai-ContainersCommon-kakftr5cnnls','eca21759-b5d2-4dab-9ff3-ed3a7572584e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2196,'d20d4d4a-443d-47bd-9ad2-0e8a55d491ca','958d4c92-0902-4cfc-85e8-408fb661a7b6','2026-06-13 07:57:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-ContainersCommon-6jjvkwebjamw','958d4c92-0902-4cfc-85e8-408fb661a7b6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2197,'2b2cc643-2033-49c3-86b7-74781a871288','958d4c92-0902-4cfc-85e8-408fb661a7b6','2026-06-13 07:57:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-ContainersCommon-6jjvkwebjamw','958d4c92-0902-4cfc-85e8-408fb661a7b6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2198,'f38c9196-9d6d-4d55-b62b-80506f9f8204','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:58',NULL,'CREATE','COMPLETE','39','4d90d585-767b-414e-ad74-7d504ecb2b99','state changed','OS::TripleO::Services::OVNDBs',NULL,1316),(2199,'38d4249d-f50f-4a83-bbf4-eed2fd86fa6f','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:57:58',NULL,'CREATE','COMPLETE','NovaDBClient','0a01ed7c-1cb9-490f-a593-dffc8faf6c69','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1330),(2200,'afd994e6-ba27-4c97-ace7-91887f6a2ec8','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:58',NULL,'CREATE','IN_PROGRESS','42','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q','state changed','OS::TripleO::Services::PlacementApi',NULL,1335),(2201,'2db7da87-77e2-41ef-be31-82cf944a4de9','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:57:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q','7a6a2551-21b0-478d-85fc-e45f21b4aa27','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2202,'2058cc88-e785-4399-ad59-89fddc583b2d','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:57:58',NULL,'CREATE','IN_PROGRESS','43','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,1339),(2203,'69ff34a9-198c-43a1-99f8-1bc6aab8da04','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:57:58',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-ApacheServiceBase-lbvjh7mvmkfr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1340),(2204,'23587743-690e-4a99-976b-32c6dbfd1946','7dc83628-82fd-48a0-abc3-de7f9455006d','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z','7dc83628-82fd-48a0-abc3-de7f9455006d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2205,'85d8cacb-bf47-4a06-b6fe-12db8c0177cc','0a138346-4a7c-40b8-b1d6-5fcc4e5b1ec5','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-ApacheServiceBase-lbvjh7mvmkfr','0a138346-4a7c-40b8-b1d6-5fcc4e5b1ec5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2206,'f10f0da3-071e-4eb5-8a07-efc67b9db4dc','7dc83628-82fd-48a0-abc3-de7f9455006d','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-ContainersCommon-aq5egzctzmqa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2207,'ee54e643-9d50-4771-be23-91a61e32101f','0a138346-4a7c-40b8-b1d6-5fcc4e5b1ec5','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-ApacheServiceBase-lbvjh7mvmkfr-ApacheNetworks-cgu4cq44pojg','state changed','OS::Heat::Value',NULL,1341),(2208,'9f3a4d84-e6e6-4501-a24a-9e6913f76ad9','0a138346-4a7c-40b8-b1d6-5fcc4e5b1ec5','2026-06-13 07:57:59',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-ApacheServiceBase-lbvjh7mvmkfr-ApacheNetworks-cgu4cq44pojg','state changed','OS::Heat::Value',NULL,1341),(2209,'52d4770b-acfd-4483-8530-f2b943503410','0b22a4ba-4a5f-4638-9531-31bb9bf1c981','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-ContainersCommon-aq5egzctzmqa','0b22a4ba-4a5f-4638-9531-31bb9bf1c981','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2210,'5200d747-1cb9-4b0e-96f4-46c91b27a65a','0a138346-4a7c-40b8-b1d6-5fcc4e5b1ec5','2026-06-13 07:57:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-ApacheServiceBase-lbvjh7mvmkfr','0a138346-4a7c-40b8-b1d6-5fcc4e5b1ec5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2211,'caf5f8ea-c7ce-468c-a280-99cb1d3fc71d','0b22a4ba-4a5f-4638-9531-31bb9bf1c981','2026-06-13 07:57:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-ContainersCommon-aq5egzctzmqa','0b22a4ba-4a5f-4638-9531-31bb9bf1c981','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2212,'81f800c4-cb66-4dd7-8407-3e52bcd7ba48','a33c18f2-769c-434a-803b-e4f04dc048e2','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-40-cqrpvcdb7rai-RoleParametersValue-gud5fpnh52h3','state changed','OS::Heat::Value',NULL,1342),(2213,'d75bc47a-da1e-4a34-ab44-a764b9a98c1f','a33c18f2-769c-434a-803b-e4f04dc048e2','2026-06-13 07:57:59',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-40-cqrpvcdb7rai-RoleParametersValue-gud5fpnh52h3','state changed','OS::Heat::Value',NULL,1342),(2214,'750409ba-ff70-434c-82b5-d2dd0dfa5d25','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-RoleParametersValue-erdhiajl54b2','state changed','OS::Heat::Value',NULL,1343),(2215,'7ba4b79c-baf2-4c3e-b132-56216dad5b0d','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:57:59',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-RoleParametersValue-erdhiajl54b2','state changed','OS::Heat::Value',NULL,1343),(2216,'1bf916f1-30a7-41d5-be44-47fe0cce427b','a33c18f2-769c-434a-803b-e4f04dc048e2','2026-06-13 07:57:59',NULL,'CREATE','COMPLETE','ContainersCommon','eca21759-b5d2-4dab-9ff3-ed3a7572584e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2217,'e27186ba-9b97-483d-89c9-79de782ab862','a33c18f2-769c-434a-803b-e4f04dc048e2','2026-06-13 07:57:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-40-cqrpvcdb7rai','a33c18f2-769c-434a-803b-e4f04dc048e2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2218,'eca84195-1198-41a6-9c27-89ef06c73da1','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:57:59',NULL,'CREATE','COMPLETE','ContainersCommon','958d4c92-0902-4cfc-85e8-408fb661a7b6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2219,'2fd6f170-cde1-40d2-99a9-3dc0d351c32e','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaLogging-jbwoy3tjw3xg','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1345),(2220,'9972f587-0fd3-4c86-9b31-b384250379d9','5267c3b5-87f6-4a55-ba9f-41bc1b4436f4','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaLogging-jbwoy3tjw3xg','5267c3b5-87f6-4a55-ba9f-41bc1b4436f4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2221,'6f581c5a-3dc6-4139-985c-49304bd7d4cf','5267c3b5-87f6-4a55-ba9f-41bc1b4436f4','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaLogging-jbwoy3tjw3xg-InitLogContainerName-ujc6xmxbahhz','state changed','OS::Heat::Value',NULL,1346),(2222,'83b89895-aa5e-4141-86e1-cea0d1cdd747','5267c3b5-87f6-4a55-ba9f-41bc1b4436f4','2026-06-13 07:57:59',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaLogging-jbwoy3tjw3xg-InitLogContainerName-ujc6xmxbahhz','state changed','OS::Heat::Value',NULL,1346),(2223,'ce92ff1d-2e23-4321-88e3-f56a94520ab5','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:57:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-ContainersCommon-4vgvbb2ngjsm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2224,'dad858ba-70ba-44bf-a48a-d857b3fa04ad','d65083cb-1a9a-4238-ac42-125649926972','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-ContainersCommon-4vgvbb2ngjsm','d65083cb-1a9a-4238-ac42-125649926972','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2225,'3970e961-bbd7-4e1c-97a3-27f6383242bb','d65083cb-1a9a-4238-ac42-125649926972','2026-06-13 07:58:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-ContainersCommon-4vgvbb2ngjsm','d65083cb-1a9a-4238-ac42-125649926972','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2226,'4cd63eda-04c1-4f3b-bf67-17db5dc74bde','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:58:00',NULL,'CREATE','COMPLETE','ApacheServiceBase','0a138346-4a7c-40b8-b1d6-5fcc4e5b1ec5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1340),(2227,'f293e7bc-a4a0-4ded-9848-4b739642a30a','7dc83628-82fd-48a0-abc3-de7f9455006d','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','RabbitmqBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1347),(2228,'63393a67-8894-44dd-81d1-0e5ba3547fb4','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:00',NULL,'CREATE','COMPLETE','40','a33c18f2-769c-434a-803b-e4f04dc048e2','state changed','OS::TripleO::Services::OVNController',NULL,1327),(2229,'328f4546-8559-4070-931e-845ac5c3ac7c','7dc83628-82fd-48a0-abc3-de7f9455006d','2026-06-13 07:58:00',NULL,'CREATE','COMPLETE','ContainersCommon','0b22a4ba-4a5f-4638-9531-31bb9bf1c981','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2230,'3bbc530b-25f8-408c-9db0-c0778d4e74b5','52d9821f-9781-4c98-b798-b173641dc099','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55','52d9821f-9781-4c98-b798-b173641dc099','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2231,'5ee4b54e-096f-4f5f-a6f3-df36598dabd5','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaBase-qmub7kaodium','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1350),(2232,'5e32a4c2-814e-4fd8-938c-a69479a9cfc8','52d9821f-9781-4c98-b798-b173641dc099','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','RabbitMQServiceBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-RabbitMQServiceBase-a4cm3dtj23bt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1351),(2233,'48eb184d-9fb1-493f-b78b-eec712001e2e','8cb9804a-01d9-404e-ab47-21d876a41402','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaBase-qmub7kaodium','8cb9804a-01d9-404e-ab47-21d876a41402','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2234,'dab806eb-e8fb-4079-a427-c1c6982c8c05','db0c5a49-9b37-4593-8fd7-51ba9865a6e6','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-RabbitMQServiceBase-a4cm3dtj23bt','db0c5a49-9b37-4593-8fd7-51ba9865a6e6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2235,'0584912d-7136-44ba-a83f-044bef99aa5e','8cb9804a-01d9-404e-ab47-21d876a41402','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaBase-qmub7kaodium-RoleParametersValue-m6jcwmhgwgit','state changed','OS::Heat::Value',NULL,1354),(2236,'16453b4a-5260-4474-957a-8eaca78069ee','8cb9804a-01d9-404e-ab47-21d876a41402','2026-06-13 07:58:00',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaBase-qmub7kaodium-RoleParametersValue-m6jcwmhgwgit','state changed','OS::Heat::Value',NULL,1354),(2237,'a2b442ea-491f-4bde-9152-451bf5251759','8cb9804a-01d9-404e-ab47-21d876a41402','2026-06-13 07:58:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaBase-qmub7kaodium','8cb9804a-01d9-404e-ab47-21d876a41402','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2238,'73c2e61b-3e8e-4a54-9d25-e826821d9996','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','44','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-44-bfymjzxkdedj','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1355),(2239,'3b36ca03-e49b-4927-8c56-7709c80cbae4','db0c5a49-9b37-4593-8fd7-51ba9865a6e6','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-RabbitMQServiceBase-a4cm3dtj23bt-RoleParametersValue-uc34kg7uerr3','state changed','OS::Heat::Value',NULL,1356),(2240,'7b2f610c-e9b0-4a8e-b431-6f7b7ee21afb','db0c5a49-9b37-4593-8fd7-51ba9865a6e6','2026-06-13 07:58:00',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-RabbitMQServiceBase-a4cm3dtj23bt-RoleParametersValue-uc34kg7uerr3','state changed','OS::Heat::Value',NULL,1356),(2241,'b92b248e-d9b6-478f-9ae4-511379c66544','4c543c0a-1bf3-4a3e-8c37-56a8382738a2','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-44-bfymjzxkdedj','4c543c0a-1bf3-4a3e-8c37-56a8382738a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2242,'e0fdb488-85b9-4355-9490-964d795574d9','5267c3b5-87f6-4a55-ba9f-41bc1b4436f4','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaLogging-jbwoy3tjw3xg-RoleParametersValue-vdkbwd72v5yz','state changed','OS::Heat::Value',NULL,1357),(2243,'1a81bbf9-499d-4b2e-8e9e-e17d9fdf185d','5267c3b5-87f6-4a55-ba9f-41bc1b4436f4','2026-06-13 07:58:00',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaLogging-jbwoy3tjw3xg-RoleParametersValue-vdkbwd72v5yz','state changed','OS::Heat::Value',NULL,1357),(2244,'eb156b7d-b537-42b7-ab83-1ceec84a73f2','4c543c0a-1bf3-4a3e-8c37-56a8382738a2','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-44-bfymjzxkdedj-ContainersCommon-bwa2z2rmcleo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2245,'ff9b4250-f6a9-43ef-9baf-6a22930ba71d','5267c3b5-87f6-4a55-ba9f-41bc1b4436f4','2026-06-13 07:58:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z-NovaLogging-jbwoy3tjw3xg','5267c3b5-87f6-4a55-ba9f-41bc1b4436f4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2246,'226adc57-a3c6-40ce-a230-2353d7d6dadd','f08dd052-78dd-4c36-8430-42284a137410','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-44-bfymjzxkdedj-ContainersCommon-bwa2z2rmcleo','f08dd052-78dd-4c36-8430-42284a137410','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2247,'3472108f-4a9a-4128-9768-6e9ba51f5339','f08dd052-78dd-4c36-8430-42284a137410','2026-06-13 07:58:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-44-bfymjzxkdedj-ContainersCommon-bwa2z2rmcleo','f08dd052-78dd-4c36-8430-42284a137410','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2248,'e808e03d-1963-4b9f-89ae-71afb73a2588','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:58:00',NULL,'CREATE','IN_PROGRESS','PlacementLogging','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-PlacementLogging-3eghd3ndvpfg','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(2249,'6ee7dc79-89cb-48e3-94af-c55b3b9678de','42d30573-52b0-49fd-ae85-ea4a154d6283','2026-06-13 07:58:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-PlacementLogging-3eghd3ndvpfg','42d30573-52b0-49fd-ae85-ea4a154d6283','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2250,'3803f609-3a01-4f1a-af45-ab6d0434b785','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','ContainersCommon','d65083cb-1a9a-4238-ac42-125649926972','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2251,'df655fd2-bc4c-40c7-9bfa-aa9a52781b8b','7dc83628-82fd-48a0-abc3-de7f9455006d','2026-06-13 07:58:01',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RoleParametersValue-ywl7oriqf76r','state changed','OS::Heat::Value',NULL,1358),(2252,'bb614073-6241-4108-adec-c99f96f54c12','7dc83628-82fd-48a0-abc3-de7f9455006d','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RoleParametersValue-ywl7oriqf76r','state changed','OS::Heat::Value',NULL,1358),(2253,'e8b04105-649f-4859-8c0d-029da3f6259d','42d30573-52b0-49fd-ae85-ea4a154d6283','2026-06-13 07:58:01',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-PlacementLogging-3eghd3ndvpfg-RoleParametersValue-gs2ylk2ng76i','state changed','OS::Heat::Value',NULL,1359),(2254,'999f98b1-2642-4ce1-a50e-df2d0ba3ef56','42d30573-52b0-49fd-ae85-ea4a154d6283','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-PlacementLogging-3eghd3ndvpfg-RoleParametersValue-gs2ylk2ng76i','state changed','OS::Heat::Value',NULL,1359),(2255,'e86f2f68-66d9-4444-ac08-3d337783f9d2','42d30573-52b0-49fd-ae85-ea4a154d6283','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-PlacementLogging-3eghd3ndvpfg','42d30573-52b0-49fd-ae85-ea4a154d6283','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2256,'b4daeb84-e13d-43ae-a99f-2551b12ef48c','52d9821f-9781-4c98-b798-b173641dc099','2026-06-13 07:58:01',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-ContainersCommon-dmqoiisawipz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2257,'9b0b8efd-945a-4255-84ed-58aa7f250306','be5b7af0-e6c3-4de9-b148-247bd613225b','2026-06-13 07:58:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-ContainersCommon-dmqoiisawipz','be5b7af0-e6c3-4de9-b148-247bd613225b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2258,'92cd26fc-ad4e-4b09-afdb-9f8630d90390','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','NovaBase','8cb9804a-01d9-404e-ab47-21d876a41402','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1350),(2259,'4b520f3b-10ab-4dca-aca1-03ccd8926fdc','be5b7af0-e6c3-4de9-b148-247bd613225b','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-ContainersCommon-dmqoiisawipz','be5b7af0-e6c3-4de9-b148-247bd613225b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2260,'dd35133a-2a17-4180-a032-68ab0781dc5d','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','NovaLogging','5267c3b5-87f6-4a55-ba9f-41bc1b4436f4','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1345),(2261,'3eaef354-63be-4942-94d3-19b2fe3f271c','91cc2fe5-a1be-4e47-9141-80087855f516','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-37-4ba3tfilvg2z','91cc2fe5-a1be-4e47-9141-80087855f516','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2262,'4bac7a61-ed85-494c-9031-0d24906dc03e','db0c5a49-9b37-4593-8fd7-51ba9865a6e6','2026-06-13 07:58:01',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-RabbitMQServiceBase-a4cm3dtj23bt-ContainersCommon-43pxabnw2tho','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2263,'cb0a7880-dc79-4c34-a7c8-1ef122774eae','47ca00a4-0307-4f71-820e-a750fa50b200','2026-06-13 07:58:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-RabbitMQServiceBase-a4cm3dtj23bt-ContainersCommon-43pxabnw2tho','47ca00a4-0307-4f71-820e-a750fa50b200','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2264,'747c8b7d-6535-4bd4-a84e-c45732a44b6a','47ca00a4-0307-4f71-820e-a750fa50b200','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-RabbitMQServiceBase-a4cm3dtj23bt-ContainersCommon-43pxabnw2tho','47ca00a4-0307-4f71-820e-a750fa50b200','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2265,'60075bce-eaeb-4433-9175-e6130b706ddd','4c543c0a-1bf3-4a3e-8c37-56a8382738a2','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','ContainersCommon','f08dd052-78dd-4c36-8430-42284a137410','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2266,'2d367b44-40b7-4ffa-bb86-237a592c4630','4c543c0a-1bf3-4a3e-8c37-56a8382738a2','2026-06-13 07:58:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-44-bfymjzxkdedj','4c543c0a-1bf3-4a3e-8c37-56a8382738a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2267,'7d6920ba-7c7e-4961-a6bc-ae79402eeb7c','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:58:01',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-MySQLClient-lg5idcscqgcr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2268,'8180b8b5-089d-4526-bed8-a81c9dd1d0b8','a527fe42-8782-4d44-99f5-036a5acd2d6d','2026-06-13 07:58:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-MySQLClient-lg5idcscqgcr','a527fe42-8782-4d44-99f5-036a5acd2d6d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2269,'68355c23-57d2-42a5-9c3f-03553517db23','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:58:02',NULL,'CREATE','COMPLETE','PlacementLogging','42d30573-52b0-49fd-ae85-ea4a154d6283','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(2270,'9daf7f96-6984-4d7a-a165-7efc3e848d4c','a527fe42-8782-4d44-99f5-036a5acd2d6d','2026-06-13 07:58:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-MySQLClient-lg5idcscqgcr','a527fe42-8782-4d44-99f5-036a5acd2d6d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2271,'da457f98-fde9-412a-b698-30fdcee4854b','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:02',NULL,'CREATE','COMPLETE','37','91cc2fe5-a1be-4e47-9141-80087855f516','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1312),(2272,'63feb768-5013-44f3-b320-30c0fbdcf782','52d9821f-9781-4c98-b798-b173641dc099','2026-06-13 07:58:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-RoleParametersValue-eusf5udvkoay','state changed','OS::Heat::Value',NULL,1363),(2273,'21f0e02e-8872-4ae3-a062-19c00f25e50d','52d9821f-9781-4c98-b798-b173641dc099','2026-06-13 07:58:02',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-RoleParametersValue-eusf5udvkoay','state changed','OS::Heat::Value',NULL,1363),(2274,'5635303d-0f58-4b10-bc47-126a4ebe838d','52d9821f-9781-4c98-b798-b173641dc099','2026-06-13 07:58:02',NULL,'CREATE','COMPLETE','ContainersCommon','be5b7af0-e6c3-4de9-b148-247bd613225b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2275,'b4bfa3a5-d9d9-4001-be32-6d058d96f3db','db0c5a49-9b37-4593-8fd7-51ba9865a6e6','2026-06-13 07:58:02',NULL,'CREATE','COMPLETE','ContainersCommon','47ca00a4-0307-4f71-820e-a750fa50b200','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2276,'514cc130-fda5-4a8b-92ad-68e6ba9347ca','db0c5a49-9b37-4593-8fd7-51ba9865a6e6','2026-06-13 07:58:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55-RabbitMQServiceBase-a4cm3dtj23bt','db0c5a49-9b37-4593-8fd7-51ba9865a6e6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2277,'40849c3e-3958-4338-a579-24a89ef67205','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:02',NULL,'CREATE','COMPLETE','44','4c543c0a-1bf3-4a3e-8c37-56a8382738a2','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1355),(2278,'0b231af7-456d-4b44-96a2-f9e8c0d39c51','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:02',NULL,'CREATE','IN_PROGRESS','41','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-41-bvy55xepkeme','state changed','OS::TripleO::Services::Pacemaker',NULL,1370),(2279,'a56cf53c-90fe-457c-9d5d-9c99cebf32cf','0ab9ccdc-127b-4f19-8aac-b101fca95971','2026-06-13 07:58:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-41-bvy55xepkeme','0ab9ccdc-127b-4f19-8aac-b101fca95971','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2280,'986b04dc-9888-4723-b542-205d7a64e21f','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:58:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-RoleParametersValue-ipadpshiq6ua','state changed','OS::Heat::Value',NULL,1373),(2281,'e11a5acf-5ae9-4d5b-ba89-fd7d984bf588','0ab9ccdc-127b-4f19-8aac-b101fca95971','2026-06-13 07:58:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-41-bvy55xepkeme','0ab9ccdc-127b-4f19-8aac-b101fca95971','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2282,'50bb35fc-9d6c-4df5-9967-d29ede4b24c6','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:58:03',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q-RoleParametersValue-ipadpshiq6ua','state changed','OS::Heat::Value',NULL,1373),(2283,'4500962b-7942-4ed6-80fa-fc1d690e403f','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:58:03',NULL,'CREATE','COMPLETE','MySQLClient','a527fe42-8782-4d44-99f5-036a5acd2d6d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2284,'4879dcd8-4a38-4bfa-a38a-5c0cea827aba','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:03',NULL,'CREATE','IN_PROGRESS','48','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-48-qii54qnltgho','state changed','OS::TripleO::Services::Snmp',NULL,1374),(2285,'4d647ef1-e70e-4a32-a555-713a3bebcc15','7a6a2551-21b0-478d-85fc-e45f21b4aa27','2026-06-13 07:58:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-42-tzfrqvrdkv6q','7a6a2551-21b0-478d-85fc-e45f21b4aa27','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2286,'07a611ae-8ae7-4447-9bf1-a27350abecc9','a77222b6-0900-406a-9659-3b8db67cebb8','2026-06-13 07:58:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-48-qii54qnltgho','a77222b6-0900-406a-9659-3b8db67cebb8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2287,'219f13b2-6114-464d-81cc-b0923dc8d36a','a77222b6-0900-406a-9659-3b8db67cebb8','2026-06-13 07:58:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-48-qii54qnltgho','a77222b6-0900-406a-9659-3b8db67cebb8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2288,'f826eb7b-9fee-43f6-8a7b-018e20c5cd30','52d9821f-9781-4c98-b798-b173641dc099','2026-06-13 07:58:03',NULL,'CREATE','COMPLETE','RabbitMQServiceBase','db0c5a49-9b37-4593-8fd7-51ba9865a6e6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1351),(2289,'1ac64833-199c-4750-aefa-5f46e502d818','52d9821f-9781-4c98-b798-b173641dc099','2026-06-13 07:58:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z-RabbitmqBase-axidcyepon55','52d9821f-9781-4c98-b798-b173641dc099','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2290,'a941e7ed-0e0c-4e73-b30a-9395221e0712','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:03',NULL,'CREATE','COMPLETE','42','7a6a2551-21b0-478d-85fc-e45f21b4aa27','state changed','OS::TripleO::Services::PlacementApi',NULL,1335),(2291,'0244bf23-27bb-4bb0-819c-b3a4c0462062','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:03',NULL,'CREATE','COMPLETE','41','0ab9ccdc-127b-4f19-8aac-b101fca95971','state changed','OS::TripleO::Services::Pacemaker',NULL,1370),(2292,'66573dc8-98c9-4db5-9d38-96b4d6b5c60f','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:04',NULL,'CREATE','COMPLETE','48','a77222b6-0900-406a-9659-3b8db67cebb8','state changed','OS::TripleO::Services::Snmp',NULL,1374),(2293,'7df8892b-6b4f-404f-a369-7f32a4e7e597','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:04',NULL,'CREATE','IN_PROGRESS','45','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-45-wt46cjkg5pk4','state changed','OS::TripleO::Services::Podman',NULL,1383),(2294,'e7231815-8ebe-4e38-b1d5-6e44fd2cec75','7dc83628-82fd-48a0-abc3-de7f9455006d','2026-06-13 07:58:04',NULL,'CREATE','COMPLETE','RabbitmqBase','52d9821f-9781-4c98-b798-b173641dc099','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1347),(2295,'132f80ca-fcc8-4c17-b6e6-617ed84611b6','7dc83628-82fd-48a0-abc3-de7f9455006d','2026-06-13 07:58:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-43-75kdojibm47z','7dc83628-82fd-48a0-abc3-de7f9455006d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2296,'61184a61-2d81-4662-96da-3fe270205a2c','c5ba6a4b-7c44-4857-a73f-c8a5eae60d19','2026-06-13 07:58:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-45-wt46cjkg5pk4','c5ba6a4b-7c44-4857-a73f-c8a5eae60d19','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2297,'6fdc46a6-c8da-4d36-884e-a216e8a0c010','c5ba6a4b-7c44-4857-a73f-c8a5eae60d19','2026-06-13 07:58:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-45-wt46cjkg5pk4','c5ba6a4b-7c44-4857-a73f-c8a5eae60d19','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2298,'6cc86cce-c115-459c-b6a4-5dc10be44755','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:04',NULL,'CREATE','IN_PROGRESS','46','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5','state changed','OS::TripleO::Services::Redis',NULL,1386),(2299,'fbcda7f1-93b6-4504-8777-239c969ae132','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:04',NULL,'CREATE','IN_PROGRESS','52','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr','state changed','OS::TripleO::Services::SwiftStorage',NULL,1387),(2300,'79634f41-5834-48a2-9279-37f48e2a6c49','10bc07ca-d017-4469-a46b-b86fbf392796','2026-06-13 07:58:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5','10bc07ca-d017-4469-a46b-b86fbf392796','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2301,'24d3c24f-ec7c-4890-84ea-64e0c2ac2f3f','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','2026-06-13 07:58:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2302,'d509a32a-eded-4859-bc7d-c8fd84510df3','10bc07ca-d017-4469-a46b-b86fbf392796','2026-06-13 07:58:04',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RoleParametersValue-kawzeb67cvvq','state changed','OS::Heat::Value',NULL,1388),(2303,'7795bcd9-dee3-4b46-8c1b-937f2f67ea07','10bc07ca-d017-4469-a46b-b86fbf392796','2026-06-13 07:58:04',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RoleParametersValue-kawzeb67cvvq','state changed','OS::Heat::Value',NULL,1388),(2304,'eed21450-db44-470e-99c9-d3deda45ca9d','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','2026-06-13 07:58:04',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr-SwiftBase-niopdqotrwgs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1389),(2305,'2e2e3cbf-7e0b-42c6-8609-8e59d486edd8','3dabd187-ac5a-4f2d-911b-3466b8cf8b9e','2026-06-13 07:58:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr-SwiftBase-niopdqotrwgs','3dabd187-ac5a-4f2d-911b-3466b8cf8b9e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2306,'bfb1ce1e-3c9f-4339-8549-4af65defeac6','3dabd187-ac5a-4f2d-911b-3466b8cf8b9e','2026-06-13 07:58:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr-SwiftBase-niopdqotrwgs','3dabd187-ac5a-4f2d-911b-3466b8cf8b9e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2307,'d9f0cb8c-521e-4041-8877-fb211114c560','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:05',NULL,'CREATE','COMPLETE','43','7dc83628-82fd-48a0-abc3-de7f9455006d','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,1339),(2308,'6e087196-b97a-49e5-9cb5-517a98f5b929','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:05',NULL,'CREATE','COMPLETE','45','c5ba6a4b-7c44-4857-a73f-c8a5eae60d19','state changed','OS::TripleO::Services::Podman',NULL,1383),(2309,'d7ee70ea-31ec-4508-ab72-016b612b0dbe','10bc07ca-d017-4469-a46b-b86fbf392796','2026-06-13 07:58:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-ContainersCommon-qom5skznykdm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2310,'150d4b2d-0706-445e-aaa3-f571b779e1a1','438204d0-1a68-482c-98d1-63232d98a86d','2026-06-13 07:58:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-ContainersCommon-qom5skznykdm','438204d0-1a68-482c-98d1-63232d98a86d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2311,'81d5b296-495e-4236-bb3d-752af2c00688','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:05',NULL,'CREATE','IN_PROGRESS','49','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-49-r3gg3mjh7kix','state changed','OS::TripleO::Services::Sshd',NULL,1398),(2312,'2607a4ca-c64c-4c33-bf12-309ee0d817b7','438204d0-1a68-482c-98d1-63232d98a86d','2026-06-13 07:58:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-ContainersCommon-qom5skznykdm','438204d0-1a68-482c-98d1-63232d98a86d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2313,'15492be5-4369-4824-8b96-00938623ce57','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','2026-06-13 07:58:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr-ContainersCommon-svipgkd5k3ot','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2314,'0e1519ef-208b-429f-8ab6-ef5661d99173','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','2026-06-13 07:58:05',NULL,'CREATE','COMPLETE','SwiftBase','3dabd187-ac5a-4f2d-911b-3466b8cf8b9e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1389),(2315,'59c6b657-f1a2-430f-954d-d67536822f58','dc4daddb-d434-48a7-b0f5-6e725a2383b6','2026-06-13 07:58:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-49-r3gg3mjh7kix','dc4daddb-d434-48a7-b0f5-6e725a2383b6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2316,'a0f615c2-9a91-4bbb-8949-524ae901b719','f4bb67c9-4878-4156-ba41-3afd2196bc2e','2026-06-13 07:58:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr-ContainersCommon-svipgkd5k3ot','f4bb67c9-4878-4156-ba41-3afd2196bc2e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2317,'1a6e44d0-2977-4424-acf7-03e6f518b538','dc4daddb-d434-48a7-b0f5-6e725a2383b6','2026-06-13 07:58:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-49-r3gg3mjh7kix','dc4daddb-d434-48a7-b0f5-6e725a2383b6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2318,'bb13a84e-882a-4fb1-8522-52dcc5ab750f','f4bb67c9-4878-4156-ba41-3afd2196bc2e','2026-06-13 07:58:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr-ContainersCommon-svipgkd5k3ot','f4bb67c9-4878-4156-ba41-3afd2196bc2e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2319,'a40c7675-e0c2-432e-b99d-455b1f5c418a','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:06',NULL,'CREATE','IN_PROGRESS','47','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-47-pfmgbjkkwh7u','state changed','OS::TripleO::Services::Rsyslog',NULL,1401),(2320,'be225e85-38fb-4d81-927c-c43f0b8c6f25','763cfb7b-5c21-4400-83d3-496855b2eda8','2026-06-13 07:58:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-47-pfmgbjkkwh7u','763cfb7b-5c21-4400-83d3-496855b2eda8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2321,'a3526d96-928f-4238-bc3a-ce96adc95e37','763cfb7b-5c21-4400-83d3-496855b2eda8','2026-06-13 07:58:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-47-pfmgbjkkwh7u-RoleParametersValue-zffvaa4iqlzi','state changed','OS::Heat::Value',NULL,1402),(2322,'41ad0fc5-9d27-46bb-9fec-dc17048d00b0','763cfb7b-5c21-4400-83d3-496855b2eda8','2026-06-13 07:58:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-47-pfmgbjkkwh7u-RoleParametersValue-zffvaa4iqlzi','state changed','OS::Heat::Value',NULL,1402),(2323,'80fa99d5-fe5a-4c56-b848-8c7dd1caad4d','10bc07ca-d017-4469-a46b-b86fbf392796','2026-06-13 07:58:06',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1403),(2324,'240579e8-e13c-4b02-9724-7530cff2416f','15f6d5dc-5d5b-492e-a736-12efd7db39e7','2026-06-13 07:58:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi','15f6d5dc-5d5b-492e-a736-12efd7db39e7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2325,'90be565c-3ec3-4505-acc4-35221e7b26eb','10bc07ca-d017-4469-a46b-b86fbf392796','2026-06-13 07:58:06',NULL,'CREATE','COMPLETE','ContainersCommon','438204d0-1a68-482c-98d1-63232d98a86d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2326,'a810f10d-ff8a-4561-82b5-3ef75e738784','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','2026-06-13 07:58:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr-RoleParametersValue-jwws4u4e5i3z','state changed','OS::Heat::Value',NULL,1404),(2327,'ed711049-3d9d-41cb-b2f1-afd0fa6ccc21','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','2026-06-13 07:58:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr-RoleParametersValue-jwws4u4e5i3z','state changed','OS::Heat::Value',NULL,1404),(2328,'e8e8a56d-00c8-4fba-87f3-cc55bc34e0f4','15f6d5dc-5d5b-492e-a736-12efd7db39e7','2026-06-13 07:58:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi-RoleParametersValue-53ycek3dukbp','state changed','OS::Heat::Value',NULL,1405),(2329,'b1121007-1f48-421b-8b6d-aef2e6533e8e','15f6d5dc-5d5b-492e-a736-12efd7db39e7','2026-06-13 07:58:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi-RoleParametersValue-53ycek3dukbp','state changed','OS::Heat::Value',NULL,1405),(2330,'fe74f200-1e7c-4202-8786-80d391380022','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:06',NULL,'CREATE','COMPLETE','49','dc4daddb-d434-48a7-b0f5-6e725a2383b6','state changed','OS::TripleO::Services::Sshd',NULL,1398),(2331,'9ac8bcd9-cb5a-4ddd-b53a-b700d1fa1b82','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','2026-06-13 07:58:06',NULL,'CREATE','COMPLETE','ContainersCommon','f4bb67c9-4878-4156-ba41-3afd2196bc2e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2332,'ea60daaa-c5a0-4d28-997a-58afe5592caa','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','2026-06-13 07:58:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-52-p7wzsdzyeysr','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2333,'63aaf4b2-a59b-4524-b095-fa998df8d2e5','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:07',NULL,'CREATE','IN_PROGRESS','53','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-53-q6tl63d5ui5a','state changed','OS::TripleO::Services::Timesync',NULL,1407),(2334,'599530d4-a23e-4648-98ce-1c23f612251b','763cfb7b-5c21-4400-83d3-496855b2eda8','2026-06-13 07:58:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-47-pfmgbjkkwh7u-ContainersCommon-7xyj4k7dfqga','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2335,'4d498918-29ec-44ab-a069-c63faf2fee2d','8f7ce53c-67d0-4626-9b92-79a4acfd69cf','2026-06-13 07:58:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-53-q6tl63d5ui5a','8f7ce53c-67d0-4626-9b92-79a4acfd69cf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2336,'02d2b772-32f7-44a2-8310-7202ba970985','8f7ce53c-67d0-4626-9b92-79a4acfd69cf','2026-06-13 07:58:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-53-q6tl63d5ui5a','8f7ce53c-67d0-4626-9b92-79a4acfd69cf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2337,'0f601ffa-d03b-44cf-9fbb-1f855b379e42','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:07',NULL,'CREATE','COMPLETE','53','8f7ce53c-67d0-4626-9b92-79a4acfd69cf','state changed','OS::TripleO::Services::Timesync',NULL,1407),(2338,'9fbc286e-599b-46d3-84c3-aa417ba654a3','54dabcf2-3204-4795-80fa-2652276672a3','2026-06-13 07:58:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-47-pfmgbjkkwh7u-ContainersCommon-7xyj4k7dfqga','54dabcf2-3204-4795-80fa-2652276672a3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2339,'5798d025-4b4f-482d-a6a6-128c7b239672','54dabcf2-3204-4795-80fa-2652276672a3','2026-06-13 07:58:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-47-pfmgbjkkwh7u-ContainersCommon-7xyj4k7dfqga','54dabcf2-3204-4795-80fa-2652276672a3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2340,'9f50f188-069a-473b-86ae-ecea7ae3ff58','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:07',NULL,'CREATE','COMPLETE','52','b70114c8-e8e6-4c78-b7b6-f8597d22fa53','state changed','OS::TripleO::Services::SwiftStorage',NULL,1387),(2341,'eea5c0d0-967b-4281-b3c2-943097362222','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:07',NULL,'CREATE','IN_PROGRESS','57','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-57-57jsxcmksugv','state changed','OS::TripleO::Services::Tuned',NULL,1410),(2342,'6ec30774-6e2d-4b37-860d-5deb11351c52','4e3d2e91-01fa-4700-aef5-c5dd7f40a102','2026-06-13 07:58:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-57-57jsxcmksugv','4e3d2e91-01fa-4700-aef5-c5dd7f40a102','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2343,'e1869887-e978-4413-a13f-8b07fc080b89','4e3d2e91-01fa-4700-aef5-c5dd7f40a102','2026-06-13 07:58:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-57-57jsxcmksugv-RoleParametersValue-fz6ox7vvh3kx','state changed','OS::Heat::Value',NULL,1414),(2344,'2f1b4c89-70a1-4605-b489-6768be8b9a99','4e3d2e91-01fa-4700-aef5-c5dd7f40a102','2026-06-13 07:58:07',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-57-57jsxcmksugv-RoleParametersValue-fz6ox7vvh3kx','state changed','OS::Heat::Value',NULL,1414),(2345,'40b704b4-f67e-4d52-8056-655512004724','4e3d2e91-01fa-4700-aef5-c5dd7f40a102','2026-06-13 07:58:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-57-57jsxcmksugv','4e3d2e91-01fa-4700-aef5-c5dd7f40a102','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2346,'4bf7e5dd-985c-40e4-828b-290cd2b4e604','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:08',NULL,'CREATE','IN_PROGRESS','56','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-56-qjk7xvmg4vac','state changed','OS::TripleO::Services::TripleoPackages',NULL,1415),(2347,'e4020fce-7750-462a-9ffb-394c9dc48a0b','15f6d5dc-5d5b-492e-a736-12efd7db39e7','2026-06-13 07:58:08',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi-ContainersCommon-kfjtgcoeln6t','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2348,'0e94992c-0caa-43aa-9400-a305ad1461b2','2280aeeb-e275-4918-9a4f-63768cf0e6d9','2026-06-13 07:58:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-56-qjk7xvmg4vac','2280aeeb-e275-4918-9a4f-63768cf0e6d9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2349,'5ea15016-2b79-46ef-a422-0704a3da18ac','455e98ff-310d-4f09-b2c7-7e468e4d565d','2026-06-13 07:58:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi-ContainersCommon-kfjtgcoeln6t','455e98ff-310d-4f09-b2c7-7e468e4d565d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2350,'ea376e69-1a8e-4501-917d-50dd285951ce','455e98ff-310d-4f09-b2c7-7e468e4d565d','2026-06-13 07:58:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi-ContainersCommon-kfjtgcoeln6t','455e98ff-310d-4f09-b2c7-7e468e4d565d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2351,'7761361d-1cef-44eb-838f-b9a81ee494eb','2280aeeb-e275-4918-9a4f-63768cf0e6d9','2026-06-13 07:58:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-56-qjk7xvmg4vac-RoleParametersValue-gin2fuqgv53g','state changed','OS::Heat::Value',NULL,1416),(2352,'9efffdfe-7a41-4717-92de-0ef9c26faf5e','2280aeeb-e275-4918-9a4f-63768cf0e6d9','2026-06-13 07:58:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-56-qjk7xvmg4vac-RoleParametersValue-gin2fuqgv53g','state changed','OS::Heat::Value',NULL,1416),(2353,'709260e1-94a8-4edb-9bdf-94f63642c730','763cfb7b-5c21-4400-83d3-496855b2eda8','2026-06-13 07:58:08',NULL,'CREATE','COMPLETE','ContainersCommon','54dabcf2-3204-4795-80fa-2652276672a3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2354,'dd2817ac-493a-4eda-8ebe-13d4ab9d97a9','763cfb7b-5c21-4400-83d3-496855b2eda8','2026-06-13 07:58:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-47-pfmgbjkkwh7u','763cfb7b-5c21-4400-83d3-496855b2eda8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2355,'91f21fde-3004-43ea-ba16-e695b688821f','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:08',NULL,'CREATE','COMPLETE','57','4e3d2e91-01fa-4700-aef5-c5dd7f40a102','state changed','OS::TripleO::Services::Tuned',NULL,1410),(2356,'0936759f-68c3-49d6-9a6b-cb013fa9c42e','15f6d5dc-5d5b-492e-a736-12efd7db39e7','2026-06-13 07:58:09',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi-RedisBase-nca6atdr3cxn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1417),(2357,'26b59ed0-6953-4c8c-86cd-229db07933cd','6cb141eb-347c-4569-aaad-af0cad9bfef0','2026-06-13 07:58:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi-RedisBase-nca6atdr3cxn','6cb141eb-347c-4569-aaad-af0cad9bfef0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2358,'d781149a-41d0-433c-bad1-bf38397492a6','6cb141eb-347c-4569-aaad-af0cad9bfef0','2026-06-13 07:58:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi-RedisBase-nca6atdr3cxn','6cb141eb-347c-4569-aaad-af0cad9bfef0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2359,'ceb26d7f-b514-49e5-904b-d1e04aa3dba2','15f6d5dc-5d5b-492e-a736-12efd7db39e7','2026-06-13 07:58:09',NULL,'CREATE','COMPLETE','ContainersCommon','455e98ff-310d-4f09-b2c7-7e468e4d565d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2360,'44190ace-4a5f-4d58-b333-9812e65c4d48','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:09',NULL,'CREATE','COMPLETE','47','763cfb7b-5c21-4400-83d3-496855b2eda8','state changed','OS::TripleO::Services::Rsyslog',NULL,1401),(2361,'fb875290-d41d-4f37-8961-dae839e2a9c1','2280aeeb-e275-4918-9a4f-63768cf0e6d9','2026-06-13 07:58:09',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-56-qjk7xvmg4vac-Podman-hwdaroprlhq2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1418),(2362,'676fe5c8-6809-4fb7-898d-48879bdc7653','a3b5941e-1c10-47e7-a7f7-ab023816b21e','2026-06-13 07:58:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-56-qjk7xvmg4vac-Podman-hwdaroprlhq2','a3b5941e-1c10-47e7-a7f7-ab023816b21e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2363,'6c351b1d-098d-4097-a5f0-8695924dce1d','a3b5941e-1c10-47e7-a7f7-ab023816b21e','2026-06-13 07:58:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-56-qjk7xvmg4vac-Podman-hwdaroprlhq2','a3b5941e-1c10-47e7-a7f7-ab023816b21e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2364,'f8892f04-4c28-40fe-9481-110479bda03a','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:09',NULL,'CREATE','IN_PROGRESS','51','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-51-3kxxo6r3rz7v','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1422),(2365,'62efba3b-4c53-4968-a976-01c20a6a1b99','d6336c6b-68e9-46a1-9913-6f42d915a32d','2026-06-13 07:58:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-51-3kxxo6r3rz7v','d6336c6b-68e9-46a1-9913-6f42d915a32d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2366,'d785dff5-903a-457d-a9e3-462cde5a69ac','d6336c6b-68e9-46a1-9913-6f42d915a32d','2026-06-13 07:58:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-51-3kxxo6r3rz7v-RoleParametersValue-c25crn5fg6ge','state changed','OS::Heat::Value',NULL,1423),(2367,'52c9d634-6925-41d6-aec4-c94e7bb249c9','d6336c6b-68e9-46a1-9913-6f42d915a32d','2026-06-13 07:58:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-51-3kxxo6r3rz7v-RoleParametersValue-c25crn5fg6ge','state changed','OS::Heat::Value',NULL,1423),(2368,'875e8a0d-65a2-4678-82f4-f7f01f318642','d6336c6b-68e9-46a1-9913-6f42d915a32d','2026-06-13 07:58:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-51-3kxxo6r3rz7v','d6336c6b-68e9-46a1-9913-6f42d915a32d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2369,'4dbf5a28-070a-44f9-a0db-c3f0448a8cfa','15f6d5dc-5d5b-492e-a736-12efd7db39e7','2026-06-13 07:58:10',NULL,'CREATE','COMPLETE','RedisBase','6cb141eb-347c-4569-aaad-af0cad9bfef0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1417),(2370,'93d66598-2779-4ed9-94ab-fad40abc7ed7','15f6d5dc-5d5b-492e-a736-12efd7db39e7','2026-06-13 07:58:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5-RedisBase-kuvjmiy6bpyi','15f6d5dc-5d5b-492e-a736-12efd7db39e7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2371,'c48cdef7-4075-4d80-abd0-f49a761e9438','2280aeeb-e275-4918-9a4f-63768cf0e6d9','2026-06-13 07:58:10',NULL,'CREATE','COMPLETE','Podman','a3b5941e-1c10-47e7-a7f7-ab023816b21e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1418),(2372,'27d75e13-224b-4065-8298-3edb53a620bb','2280aeeb-e275-4918-9a4f-63768cf0e6d9','2026-06-13 07:58:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-56-qjk7xvmg4vac','2280aeeb-e275-4918-9a4f-63768cf0e6d9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2373,'83626191-bfed-4d62-a792-a593c79ed3c9','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:10',NULL,'CREATE','COMPLETE','51','d6336c6b-68e9-46a1-9913-6f42d915a32d','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1422),(2374,'b8a186e1-fcce-418c-bffd-4d5a6eb02c34','10bc07ca-d017-4469-a46b-b86fbf392796','2026-06-13 07:58:10',NULL,'CREATE','COMPLETE','RedisBase','15f6d5dc-5d5b-492e-a736-12efd7db39e7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1403),(2375,'484d25be-895f-491c-b54e-aa0832a8b012','10bc07ca-d017-4469-a46b-b86fbf392796','2026-06-13 07:58:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-46-x6nkcldjail5','10bc07ca-d017-4469-a46b-b86fbf392796','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2376,'350d28f6-1039-423f-9f0b-cd751e8313b7','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:10',NULL,'CREATE','IN_PROGRESS','55','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-55-goajokm2y5ez','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1426),(2377,'3c3187a8-af9a-46fa-a137-ac315b3fdb9b','ed047c0a-abfc-4e7b-8e14-546fc4dc2fa1','2026-06-13 07:58:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-55-goajokm2y5ez','ed047c0a-abfc-4e7b-8e14-546fc4dc2fa1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2378,'cce48b2e-a80e-493e-b69c-1e500799f5f3','ed047c0a-abfc-4e7b-8e14-546fc4dc2fa1','2026-06-13 07:58:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-55-goajokm2y5ez-RoleParametersValue-csvbbfs6k3sr','state changed','OS::Heat::Value',NULL,1427),(2379,'c9c4a006-64dc-4e07-a509-e5e805b5ed6f','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:11',NULL,'CREATE','COMPLETE','56','2280aeeb-e275-4918-9a4f-63768cf0e6d9','state changed','OS::TripleO::Services::TripleoPackages',NULL,1415),(2380,'058113d9-7da2-41d3-a607-9c98e3ffa0b7','ed047c0a-abfc-4e7b-8e14-546fc4dc2fa1','2026-06-13 07:58:11',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-55-goajokm2y5ez-RoleParametersValue-csvbbfs6k3sr','state changed','OS::Heat::Value',NULL,1427),(2381,'0a023bf4-ad1c-4b68-aff6-74b4d146eb07','ed047c0a-abfc-4e7b-8e14-546fc4dc2fa1','2026-06-13 07:58:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-55-goajokm2y5ez','ed047c0a-abfc-4e7b-8e14-546fc4dc2fa1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2382,'9b3cf45d-5b86-4fe5-a6a2-e3befca5ebf5','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:11',NULL,'CREATE','COMPLETE','46','10bc07ca-d017-4469-a46b-b86fbf392796','state changed','OS::TripleO::Services::Redis',NULL,1386),(2383,'28cd3005-808e-4e18-ae99-9186f82d8035','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:12',NULL,'CREATE','COMPLETE','55','ed047c0a-abfc-4e7b-8e14-546fc4dc2fa1','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1426),(2384,'c6c43d3e-417e-4d54-a0ce-c2338950c268','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:12',NULL,'CREATE','IN_PROGRESS','50','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo','state changed','OS::TripleO::Services::SwiftProxy',NULL,1435),(2385,'a08d54b8-72e8-4dd0-b144-c7db749a746c','2417b6a7-11f5-42bd-a4fd-84591ea8814b','2026-06-13 07:58:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo','2417b6a7-11f5-42bd-a4fd-84591ea8814b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2386,'7d402bd2-e981-4c32-976f-9ce0b7f6c492','2417b6a7-11f5-42bd-a4fd-84591ea8814b','2026-06-13 07:58:12',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-TLSProxyBase-ermzczakcdph','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1436),(2387,'89891517-43fd-4436-b4e7-df102d9fde70','6c0eac33-5a7d-4d89-b876-0012a01ce376','2026-06-13 07:58:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-TLSProxyBase-ermzczakcdph','6c0eac33-5a7d-4d89-b876-0012a01ce376','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2388,'4e8c1aa8-d054-4894-8104-48a9e6563b5a','6c0eac33-5a7d-4d89-b876-0012a01ce376','2026-06-13 07:58:12',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-TLSProxyBase-ermzczakcdph-ApacheNetworks-4u6ghcbdgsk4','state changed','OS::Heat::Value',NULL,1437),(2389,'80e18726-fa5f-429f-9d82-a07aaa0d1768','6c0eac33-5a7d-4d89-b876-0012a01ce376','2026-06-13 07:58:12',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-TLSProxyBase-ermzczakcdph-ApacheNetworks-4u6ghcbdgsk4','state changed','OS::Heat::Value',NULL,1437),(2390,'e1474f56-40c8-443b-9614-e94c8f0942b6','6c0eac33-5a7d-4d89-b876-0012a01ce376','2026-06-13 07:58:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-TLSProxyBase-ermzczakcdph','6c0eac33-5a7d-4d89-b876-0012a01ce376','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2391,'e23add66-7079-4ea4-ace5-2325335a3eab','2417b6a7-11f5-42bd-a4fd-84591ea8814b','2026-06-13 07:58:13',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-SwiftBase-dqpg64tt7pmg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1438),(2392,'7556e241-9267-42fd-9e10-4b6a946c2ecd','a09d0ca7-5a83-4346-9315-7eaaa853d6fb','2026-06-13 07:58:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-SwiftBase-dqpg64tt7pmg','a09d0ca7-5a83-4346-9315-7eaaa853d6fb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2393,'c0a35ce6-9747-4e83-b9eb-8efaeda4bf1a','2417b6a7-11f5-42bd-a4fd-84591ea8814b','2026-06-13 07:58:13',NULL,'CREATE','COMPLETE','TLSProxyBase','6c0eac33-5a7d-4d89-b876-0012a01ce376','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1436),(2394,'34c06746-b32c-4ea1-9222-7aee2dc056d4','a09d0ca7-5a83-4346-9315-7eaaa853d6fb','2026-06-13 07:58:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-SwiftBase-dqpg64tt7pmg','a09d0ca7-5a83-4346-9315-7eaaa853d6fb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2395,'7d8fc117-c44f-4d0c-9b45-dd4b44723afb','2417b6a7-11f5-42bd-a4fd-84591ea8814b','2026-06-13 07:58:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-RoleParametersValue-doar5cg7ma4c','state changed','OS::Heat::Value',NULL,1439),(2396,'e085f7e6-7814-4de6-8cbf-87cbd1fbf048','2417b6a7-11f5-42bd-a4fd-84591ea8814b','2026-06-13 07:58:14',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-RoleParametersValue-doar5cg7ma4c','state changed','OS::Heat::Value',NULL,1439),(2397,'132e583a-670c-4b47-8cbe-2a998a336fd7','2417b6a7-11f5-42bd-a4fd-84591ea8814b','2026-06-13 07:58:14',NULL,'CREATE','COMPLETE','SwiftBase','a09d0ca7-5a83-4346-9315-7eaaa853d6fb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1438),(2398,'9086fe77-afbc-40d2-a2c0-35a58089781c','2417b6a7-11f5-42bd-a4fd-84591ea8814b','2026-06-13 07:58:15',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-ContainersCommon-valmsjto3hzh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2399,'6fcb2365-0e12-4451-85ba-ec16f5091c4f','5afdf01d-4883-40e2-961f-a2ef5e306681','2026-06-13 07:58:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-ContainersCommon-valmsjto3hzh','5afdf01d-4883-40e2-961f-a2ef5e306681','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2400,'8137ae22-94da-42d7-8751-2f19fbd58654','5afdf01d-4883-40e2-961f-a2ef5e306681','2026-06-13 07:58:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo-ContainersCommon-valmsjto3hzh','5afdf01d-4883-40e2-961f-a2ef5e306681','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2401,'2e397cac-e626-4382-8f62-4475c9a89787','2417b6a7-11f5-42bd-a4fd-84591ea8814b','2026-06-13 07:58:16',NULL,'CREATE','COMPLETE','ContainersCommon','5afdf01d-4883-40e2-961f-a2ef5e306681','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2402,'9b9a734b-eb0a-4943-9830-d49e6e88fab9','2417b6a7-11f5-42bd-a4fd-84591ea8814b','2026-06-13 07:58:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-50-jksbp2oxjvwo','2417b6a7-11f5-42bd-a4fd-84591ea8814b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2403,'defe1bce-b58c-43d3-a63d-730e209d9cd8','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:17',NULL,'CREATE','COMPLETE','50','2417b6a7-11f5-42bd-a4fd-84591ea8814b','state changed','OS::TripleO::Services::SwiftProxy',NULL,1435),(2404,'4fd0e2c8-abda-4afe-ba67-ec74944f1249','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:18',NULL,'CREATE','IN_PROGRESS','54','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-54-7oksfucf3t73','state changed','OS::TripleO::Services::Timezone',NULL,1446),(2405,'2055b852-0311-4961-b3ca-1cd8de97800e','bbe43c19-8d0e-4220-b368-434dc30b1dae','2026-06-13 07:58:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-54-7oksfucf3t73','bbe43c19-8d0e-4220-b368-434dc30b1dae','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2406,'db2042dd-16fe-4554-8ea8-7ec58897d781','bbe43c19-8d0e-4220-b368-434dc30b1dae','2026-06-13 07:58:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5-54-7oksfucf3t73','bbe43c19-8d0e-4220-b368-434dc30b1dae','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2407,'429efc35-cf87-4328-ac07-d683f6c843cb','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:19',NULL,'CREATE','COMPLETE','54','bbe43c19-8d0e-4220-b368-434dc30b1dae','state changed','OS::TripleO::Services::Timezone',NULL,1446),(2408,'fc6b5cdd-d47e-4399-a505-5c22c3816517','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','2026-06-13 07:58:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceChain-utbuhe62mcy5','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2409,'f9469609-fec8-4646-82dd-99811cd51f2d','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:19',NULL,'CREATE','COMPLETE','ServiceChain','d32fbd3a-accc-45e0-9ee0-9eaedc1a3139','state changed','OS::Heat::ResourceChain',NULL,88),(2410,'ce32b412-9e69-4a22-8bce-7be127fc5ea8','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:21',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ControllerServiceChain-yt3pkirjlivz-FirewallFrontendRules-7kkucyzt6emg','state changed','OS::Heat::Value',NULL,1455),(2411,'9d266e35-3e0c-4fa1-a618-5773065e3c0c','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:21',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-yt3pkirjlivz-MonitoringSubscriptionsConfig-nt4gda3gwcta','state changed','OS::Heat::Value',NULL,1456),(2412,'c9886966-821b-46cb-8699-0492e8c5b79d','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:21',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-yt3pkirjlivz-MonitoringSubscriptionsConfig-nt4gda3gwcta','state changed','OS::Heat::Value',NULL,1456),(2413,'12e6d1f0-c103-42fa-a9bb-753d82b25a23','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:21',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ControllerServiceChain-yt3pkirjlivz-FirewallFrontendRules-7kkucyzt6emg','state changed','OS::Heat::Value',NULL,1455),(2414,'4a1412f5-a8fc-47bf-a711-164f65e6239b','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:21',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ControllerServiceChain-yt3pkirjlivz-DockerConfig-3exa7fjpuibs','state changed','OS::Heat::Value',NULL,1457),(2415,'ff8bbe74-db27-424f-8941-2637c3b1ca81','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:21',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ControllerServiceChain-yt3pkirjlivz-DockerConfig-3exa7fjpuibs','state changed','OS::Heat::Value',NULL,1457),(2416,'da99b688-a912-4440-9735-92b9099a080d','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:22',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-PostUpgradeTasks-54bukchqt6rc','state changed','OS::Heat::Value',NULL,1458),(2417,'65489dd4-5508-4d55-8e69-ae8abe846420','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:22',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-PostUpgradeTasks-54bukchqt6rc','state changed','OS::Heat::Value',NULL,1458),(2418,'ef487201-ceba-49ea-8c54-0d9efa428621','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:22',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ControllerServiceChain-yt3pkirjlivz-PuppetStepConfig-zaffhygx3dq5','state changed','OS::Heat::Value',NULL,1459),(2419,'dc1bb43e-36b7-40b4-af07-f67a11d7a60a','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:22',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ControllerServiceChain-yt3pkirjlivz-PuppetStepConfig-zaffhygx3dq5','state changed','OS::Heat::Value',NULL,1459),(2420,'b5a35553-0084-42f0-a462-e9271cdfe3a4','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:22',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ControllerServiceChain-yt3pkirjlivz-AnsibleGroupVars-3eefamjcameg','state changed','OS::Heat::Value',NULL,1460),(2421,'09fb2b10-bcd2-4219-88b7-e322591bf624','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:22',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ControllerServiceChain-yt3pkirjlivz-AnsibleGroupVars-3eefamjcameg','state changed','OS::Heat::Value',NULL,1460),(2422,'3376c561-374d-4e80-a5a2-b40112a348e6','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:22',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-UpgradeTasks-4ona6xjamnza','state changed','OS::Heat::Value',NULL,1461),(2423,'38da9be4-a72d-4129-90a9-1af157ff1acd','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:22',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ExternalDeployTasks-bd4tesazsbzh','state changed','OS::Heat::Value',NULL,1462),(2424,'28f52d48-1bc1-4ceb-ad3c-e7500b5d3f5e','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:22',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-UpgradeTasks-4ona6xjamnza','state changed','OS::Heat::Value',NULL,1461),(2425,'8a066b2d-9008-45b6-a5a4-ea3368f99eb8','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:22',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ExternalDeployTasks-bd4tesazsbzh','state changed','OS::Heat::Value',NULL,1462),(2426,'b1869c5a-1788-468c-805a-ed0e67f5d182','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:23',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-UpgradeBatchTasks-wdeokjpw64ub','state changed','OS::Heat::Value',NULL,1463),(2427,'29a347f6-8ea8-4782-ad92-3efb804af807','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:23',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-UpdateTasks-4vkny2upgabe','state changed','OS::Heat::Value',NULL,1464),(2428,'83dd13bb-aff1-4a6f-a9fa-934b4107caa4','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:23',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-UpgradeBatchTasks-wdeokjpw64ub','state changed','OS::Heat::Value',NULL,1463),(2429,'ced36826-591c-40b6-af40-13531bf45b79','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:23',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-UpdateTasks-4vkny2upgabe','state changed','OS::Heat::Value',NULL,1464),(2430,'e8f78d17-acdd-4e3b-b53b-0d71d16f485b','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:23',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ControllerServiceChain-yt3pkirjlivz-FirewallRules-dhfl5hqclhc4','state changed','OS::Heat::Value',NULL,1465),(2431,'66c90283-6b33-4c09-9feb-661fb9e7c3e9','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:23',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ControllerServiceChain-yt3pkirjlivz-FirewallRules-dhfl5hqclhc4','state changed','OS::Heat::Value',NULL,1465),(2432,'8ee8b746-30d3-4e13-92bf-adbe3c7ed953','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:23',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-HostFirewallTasks-a53e4pbkz6gn','state changed','OS::Heat::Value',NULL,1466),(2433,'75aec2d9-e9bc-443a-866d-d36287e41923','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:23',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-HostFirewallTasks-a53e4pbkz6gn','state changed','OS::Heat::Value',NULL,1466),(2434,'06d43cd8-12f5-4d07-8c41-d08cb4b559c1','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:24',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-DeployStepsTasks-riuwejchwlmh','state changed','OS::Heat::Value',NULL,1467),(2435,'e31628d0-13b9-4eea-9c2a-cbafafd1102a','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:24',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ControllerServiceChain-yt3pkirjlivz-DockerConfigScripts-ysholqv7ywzl','state changed','OS::Heat::Value',NULL,1468),(2436,'44967f0d-7dfb-48d4-a48e-0275c846b5ac','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:24',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ControllerServiceChain-yt3pkirjlivz-DockerConfigScripts-ysholqv7ywzl','state changed','OS::Heat::Value',NULL,1468),(2437,'950e9754-120b-46c9-b43a-0ac0cd76ed1a','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:24',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-DeployStepsTasks-riuwejchwlmh','state changed','OS::Heat::Value',NULL,1467),(2438,'926a4129-b55a-45d3-b687-fe7ef44d56bc','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:24',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ExternalUpgradeTasks-jdgb2a34l77g','state changed','OS::Heat::Value',NULL,1469),(2439,'607ea89b-ad87-4729-9ea1-f95e9abf6c2b','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:24',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ExternalUpgradeTasks-jdgb2a34l77g','state changed','OS::Heat::Value',NULL,1469),(2440,'689e1777-9d4d-42a5-aac7-be7fc8578d9c','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:24',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-HostPrepTasks-leclesg6mnye','state changed','OS::Heat::Value',NULL,1470),(2441,'f0121440-90e5-4dda-81eb-002191525062','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:24',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-HostPrepTasks-leclesg6mnye','state changed','OS::Heat::Value',NULL,1470),(2442,'f3d83490-b6be-4c67-a403-baa3aafd888e','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:25',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ControllerServiceChain-yt3pkirjlivz-KollaConfig-vvou4wtn4i4x','state changed','OS::Heat::Value',NULL,1471),(2443,'95fd90fe-18fb-4541-830b-e69964603d23','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:25',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceNames-5siifvulinvb','state changed','OS::Heat::Value',NULL,1472),(2444,'5730f4e1-f8b4-4cb4-a708-1abf3aadd732','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:25',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceNames-5siifvulinvb','state changed','OS::Heat::Value',NULL,1472),(2445,'bdfa9f9e-32dc-455e-950a-b8827c9e4886','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:25',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ControllerServiceChain-yt3pkirjlivz-KollaConfig-vvou4wtn4i4x','state changed','OS::Heat::Value',NULL,1471),(2446,'f16ace49-52b5-4785-8603-ccb5d34d5364','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:25',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ExternalUpdateTasks-6sxb6rtalmbe','state changed','OS::Heat::Value',NULL,1473),(2447,'3d5bb266-4768-49a7-85f9-c6d0a0c44ab0','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:25',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ExternalUpdateTasks-6sxb6rtalmbe','state changed','OS::Heat::Value',NULL,1473),(2448,'66ebf1ee-bcff-4f67-ba01-72eca1697cc0','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:25',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceServerMetadataHook-h4iarfpdbbuo','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,1474),(2449,'587c98bc-e95e-4279-a523-859c8df59abf','c97dd032-f371-461b-91d4-9f1cfd6721fd','2026-06-13 07:58:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceServerMetadataHook-h4iarfpdbbuo','c97dd032-f371-461b-91d4-9f1cfd6721fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2450,'6623c2ea-2c39-41fc-9703-88d2b993dbcd','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:26',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-PreUpgradeRollingTasks-6znorrmehu6d','state changed','OS::Heat::Value',NULL,1475),(2451,'bc469975-9182-4b06-8d83-0ff32c420d01','c97dd032-f371-461b-91d4-9f1cfd6721fd','2026-06-13 07:58:26',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceServerMetadataHook-h4iarfpdbbuo-IncomingMetadataSettings-4xn63vpmyuu3','state changed','OS::Heat::Value',NULL,1476),(2452,'69dd5a4f-ced0-4859-ab9d-dfe45c52ee96','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:26',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-DockerPuppetTasks-al4hoblwz3ej','state changed','OS::Heat::Value',NULL,1477),(2453,'0a69757d-eb27-48d3-8014-f5374a7bb01d','c97dd032-f371-461b-91d4-9f1cfd6721fd','2026-06-13 07:58:26',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceServerMetadataHook-h4iarfpdbbuo-IncomingMetadataSettings-4xn63vpmyuu3','state changed','OS::Heat::Value',NULL,1476),(2454,'7617beb4-4696-46a3-b9d9-ebe9810e10ef','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:26',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-DockerPuppetTasks-al4hoblwz3ej','state changed','OS::Heat::Value',NULL,1477),(2455,'420a8054-798b-44d7-b4a3-f38d57d18243','c97dd032-f371-461b-91d4-9f1cfd6721fd','2026-06-13 07:58:26',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceServerMetadataHook-h4iarfpdbbuo-IndividualServices-tu3vywxgjoyz','state changed','OS::Heat::Value',NULL,1479),(2456,'a5793537-1b77-4cc6-985c-466726e7b5f4','c97dd032-f371-461b-91d4-9f1cfd6721fd','2026-06-13 07:58:26',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceServerMetadataHook-h4iarfpdbbuo-IndividualServices-tu3vywxgjoyz','state changed','OS::Heat::Value',NULL,1479),(2457,'35202ecd-fed0-4f47-bb75-108158c4b993','c97dd032-f371-461b-91d4-9f1cfd6721fd','2026-06-13 07:58:26',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceServerMetadataHook-h4iarfpdbbuo-CompactServices-ocow43n37vo7','state changed','OS::Heat::Value',NULL,1480),(2458,'8739705b-f89a-4250-b71a-76365669ec95','c97dd032-f371-461b-91d4-9f1cfd6721fd','2026-06-13 07:58:26',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceServerMetadataHook-h4iarfpdbbuo-CompactServices-ocow43n37vo7','state changed','OS::Heat::Value',NULL,1480),(2459,'70e0f6f1-bfce-4d0d-8021-e79d61890d53','c97dd032-f371-461b-91d4-9f1cfd6721fd','2026-06-13 07:58:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceServerMetadataHook-h4iarfpdbbuo','c97dd032-f371-461b-91d4-9f1cfd6721fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2460,'ef30f105-3afa-4100-ba95-7daf87909e6a','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:26',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-PreUpgradeRollingTasks-6znorrmehu6d','state changed','OS::Heat::Value',NULL,1475),(2461,'4478ad5d-f186-4e1a-b8b0-c4acd4cacd27','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:26',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ControllerServiceChain-yt3pkirjlivz-PuppetConfig-rweu5i7tsnxy','state changed','OS::Heat::Value',NULL,1481),(2462,'ee46180a-ff95-4633-88dc-88b756629c2d','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:26',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ScaleTasks-4cttlk7in7nw','state changed','OS::Heat::Value',NULL,1482),(2463,'1b2dea83-66b3-4f1b-b7ed-6b9f48287839','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:26',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ScaleTasks-4cttlk7in7nw','state changed','OS::Heat::Value',NULL,1482),(2464,'5ee3df97-70fa-4085-8992-ca41fbac9e3d','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:26',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ControllerServiceChain-yt3pkirjlivz-PuppetConfig-rweu5i7tsnxy','state changed','OS::Heat::Value',NULL,1481),(2465,'5f0d9bb0-5a42-4cfa-9abf-bb586f6d73e0','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:26',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','c97dd032-f371-461b-91d4-9f1cfd6721fd','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,1474),(2466,'100f8711-d740-4e61-a007-3c4adfe034d9','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:26',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ContainerPuppetTasks-2dr7qdfqssfo','state changed','OS::Heat::Value',NULL,1483),(2467,'c8ee763b-74f0-4334-8b8b-e3affba9e4d8','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:27',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ContainerPuppetTasks-2dr7qdfqssfo','state changed','OS::Heat::Value',NULL,1483),(2468,'1d743d4d-5a40-4e07-972a-913860439262','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:27',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceConfigSettings-nj4b557mjzvh','state changed','OS::Heat::Value',NULL,1484),(2469,'555b74aa-6581-47d4-b08f-09a681c021ee','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:27',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-PreDeployStepTasks-igh3sbhcf4mt','state changed','OS::Heat::Value',NULL,1485),(2470,'ad8396b4-b585-4192-8607-f9944b77027e','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:27',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-PreDeployStepTasks-igh3sbhcf4mt','state changed','OS::Heat::Value',NULL,1485),(2471,'c4a565f7-164b-4854-a9fa-748fa655c7f7','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:27',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-IpaRegistrationTasks-npepaiwn7vs3','state changed','OS::Heat::Value',NULL,1486),(2472,'e369c221-b3de-41c3-9cf6-f948cc9d1dae','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:27',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ControllerServiceChain-yt3pkirjlivz-ServiceConfigSettings-nj4b557mjzvh','state changed','OS::Heat::Value',NULL,1484),(2473,'3a78df90-b5ff-4eb0-8f51-739ad7fe2a1e','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:27',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-IpaRegistrationTasks-npepaiwn7vs3','state changed','OS::Heat::Value',NULL,1486),(2474,'8c3b8151-166c-4454-b876-d73cbbae639c','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:27',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ControllerServiceChain-yt3pkirjlivz-GlobalConfigSettings-b2apsmhh7rmh','state changed','OS::Heat::Value',NULL,1487),(2475,'adcdf426-d3a2-499a-84ef-50dc7df93a80','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:27',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ControllerServiceChain-yt3pkirjlivz-GlobalConfigSettings-b2apsmhh7rmh','state changed','OS::Heat::Value',NULL,1487),(2476,'c08dd3f6-7a3e-40eb-b161-8be24f301de2','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:28',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-PostUpdateTasks-z3sqvphmf6ze','state changed','OS::Heat::Value',NULL,1488),(2477,'a4fb366d-67c3-4d5e-862a-e0e8df426b9b','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:28',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-yt3pkirjlivz-KeystoneResourcesConfigs-7jvcnh35lwqz','state changed','OS::Heat::Value',NULL,1489),(2478,'ac041b25-46ec-4ab5-9d49-d2ad6fac7bce','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:28',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-yt3pkirjlivz-KeystoneResourcesConfigs-7jvcnh35lwqz','state changed','OS::Heat::Value',NULL,1489),(2479,'70e67a0e-ddf3-4a15-a867-e041b8bc849c','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:28',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-PostUpdateTasks-z3sqvphmf6ze','state changed','OS::Heat::Value',NULL,1488),(2480,'2a385083-4c33-4fa4-bda6-38ee01935906','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:28',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ExternalPostDeployTasks-jbxu64yzymgd','state changed','OS::Heat::Value',NULL,1491),(2481,'65a8afcf-c4f3-4c6e-8100-6873c9208644','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:28',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ControllerServiceChain-yt3pkirjlivz-ExternalPostDeployTasks-jbxu64yzymgd','state changed','OS::Heat::Value',NULL,1491),(2482,'0dd6fdf5-fe5a-4e34-a1bf-2b2714fb3898','c7d3c374-e753-4982-bfd2-6e25c8731be3','2026-06-13 07:58:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-yt3pkirjlivz','c7d3c374-e753-4982-bfd2-6e25c8731be3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2483,'87050be0-72b6-4990-9ac5-5902dd70af4b','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:28',NULL,'CREATE','COMPLETE','ControllerServiceChain','c7d3c374-e753-4982-bfd2-6e25c8731be3','state changed','OS::TripleO::ControllerServices',NULL,86),(2484,'33f35e0e-4c7e-4186-8d50-a374be174d62','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:29',NULL,'CREATE','IN_PROGRESS','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-g6ba6jthv5mn','state changed','OS::Heat::Value',NULL,1527),(2485,'5fb02b7d-1d14-461c-8d51-5dbe6ef7ecef','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:29',NULL,'CREATE','COMPLETE','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-g6ba6jthv5mn','state changed','OS::Heat::Value',NULL,1527),(2486,'f267162a-f8ca-448a-b09b-dedae5ef575d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-wkfwdz5pkgqr','state changed','OS::Heat::Value',NULL,1528),(2487,'97f61e17-db8c-41c3-8cb5-ca9fe751f0fc','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','COMPLETE','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-wkfwdz5pkgqr','state changed','OS::Heat::Value',NULL,1528),(2488,'3876be39-6c8f-4eaa-94af-9870b263f13d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-nnilqtqwtg4j','state changed','OS::Heat::Value',NULL,1529),(2489,'28005c63-9964-4405-976c-118e297a2949','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','COMPLETE','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-nnilqtqwtg4j','state changed','OS::Heat::Value',NULL,1529),(2490,'d3d4b998-1a9e-4490-9fbb-0bdc927742e3','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','IN_PROGRESS','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-y4soj2uhfna6','state changed','OS::Heat::Value',NULL,1533),(2491,'5ba973a8-56c8-4d98-b5a7-cb2ae9cc018c','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','IN_PROGRESS','BlockStorageConfigData','overcloud-BlockStorageConfigData-szhrapgdp4fv','state changed','OS::Heat::Value',NULL,1534),(2492,'b222ae22-8ace-4337-977a-c1a6dc7a9a8c','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','COMPLETE','BlockStorageConfigData','overcloud-BlockStorageConfigData-szhrapgdp4fv','state changed','OS::Heat::Value',NULL,1534),(2493,'89ad0717-4f16-4eea-9f5c-db251edaab52','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','COMPLETE','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-y4soj2uhfna6','state changed','OS::Heat::Value',NULL,1533),(2494,'5015d4f6-13dd-43ec-8067-69a7b3d7e16f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','IN_PROGRESS','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-fp7do7hhk6wm','state changed','OS::Heat::Value',NULL,1532),(2495,'ba6ecff8-5458-40e3-ab26-cfb6a45fcf81','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','COMPLETE','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-fp7do7hhk6wm','state changed','OS::Heat::Value',NULL,1532),(2496,'742049ac-bb40-49f3-ac59-3e48cb987711','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','IN_PROGRESS','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-ay3kukc3z45c','state changed','OS::Heat::Value',NULL,1536),(2497,'dbbf4d54-0ad3-4bed-b5ce-fc3bd8a552db','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','IN_PROGRESS','NetworkerConfigData','overcloud-NetworkerConfigData-3xrholpaluyb','state changed','OS::Heat::Value',NULL,1537),(2498,'487d6048-dad6-47f5-94dc-863b2b5fc97f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','COMPLETE','NetworkerConfigData','overcloud-NetworkerConfigData-3xrholpaluyb','state changed','OS::Heat::Value',NULL,1537),(2499,'8bfdb9d0-8dc5-4392-b0a5-3f11d296078a','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:30',NULL,'CREATE','COMPLETE','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-ay3kukc3z45c','state changed','OS::Heat::Value',NULL,1536),(2500,'e25cc136-b917-4a35-b11f-3c8430667531','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','IN_PROGRESS','CellControllerConfigData','overcloud-CellControllerConfigData-j5b27ebbdmnk','state changed','OS::Heat::Value',NULL,1539),(2501,'79d48658-b37b-4ce5-a766-f75c98c2c411','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','COMPLETE','CellControllerConfigData','overcloud-CellControllerConfigData-j5b27ebbdmnk','state changed','OS::Heat::Value',NULL,1539),(2502,'5996cf99-540a-414d-96e5-2f998f52f599','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-bybqz7as7g7u','state changed','OS::Heat::Value',NULL,1540),(2503,'337581e2-0882-4c26-81db-b170f9da33b6','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','IN_PROGRESS','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-ptmulwxdeero','state changed','OS::Heat::Value',NULL,1541),(2504,'2f2d99bc-a629-43c5-8a27-b402d4717993','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','COMPLETE','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-bybqz7as7g7u','state changed','OS::Heat::Value',NULL,1540),(2505,'7dcc8520-4da8-4b10-9b0a-db74dce4ed71','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','COMPLETE','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-ptmulwxdeero','state changed','OS::Heat::Value',NULL,1541),(2506,'8b4a4fa0-dd0b-4b49-a928-53bf9757da0c','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','IN_PROGRESS','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-knsworg4d7zi','state changed','OS::Heat::Value',NULL,1544),(2507,'0942aaed-603c-48c2-a7be-959eb88d94c7','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','COMPLETE','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-knsworg4d7zi','state changed','OS::Heat::Value',NULL,1544),(2508,'34e2913a-4847-4cba-ad18-3bbf4894c5b0','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-FirewallFrontendRules-uruquzudpa6k','state changed','OS::Heat::Value',NULL,1546),(2509,'aa6af6e7-e541-4b84-bb24-393332385e88','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-FirewallFrontendRules-uruquzudpa6k','state changed','OS::Heat::Value',NULL,1546),(2510,'a5b6eec9-f9f5-4594-8cdf-0e42a58d576b','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','IN_PROGRESS','CephStorageConfigData','overcloud-CephStorageConfigData-digf3ul2evrw','state changed','OS::Heat::Value',NULL,1545),(2511,'f0b5aaf3-0728-48d6-abb6-fe90b26b4cac','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','IN_PROGRESS','GlobalConfig','overcloud-GlobalConfig-2lvkwipy7rfs','state changed','OS::Heat::Value',NULL,1547),(2512,'ee2e3403-77c7-47de-b819-2277151243f6','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','COMPLETE','GlobalConfig','overcloud-GlobalConfig-2lvkwipy7rfs','state changed','OS::Heat::Value',NULL,1547),(2513,'2f1acb46-413c-4a25-a06b-8258cc2b5212','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','COMPLETE','CephStorageConfigData','overcloud-CephStorageConfigData-digf3ul2evrw','state changed','OS::Heat::Value',NULL,1545),(2514,'3d4e03a1-eeea-49bb-beb4-0136cf5f3dd2','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','IN_PROGRESS','CellControllerGroupVars','overcloud-CellControllerGroupVars-7iimkuaw3qv4','state changed','OS::Heat::Value',NULL,1548),(2515,'a24d1ebe-0ef1-4c06-be75-2da114cd2491','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:31',NULL,'CREATE','COMPLETE','CellControllerGroupVars','overcloud-CellControllerGroupVars-7iimkuaw3qv4','state changed','OS::Heat::Value',NULL,1548),(2516,'b9b95220-cb55-4ef6-9906-66e67a5d44c1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','IN_PROGRESS','CephStorageGroupVars','overcloud-CephStorageGroupVars-v62xrjss6g5j','state changed','OS::Heat::Value',NULL,1549),(2517,'d9187d5d-629e-434c-a54b-8cb22b44fa50','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','IN_PROGRESS','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-w7o6mtclo5ms','state changed','OS::Heat::Value',NULL,1550),(2518,'262d706f-1746-4dfd-8eb4-fd428febb9cf','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','COMPLETE','CephStorageGroupVars','overcloud-CephStorageGroupVars-v62xrjss6g5j','state changed','OS::Heat::Value',NULL,1549),(2519,'69752e13-576a-4889-993d-1409bdfaa8dd','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','COMPLETE','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-w7o6mtclo5ms','state changed','OS::Heat::Value',NULL,1550),(2520,'5b185116-b521-44ae-9369-19650f5bcffc','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','IN_PROGRESS','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-frw7roha7dqo','state changed','OS::Heat::Value',NULL,1551),(2521,'28944ba6-abbe-4c28-a2ef-8c233039b230','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','COMPLETE','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-frw7roha7dqo','state changed','OS::Heat::Value',NULL,1551),(2522,'17264353-a2ab-47d2-a287-347a7ac8980b','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','IN_PROGRESS','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-laoq5id2swg4','state changed','OS::Heat::Value',NULL,1553),(2523,'6253a1e1-6b89-4661-875a-45f4871815c5','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','COMPLETE','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-laoq5id2swg4','state changed','OS::Heat::Value',NULL,1553),(2524,'1afe1ff8-b5a9-40ac-94c8-528837890194','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','IN_PROGRESS','NetworkerGroupVars','overcloud-NetworkerGroupVars-6a32klf4yo6f','state changed','OS::Heat::Value',NULL,1555),(2525,'638d4353-e9de-4dcd-a353-19e0fff97e24','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','COMPLETE','NetworkerGroupVars','overcloud-NetworkerGroupVars-6a32klf4yo6f','state changed','OS::Heat::Value',NULL,1555),(2526,'9f7f987d-bac5-4e36-8c73-e2b02a04d870','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','IN_PROGRESS','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-tozclk3f4ery','state changed','OS::Heat::Value',NULL,1557),(2527,'c2c7ae38-e73b-422c-b5d2-b8aef9f747ec','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','IN_PROGRESS','ControllerGroupVars','overcloud-ControllerGroupVars-upu5r32hnf2t','state changed','OS::Heat::Value',NULL,1552),(2528,'ba3827aa-e435-47b8-83f0-221ab65f144e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','COMPLETE','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-tozclk3f4ery','state changed','OS::Heat::Value',NULL,1557),(2529,'8207c6b4-8600-4334-94f9-e7a029f87fa5','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','IN_PROGRESS','ComputeGroupVars','overcloud-ComputeGroupVars-rllqmwceqbjt','state changed','OS::Heat::Value',NULL,1558),(2530,'e76660f1-53c0-47f1-8988-57410149c614','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','IN_PROGRESS','ControllerServiceNames','overcloud-ControllerServiceNames-dk733amhgtpu','state changed','OS::Heat::Value',NULL,1560),(2531,'6a36a8c3-9eba-4686-a45b-9b16704fa86c','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','COMPLETE','ControllerServiceNames','overcloud-ControllerServiceNames-dk733amhgtpu','state changed','OS::Heat::Value',NULL,1560),(2532,'7bb28bc1-b5d6-4a37-8b2e-779138ccc2cd','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','COMPLETE','ControllerGroupVars','overcloud-ControllerGroupVars-upu5r32hnf2t','state changed','OS::Heat::Value',NULL,1552),(2533,'53eca111-7493-4132-903a-23f65f14915a','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','IN_PROGRESS','ComputeConfigData','overcloud-ComputeConfigData-qj45ro3t4mjz','state changed','OS::Heat::Value',NULL,1561),(2534,'cebcbca7-46cb-438d-82b8-bf32189cdefa','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','COMPLETE','ComputeGroupVars','overcloud-ComputeGroupVars-rllqmwceqbjt','state changed','OS::Heat::Value',NULL,1558),(2535,'e0db9fed-206a-4921-abe7-44c8614a23c7','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:32',NULL,'CREATE','COMPLETE','ComputeConfigData','overcloud-ComputeConfigData-qj45ro3t4mjz','state changed','OS::Heat::Value',NULL,1561),(2536,'c06a0cdc-e95d-404f-ade5-ca76c34552c9','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:33',NULL,'CREATE','IN_PROGRESS','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-euwijhxsvspr','state changed','OS::Heat::Value',NULL,1562),(2537,'e226cfda-1121-4624-9f3e-67be09af4967','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:33',NULL,'CREATE','COMPLETE','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-euwijhxsvspr','state changed','OS::Heat::Value',NULL,1562),(2538,'39b88e8c-7d38-4253-812c-eff0b488dad1','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:33',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-yvnz6bxzdr3g','state changed','OS::Heat::ResourceGroup',NULL,1563),(2539,'6c256e51-242c-499c-8570-9825b80d70bc','8f6fff5b-c280-4668-bb95-713977c9a910','2026-06-13 07:58:33',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g','8f6fff5b-c280-4668-bb95-713977c9a910','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2540,'b373a21b-2d0c-4fb1-95c2-8de6dbddc8d3','8f6fff5b-c280-4668-bb95-713977c9a910','2026-06-13 07:58:33',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g','8f6fff5b-c280-4668-bb95-713977c9a910','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2541,'66f8f417-657e-474c-a5fb-0f7caf434abb','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:33',NULL,'CREATE','IN_PROGRESS','ControllerConfigData','overcloud-ControllerConfigData-vjmopewp2wbn','state changed','OS::Heat::Value',NULL,1566),(2542,'deaf52c8-cbda-4b5e-9543-9df9a1519566','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:33',NULL,'CREATE','COMPLETE','ControllerConfigData','overcloud-ControllerConfigData-vjmopewp2wbn','state changed','OS::Heat::Value',NULL,1566),(2543,'2b6beacf-9096-416c-8752-bdc2b7c6c228','8f6fff5b-c280-4668-bb95-713977c9a910','2026-06-13 07:58:34',NULL,'UPDATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g','8f6fff5b-c280-4668-bb95-713977c9a910','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(2544,'66d187d8-9e4f-4547-9c73-e29e8fcfce59','8f6fff5b-c280-4668-bb95-713977c9a910','2026-06-13 07:58:34',NULL,'CREATE','IN_PROGRESS','0','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa','state changed','OS::TripleO::Controller',NULL,1567),(2545,'8f85cbc2-0f1c-4791-8a0c-a6fc50cd8168','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:34',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa','496ede04-262a-4214-9a84-89e87bda6ef7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2546,'f8d17f60-58e3-45cf-a465-27464b8b3319','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:35',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-DeploymentActions-mhvsvg2uu2ro','state changed','OS::Heat::Value',NULL,1568),(2547,'60d7566f-30f9-4c65-9c4a-b1aae12d3c9d','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:35',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-DeploymentActions-mhvsvg2uu2ro','state changed','OS::Heat::Value',NULL,1568),(2548,'26ad1ee0-1e6b-4d7e-a682-48fd0371b393','8f6fff5b-c280-4668-bb95-713977c9a910','2026-06-13 07:58:35',NULL,'CREATE','IN_PROGRESS','2','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw','state changed','OS::TripleO::Controller',NULL,1570),(2549,'86e08eda-d678-4e2a-888a-f0b002829bcf','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:35',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw','25142736-f3a8-45c9-9625-b42c209caae7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2550,'74931ed2-33e6-410c-bed3-e188afc6c8d7','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:36',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-DeploymentActions-wfi5ni4wpu5u','state changed','OS::Heat::Value',NULL,1571),(2551,'88b0697d-855f-4b01-8a63-cbabcd1cc7eb','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:36',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-DeploymentActions-wfi5ni4wpu5u','state changed','OS::Heat::Value',NULL,1571),(2552,'9bbb3947-8271-42f1-84e2-7d47e5579592','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:36',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-Controller-2h447wbpnje6','state changed','OS::TripleO::ControllerServer',NULL,1572),(2553,'3f22f8be-ffc5-4cb3-a459-2b869096f82b','46e418cc-792e-4caa-a183-b5576d1cfefe','2026-06-13 07:58:36',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-Controller-2h447wbpnje6','46e418cc-792e-4caa-a183-b5576d1cfefe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2554,'744ccc5b-055b-4f43-aabd-62c2ce924fb3','46e418cc-792e-4caa-a183-b5576d1cfefe','2026-06-13 07:58:36',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-Controller-2h447wbpnje6-ControlPlanePort-7iq6qwgo6pl7','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1574),(2555,'c9553f38-af24-4751-b1ff-d92d1d1d5655','290e04b5-88ff-4049-a226-dab7f07ea488','2026-06-13 07:58:36',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-Controller-2h447wbpnje6-ControlPlanePort-7iq6qwgo6pl7','290e04b5-88ff-4049-a226-dab7f07ea488','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2556,'5fe11b83-813c-4017-929d-a3ce002f02b9','290e04b5-88ff-4049-a226-dab7f07ea488','2026-06-13 07:58:36',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-Controller-2h447wbpnje6-ControlPlanePort-7iq6qwgo6pl7','290e04b5-88ff-4049-a226-dab7f07ea488','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2557,'9e758506-cf2e-45ee-bd52-8aa3a4aa3519','8f6fff5b-c280-4668-bb95-713977c9a910','2026-06-13 07:58:36',NULL,'CREATE','IN_PROGRESS','1','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd','state changed','OS::TripleO::Controller',NULL,1575),(2558,'852fdd80-7965-4ea1-b1ee-1947e82c4d6b','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:36',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd','68d593b7-c5ba-4944-9c60-248c0436d714','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2559,'b3bd1b29-3eb0-4356-83f6-08028aea5101','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:37',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-Controller-gzna7j43ttps','state changed','OS::TripleO::ControllerServer',NULL,1576),(2560,'fb8721ad-f406-45f7-a1c6-d9bdb8fac133','ac5cdab9-7d81-4f01-acff-b0afab2738f7','2026-06-13 07:58:37',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-Controller-gzna7j43ttps','ac5cdab9-7d81-4f01-acff-b0afab2738f7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2561,'eb6c6b56-fa02-44aa-8141-b8b0337453f7','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:37',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-DeploymentActions-gc5adrllzztb','state changed','OS::Heat::Value',NULL,1577),(2562,'f14f06b5-7708-4075-86ca-130bce07f874','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:37',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-DeploymentActions-gc5adrllzztb','state changed','OS::Heat::Value',NULL,1577),(2563,'773a4b9a-3929-46e5-bcdf-6fd1f92714a4','ac5cdab9-7d81-4f01-acff-b0afab2738f7','2026-06-13 07:58:37',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-Controller-gzna7j43ttps-ControlPlanePort-amaffwrskysj','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1579),(2564,'06e516d1-c3bc-4e16-983f-c5e03b2dd1a7','46e418cc-792e-4caa-a183-b5576d1cfefe','2026-06-13 07:58:37',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-2h447wbpnje6-deployed-server-vfuqsmlbtqmt','state changed','OS::Heat::DeployedServer',NULL,1580),(2565,'25d5eed9-3b66-41c6-9225-dcd8f49e436e','ccce7b1b-b8aa-4a23-8554-38299a8c7e07','2026-06-13 07:58:37',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-Controller-gzna7j43ttps-ControlPlanePort-amaffwrskysj','ccce7b1b-b8aa-4a23-8554-38299a8c7e07','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2566,'31910912-e598-4f65-8490-667362cd795b','ccce7b1b-b8aa-4a23-8554-38299a8c7e07','2026-06-13 07:58:37',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-Controller-gzna7j43ttps-ControlPlanePort-amaffwrskysj','ccce7b1b-b8aa-4a23-8554-38299a8c7e07','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2567,'99a08b58-37af-4694-a705-b96ce14540b0','46e418cc-792e-4caa-a183-b5576d1cfefe','2026-06-13 07:58:37',NULL,'CREATE','COMPLETE','deployed-server','1619c193-9093-4a96-a157-1c0f7b5b9297','state changed','OS::Heat::DeployedServer',NULL,1580),(2568,'41314b6a-8f0b-4dd8-bfb2-674c5e3fdc65','46e418cc-792e-4caa-a183-b5576d1cfefe','2026-06-13 07:58:37',NULL,'CREATE','COMPLETE','ControlPlanePort','290e04b5-88ff-4049-a226-dab7f07ea488','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1574),(2569,'63205542-de81-4baa-9037-f80b4ad3e11a','46e418cc-792e-4caa-a183-b5576d1cfefe','2026-06-13 07:58:37',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-Controller-2h447wbpnje6','46e418cc-792e-4caa-a183-b5576d1cfefe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2570,'ba81c768-7045-440a-992d-b61e7cb33c98','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-Controller-rd5k6vuzi7s4','state changed','OS::TripleO::ControllerServer',NULL,1581),(2571,'0b07a80c-0f9f-41cf-9132-73bc217d9fa1','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','Controller','46e418cc-792e-4caa-a183-b5576d1cfefe','state changed','OS::TripleO::ControllerServer',NULL,1572),(2572,'ebb5f264-e1f2-41a8-b339-9218da9bc2bb','e9d8db0d-5ceb-412f-946f-0e6fe34509ea','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-Controller-rd5k6vuzi7s4','e9d8db0d-5ceb-412f-946f-0e6fe34509ea','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2573,'506de2c9-47df-4edb-9820-49dbbeba6f39','ac5cdab9-7d81-4f01-acff-b0afab2738f7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-gzna7j43ttps-deployed-server-bepog5y7sryn','state changed','OS::Heat::DeployedServer',NULL,1582),(2574,'05b66272-c301-463c-a701-0c753bf6d232','ac5cdab9-7d81-4f01-acff-b0afab2738f7','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','ControlPlanePort','ccce7b1b-b8aa-4a23-8554-38299a8c7e07','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1579),(2575,'a78bacb3-7063-4edd-8afc-93839881915f','ac5cdab9-7d81-4f01-acff-b0afab2738f7','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','deployed-server','71f9470d-ee37-4091-9042-f805b2171718','state changed','OS::Heat::DeployedServer',NULL,1582),(2576,'9fc6a324-f24c-4475-9044-c40379ae27a8','e9d8db0d-5ceb-412f-946f-0e6fe34509ea','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-rd5k6vuzi7s4-deployed-server-tizbnyax3whu','state changed','OS::Heat::DeployedServer',NULL,1584),(2577,'b06d094a-c8e7-4fdb-9241-1e242f57ebef','ac5cdab9-7d81-4f01-acff-b0afab2738f7','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-Controller-gzna7j43ttps','ac5cdab9-7d81-4f01-acff-b0afab2738f7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2578,'e7b7b2ea-058e-4b8b-86f3-741fad96fc16','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-PreNetworkConfig-cjznk632zfjp','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2579,'1e7dde2d-3228-492d-ab76-2fd7491b2cc8','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NetHostMap-rlhcvsghoiaz','state changed','OS::Heat::Value',NULL,1586),(2580,'541b842c-85b5-4fb1-bff6-7dc179dc9e30','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-ControllerExtraConfigPre-iyj3rrm3lc3s','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1585),(2581,'cc47f6e1-a478-479f-b4a3-0e9d219e0a2a','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','PreNetworkConfig','0bee2f16-fc7c-4e5a-9abd-af9e7562acae','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2582,'7fdc2b09-51e1-4085-82ee-3341e84cdcb3','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-TenantPort-tk46rhdcj6j7','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1587),(2583,'9f4233cc-1306-4a53-9cde-61cdcd137f4c','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NodeTLSCAData-5u6hdhj4gdo3','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2584,'ce08110a-a9ac-4b1c-add1-26489bc49adb','e9d8db0d-5ceb-412f-946f-0e6fe34509ea','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','deployed-server','017dd8f4-216e-49a3-9d4a-c6df1b715b59','state changed','OS::Heat::DeployedServer',NULL,1584),(2585,'7d62f414-227b-4206-b168-71d291fc504f','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','NodeTLSCAData','b867b923-c56b-4e6d-9359-18c076cedf63','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2586,'20bbfe82-8d10-4ca1-b7aa-d8554555dab7','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NetHostMap-rlhcvsghoiaz','state changed','OS::Heat::Value',NULL,1586),(2587,'0662f4d1-c479-4d17-a3f5-1d71ed811224','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-ExternalPort-ybni2ajwclvw','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1589),(2588,'df411ce0-2986-4099-ae1a-d59fecf3f224','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-StorageMgmtPort-76zi4pqi7j67','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1588),(2589,'7f43cad6-be7c-4a7c-aab2-4f248b92dcb8','93d7e1af-b459-472a-9995-598b0537a9dd','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-ControllerExtraConfigPre-iyj3rrm3lc3s','93d7e1af-b459-472a-9995-598b0537a9dd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2590,'9ea74fae-d534-4984-869a-a2d922898915','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-InternalApiPort-ah75cru2jvdq','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1591),(2591,'0d44f52c-4158-4831-bce3-2bf21510c24d','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-StoragePort-qwn2q3juswe4','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1592),(2592,'7ea9ef8b-d4b5-4895-8d50-738ef9dc8f6f','b2a48dfb-a82b-4263-a427-435eb95e47c1','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-TenantPort-tk46rhdcj6j7','b2a48dfb-a82b-4263-a427-435eb95e47c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2593,'35dfb004-6628-40cd-9eae-82ffe0d34946','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-ControllerAnsibleHostVars-5q3lx6rzvcof','state changed','OS::Heat::Value',NULL,1594),(2594,'4ebab225-245c-4c9c-85db-e85939083f68','dd1b2bbe-3eb1-43fd-87a5-c883439ea011','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-ExternalPort-ybni2ajwclvw','dd1b2bbe-3eb1-43fd-87a5-c883439ea011','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2595,'b77ec98a-4959-4f9e-95ec-0284707c0149','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-ControllerAnsibleHostVars-5q3lx6rzvcof','state changed','OS::Heat::Value',NULL,1594),(2596,'ddf4fdca-587e-4b41-a057-0ee321916c3f','93d7e1af-b459-472a-9995-598b0537a9dd','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-ControllerExtraConfigPre-iyj3rrm3lc3s','93d7e1af-b459-472a-9995-598b0537a9dd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2597,'05ef1654-2f64-4d30-bc68-868a7240785d','4767567f-9ae6-47bc-b3e7-885401861efb','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-StorageMgmtPort-76zi4pqi7j67','4767567f-9ae6-47bc-b3e7-885401861efb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2598,'857314e0-8f03-4e12-80b8-88c6a67494a2','37d80bce-efc7-427a-8800-9537620d7538','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-InternalApiPort-ah75cru2jvdq','37d80bce-efc7-427a-8800-9537620d7538','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2599,'b10b5ed2-5d9f-4a15-aa58-a21b4e97bcd0','493ff183-ae29-4d4e-a983-66fc2b23b499','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-StoragePort-qwn2q3juswe4','493ff183-ae29-4d4e-a983-66fc2b23b499','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2600,'c9557c66-333e-41f9-b81e-3ec0843abdb4','b2a48dfb-a82b-4263-a427-435eb95e47c1','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-TenantPort-tk46rhdcj6j7-TenantDeployedPort-os4alzl4qso4','state changed','OS::Heat::Value',NULL,1595),(2601,'3898a8c5-5fc6-4bf1-bebb-4e1961d36fa1','b2a48dfb-a82b-4263-a427-435eb95e47c1','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-TenantPort-tk46rhdcj6j7-TenantDeployedPort-os4alzl4qso4','state changed','OS::Heat::Value',NULL,1595),(2602,'6ade901c-8b7c-45ce-abda-cc72ae083fd5','37d80bce-efc7-427a-8800-9537620d7538','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-InternalApiPort-ah75cru2jvdq-InternalApiDeployedPort-32uw25sisnfx','state changed','OS::Heat::Value',NULL,1596),(2603,'778b5ea7-aa32-4aa3-af75-929318599359','4767567f-9ae6-47bc-b3e7-885401861efb','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-StorageMgmtPort-76zi4pqi7j67-StorageMgmtDeployedPort-7m6twlog7mlv','state changed','OS::Heat::Value',NULL,1597),(2604,'511e9ad1-41e0-474e-8092-c951ae7d4da8','37d80bce-efc7-427a-8800-9537620d7538','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-InternalApiPort-ah75cru2jvdq-InternalApiDeployedPort-32uw25sisnfx','state changed','OS::Heat::Value',NULL,1596),(2605,'490ec21d-756f-43f0-996c-ccd6a36caedc','493ff183-ae29-4d4e-a983-66fc2b23b499','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-StoragePort-qwn2q3juswe4-StorageDeployedPort-li57acgaleyy','state changed','OS::Heat::Value',NULL,1598),(2606,'d677f214-bf21-4632-9ef8-a527a8b2b136','b2a48dfb-a82b-4263-a427-435eb95e47c1','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-TenantPort-tk46rhdcj6j7','b2a48dfb-a82b-4263-a427-435eb95e47c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2607,'36397d93-3567-4858-914e-a4d4780139a9','dd1b2bbe-3eb1-43fd-87a5-c883439ea011','2026-06-13 07:58:38',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-ExternalPort-ybni2ajwclvw-ExternalDeployedPort-5srwueaottvs','state changed','OS::Heat::Value',NULL,1599),(2608,'347ee10b-8e14-4f5a-a041-be3e3d8c4607','4767567f-9ae6-47bc-b3e7-885401861efb','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-StorageMgmtPort-76zi4pqi7j67-StorageMgmtDeployedPort-7m6twlog7mlv','state changed','OS::Heat::Value',NULL,1597),(2609,'25526a7d-a36c-4882-a064-63701e40b543','37d80bce-efc7-427a-8800-9537620d7538','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-InternalApiPort-ah75cru2jvdq','37d80bce-efc7-427a-8800-9537620d7538','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2610,'317f2eae-7e29-4485-a108-cb8b66139512','493ff183-ae29-4d4e-a983-66fc2b23b499','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-StoragePort-qwn2q3juswe4-StorageDeployedPort-li57acgaleyy','state changed','OS::Heat::Value',NULL,1598),(2611,'7ff3a1b8-e63e-4d7b-8473-a5f36ac0e8df','4767567f-9ae6-47bc-b3e7-885401861efb','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-StorageMgmtPort-76zi4pqi7j67','4767567f-9ae6-47bc-b3e7-885401861efb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2612,'5b3bcb1e-0463-4e9d-90ce-91454d9cfb2c','493ff183-ae29-4d4e-a983-66fc2b23b499','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-StoragePort-qwn2q3juswe4','493ff183-ae29-4d4e-a983-66fc2b23b499','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2613,'adb1cec2-741b-4e22-bf7c-3f6ce88dfef8','dd1b2bbe-3eb1-43fd-87a5-c883439ea011','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-ExternalPort-ybni2ajwclvw-ExternalDeployedPort-5srwueaottvs','state changed','OS::Heat::Value',NULL,1599),(2614,'b459f69c-b1bd-4f41-b257-5c61fdb01160','dd1b2bbe-3eb1-43fd-87a5-c883439ea011','2026-06-13 07:58:38',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-ExternalPort-ybni2ajwclvw','dd1b2bbe-3eb1-43fd-87a5-c883439ea011','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2615,'fd7972da-2014-4d75-85ff-9206e580f92c','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','Controller','ac5cdab9-7d81-4f01-acff-b0afab2738f7','state changed','OS::TripleO::ControllerServer',NULL,1576),(2616,'6056824d-9f5a-4221-89b5-b4b44e240f9c','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-ControllerExtraConfigPre-upcbdmzpxdh6','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1601),(2617,'249f4fec-a1aa-4b4f-a746-3d68804a153e','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-TenantPort-g444xszn4l5j','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1602),(2618,'b2eb9cc0-4d84-481b-832f-e068c64bfcdd','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-ExternalPort-ecj5gmejb3p4','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1603),(2619,'006113c9-e045-44f1-bd47-1a0febc009dd','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-StoragePort-sffyeuaeqa45','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1605),(2620,'54ce7d40-7d44-4b5a-b242-9f0d9f09ad23','e9d8db0d-5ceb-412f-946f-0e6fe34509ea','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-Controller-rd5k6vuzi7s4-ControlPlanePort-vihqhu4k7ui6','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1604),(2621,'12b65287-a419-4d38-9add-57c860b83184','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-StorageMgmtPort-ywsfzrnamebx','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1606),(2622,'91251fbc-928c-4b7f-9a81-14f0b5a76c6b','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NetHostMap-fknxj2bkaexr','state changed','OS::Heat::Value',NULL,1607),(2623,'4e212157-ebe1-45ea-9922-8b45c515a068','dd342ebe-a283-480b-bba5-f02ea2d8c104','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-ExternalPort-ecj5gmejb3p4','dd342ebe-a283-480b-bba5-f02ea2d8c104','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2624,'3f832dfb-bf09-42a4-b40b-3e84136d49c8','363e7b2f-4012-429b-b918-9437a3bcd65d','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-ControllerExtraConfigPre-upcbdmzpxdh6','363e7b2f-4012-429b-b918-9437a3bcd65d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2625,'0ab15ae9-f682-4707-8784-882c614d8d96','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NetHostMap-fknxj2bkaexr','state changed','OS::Heat::Value',NULL,1607),(2626,'5015e05b-a69e-416e-b8a1-fc91eabbcbbd','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-InternalApiPort-hrllw2z6r46w','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1608),(2627,'e3feba42-2d69-4490-ab46-4c648deded3b','db6e3f19-340b-4d3e-9dcb-cdcef17c9a62','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-Controller-rd5k6vuzi7s4-ControlPlanePort-vihqhu4k7ui6','db6e3f19-340b-4d3e-9dcb-cdcef17c9a62','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2628,'9541fa73-595b-4dc9-8ce8-163f8840075e','363e7b2f-4012-429b-b918-9437a3bcd65d','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-ControllerExtraConfigPre-upcbdmzpxdh6','363e7b2f-4012-429b-b918-9437a3bcd65d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2629,'0d278a34-96fc-4858-a1cb-d9c7360fb7c3','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NodeTLSCAData-qlauukoogrx4','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2630,'9ebe09e0-5a65-42ac-abd1-eabf2ee5acc3','6189cdcb-2714-4503-94da-e59e59ff0f7b','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-StoragePort-sffyeuaeqa45','6189cdcb-2714-4503-94da-e59e59ff0f7b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2631,'21228322-a135-43ac-8886-9468b2b0b17b','db6e3f19-340b-4d3e-9dcb-cdcef17c9a62','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-Controller-rd5k6vuzi7s4-ControlPlanePort-vihqhu4k7ui6','db6e3f19-340b-4d3e-9dcb-cdcef17c9a62','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2632,'a361eaef-c419-41d8-aacc-e71f8b419a95','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-ControllerAnsibleHostVars-jgt65o7sihwj','state changed','OS::Heat::Value',NULL,1611),(2633,'cf717c9b-abcd-4330-b295-250379a6780c','7d20abd7-0c77-4c6c-91a1-5c5c48cab63b','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-InternalApiPort-hrllw2z6r46w','7d20abd7-0c77-4c6c-91a1-5c5c48cab63b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2634,'ad8b816a-e30b-472e-8857-4a4a8f734be5','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','NodeTLSCAData','52834203-2f39-488f-9d68-cbb0f7937dfa','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2635,'49733751-0697-4d69-9ed9-bc3d67d74f6c','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-ControllerAnsibleHostVars-jgt65o7sihwj','state changed','OS::Heat::Value',NULL,1611),(2636,'96da0293-1717-47df-b6a3-3a3b43632193','ab960084-c337-4691-acad-c4da5bdae3dd','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-TenantPort-g444xszn4l5j','ab960084-c337-4691-acad-c4da5bdae3dd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2637,'ca21ff08-4ab3-436c-a54f-df607d01ac72','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','363e7b2f-4012-429b-b918-9437a3bcd65d','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1601),(2638,'55d65ac0-4136-487a-8389-114f6308fa32','dd342ebe-a283-480b-bba5-f02ea2d8c104','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-ExternalPort-ecj5gmejb3p4-ExternalDeployedPort-j4jfvpbattab','state changed','OS::Heat::Value',NULL,1612),(2639,'fd4c177e-dc90-47ca-8c6c-0366f2a65592','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','93d7e1af-b459-472a-9995-598b0537a9dd','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1585),(2640,'1d9d0f18-1239-4361-8cb3-baabfb657358','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-PreNetworkConfig-45er3vyci4fb','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2641,'b634e58c-0d74-46b8-9c0b-3d3b09498810','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','TenantPort','b2a48dfb-a82b-4263-a427-435eb95e47c1','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1587),(2642,'c482450e-fd18-442f-8dd6-9ce68c76d77e','dd342ebe-a283-480b-bba5-f02ea2d8c104','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-ExternalPort-ecj5gmejb3p4-ExternalDeployedPort-j4jfvpbattab','state changed','OS::Heat::Value',NULL,1612),(2643,'19712a8e-2b44-41ec-90dd-4c01ba202880','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','ExternalPort','dd1b2bbe-3eb1-43fd-87a5-c883439ea011','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1589),(2644,'98663d9d-d5a5-4b20-a033-14b4755d442f','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','StorageMgmtPort','4767567f-9ae6-47bc-b3e7-885401861efb','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1588),(2645,'042a4b6d-1c6c-457e-898b-f521c854f07b','dd342ebe-a283-480b-bba5-f02ea2d8c104','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-ExternalPort-ecj5gmejb3p4','dd342ebe-a283-480b-bba5-f02ea2d8c104','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2646,'719055b3-4b3f-4ff0-af46-d36bae228676','f7165cc4-f07b-4dfe-81ea-bee4f5d85fad','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-StorageMgmtPort-ywsfzrnamebx','f7165cc4-f07b-4dfe-81ea-bee4f5d85fad','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2647,'4fe9d951-bffc-4251-9c0f-f22034f3a30e','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','StoragePort','493ff183-ae29-4d4e-a983-66fc2b23b499','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1592),(2648,'ce35097f-807a-4bfd-ad60-f206f857681d','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','InternalApiPort','37d80bce-efc7-427a-8800-9537620d7538','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1591),(2649,'caa368f1-eac2-4cd9-8de8-1faf2a1d1980','7d20abd7-0c77-4c6c-91a1-5c5c48cab63b','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-InternalApiPort-hrllw2z6r46w-InternalApiDeployedPort-azq2y4yw2loj','state changed','OS::Heat::Value',NULL,1617),(2650,'1864ad67-8498-4c2e-9a0e-7630f5a69e69','6189cdcb-2714-4503-94da-e59e59ff0f7b','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-StoragePort-sffyeuaeqa45-StorageDeployedPort-j5lidpazjxip','state changed','OS::Heat::Value',NULL,1618),(2651,'685ba03f-a41c-4f7a-a08b-b5dccea3c2ba','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NodeExtraConfig-feyibudm6wcy','state changed','OS::TripleO::NodeExtraConfig',NULL,1619),(2652,'ee1c9ce7-dd48-4779-86a1-1845c4872d2c','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','PreNetworkConfig','f3393c71-5040-4193-8b8f-78f252babf01','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2653,'e797be29-5e27-4ea9-aa55-28da3dd344bc','6189cdcb-2714-4503-94da-e59e59ff0f7b','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-StoragePort-sffyeuaeqa45-StorageDeployedPort-j5lidpazjxip','state changed','OS::Heat::Value',NULL,1618),(2654,'c5e29416-3d4e-4e56-b25a-309422e1c630','7d20abd7-0c77-4c6c-91a1-5c5c48cab63b','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-InternalApiPort-hrllw2z6r46w-InternalApiDeployedPort-azq2y4yw2loj','state changed','OS::Heat::Value',NULL,1617),(2655,'c2a5728c-155b-41c1-b0a5-2edff1a59e6a','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NodeExtraConfig-fgfjcox3c54z','state changed','OS::TripleO::NodeExtraConfig',NULL,1620),(2656,'aa676f0d-7d00-45c5-a92b-343b7d2670ce','7d20abd7-0c77-4c6c-91a1-5c5c48cab63b','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-InternalApiPort-hrllw2z6r46w','7d20abd7-0c77-4c6c-91a1-5c5c48cab63b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2657,'cc7a779c-88d5-435e-bf01-bbeb0ab5ba78','6189cdcb-2714-4503-94da-e59e59ff0f7b','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-StoragePort-sffyeuaeqa45','6189cdcb-2714-4503-94da-e59e59ff0f7b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2658,'89aea905-ad4f-4c14-b19f-b690e44af4b7','79195776-5b5a-4c36-92e4-6b227044b6a5','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NodeExtraConfig-feyibudm6wcy','79195776-5b5a-4c36-92e4-6b227044b6a5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2659,'67e77471-08ba-4b91-b240-4d8958adcb9a','79195776-5b5a-4c36-92e4-6b227044b6a5','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NodeExtraConfig-feyibudm6wcy','79195776-5b5a-4c36-92e4-6b227044b6a5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2660,'74843b43-80b9-415e-a345-c61a6e2c4d7c','ab960084-c337-4691-acad-c4da5bdae3dd','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-TenantPort-g444xszn4l5j-TenantDeployedPort-tiixtipup2ix','state changed','OS::Heat::Value',NULL,1628),(2661,'715c22db-56bb-4526-8c97-65a27ad6cbe3','8da78ce4-2115-43b2-8eee-7daa4a601e91','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NodeExtraConfig-fgfjcox3c54z','8da78ce4-2115-43b2-8eee-7daa4a601e91','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2662,'c74c313b-e6b5-4324-9303-1be3b19f3bbe','ab960084-c337-4691-acad-c4da5bdae3dd','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-TenantPort-g444xszn4l5j-TenantDeployedPort-tiixtipup2ix','state changed','OS::Heat::Value',NULL,1628),(2663,'bc39659f-5805-4b45-a4ec-e289af734a23','f7165cc4-f07b-4dfe-81ea-bee4f5d85fad','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-StorageMgmtPort-ywsfzrnamebx-StorageMgmtDeployedPort-vlbrszngc6lz','state changed','OS::Heat::Value',NULL,1630),(2664,'d3e9dcf4-833a-4594-85c1-947d881505f4','f7165cc4-f07b-4dfe-81ea-bee4f5d85fad','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-StorageMgmtPort-ywsfzrnamebx-StorageMgmtDeployedPort-vlbrszngc6lz','state changed','OS::Heat::Value',NULL,1630),(2665,'6ab3f78a-db55-4b3c-86e2-e617c89ad34f','ab960084-c337-4691-acad-c4da5bdae3dd','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-TenantPort-g444xszn4l5j','ab960084-c337-4691-acad-c4da5bdae3dd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2666,'34d1819d-2840-494a-b06c-353cd70051cf','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NetIpMap-6omsbtoifoa2','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1631),(2667,'40c5246c-fa58-4a60-9a9f-7ecc6257f5c3','f7165cc4-f07b-4dfe-81ea-bee4f5d85fad','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-StorageMgmtPort-ywsfzrnamebx','f7165cc4-f07b-4dfe-81ea-bee4f5d85fad','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2668,'55074e39-0178-4039-9336-61f059e7d5c6','8da78ce4-2115-43b2-8eee-7daa4a601e91','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NodeExtraConfig-fgfjcox3c54z','8da78ce4-2115-43b2-8eee-7daa4a601e91','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2669,'7cebc5aa-e733-4ecf-bf98-0b31c15b7a7e','20c87a22-0e46-44d2-99a3-9e8585dae408','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NetIpMap-6omsbtoifoa2','20c87a22-0e46-44d2-99a3-9e8585dae408','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2670,'eff3ef25-7234-4d12-9c48-d556d6fc6cac','20c87a22-0e46-44d2-99a3-9e8585dae408','2026-06-13 07:58:39',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NetIpMap-6omsbtoifoa2-NetIpMapValue-5bnnrr2dqqy4','state changed','OS::Heat::Value',NULL,1632),(2671,'ab4e365c-a21d-4cc5-8171-af2b7a4eb5d9','20c87a22-0e46-44d2-99a3-9e8585dae408','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NetIpMap-6omsbtoifoa2-NetIpMapValue-5bnnrr2dqqy4','state changed','OS::Heat::Value',NULL,1632),(2672,'a604b0fa-03c0-4b4d-b32f-2950922b273e','20c87a22-0e46-44d2-99a3-9e8585dae408','2026-06-13 07:58:39',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa-NetIpMap-6omsbtoifoa2','20c87a22-0e46-44d2-99a3-9e8585dae408','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2673,'6b95a8cf-ac4a-4fa9-a7aa-0425dddc7b5e','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','ExternalPort','dd342ebe-a283-480b-bba5-f02ea2d8c104','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1603),(2674,'86b52363-fc19-4369-972c-bc4b3647f704','e9d8db0d-5ceb-412f-946f-0e6fe34509ea','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','ControlPlanePort','db6e3f19-340b-4d3e-9dcb-cdcef17c9a62','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1604),(2675,'ff51a6e0-0dfb-405c-a55f-532013a16db2','e9d8db0d-5ceb-412f-946f-0e6fe34509ea','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-Controller-rd5k6vuzi7s4','e9d8db0d-5ceb-412f-946f-0e6fe34509ea','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2676,'30be455e-a1dd-4775-bcb7-66af8dd4977a','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','StoragePort','6189cdcb-2714-4503-94da-e59e59ff0f7b','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1605),(2677,'4a21b48b-fe95-4223-aec9-d1d457c5cb3c','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','InternalApiPort','7d20abd7-0c77-4c6c-91a1-5c5c48cab63b','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1608),(2678,'739792c8-bbbd-4897-a6f9-baee1b56f363','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','TenantPort','ab960084-c337-4691-acad-c4da5bdae3dd','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1602),(2679,'0c0ed430-6a17-4ebc-8cad-12aa16daaba9','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','StorageMgmtPort','f7165cc4-f07b-4dfe-81ea-bee4f5d85fad','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1606),(2680,'6f9f97c5-5a60-496d-9e7a-6d7c4cf85488','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','NodeExtraConfig','79195776-5b5a-4c36-92e4-6b227044b6a5','state changed','OS::TripleO::NodeExtraConfig',NULL,1619),(2681,'47d018c4-2ac2-4bbb-a5cf-5540f9bf8888','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','NodeExtraConfig','8da78ce4-2115-43b2-8eee-7daa4a601e91','state changed','OS::TripleO::NodeExtraConfig',NULL,1620),(2682,'3c45b8fc-dabe-433d-aae6-8cc47b5480eb','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:40',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NetIpMap-jxzpzpz54wgh','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1643),(2683,'1035b99f-755d-4ef5-97c8-0301a36a32d9','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','NetIpMap','20c87a22-0e46-44d2-99a3-9e8585dae408','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1631),(2684,'fad0d5ba-1a97-4ea5-8de3-21a002194ca1','496ede04-262a-4214-9a84-89e87bda6ef7','2026-06-13 07:58:40',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-0-cfx6wmb7fgsa','496ede04-262a-4214-9a84-89e87bda6ef7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2685,'2e1d82b9-ba90-413f-b425-d92defbd34a9','af33a3cf-5c0d-4ab1-8d67-c169bc09fabd','2026-06-13 07:58:40',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NetIpMap-jxzpzpz54wgh','af33a3cf-5c0d-4ab1-8d67-c169bc09fabd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2686,'fd4c3980-fd62-4e34-bfca-456f8c287594','af33a3cf-5c0d-4ab1-8d67-c169bc09fabd','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NetIpMap-jxzpzpz54wgh-NetIpMapValue-zszcxk2uoxv7','state changed','OS::Heat::Value',NULL,1644),(2687,'56970151-a452-42a6-9402-57c9997f127c','af33a3cf-5c0d-4ab1-8d67-c169bc09fabd','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NetIpMap-jxzpzpz54wgh-NetIpMapValue-zszcxk2uoxv7','state changed','OS::Heat::Value',NULL,1644),(2688,'801fa951-fc26-4d18-b537-053ab2e086b4','af33a3cf-5c0d-4ab1-8d67-c169bc09fabd','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw-NetIpMap-jxzpzpz54wgh','af33a3cf-5c0d-4ab1-8d67-c169bc09fabd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2689,'b6534636-6b01-4641-9a25-a7eb523cae5a','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','Controller','e9d8db0d-5ceb-412f-946f-0e6fe34509ea','state changed','OS::TripleO::ControllerServer',NULL,1581),(2690,'c24a6305-c2d7-4367-a8b0-f0e3aaf0f5b7','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-StorageMgmtPort-laoldat2zxee','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1646),(2691,'7015134b-c44b-4f88-9d44-8ed4459e305e','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NodeTLSCAData-lln6mla2bnrv','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2692,'0e59cdb8-7840-44f0-9b29-aaeda86e7157','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-ControllerExtraConfigPre-r3wesfa7f5n2','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1647),(2693,'2fe9d7e8-9f7a-4448-8f1f-03f2f0230248','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','NodeTLSCAData','ae1806c3-334e-407d-a789-94ec69b90838','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2694,'a8e3f9dc-92bc-4511-9f04-3075d8f9f3ed','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-StoragePort-yp6pcl6dgvcq','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1648),(2695,'a356b94b-96ca-4151-aebe-367beafa9414','b3897920-735e-4c22-8e7f-b35b9d3c8d88','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-StorageMgmtPort-laoldat2zxee','b3897920-735e-4c22-8e7f-b35b9d3c8d88','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2696,'ecad6ce7-5db2-4f8e-849c-87724b35d0c4','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-ExternalPort-ehf6chnwhhhc','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1649),(2697,'b388bd3e-f62f-4c87-b387-f0ae2c9f5394','615e5116-16b4-40ab-89c7-1ba7181b56a9','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-ControllerExtraConfigPre-r3wesfa7f5n2','615e5116-16b4-40ab-89c7-1ba7181b56a9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2698,'3ccf9711-3d51-4d4f-8c54-1001a0fa5006','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NetHostMap-yxpie7odgpbi','state changed','OS::Heat::Value',NULL,1650),(2699,'b8d57947-3e36-47f2-b3e0-c56cb8450fc4','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-InternalApiPort-za5cwwlowlab','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1651),(2700,'ba7d8262-06cf-44cd-b6e0-8c0086aaf8d0','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NetHostMap-yxpie7odgpbi','state changed','OS::Heat::Value',NULL,1650),(2701,'7bc65bca-0d95-4f5d-adaf-4f61eda8f905','615e5116-16b4-40ab-89c7-1ba7181b56a9','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-ControllerExtraConfigPre-r3wesfa7f5n2','615e5116-16b4-40ab-89c7-1ba7181b56a9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2702,'88739233-fe85-4e04-95e0-3595bd9490ba','e2d906bf-826c-444b-b0b4-ad28a4284692','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-StoragePort-yp6pcl6dgvcq','e2d906bf-826c-444b-b0b4-ad28a4284692','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2703,'46b41d8e-0bab-469a-9203-b1b0890bf612','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-PreNetworkConfig-42n2mba6tv4d','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2704,'3d938762-7bdd-4144-8130-4fc1196d4ce6','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-TenantPort-uhw5xuyt6eqe','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1654),(2705,'822350ad-77ad-4e63-a6cf-da15743cc3d5','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-ControllerAnsibleHostVars-u6gvcbd7hwnu','state changed','OS::Heat::Value',NULL,1655),(2706,'0866c0f1-0866-45c3-a415-810886e71792','d3991387-ea60-46ff-89cb-1db69ffec7c9','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-ExternalPort-ehf6chnwhhhc','d3991387-ea60-46ff-89cb-1db69ffec7c9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2707,'d2962d17-c32f-4c32-acfa-902f77a9be5f','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-ControllerAnsibleHostVars-u6gvcbd7hwnu','state changed','OS::Heat::Value',NULL,1655),(2708,'64b37b2a-c03c-4c8a-8328-e3f383387fcf','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','PreNetworkConfig','5fdd3723-c752-4c56-bca8-5467a0e2d97b','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2709,'f7c5e0ca-065d-432c-b02c-2a7266aaa60e','65d7065a-7fcf-41c5-969e-ff7aafbf0071','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-InternalApiPort-za5cwwlowlab','65d7065a-7fcf-41c5-969e-ff7aafbf0071','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2710,'691e8218-fcc6-4002-a2cf-b75763254989','b3897920-735e-4c22-8e7f-b35b9d3c8d88','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-StorageMgmtPort-laoldat2zxee-StorageMgmtDeployedPort-3xmlnvf72xsx','state changed','OS::Heat::Value',NULL,1656),(2711,'40a7d4f1-1e3f-4d0e-9234-3ad272850698','2e8d5fbd-ab3e-4900-947c-ff537567adf0','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-TenantPort-uhw5xuyt6eqe','2e8d5fbd-ab3e-4900-947c-ff537567adf0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2712,'2bd64a5e-a2e8-40cb-a305-51fa57589e86','b3897920-735e-4c22-8e7f-b35b9d3c8d88','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-StorageMgmtPort-laoldat2zxee-StorageMgmtDeployedPort-3xmlnvf72xsx','state changed','OS::Heat::Value',NULL,1656),(2713,'4c767194-47c3-43ff-89e1-a6fe6481d101','e2d906bf-826c-444b-b0b4-ad28a4284692','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-StoragePort-yp6pcl6dgvcq-StorageDeployedPort-wf53nrrfpuwf','state changed','OS::Heat::Value',NULL,1657),(2714,'037ca1f6-1735-4ab8-8730-65a1010c81c8','8f6fff5b-c280-4668-bb95-713977c9a910','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','0','496ede04-262a-4214-9a84-89e87bda6ef7','state changed','OS::TripleO::Controller',NULL,1567),(2715,'44049d5a-b64c-4aa3-83a1-5682b646f0ea','d3991387-ea60-46ff-89cb-1db69ffec7c9','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-ExternalPort-ehf6chnwhhhc-ExternalDeployedPort-eplayakzoiqf','state changed','OS::Heat::Value',NULL,1658),(2716,'5e8fb501-f098-4710-bf2d-277fba809746','b3897920-735e-4c22-8e7f-b35b9d3c8d88','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-StorageMgmtPort-laoldat2zxee','b3897920-735e-4c22-8e7f-b35b9d3c8d88','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2717,'e22dbd43-6040-47cb-bea2-cfdb672ebade','e2d906bf-826c-444b-b0b4-ad28a4284692','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-StoragePort-yp6pcl6dgvcq-StorageDeployedPort-wf53nrrfpuwf','state changed','OS::Heat::Value',NULL,1657),(2718,'cbcab0c0-c955-4f07-a0b6-cc5ca1ce1848','d3991387-ea60-46ff-89cb-1db69ffec7c9','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-ExternalPort-ehf6chnwhhhc-ExternalDeployedPort-eplayakzoiqf','state changed','OS::Heat::Value',NULL,1658),(2719,'67fe70d9-4221-4eea-bbed-3b0003d3222a','e2d906bf-826c-444b-b0b4-ad28a4284692','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-StoragePort-yp6pcl6dgvcq','e2d906bf-826c-444b-b0b4-ad28a4284692','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2720,'7936c3ce-c379-4c67-8195-d25b26fd9eed','d3991387-ea60-46ff-89cb-1db69ffec7c9','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-ExternalPort-ehf6chnwhhhc','d3991387-ea60-46ff-89cb-1db69ffec7c9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2721,'da9a21da-e558-45ba-8f1f-744253279dca','65d7065a-7fcf-41c5-969e-ff7aafbf0071','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-InternalApiPort-za5cwwlowlab-InternalApiDeployedPort-iyh7wd3v6wj3','state changed','OS::Heat::Value',NULL,1659),(2722,'49b19a7e-21f3-469f-a79e-ab92ac8eecba','2e8d5fbd-ab3e-4900-947c-ff537567adf0','2026-06-13 07:58:41',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-TenantPort-uhw5xuyt6eqe-TenantDeployedPort-dnxh2p7upwbn','state changed','OS::Heat::Value',NULL,1660),(2723,'a319b18a-4655-4b9a-88ec-33b29df78638','65d7065a-7fcf-41c5-969e-ff7aafbf0071','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-InternalApiPort-za5cwwlowlab-InternalApiDeployedPort-iyh7wd3v6wj3','state changed','OS::Heat::Value',NULL,1659),(2724,'100bb1a6-0710-4c35-9b6a-d629e2a044c0','2e8d5fbd-ab3e-4900-947c-ff537567adf0','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-TenantPort-uhw5xuyt6eqe-TenantDeployedPort-dnxh2p7upwbn','state changed','OS::Heat::Value',NULL,1660),(2725,'960190e2-1652-4b60-b5fe-0c1b8b1f2e54','65d7065a-7fcf-41c5-969e-ff7aafbf0071','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-InternalApiPort-za5cwwlowlab','65d7065a-7fcf-41c5-969e-ff7aafbf0071','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2726,'d8602375-1478-44ff-ad75-4c5d4ac10f64','2e8d5fbd-ab3e-4900-947c-ff537567adf0','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-TenantPort-uhw5xuyt6eqe','2e8d5fbd-ab3e-4900-947c-ff537567adf0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2727,'aa8a951f-5533-4c5f-9e9c-de64ff8cc733','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','NetIpMap','af33a3cf-5c0d-4ab1-8d67-c169bc09fabd','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1643),(2728,'2f823984-f5fd-41e2-bdc1-22970d288ab7','25142736-f3a8-45c9-9625-b42c209caae7','2026-06-13 07:58:41',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-2-hr45ozrjz4nw','25142736-f3a8-45c9-9625-b42c209caae7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2729,'6e6c6f7e-02d2-40e6-89df-8dfc8996a6cc','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:42',NULL,'CREATE','COMPLETE','StorageMgmtPort','b3897920-735e-4c22-8e7f-b35b9d3c8d88','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1646),(2730,'b80ea10a-6380-4112-88b9-54e4169ff860','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:42',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','615e5116-16b4-40ab-89c7-1ba7181b56a9','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1647),(2731,'26fb9f3b-d251-4fb6-8598-94ad97801591','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:42',NULL,'CREATE','COMPLETE','StoragePort','e2d906bf-826c-444b-b0b4-ad28a4284692','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1648),(2732,'ca27ce4d-c9af-409d-a093-13d96fcc975f','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:42',NULL,'CREATE','COMPLETE','ExternalPort','d3991387-ea60-46ff-89cb-1db69ffec7c9','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1649),(2733,'e2209e8f-fa0b-434f-92d8-714aa0ddc83f','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:42',NULL,'CREATE','COMPLETE','InternalApiPort','65d7065a-7fcf-41c5-969e-ff7aafbf0071','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1651),(2734,'183cf170-e438-44b8-921b-1a84df3f0895','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:42',NULL,'CREATE','COMPLETE','TenantPort','2e8d5fbd-ab3e-4900-947c-ff537567adf0','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1654),(2735,'a1f16ea8-6ffa-4996-9452-7736e2ec9bf6','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:42',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NodeExtraConfig-rbusg7qmxo25','state changed','OS::TripleO::NodeExtraConfig',NULL,1664),(2736,'4094d9ed-7cba-4287-aef1-41d74919752d','8f6fff5b-c280-4668-bb95-713977c9a910','2026-06-13 07:58:42',NULL,'CREATE','COMPLETE','2','25142736-f3a8-45c9-9625-b42c209caae7','state changed','OS::TripleO::Controller',NULL,1570),(2737,'f423a159-a856-4fb6-ab28-360dc38a6f21','b7ce87d6-2e91-46f6-88c4-eba7e17afb66','2026-06-13 07:58:42',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NodeExtraConfig-rbusg7qmxo25','b7ce87d6-2e91-46f6-88c4-eba7e17afb66','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2738,'d5d1bfa0-77fa-4363-9744-b39b494bb540','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:42',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NetIpMap-xz3ododffden','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1673),(2739,'4cddcfb8-5bc2-4f5b-badf-9a6de8907731','b7ce87d6-2e91-46f6-88c4-eba7e17afb66','2026-06-13 07:58:42',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NodeExtraConfig-rbusg7qmxo25','b7ce87d6-2e91-46f6-88c4-eba7e17afb66','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2740,'6a1ad1e2-dc01-42dc-a99c-9a7fcd912c5d','b39878ec-d24f-479e-80b0-0a14ce05dd55','2026-06-13 07:58:42',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NetIpMap-xz3ododffden','b39878ec-d24f-479e-80b0-0a14ce05dd55','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2741,'d7d2afd9-06e1-4984-a961-0fc0618d11e1','b39878ec-d24f-479e-80b0-0a14ce05dd55','2026-06-13 07:58:43',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NetIpMap-xz3ododffden-NetIpMapValue-pqioocaakjlv','state changed','OS::Heat::Value',NULL,1674),(2742,'e8439d69-236d-4cc2-a929-0adaca45ef8b','b39878ec-d24f-479e-80b0-0a14ce05dd55','2026-06-13 07:58:43',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NetIpMap-xz3ododffden-NetIpMapValue-pqioocaakjlv','state changed','OS::Heat::Value',NULL,1674),(2743,'2fb4ac29-e16d-4a6d-8416-210dc609bb59','b39878ec-d24f-479e-80b0-0a14ce05dd55','2026-06-13 07:58:43',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd-NetIpMap-xz3ododffden','b39878ec-d24f-479e-80b0-0a14ce05dd55','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2744,'c95b64f5-f791-4159-a269-5384c8da5c71','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:43',NULL,'CREATE','COMPLETE','NodeExtraConfig','b7ce87d6-2e91-46f6-88c4-eba7e17afb66','state changed','OS::TripleO::NodeExtraConfig',NULL,1664),(2745,'9e28bd47-792a-4888-b0ee-a2ab5175c917','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:43',NULL,'CREATE','COMPLETE','NetIpMap','b39878ec-d24f-479e-80b0-0a14ce05dd55','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1673),(2746,'9b5b4827-8220-4e0e-aef5-04bff59684b3','68d593b7-c5ba-4944-9c60-248c0436d714','2026-06-13 07:58:44',NULL,'CREATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g-1-ltwda2nuu4qd','68d593b7-c5ba-4944-9c60-248c0436d714','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2747,'2b2b888e-bbc7-4423-9c7c-615bb40ff2ea','8f6fff5b-c280-4668-bb95-713977c9a910','2026-06-13 07:58:44',NULL,'CREATE','COMPLETE','1','68d593b7-c5ba-4944-9c60-248c0436d714','state changed','OS::TripleO::Controller',NULL,1575),(2748,'b839de0c-f350-4287-afad-20db5f1e06f6','8f6fff5b-c280-4668-bb95-713977c9a910','2026-06-13 07:58:44',NULL,'UPDATE','COMPLETE','overcloud-Controller-yvnz6bxzdr3g','8f6fff5b-c280-4668-bb95-713977c9a910','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(2749,'00f030a0-24b3-4bcb-a819-14aed78e0b76','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:45',NULL,'CREATE','COMPLETE','Controller','8f6fff5b-c280-4668-bb95-713977c9a910','state changed','OS::Heat::ResourceGroup',NULL,1563),(2750,'6b62db49-54c7-46d8-bf34-1d08e71901e2','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','IN_PROGRESS','ServerIdMap','overcloud-ServerIdMap-2nt7c6ii7b4f','state changed','OS::Heat::Value',NULL,1690),(2751,'edf4581e-4691-45e6-946e-b1c0fb0dbb73','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','COMPLETE','ServerIdMap','overcloud-ServerIdMap-2nt7c6ii7b4f','state changed','OS::Heat::Value',NULL,1690),(2752,'4877557d-fc46-4aca-8108-acd3f2d1156d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','IN_PROGRESS','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-mlz2tmn3suay','state changed','OS::Heat::Value',NULL,1692),(2753,'09dcd7e8-e82a-4ec1-a097-84bc534f7bc6','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','IN_PROGRESS','ControllerServers','overcloud-ControllerServers-boobts3n2lqz','state changed','OS::Heat::Value',NULL,1691),(2754,'96d75e94-71ee-4445-9e41-0f89dbc5e03a','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','COMPLETE','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-mlz2tmn3suay','state changed','OS::Heat::Value',NULL,1692),(2755,'77c6f1a1-72d0-47b4-ad65-da958bea132b','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','COMPLETE','ControllerServers','overcloud-ControllerServers-boobts3n2lqz','state changed','OS::Heat::Value',NULL,1691),(2756,'a071e791-3036-4205-97eb-e53ed6774b6f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','IN_PROGRESS','BlacklistedHostnames','overcloud-BlacklistedHostnames-5vx5deotqe6y','state changed','OS::Heat::Value',NULL,1693),(2757,'67898933-6607-481c-b6fa-93a8ff168c3b','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','COMPLETE','BlacklistedHostnames','overcloud-BlacklistedHostnames-5vx5deotqe6y','state changed','OS::Heat::Value',NULL,1693),(2758,'795c500d-3e87-44cf-baf3-3acdd3731b80','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','IN_PROGRESS','AllNodesExtraConfig','overcloud-AllNodesExtraConfig-7e4pjmhha3ux','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2759,'89115d0c-e886-457e-bde0-6ed79a95483d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','COMPLETE','AllNodesExtraConfig','8e3f2ad7-6d86-4e49-8d52-95f728adb6f0','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2760,'fb3e86ae-248e-463f-84cd-fd128b6e4dc3','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','IN_PROGRESS','HostsEntryValue','overcloud-HostsEntryValue-xjnn4cadilw4','state changed','OS::Heat::Value',NULL,1695),(2761,'184ebc16-209b-4b15-ae6f-243653a753ad','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','IN_PROGRESS','AnsibleHostVars','overcloud-AnsibleHostVars-7wp45cwck26s','state changed','OS::Heat::Value',NULL,1694),(2762,'28e62307-c590-4f6b-8ac6-46b5d02c6b8d','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','COMPLETE','HostsEntryValue','overcloud-HostsEntryValue-xjnn4cadilw4','state changed','OS::Heat::Value',NULL,1695),(2763,'7c3f9185-1182-493f-b4f4-97349bb0ce6f','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','COMPLETE','AnsibleHostVars','overcloud-AnsibleHostVars-7wp45cwck26s','state changed','OS::Heat::Value',NULL,1694),(2764,'a865fd99-0c6b-4217-8efd-a05da6b27160','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:46',NULL,'CREATE','IN_PROGRESS','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-54dkc3nyapdq','state changed','OS::Heat::Value',NULL,1698),(2765,'e9d4bbf9-c0f4-4a03-a4e0-29dd45cf85de','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:47',NULL,'CREATE','COMPLETE','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-54dkc3nyapdq','state changed','OS::Heat::Value',NULL,1698),(2766,'0dbccce6-0a9f-4b4e-a676-c8a53da1cf9e','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:47',NULL,'CREATE','IN_PROGRESS','ControllerIpListMap','overcloud-ControllerIpListMap-xhtahbrajbty','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1700),(2767,'21ac40fa-5940-4f8e-b4b4-15942f941b55','ec01edda-ff01-4078-86bc-81085698f24c','2026-06-13 07:58:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerIpListMap-xhtahbrajbty','ec01edda-ff01-4078-86bc-81085698f24c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2768,'19389a07-f119-4dbf-a8f2-b5bb90dff1e8','ec01edda-ff01-4078-86bc-81085698f24c','2026-06-13 07:58:47',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ControllerIpListMap-xhtahbrajbty-EnabledServicesValue-7ll52ekqmqcs','state changed','OS::Heat::Value',NULL,1702),(2769,'97a39eb6-2183-46d5-b0be-29b78d15d34d','ec01edda-ff01-4078-86bc-81085698f24c','2026-06-13 07:58:47',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ControllerIpListMap-xhtahbrajbty-EnabledServicesValue-7ll52ekqmqcs','state changed','OS::Heat::Value',NULL,1702),(2770,'435edc15-307f-4e2a-b1aa-a7e1e94cc267','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:47',NULL,'CREATE','IN_PROGRESS','AllNodesDeploySteps','overcloud-AllNodesDeploySteps-w42hgi4vvae7','state changed','OS::TripleO::PostDeploySteps',NULL,1703),(2771,'544d12a6-9216-43f5-9d06-ca3fb76a557a','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:47',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-w42hgi4vvae7','355cbf9f-aeca-4c07-aede-66a3131f26fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2772,'7d245236-cc7d-4981-869d-1cd40aa6717a','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:48',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ScaleTasks-cukxyq56k3ea','state changed','OS::Heat::Value',NULL,1704),(2773,'4257553d-00f1-4dca-a97f-9d067b853ab9','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:48',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ScaleTasks-cukxyq56k3ea','state changed','OS::Heat::Value',NULL,1704),(2774,'cf2d731b-3c8b-440d-a55d-363f5004175d','ec01edda-ff01-4078-86bc-81085698f24c','2026-06-13 07:58:48',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ControllerIpListMap-xhtahbrajbty-NetIpMapValue-bwpgfsynacol','state changed','OS::Heat::Value',NULL,1705),(2775,'f93bbde0-754d-4398-b42c-4663aec624a6','ec01edda-ff01-4078-86bc-81085698f24c','2026-06-13 07:58:48',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ControllerIpListMap-xhtahbrajbty-NetIpMapValue-bwpgfsynacol','state changed','OS::Heat::Value',NULL,1705),(2776,'52aad8ec-73f3-4be0-b45e-4d97c3a2f54c','ec01edda-ff01-4078-86bc-81085698f24c','2026-06-13 07:58:48',NULL,'CREATE','COMPLETE','overcloud-ControllerIpListMap-xhtahbrajbty','ec01edda-ff01-4078-86bc-81085698f24c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2777,'de424abf-5358-46e5-b3b6-da791ebbdadb','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:49',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-PreDeployStepTasks-qf4ggmb2cxel','state changed','OS::Heat::Value',NULL,1706),(2778,'b7047af2-797e-4040-9818-df437504fd02','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:49',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-PreDeployStepTasks-qf4ggmb2cxel','state changed','OS::Heat::Value',NULL,1706),(2779,'4122847c-9fd1-4c48-a67d-e4bc8bf689db','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:49',NULL,'CREATE','COMPLETE','ControllerIpListMap','ec01edda-ff01-4078-86bc-81085698f24c','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1700),(2780,'296009a0-9ee2-44f0-a5e3-979212d4c8db','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:50',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPost','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ControllerExtraConfigPost-vb4sqfla2bwg','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1707),(2781,'b0bdc9e2-b390-4c1a-aecb-4d8403fec6ce','b5dd976d-d7e7-456c-8c3d-3637c8bcb076','2026-06-13 07:58:50',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ControllerExtraConfigPost-vb4sqfla2bwg','b5dd976d-d7e7-456c-8c3d-3637c8bcb076','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2782,'fb78f8da-a577-4051-a322-d96b8dffb9b5','b5dd976d-d7e7-456c-8c3d-3637c8bcb076','2026-06-13 07:58:50',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ControllerExtraConfigPost-vb4sqfla2bwg','b5dd976d-d7e7-456c-8c3d-3637c8bcb076','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2783,'19578ab4-b358-4bbd-ae42-4098a0a76d61','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:51',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ExternalUpdateTasks-oqmgd2srmria','state changed','OS::Heat::Value',NULL,1708),(2784,'133a4113-298d-4717-9b4e-ae86e157e44f','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:51',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ExternalUpdateTasks-oqmgd2srmria','state changed','OS::Heat::Value',NULL,1708),(2785,'c83257a6-76a2-4f88-a45c-399e32e57207','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:51',NULL,'CREATE','COMPLETE','ControllerExtraConfigPost','b5dd976d-d7e7-456c-8c3d-3637c8bcb076','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1707),(2786,'4504930c-4e7d-4e52-bc74-48ed8b8fb1b3','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:52',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ExternalUpgradeTasks-v4jwksbuo53i','state changed','OS::Heat::Value',NULL,1710),(2787,'6a167333-bbd2-4b34-98cd-5b408ccfa2ff','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:52',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ExternalUpgradeTasks-v4jwksbuo53i','state changed','OS::Heat::Value',NULL,1710),(2788,'683c9f6b-3836-4646-a241-5ebc83cad098','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:53',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ExternalDeployTasks-2z4slbh5azhi','state changed','OS::Heat::Value',NULL,1711),(2789,'f06f64c2-0cf0-48ee-b8a9-7a62ae58b256','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:53',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ExternalDeployTasks-2z4slbh5azhi','state changed','OS::Heat::Value',NULL,1711),(2790,'68f2c2c1-23ca-4a72-88c3-8e58e004ad6c','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:54',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ExternalPostDeployTasks-w554cirjpd3h','state changed','OS::Heat::Value',NULL,1712),(2791,'ba0dd472-7795-468c-9495-304dfe2e38b6','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:54',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ExternalPostDeployTasks-w554cirjpd3h','state changed','OS::Heat::Value',NULL,1712),(2792,'cb17d8b6-2849-49cd-936b-00fee1c51326','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:55',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPost','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ComputeExtraConfigPost-5oo4duec4rqd','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1713),(2793,'d6203890-1d97-4a15-9e9c-741df5f3194b','d3c01d56-0160-4972-bdde-e602f2c318ed','2026-06-13 07:58:55',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ComputeExtraConfigPost-5oo4duec4rqd','d3c01d56-0160-4972-bdde-e602f2c318ed','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2794,'92e59d7c-9cc6-484f-b3c0-04bc7cc5fc0b','d3c01d56-0160-4972-bdde-e602f2c318ed','2026-06-13 07:58:55',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ComputeExtraConfigPost-5oo4duec4rqd','d3c01d56-0160-4972-bdde-e602f2c318ed','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2795,'39a937b9-24c7-422c-a3c6-10122e235bad','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:56',NULL,'CREATE','IN_PROGRESS','BootstrapServerId','overcloud-AllNodesDeploySteps-w42hgi4vvae7-BootstrapServerId-yuw7aehtwpph','state changed','OS::Heat::Value',NULL,1714),(2796,'21c801b0-045a-4eb8-9c0b-f5c3d159dab1','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:56',NULL,'CREATE','COMPLETE','BootstrapServerId','overcloud-AllNodesDeploySteps-w42hgi4vvae7-BootstrapServerId-yuw7aehtwpph','state changed','OS::Heat::Value',NULL,1714),(2797,'0e69b38d-993d-4a87-b701-569b067906f1','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:56',NULL,'CREATE','COMPLETE','ComputeExtraConfigPost','d3c01d56-0160-4972-bdde-e602f2c318ed','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1713),(2798,'11097222-c295-4b22-af09-2fab17862b51','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:56',NULL,'CREATE','IN_PROGRESS','ControllerPostConfig','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ControllerPostConfig-yuondwoayg7z','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(2799,'36a427c0-fed6-475b-b447-e4454a11cc42','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:56',NULL,'CREATE','IN_PROGRESS','ComputePostConfig','overcloud-AllNodesDeploySteps-w42hgi4vvae7-ComputePostConfig-iwiazkcgg4mf','state changed','OS::TripleO::Tasks::ComputePostConfig',NULL,NULL),(2800,'bede2746-ca06-42ae-ba68-759b4822cae6','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:56',NULL,'CREATE','COMPLETE','ComputePostConfig','5b06adfd-1ab3-40fc-bfeb-77e11690e429','state changed','OS::TripleO::Tasks::ComputePostConfig',NULL,NULL),(2801,'6df20051-2436-41eb-81f4-f78dd075e010','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:56',NULL,'CREATE','COMPLETE','ControllerPostConfig','14d743ed-8e7b-45c1-b709-2b5a4ac460b2','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(2802,'6cf025bc-78c7-4dce-a479-ed7ba7adb0b7','355cbf9f-aeca-4c07-aede-66a3131f26fd','2026-06-13 07:58:56',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-w42hgi4vvae7','355cbf9f-aeca-4c07-aede-66a3131f26fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2803,'b15db230-439c-43ac-9b19-1dc28e909894','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:56',NULL,'CREATE','COMPLETE','AllNodesDeploySteps','355cbf9f-aeca-4c07-aede-66a3131f26fd','state changed','OS::TripleO::PostDeploySteps',NULL,1703),(2804,'c86f5b36-9b97-4945-8fa5-f7d06bf12b96','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','2026-06-13 07:58:56',NULL,'CREATE','COMPLETE','overcloud','4379cfaa-70fd-4828-bfa3-ea673db7ca9d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL);
/*!40000 ALTER TABLE `event` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `migrate_version`
--

DROP TABLE IF EXISTS `migrate_version`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `migrate_version` (
  `repository_id` varchar(250) NOT NULL,
  `repository_path` text DEFAULT NULL,
  `version` int(11) DEFAULT NULL,
  PRIMARY KEY (`repository_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_swedish_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `migrate_version`
--

LOCK TABLES `migrate_version` WRITE;
/*!40000 ALTER TABLE `migrate_version` DISABLE KEYS */;
INSERT INTO `migrate_version` VALUES ('heat','/usr/lib/python3.9/site-packages/heat/db/sqlalchemy/migrate_repo',86);
/*!40000 ALTER TABLE `migrate_version` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `raw_template`
--

DROP TABLE IF EXISTS `raw_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `raw_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `template` longtext DEFAULT NULL,
  `files` longtext DEFAULT NULL,
  `environment` longtext DEFAULT NULL,
  `files_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `raw_tmpl_files_fkey_ref` (`files_id`),
  CONSTRAINT `raw_tmpl_files_fkey_ref` FOREIGN KEY (`files_id`) REFERENCES `raw_template_files` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=408 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `raw_template`
--

LOCK TABLES `raw_template` WRITE;
/*!40000 ALTER TABLE `raw_template` DISABLE KEYS */;
INSERT INTO `raw_template` VALUES (1,'2026-06-13 07:56:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deploy an OpenStack environment, consisting of several node types (roles), Controller, Compute, BlockStorage, SwiftStorage and CephStorage. The Storage roles enable independent scaling of the storage components, but the minimal deployment is one Controller and one Compute node.\\n\", \"parameters\": {\"CloudNameStorage\": {\"default\": \"overcloud.storage.localdomain\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.localdomain\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageMgmtVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageMgmtVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.localdomain\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"InternalApiVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the InternalApiVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudName\": {\"default\": \"overcloud.localdomain\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"PublicVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the PublicVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"ExternalVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ExternalVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.localdomain\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}, \"ExtraHostFileEntries\": {\"default\": [], \"description\": \"List of extra hosts entries to be appended to /etc/hosts\", \"type\": \"comma_delimited_list\"}, \"UndercloudHostsEntries\": {\"default\": [], \"description\": \"List of undercloud hosts entries to be appended to /etc/hosts. The value is populated with the HEAT_HOSTS entries on the undercloud by tripleoclient when running deploy.\\n\", \"type\": \"comma_delimited_list\"}, \"EndpointMapOverride\": {\"default\": {}, \"description\": \"Can be used to override the calcluated EndpointMap\", \"type\": \"json\"}, \"ExtraConfig\": {\"default\": {}, \"description\": \"Additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"DeployedServerPortMap\": {\"default\": {}, \"type\": \"json\"}, \"NeutronControlPlaneID\": {\"default\": \"ctlplane\", \"type\": \"string\", \"description\": \"Neutron ID or name for ctlplane network.\"}, \"NeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create for accessing external networks.\", \"type\": \"string\"}, \"NeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"Which interface to add to the NeutronPhysicalBridge.\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"DnsSearchDomains\": {\"default\": [], \"description\": \"A list of DNS search domains to be added (in order) to resolv.conf.\", \"type\": \"comma_delimited_list\"}, \"ControlFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ControlVirtualIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"RabbitCookieSalt\": {\"type\": \"string\", \"default\": \"unset\", \"description\": \"Salt for the rabbit cookie, change this to force the randomly generated rabbit cookie to change.\"}, \"CloudDomain\": {\"default\": \"localdomain\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API.\\n\", \"type\": \"json\"}, \"HypervisorNeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create on each hypervisor. This defaults to br-ex the same as the control plane nodes, as we have a uniform configuration of the openvswitch agent. Typically should not need to be changed.\\n\", \"type\": \"string\"}, \"HypervisorNeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"What interface to add to the HypervisorNeutronPhysicalBridge.\", \"type\": \"string\"}, \"NodeCreateBatchSize\": {\"default\": 30, \"description\": \"Maxiumum batch size for creating nodes\", \"type\": \"number\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaLocalMetadataPerCell\": {\"default\": false, \"description\": \"Indicates that the nova-metadata API service has been deployed per-cell, so that we can have better performance and data isolation in a multi-cell deployment. Users should consider the use of this configuration depending on how neutron is setup. If networks span cells, you might need to run nova-metadata API service globally. If your networks are segmented along cell boundaries, then you can run nova-metadata API service per cell. When running nova-metadata API service per cell, you should also configure each Neutron metadata-agent to point to the corresponding nova-metadata API service.\\n\", \"type\": \"boolean\"}, \"BondInterfaceOvsOptions\": {\"default\": \"\", \"description\": \"The ovs_options or bonding_options string for the bond interface. Set things like lacp=active and/or bond_mode=balance-slb for OVS bonds or like mode=4 for Linux bonds using this option.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^((?!balance.tcp).)*$\", \"description\": \"The balance-tcp bond mode is known to cause packet loss and should not be used in BondInterfaceOvsOptions.\"}]}, \"NetworkConfigWithAnsible\": {\"description\": \"NetworkConfig with ansible flag\", \"type\": \"boolean\", \"default\": true}, \"ControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ControllerNetworkConfigTemplate\": {\"description\": \"Controller NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"controllerExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use CellControllerComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\"}, \"ControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Controller node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"ControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Controller ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Controller ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nControllerServiceChain resource and the Controller resource group.\\nFor example:\\nControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerNetworkConfigTemplate\": {\"description\": \"CellController NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellController node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"CellControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellController ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellController ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerServiceChain resource and the CellController resource group.\\nFor example:\\nCellControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerComputeNetworkConfigTemplate\": {\"description\": \"CellControllerCompute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellControllerCompute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-compute-%index%\"}, \"CellControllerComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellControllerCompute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellControllerCompute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerComputeServiceChain resource and the CellControllerCompute resource group.\\nFor example:\\nCellControllerComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ComputeNetworkConfigTemplate\": {\"description\": \"Compute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NovaComputeExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use ComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\"}, \"ComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Compute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-novacompute-%index%\"}, \"ComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Compute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Compute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NovaComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"DEPRECATED - use ComputeSchedulerHints instead\", \"default\": {}}, \"ComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nComputeServiceChain resource and the Compute resource group.\\nFor example:\\nComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"BlockStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"BlockStorageNetworkConfigTemplate\": {\"description\": \"BlockStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"BlockStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\"}, \"BlockStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"BlockStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"BlockStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"BlockStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for BlockStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-blockstorage-%index%\"}, \"BlockStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from BlockStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"BlockStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for BlockStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"BlockStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"BlockStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"BlockStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"BlockStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"BlockStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nBlockStorageServiceChain resource and the BlockStorage resource group.\\nFor example:\\nBlockStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"BlockStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ObjectStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ObjectStorageNetworkConfigTemplate\": {\"description\": \"ObjectStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ObjectStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\"}, \"ObjectStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ObjectStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ObjectStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for ObjectStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-objectstorage-%index%\"}, \"ObjectStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from ObjectStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ObjectStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for ObjectStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ObjectStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ObjectStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ObjectStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ObjectStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ObjectStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nObjectStorageServiceChain resource and the ObjectStorage resource group.\\nFor example:\\nObjectStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ObjectStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CephStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CephStorageNetworkConfigTemplate\": {\"description\": \"CephStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CephStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\"}, \"CephStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CephStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CephStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CephStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-cephstorage-%index%\"}, \"CephStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CephStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CephStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CephStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CephStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CephStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CephStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CephStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CephStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCephStorageServiceChain resource and the CephStorage resource group.\\nFor example:\\nCephStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CephStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"NetworkerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"NetworkerNetworkConfigTemplate\": {\"description\": \"Networker NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"NetworkerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\"}, \"NetworkerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"NetworkerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"NetworkerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Networker node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-networker-%index%\"}, \"NetworkerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Networker ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"NetworkerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Networker ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"NetworkerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NetworkerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"NetworkerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"NetworkerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"NetworkerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nNetworkerServiceChain resource and the Networker resource group.\\nFor example:\\nNetworkerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"NetworkerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"DeployIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AddVipsToEtcHosts\": {\"default\": true, \"type\": \"boolean\", \"description\": \"Set to true to append per network Vips to /etc/hosts on each node.\\n\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"GlobalConfigExtraMapData\": {\"type\": \"json\", \"default\": {}, \"description\": \"Map of extra global_config_settings data to set on each node.\"}, \"NetConfigDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"Configure os-net-config mappings for specific nodes Your environment file needs to look like:\\n  parameter_defaults:\\n    NetConfigDataLookup:\\n      node1:\\n        nic1: \\\"00:c8:7c:e6:f0:2e\\\"\\n      node2:\\n        nic1: \\\"00:18:7d:99:0c:b6\\\"\\n      node3:\\n        dmiString: \'system-uuid\'\\n        id: \'A8C85861-1B16-4803-8689-AFC62984F8F6\'\\n        nic1: em3\\n      # Dell PowerEdge\\n      nodegroup1:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"PowerEdge R630\\\"\\n        nic1: em3\\n        nic2: em1\\n        nic3: em2\\n      # Cisco UCS B200-M4\\\"\\n      nodegroup2:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"UCSB-B200-M4\\\"\\n        nic1: enp7s0\\n        nic2: enp6s0\\n\\nThis will result in the first node* entry where either a mac matches a local device or a DMI String matches the specified id being written as a mapping file for os-net-config. (/etc/os-net-config/mapping.yaml)\\n\"}, \"DnsServers\": {\"default\": [], \"description\": \"DNS servers to use for the Overcloud (2 max for some implementations). If not set the nameservers configured in the ctlplane subnet\'s dns_nameservers attribute will be used.\\n\", \"type\": \"comma_delimited_list\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"DnsServers\", \"NovaComputeSchedulerHints\", \"NovaComputeExtraConfig\"]}], \"conditions\": {\"add_vips_to_etc_hosts\": {\"equals\": [{\"get_param\": \"AddVipsToEtcHosts\"}, true]}, \"control_fixed_ip_not_set\": {\"equals\": [{\"get_param\": \"ControlFixedIPs\"}, []]}, \"storage_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageVirtualFixedIPs\"}, []]}}, \"storage_mgmt_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, []]}}, \"internal_api_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"InternalApiVirtualFixedIPs\"}, []]}}, \"tenant_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"TenantVirtualFixedIPs\"}, []]}}, \"public_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"PublicVirtualFixedIPs\"}, []]}}, \"set_default_mysql_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"MysqlCellInternal\"]}, \"\"]}]}]}, \"set_default_nova_vnc_proxy_cell_public\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaVNCProxyCellPublic\"]}, \"\"]}]}]}, \"set_default_nova_metadata_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaMetadataCellInternal\"]}, \"\"]}]}]}, \"dnsservers_set\": {\"not\": {\"equals\": [{\"get_param\": \"DnsServers\"}, []]}}}, \"resources\": {\"VipHosts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": [{\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"ctlplane\"]}, \"HOST\": {\"get_param\": \"CloudNameCtlplane\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage\"]}, \"HOST\": {\"get_param\": \"CloudNameStorage\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage_mgmt\"]}, \"HOST\": {\"get_param\": \"CloudNameStorageManagement\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"internal_api\"]}, \"HOST\": {\"get_param\": \"CloudNameInternal\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"external\"]}, \"HOST\": {\"get_param\": \"CloudName\"}}}}]}}, \"NetCidrMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_cidr_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"NetIpVersionMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_ip_version_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"subnets\", 0, \"ip_version\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"ServiceNetMap\": {\"type\": \"OS::TripleO::ServiceNetMap\"}, \"EndpointMap\": {\"type\": \"OS::TripleO::EndpointMap\", \"properties\": {\"CloudEndpoints\": {\"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}, \"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}}, \"NetIpMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}}}, \"EndpointMapData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"EndpointMap\", \"endpoint_map\"]}, {\"get_param\": \"EndpointMapOverride\"}, {\"if\": [\"set_default_mysql_cell_internal\", {\"MysqlCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"MysqlInternal\"]}}, {}]}, {\"if\": [\"set_default_nova_vnc_proxy_cell_public\", {\"NovaVNCProxyCellPublic\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaVNCProxyPublic\"]}}, {}]}, {\"if\": [\"set_default_nova_metadata_cell_internal\", {\"NovaMetadataCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaMetadataInternal\"]}}, {}]}]}}}, \"NodeAdminUserData\": {\"type\": \"OS::TripleO::NodeAdminUserData\"}, \"NodeTimesyncUserData\": {\"type\": \"OS::TripleO::NodeTimesyncUserData\"}, \"NodeUserData\": {\"type\": \"OS::TripleO::NodeUserData\"}, \"ControllerServiceChain\": {\"type\": \"OS::TripleO::ControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"ControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}}}, \"ControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ControllerServiceChain\", \"role_data\"]}}}, \"ControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"ControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}}}}]}}}, \"ControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ControllerServiceNetMap\"}}}}]}}}, \"ControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Controller\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"Controller\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Controller\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}}}, \"ControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Controller\", \"hostname_map\"]}]}}}}, \"ControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ControllerRoleUserData\": {\"type\": \"OS::TripleO::Controller::NodeUserData\"}, \"Controller\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ControllerCount\"}, \"removal_policies\": {\"get_param\": \"ControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Controller\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"ControllerUserData\"}}}}}, \"CellControllerServiceChain\": {\"type\": \"OS::TripleO::CellControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}}}, \"CellControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerServiceChain\", \"role_data\"]}}}, \"CellControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}}}}]}}}, \"CellControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerServiceNetMap\"}}}}]}}}, \"CellControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellController\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"CellController\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellController\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}}}, \"CellControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellController\", \"hostname_map\"]}]}}}}, \"CellControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerRoleUserData\": {\"type\": \"OS::TripleO::CellController::NodeUserData\"}, \"CellController\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellController\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerUserData\"}}}}}, \"CellControllerComputeServiceChain\": {\"type\": \"OS::TripleO::CellControllerComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}}}, \"CellControllerComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerComputeServiceChain\", \"role_data\"]}}}, \"CellControllerComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}}}}]}}}, \"CellControllerComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerComputeServiceNetMap\"}}}}]}}}, \"CellControllerComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"CellControllerCompute\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellControllerCompute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}}}, \"CellControllerComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellControllerCompute\", \"hostname_map\"]}]}}}}, \"CellControllerComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerComputeRoleUserData\": {\"type\": \"OS::TripleO::CellControllerCompute::NodeUserData\"}, \"CellControllerCompute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerComputeCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellControllerCompute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerComputeUserData\"}}}}}, \"ComputeServiceChain\": {\"type\": \"OS::TripleO::ComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"ComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}}}, \"ComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ComputeServiceChain\", \"role_data\"]}}}, \"ComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NovaComputeExtraConfig\"}, {\"get_param\": \"ComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}}}}]}}}, \"ComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ComputeServiceNetMap\"}}}}]}}}, \"ComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Compute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Compute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}}}, \"ComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Compute\", \"hostname_map\"]}]}}}}, \"ComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ComputeRoleUserData\": {\"type\": \"OS::TripleO::Compute::NodeUserData\"}, \"Compute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ComputeCount\"}, \"removal_policies\": {\"get_param\": \"ComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NovaComputeSchedulerHints\"}, {\"get_param\": \"ComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"ComputeUserData\"}}}}}, \"BlockStorageServiceChain\": {\"type\": \"OS::TripleO::BlockStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"BlockStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}}}, \"BlockStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"BlockStorageServiceChain\", \"role_data\"]}}}, \"BlockStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"BlockStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"BlockStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"BlockStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}}}}]}}}, \"BlockStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"BlockStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"BlockStorageServiceNetMap\"}}}}]}}}, \"BlockStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"BlockStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}}}, \"BlockStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"BlockStorage\", \"hostname_map\"]}]}}}}, \"BlockStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"BlockStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"BlockStorageRoleUserData\": {\"type\": \"OS::TripleO::BlockStorage::NodeUserData\"}, \"BlockStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"BlockStorageCount\"}, \"removal_policies\": {\"get_param\": \"BlockStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"BlockStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::BlockStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"BlockStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"BlockStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"BlockStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"BlockStorageUserData\"}}}}}, \"ObjectStorageServiceChain\": {\"type\": \"OS::TripleO::ObjectStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"ObjectStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}}}, \"ObjectStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ObjectStorageServiceChain\", \"role_data\"]}}}, \"ObjectStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ObjectStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"ObjectStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ObjectStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}}}}]}}}, \"ObjectStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ObjectStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ObjectStorageServiceNetMap\"}}}}]}}}, \"ObjectStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"ObjectStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}}}, \"ObjectStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"ObjectStorage\", \"hostname_map\"]}]}}}}, \"ObjectStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ObjectStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ObjectStorageRoleUserData\": {\"type\": \"OS::TripleO::ObjectStorage::NodeUserData\"}, \"ObjectStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ObjectStorageCount\"}, \"removal_policies\": {\"get_param\": \"ObjectStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ObjectStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::ObjectStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ObjectStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ObjectStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ObjectStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"ObjectStorageUserData\"}}}}}, \"CephStorageServiceChain\": {\"type\": \"OS::TripleO::CephStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"CephStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}}}, \"CephStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CephStorageServiceChain\", \"role_data\"]}}}, \"CephStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CephStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"CephStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CephStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}}}}]}}}, \"CephStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CephStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CephStorageServiceNetMap\"}}}}]}}}, \"CephStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"EnabledServices\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CephStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}}}, \"CephStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CephStorage\", \"hostname_map\"]}]}}}}, \"CephStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CephStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CephStorageRoleUserData\": {\"type\": \"OS::TripleO::CephStorage::NodeUserData\"}, \"CephStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CephStorageCount\"}, \"removal_policies\": {\"get_param\": \"CephStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CephStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CephStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CephStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CephStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CephStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"CephStorageUserData\"}}}}}, \"NetworkerServiceChain\": {\"type\": \"OS::TripleO::NetworkerServices\", \"properties\": {\"Services\": {\"get_param\": \"NetworkerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}}}, \"NetworkerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"NetworkerServiceChain\", \"role_data\"]}}}, \"NetworkerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"NetworkerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NetworkerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"NetworkerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}}]}}}, \"NetworkerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"NetworkerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetworkerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"NetworkerServiceNetMap\"}}}}]}}}, \"NetworkerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Networker\", \"ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Networker\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"NetworkerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Networker\", \"hostname_map\"]}]}}}}, \"NetworkerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NetworkerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"NetworkerRoleUserData\": {\"type\": \"OS::TripleO::Networker::NodeUserData\"}, \"Networker\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"NetworkerCount\"}, \"removal_policies\": {\"get_param\": \"NetworkerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"NetworkerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Networker\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"NetworkerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"NetworkerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NetworkerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}, \"UserData\": {\"get_resource\": \"NetworkerUserData\"}}}}}, \"ControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Controller\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Controller\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellController\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellController\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerCompute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellControllerCompute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Compute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Compute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"BlockStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"BlockStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ObjectStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"ObjectStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CephStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CephStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"NetworkerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Networker\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Networker\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ServerIdMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"server_ids\": {\"Controller\": {\"get_attr\": [\"Controller\", \"nova_server_resource\"]}, \"CellController\": {\"get_attr\": [\"CellController\", \"nova_server_resource\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}, \"Compute\": {\"get_attr\": [\"Compute\", \"nova_server_resource\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorage\", \"nova_server_resource\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorage\", \"nova_server_resource\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorage\", \"nova_server_resource\"]}, \"Networker\": {\"get_attr\": [\"Networker\", \"nova_server_resource\"]}}, \"bootstrap_server_id\": {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}}}}}}, \"DeploymentServerBlacklistDict\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"hostname\": 1}, \"for_each\": {\"hostname\": {\"get_param\": \"DeploymentServerBlacklist\"}}}}}}}, \"HostsEntryValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": {\"list_concat\": [[{\"get_param\": \"UndercloudHostsEntries\"}], [{\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}], {\"get_attr\": [\"Controller\", \"hosts_entry\"]}, {\"get_attr\": [\"CellController\", \"hosts_entry\"]}, {\"get_attr\": [\"CellControllerCompute\", \"hosts_entry\"]}, {\"get_attr\": [\"Compute\", \"hosts_entry\"]}, {\"get_attr\": [\"BlockStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"ObjectStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"CephStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"Networker\", \"hosts_entry\"]}, [{\"get_param\": \"ExtraHostFileEntries\"}]]}}}}, \"CloudNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"cloud_name_storage\": {\"get_param\": \"CloudNameStorage\"}, \"cloud_name_storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"cloud_name_internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"cloud_name_external\": {\"get_param\": \"CloudName\"}, \"cloud_name_ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}, \"GlobalConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}]}}}, \"Networks\": {\"type\": \"OS::TripleO::Network\", \"depends_on\": \"ServiceNetMap\", \"properties\": {\"CtlplaneNetworkCidrs\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}]}, \"ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}]}, \"edge_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}]}, \"edge_ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}]}}}}, \"ControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}}}}, \"ControllerNetworkConfig\": {\"type\": \"OS::TripleO::Controller::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"CellControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\"], \"service_net_map\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}}}}, \"CellControllerNetworkConfig\": {\"type\": \"OS::TripleO::CellController::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"CellControllerComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}}}}, \"CellControllerComputeNetworkConfig\": {\"type\": \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"ComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"compute\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}}}}, \"ComputeNetworkConfig\": {\"type\": \"OS::TripleO::Compute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"BlockStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"BlockStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"BlockStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}}}}, \"BlockStorageNetworkConfig\": {\"type\": \"OS::TripleO::BlockStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"ObjectStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ObjectStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ObjectStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}}}}, \"ObjectStorageNetworkConfig\": {\"type\": \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"CephStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CephStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CephStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"ceph\", \"storage\"], \"service_net_map\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}}}}, \"CephStorageNetworkConfig\": {\"type\": \"OS::TripleO::CephStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}}}, \"NetworkerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"NetworkerLocalMtu\"}, \"role_networks\": [\"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"NetworkerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}}}}, \"NetworkerNetworkConfig\": {\"type\": \"OS::TripleO::Networker::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"ControlVirtualIP\": {\"depends_on\": \"ServiceNetMap\", \"type\": \"OS::TripleO::Network::Ports::ControlPlaneVipPort\", \"properties\": {\"name\": \"control_virtual_ip\", \"dns_name\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameCtlplane\"}, 0]}, \"network\": {\"get_param\": \"NeutronControlPlaneID\"}, \"fixed_ips\": {\"if\": [\"control_fixed_ip_not_set\", [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}}], {\"get_param\": \"ControlFixedIPs\"}]}, \"replacement_policy\": \"AUTO\", \"tags\": [\"tripleo_vip_net=ctlplane\", {\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"OS::stack_name\"}}}}]}}, \"StorageVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorage\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_virtual_fixed_ip_set\", {\"get_param\": \"StorageVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"Storage\"]}}]]}, \"IsVirtualIP\": true}}, \"StorageMgmtVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageMgmtVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorageManagement\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_mgmt_virtual_fixed_ip_set\", {\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"StorageMgmt\"]}}]]}, \"IsVirtualIP\": true}}, \"InternalApiVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::InternalApiVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"internal_api_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameInternal\"}, 0]}, \"FixedIPs\": {\"if\": [\"internal_api_virtual_fixed_ip_set\", {\"get_param\": \"InternalApiVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"InternalApi\"]}}]]}, \"IsVirtualIP\": true}}, \"PublicVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::ExternalVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"external_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudName\"}, 0]}, \"FixedIPs\": {\"if\": [\"public_virtual_fixed_ip_set\", {\"get_param\": \"PublicVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"External\"]}}]]}, \"IsVirtualIP\": true}}, \"VipMap\": {\"type\": \"OS::TripleO::Network::Ports::NetVipMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"StorageIp\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address\"]}, \"StorageIpUri\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address_uri\"]}, \"ExternalIp\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address\"]}, \"ExternalIpUri\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address_uri\"]}}, \"depends_on\": \"ServiceNetMap\"}, \"AllNodesExtraConfig\": {\"type\": \"OS::TripleO::AllNodesExtraConfig\", \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}}}, \"BlacklistedIpAddresses\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellController\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Compute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Networker\", \"blacklist_ip_address\"]}]}}}, \"AnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"Controller\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"ansible_host_vars_map\"]}]}}, \"CellController\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellController\", \"ansible_host_vars_map\"]}]}}, \"CellControllerCompute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellControllerCompute\", \"ansible_host_vars_map\"]}]}}, \"Compute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Compute\", \"ansible_host_vars_map\"]}]}}, \"BlockStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"BlockStorage\", \"ansible_host_vars_map\"]}]}}, \"ObjectStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"ObjectStorage\", \"ansible_host_vars_map\"]}]}}, \"CephStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CephStorage\", \"ansible_host_vars_map\"]}]}}, \"Networker\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Networker\", \"ansible_host_vars_map\"]}]}}}}}, \"BlacklistedHostnames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellController\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Compute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Networker\", \"blacklist_hostname\"]}]}}}, \"AllNodesDeploySteps\": {\"type\": \"OS::TripleO::PostDeploySteps\", \"depends_on\": [\"AllNodesExtraConfig\"], \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"role_data\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}, \"ServiceNetMapLower\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, \"PingTestGatewayIPsMap\": {\"Controller\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"CellController\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"Compute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"CephStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}]}}, \"Networker\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}}, \"PingTestIpsMap\": {\"Controller\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"external_ip_address\"]}}}]]}, \"CellController\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"external_ip_address\"]}}}]]}, \"CellControllerCompute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"external_ip_address\"]}}}]]}, \"Compute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}}}]]}, \"BlockStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}}}]]}, \"ObjectStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}}}]]}, \"CephStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}}}]]}, \"Networker\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}}}]]}}, \"HostsEntry\": {\"get_attr\": [\"HostsEntryValue\", \"value\"]}, \"EnabledServices\": {\"list_concat\": [{\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}]}, \"ControlVirtualIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"EnabledNetworks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"NetVipMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"CloudNames\": {\"get_attr\": [\"CloudNames\", \"value\"]}, \"UndercloudHostsEntries\": {\"get_param\": \"UndercloudHostsEntries\"}, \"ExtraHostsEntries\": {\"get_param\": \"ExtraHostFileEntries\"}, \"VipHostsEntries\": {\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}, \"KeystoneResourcesConfigs\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"keystone_resources\"]}]}, \"NetCidrMap\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}}}}, \"outputs\": {\"ManagedEndpoints\": {\"description\": \"Asserts that the keystone endpoints have been provisioned.\", \"value\": true}, \"KeystoneURL\": {\"description\": \"URL for the Overcloud Keystone service\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\", \"KeystonePublic\", \"uri_no_suffix\"]}}, \"KeystoneAdminVip\": {\"description\": \"Keystone Admin VIP endpoint\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\", \"KeystoneAdminApiNetwork\"]}]}}, \"EndpointMap\": {\"description\": \"Mapping of the resources with the needed info for their endpoints.\\nThis includes the protocol used, the IP, port and also a full\\nrepresentation of the URI.\\n\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}}, \"HostsEntry\": {\"description\": \"The content that should be appended to your /etc/hosts if you want to get\\nhostname-based access to the deployed nodes (useful for testing without\\nsetting up a DNS).\\n\", \"value\": {\"list_concat_unique\": [{\"get_attr\": [\"HostsEntryValue\", \"value\"]}, {\"get_attr\": [\"VipHosts\", \"value\"]}]}}, \"EnabledServices\": {\"description\": \"The services enabled on each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}, \"RoleData\": {\"description\": \"The configuration data associated with each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}}, \"RoleConfig\": {\"description\": \"The configuration workflows associated with each role\", \"value\": {\"get_attr\": [\"AllNodesDeploySteps\", \"RoleConfig\"]}}, \"RoleNetIpMap\": {\"description\": \"Mapping of each network to a list of IPs for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerIpListMap\", \"net_ip_map\"]}, \"CellController\": {\"get_attr\": [\"CellControllerIpListMap\", \"net_ip_map\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeIpListMap\", \"net_ip_map\"]}, \"Compute\": {\"get_attr\": [\"ComputeIpListMap\", \"net_ip_map\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageIpListMap\", \"net_ip_map\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageIpListMap\", \"net_ip_map\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageIpListMap\", \"net_ip_map\"]}, \"Networker\": {\"get_attr\": [\"NetworkerIpListMap\", \"net_ip_map\"]}}}, \"RoleGroupVars\": {\"description\": \"Mapping of roles to ansible group_vars to be applied config in those roles\", \"value\": {\"Controller\": {\"map_merge\": [{\"get_attr\": [\"ControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"ControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ControllerExtraGroupVars\"}]}, \"CellController\": {\"map_merge\": [{\"get_attr\": [\"CellControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerExtraGroupVars\"}]}, \"CellControllerCompute\": {\"map_merge\": [{\"get_attr\": [\"CellControllerComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerComputeExtraGroupVars\"}]}, \"Compute\": {\"map_merge\": [{\"get_attr\": [\"ComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"ComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ComputeExtraGroupVars\"}]}, \"BlockStorage\": {\"map_merge\": [{\"get_attr\": [\"BlockStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"BlockStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"BlockStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"BlockStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"BlockStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"BlockStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"BlockStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"BlockStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"BlockStorageExtraGroupVars\"}]}, \"ObjectStorage\": {\"map_merge\": [{\"get_attr\": [\"ObjectStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"ObjectStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ObjectStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ObjectStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ObjectStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ObjectStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ObjectStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ObjectStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ObjectStorageExtraGroupVars\"}]}, \"CephStorage\": {\"map_merge\": [{\"get_attr\": [\"CephStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"CephStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CephStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CephStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CephStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CephStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CephStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CephStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CephStorageExtraGroupVars\"}]}, \"Networker\": {\"map_merge\": [{\"get_attr\": [\"NetworkerGroupVars\", \"value\"]}, {\"get_attr\": [\"NetworkerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"NetworkerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"NetworkerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"NetworkerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"NetworkerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"NetworkerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"NetworkerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"NetworkerExtraGroupVars\"}]}}}, \"RoleNetHostnameMap\": {\"description\": \"Mapping of each network to a list of hostnames for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"RoleTags\": {\"description\": \"Tags for each role, as defined in roles_data.yaml\", \"value\": {\"Controller\": [\"primary\", \"controller\", \"external_bridge\"], \"CellController\": [\"primary\", \"controller\"], \"CellControllerCompute\": [\"primary\", \"controller\", \"external_bridge\"], \"Compute\": [\"compute\", \"external_bridge\"], \"BlockStorage\": [\"storage\"], \"ObjectStorage\": [\"storage\"], \"CephStorage\": [\"ceph\", \"storage\"], \"Networker\": [\"external_bridge\"]}}, \"VipMap\": {\"description\": \"Mapping of each network to VIP addresses. Also includes the Redis and OVN DBs VIPs.\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}}, \"ServerIdData\": {\"description\": \"Mapping of each role to a list of nova server IDs and the bootstrap ID\", \"value\": {\"get_attr\": [\"ServerIdMap\", \"value\"]}}, \"BlacklistedHostnames\": {\"description\": \"List of blacklisted hostnames\", \"value\": {\"get_attr\": [\"BlacklistedHostnames\", \"value\"]}}, \"BlacklistedIpAddresses\": {\"description\": \"List of blacklisted ctlplane IP addresses\", \"value\": {\"get_attr\": [\"BlacklistedIpAddresses\", \"value\"]}}, \"GlobalConfig\": {\"description\": \"The global_config (hieradata).\", \"value\": {\"get_attr\": [\"GlobalConfig\", \"value\"]}}, \"RoleNetworkConfigMap\": {\"description\": \"Mapping of roles to network config\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkConfig\", \"config\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkConfig\", \"config\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkConfig\", \"config\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkConfig\", \"config\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkConfig\", \"config\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkConfig\", \"config\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkConfig\", \"config\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkConfig\", \"config\"]}}}, \"AnsibleHostVarsMap\": {\"description\": \"Map of Ansible Host variables per role\", \"value\": {\"get_attr\": [\"AnsibleHostVars\", \"value\"]}}, \"TripleoHeatTemplatesJinja2RenderingDataSources\": {\"description\": \"The role_data and the network_data used when rendering the THT Jinja2 templates\", \"value\": {\"roles_data\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"networks_data\": [{\"name\": \"Storage\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage\", \"dns_domain\": \"storage.ooo.test.\", \"service_net_map_replace\": \"storage\", \"subnets\": {\"storage_subnet\": {\"vlan\": 21, \"ip_subnet\": \"172.18.0.0/24\", \"allocation_pools\": [{\"start\": \"172.18.0.120\", \"end\": \"172.18.0.250\"}]}}, \"idx\": 0}, {\"name\": \"StorageMgmt\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage_mgmt\", \"dns_domain\": \"storagemgmt.ooo.test.\", \"service_net_map_replace\": \"storage_mgmt\", \"subnets\": {\"storage_mgmt_subnet\": {\"vlan\": 23, \"ip_subnet\": \"172.20.0.0/24\", \"allocation_pools\": [{\"start\": \"172.20.0.120\", \"end\": \"172.20.0.250\"}]}}, \"idx\": 1}, {\"name\": \"InternalApi\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"internal_api\", \"dns_domain\": \"internal-api.ooo.test.\", \"service_net_map_replace\": \"internal_api\", \"subnets\": {\"internal_api_subnet\": {\"vlan\": 20, \"ip_subnet\": \"172.17.0.0/24\", \"allocation_pools\": [{\"start\": \"172.17.0.120\", \"end\": \"172.17.0.250\"}]}}, \"idx\": 2}, {\"name\": \"Tenant\", \"mtu\": 1500, \"vip\": false, \"name_lower\": \"tenant\", \"dns_domain\": \"tenant.ooo.test.\", \"service_net_map_replace\": \"tenant\", \"subnets\": {\"tenant_subnet\": {\"vlan\": 22, \"ip_subnet\": \"172.19.0.0/24\", \"allocation_pools\": [{\"start\": \"172.19.0.120\", \"end\": \"172.19.0.250\"}]}}, \"idx\": 3}, {\"name\": \"External\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"external\", \"dns_domain\": \"external.ooo.test.\", \"service_net_map_replace\": \"external\", \"subnets\": {\"external_subnet\": {\"vlan\": 44, \"ip_subnet\": \"172.21.0.0/24\", \"allocation_pools\": [{\"start\": \"172.21.0.120\", \"end\": \"172.21.0.250\"}]}}, \"idx\": 4}]}}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"value\": {\"get_param\": \"AdminPassword\"}}, \"KeystoneRegion\": {\"description\": \"Keystone region for endpoint\", \"value\": {\"get_param\": \"KeystoneRegion\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(2,'2026-06-13 07:56:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(3,'2026-06-13 07:56:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mapping of service_name_network -> network name\\n\", \"parameters\": {\"ServiceNetMap\": {\"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults. Note that the key in this map must match the service_name in the service template, e.g if the service_name is heat_api the key must be either heat_api_network, or optionally HeatApiNetwork (which will be internally converted to transform captalization to underscores).\", \"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"VipSubnetMap\": {\"description\": \"Map of (network_name or service_name) -> subnet_name that defines which subnet to host the VIP. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\", \"default\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMapDeprecatedMapping\": {\"default\": {\"RabbitMqNetwork\": \"RabbitmqNetwork\", \"CephPublicNetwork\": \"CephMonNetwork\", \"SwiftMgmtNetwork\": \"SwiftStorageNetwork\"}, \"description\": \"Mapping older deprecated service names, intended for internal use only, this will be removed in future.\", \"type\": \"json\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"ServiceNetMapDeprecatedMapping\"]}], \"resources\": {\"ServiceNetMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"map_replace\": [{\"get_param\": \"ServiceNetMap\"}, {\"values\": {\"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}, \"keys\": {\"get_param\": \"ServiceNetMapDeprecatedMapping\"}}]}, {\"NovaVncProxyNetwork\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}]}}}}, \"outputs\": {\"service_net_map\": {\"value\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}, \"service_net_map_lower\": {\"value\": {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}}}}, \"vip_subnet_map\": {\"value\": {\"map_replace\": [{\"get_param\": \"VipSubnetMap\"}, {\"values\": {\"ctlplane-subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(4,'2026-06-13 07:56:43',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"NtpService\": {\"default\": \"chrony\", \"description\": \"NTP Service to use for the timesync bootstrap.\", \"type\": \"string\"}}, \"description\": \"Uses cloud-init to bootstrap timesync configuration to ensure it is done as soon as possible. We do additional and more complex configurations as part of the deployment itself.\\n\", \"conditions\": {\"use_chrony\": {\"equals\": [{\"get_param\": \"NtpService\"}, \"chrony\"]}}, \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"timesync_chrony\"}}, {\"config\": {\"get_resource\": \"timesync_sync\"}}]}}, \"timesync_chrony\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nif [ \\\"$service\\\" != \\\"chrony\\\" ]; then\\n  exit 0\\nfi\\nset -x\\nSERVERS=\\\"$ntp_servers\\\"\\nPOOLS=\\\"$ntp_pools\\\"\\nsystemctl is-active --quiet chronyd || systemctl start chronyd\\nfor server in $SERVERS; do\\n  chronyc add server \\\"${server}\\\" iburst\\ndone\\nfor pool in $POOLS; do\\n  chronyc add server \\\"${pool}\\\" iburst\\ndone\\nchronyc sources\\n\", \"params\": {\"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}, \"$ntp_pools\": {\"list_join\": [\" \", {\"get_param\": \"NtpPool\"}]}, \"$service\": {\"get_param\": \"NtpService\"}}}}}}, \"timesync_sync\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nset -x\\nif [ \\\"$service\\\" = \\\"chrony\\\" ]; then\\n    if command -v chronyc >/dev/null; then\\n        chronyc makestep\\n        chronyc waitsync 30\\n    else\\n        echo \\\"No chronyc available, skipping sync\\\"\\n    fi\\nelif [ \\\"$service\\\" = \\\"ntp\\\" ]; then\\n    if command -v ntpdate >/dev/null; then\\n        ntpdate -u $ntp_servers\\n    else\\n        echo \\\"No ntpdate available, skipping sync\\\"\\n    fi\\nfi\\nhwclock --systohc --utc\\n\", \"params\": {\"$service\": {\"get_param\": \"NtpService\"}, \"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}}}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(5,'2026-06-13 07:56:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(6,'2026-06-13 07:56:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Control Plane network.\\n\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ControlPlaneVipData\": {\"description\": \"Control Plane Virtual IP data\\n\", \"default\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"type\": \"json\"}}, \"outputs\": {\"name\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"name\"]}}, \"fixed_ips\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"fixed_ips\"]}}, \"network\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"network\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"subnets\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"control_virtual_ip\", \"dns_name\": \"overcloud\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_vip_net=ctlplane,tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(7,'2026-06-13 07:56:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(8,'2026-06-13 07:56:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Create networks to split out Overcloud traffic\", \"parameters\": {\"DeployedNetworkEnvironment\": {\"type\": \"json\", \"description\": \"Deployed network environment\", \"default\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}}, \"CtlplaneNetworkCidrs\": {\"type\": \"json\", \"description\": \"Cidrs for the ctlplane network.\"}, \"CtlplaneNetworkAttributes\": {\"type\": \"json\", \"default\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"description\": \"A map containing attributes of the undercloud ctlplane network and subnets. NOTE: The value for this parameter is automatically populated in the plan environment by tripleoclient.\\n\"}}, \"resources\": {\"NetworkExtraConfig\": {\"type\": \"OS::TripleO::Network::ExtraConfig\"}, \"NetworkAttributesMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkAttributes\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_attributes_map\"]}]}}}, \"NetworkCidrMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkCidrs\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_cidr_map\"]}]}}}, \"NetworkIpVersionMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"yaql\": {\"expression\": \"$.data.items().first().last().ip_version\", \"data\": {\"get_param\": [\"CtlplaneNetworkAttributes\", \"subnets\"]}}}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_ip_version_map\"]}]}}}}, \"outputs\": {\"net_cidr_map\": {\"value\": {\"get_attr\": [\"NetworkCidrMap\", \"value\"]}}, \"net_ip_version_map\": {\"value\": {\"get_attr\": [\"NetworkIpVersionMap\", \"value\"]}}, \"net_attributes_map\": {\"value\": {\"get_attr\": [\"NetworkAttributesMap\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"CtlplaneNetworkCidrs\": \"[\\\"192.168.122.0/24\\\"]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (9,'2026-06-13 07:56:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(10,'2026-06-13 07:56:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(11,'2026-06-13 07:56:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(12,'2026-06-13 07:56:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"internal_api_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(13,'2026-06-13 07:56:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(14,'2026-06-13 07:56:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(15,'2026-06-13 07:56:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(16,'2026-06-13 07:56:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the External network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"External network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"external_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"external_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(17,'2026-06-13 07:56:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(18,'2026-06-13 07:56:52',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIp\": {\"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"StorageIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageIpSubnet\": {\"description\": \"IP address/subnet on the storage network\", \"default\": \"\", \"type\": \"string\"}, \"StorageIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpSubnet\": {\"description\": \"IP address/subnet on the storage_mgmt network\", \"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIp\": {\"default\": \"\", \"type\": \"string\"}, \"InternalApiIpSubnet\": {\"description\": \"IP address/subnet on the internal_api network\", \"default\": \"\", \"type\": \"string\"}, \"InternalApiIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIp\": {\"default\": \"\", \"type\": \"string\"}, \"TenantIpSubnet\": {\"description\": \"IP address/subnet on the tenant network\", \"default\": \"\", \"type\": \"string\"}, \"TenantIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIp\": {\"default\": \"\", \"type\": \"string\"}, \"ExternalIpSubnet\": {\"description\": \"IP address/subnet on the external network\", \"default\": \"\", \"type\": \"string\"}, \"ExternalIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"resources\": {\"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"ctlplane\": {\"get_param\": \"ControlPlaneIp\"}, \"ctlplane_subnet\": {\"list_join\": [\"\", [{\"get_param\": \"ControlPlaneIp\"}, \"/\", {\"get_param\": \"ControlPlaneSubnetCidr\"}]]}, \"ctlplane_uri\": {\"str_replace\": {\"template\": {\"make_url\": {\"host\": {\"get_param\": \"ControlPlaneIp\"}}}, \"params\": {\"//\": \"\"}}}, \"storage\": {\"get_param\": \"StorageIp\"}, \"storage_subnet\": {\"get_param\": \"StorageIpSubnet\"}, \"storage_uri\": {\"get_param\": \"StorageIpUri\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIp\"}, \"storage_mgmt_subnet\": {\"get_param\": \"StorageMgmtIpSubnet\"}, \"storage_mgmt_uri\": {\"get_param\": \"StorageMgmtIpUri\"}, \"internal_api\": {\"get_param\": \"InternalApiIp\"}, \"internal_api_subnet\": {\"get_param\": \"InternalApiIpSubnet\"}, \"internal_api_uri\": {\"get_param\": \"InternalApiIpUri\"}, \"tenant\": {\"get_param\": \"TenantIp\"}, \"tenant_subnet\": {\"get_param\": \"TenantIpSubnet\"}, \"tenant_uri\": {\"get_param\": \"TenantIpUri\"}, \"external\": {\"get_param\": \"ExternalIp\"}, \"external_subnet\": {\"get_param\": \"ExternalIpSubnet\"}, \"external_uri\": {\"get_param\": \"ExternalIpUri\"}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"storage_mgmt_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"storage_mgmt_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"internal_api_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"internal_api_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"tenant_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"tenant_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"external\": {\"get_param\": \"ExternalNetName\"}, \"external_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}, \"external_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned IPs for a specific machine.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIp\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"StorageIp\": \"172.18.0.245\", \"StorageIpUri\": \"172.18.0.245\", \"StorageMgmtIp\": \"172.20.0.237\", \"StorageMgmtIpUri\": \"172.20.0.237\", \"InternalApiIp\": \"172.17.0.182\", \"InternalApiIpUri\": \"172.17.0.182\", \"ExternalIp\": \"172.21.0.227\", \"ExternalIpUri\": \"172.21.0.227\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(19,'2026-06-13 07:56:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (20,'2026-06-13 07:56:53',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"node_admin_username\": {\"type\": \"string\", \"default\": \"heat-admin\"}, \"node_admin_extra_ssh_keys\": {\"type\": \"comma_delimited_list\", \"default\": []}}, \"description\": \"Uses cloud-init to create an additional user with a known name, in addition to the distro-default user created by the cloud-init default.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"user_config\"}}]}}, \"user_config\": {\"type\": \"OS::Heat::CloudConfig\", \"properties\": {\"cloud_config\": {\"user\": {\"get_param\": \"node_admin_username\"}, \"ssh_authorized_keys\": {\"get_param\": \"node_admin_extra_ssh_keys\"}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(21,'2026-06-13 07:56:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"A map of OpenStack endpoints. Since the endpoints are URLs, we need to have brackets around IPv6 IP addresses. The inputs to these parameters come from net_ip_uri_map, which will include these brackets in IPv6 addresses.\", \"parameters\": {\"NetIpMap\": {\"type\": \"json\", \"default\": {}, \"description\": \"The Net IP map\"}, \"ServiceNetMap\": {\"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"The Service Net map\"}, \"EndpointMap\": {\"type\": \"json\", \"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}, \"CloudEndpoints\": {\"type\": \"json\", \"default\": {}, \"description\": \"A map containing the DNS names for the different endpoints (external, internal_api, etc.)\"}}, \"outputs\": {\"endpoint_map\": {\"value\": {\"AodhAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}}, \"AodhInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}}, \"AodhPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}}, \"BarbicanAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}}, \"BarbicanInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}}, \"BarbicanPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}}, \"CephDashboardInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}}, \"CephGrafanaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}}, \"CephRgwAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}}}}, \"CephRgwInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}}}}, \"CephRgwPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}}}}, \"CinderAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV2Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV2Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV2Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"DesignateAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}}}}, \"DesignateInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}}}}, \"DesignatePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}}}}, \"DockerRegistryInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}}, \"GaneshaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}}, \"GlanceAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}}, \"GlanceInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, \"GlancePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}}, \"GnocchiAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}}, \"GnocchiInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}}, \"GnocchiPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}}, \"HeatAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}}}}, \"HeatInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}}}}, \"HeatPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}}}}, \"HeatCfnAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}}}}, \"HeatCfnInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}}}}, \"HeatCfnPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}}, \"HorizonPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"path\": \"/dashboard\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}}}}, \"IronicAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}}}}, \"IronicInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}}}}, \"IronicPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}}}}, \"IronicInspectorAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}}, \"IronicInspectorInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}}, \"IronicInspectorPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}}, \"KeystoneAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystonePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"KeystoneV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystoneV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"ManilaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"ManilaV1Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaV1Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaV1Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"MetricsQdrPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}}, \"MysqlInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}}, \"NeutronAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}}, \"NeutronInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}}, \"NeutronPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}}, \"NovaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}}}}, \"NovaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}}}}, \"NovaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}}}}, \"NovaMetadataInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}}, \"NovaVNCProxyAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}}, \"NovaVNCProxyInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}}, \"NovaVNCProxyPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}}, \"NovajoinAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}}}}, \"NovajoinInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}}}}, \"NovajoinPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}}}}, \"OctaviaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}}, \"OctaviaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}}, \"OctaviaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}}, \"PlacementAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}}}}, \"PlacementInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}}}}, \"PlacementPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}}}}, \"SwiftAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}, \"SwiftS3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftS3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftS3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NetIpMap\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"CloudEndpoints\": {\"ctlplane\": \"overcloud.ctlplane.ooo.test\", \"storage\": \"overcloud.storage.ooo.test\", \"storage_mgmt\": \"overcloud.storagemgmt.ooo.test\", \"internal_api\": \"overcloud.internalapi.ooo.test\", \"external\": \"overcloud.ooo.test\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(22,'2026-06-13 07:56:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(23,'2026-06-13 07:56:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::Collectd,OS::TripleO::Services::ComputeCeilometerAgent,OS::TripleO::Services::CeilometerAgentIpmi,OS::TripleO::Services::IpaClient,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NovaCompute,OS::TripleO::Services::NovaLibvirt,OS::TripleO::Services::NovaLibvirtGuests,OS::TripleO::Services::NovaMigrationTarget,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::Podman,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned,OS::TripleO::Services::OVNController,OS::TripleO::Services::OVNMetadataAgent\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(24,'2026-06-13 07:56:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ObjectStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(25,'2026-06-13 07:56:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::NetworkerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (26,'2026-06-13 07:56:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(27,'2026-06-13 07:56:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CephStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(28,'2026-06-13 07:56:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::CeilometerAgentCentral,OS::TripleO::Services::CeilometerAgentNotification,OS::TripleO::Services::CinderApi,OS::TripleO::Services::CinderBackup,OS::TripleO::Services::CinderScheduler,OS::TripleO::Services::CinderVolume,OS::TripleO::Services::Clustercheck,OS::TripleO::Services::Collectd,OS::TripleO::Services::ContainerImagePrepare,OS::TripleO::Services::GlanceApi,OS::TripleO::Services::GlanceApiInternal,OS::TripleO::Services::HAproxy,OS::TripleO::Services::HeatApi,OS::TripleO::Services::HeatApiCloudwatch,OS::TripleO::Services::HeatApiCfn,OS::TripleO::Services::HeatEngine,OS::TripleO::Services::Horizon,OS::TripleO::Services::IpaClient,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::Keystone,OS::TripleO::Services::ManilaApi,OS::TripleO::Services::ManilaBackendCephFs,OS::TripleO::Services::ManilaScheduler,OS::TripleO::Services::ManilaShare,OS::TripleO::Services::Memcached,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQL,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NeutronApi,OS::TripleO::Services::NeutronCorePlugin,OS::TripleO::Services::NovaApi,OS::TripleO::Services::NovaConductor,OS::TripleO::Services::NovaMetadata,OS::TripleO::Services::NovaScheduler,OS::TripleO::Services::NovaVncProxy,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::OVNDBs,OS::TripleO::Services::OVNController,OS::TripleO::Services::Pacemaker,OS::TripleO::Services::PlacementApi,OS::TripleO::Services::OsloMessagingRpc,OS::TripleO::Services::OsloMessagingNotify,OS::TripleO::Services::Podman,OS::TripleO::Services::Redis,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::SwiftProxy,OS::TripleO::Services::SwiftRingBuilder,OS::TripleO::Services::SwiftStorage,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(29,'2026-06-13 07:56:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::BlockStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(30,'2026-06-13 07:56:56',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(31,'2026-06-13 07:56:56',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(32,'2026-06-13 07:56:56',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(33,'2026-06-13 07:56:57',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (34,'2026-06-13 07:56:56',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::CeilometerAgentCentral\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::CeilometerAgentNotification\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::CinderApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::CinderBackup\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::CinderScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::CinderVolume\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::Clustercheck\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::ContainerImagePrepare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::GlanceApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::GlanceApiInternal\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::HAproxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::HeatApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::HeatApiCloudwatch\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::HeatApiCfn\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::HeatEngine\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Horizon\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::IpaClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::Keystone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::ManilaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::ManilaBackendCephFs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::ManilaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"21\"]}, \"26\": {\"type\": \"OS::TripleO::Services::ManilaShare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"22\"]}, \"27\": {\"type\": \"OS::TripleO::Services::Memcached\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"23\"]}, \"28\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"24\"]}, \"29\": {\"type\": \"OS::TripleO::Services::MySQL\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"25\"]}, \"30\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"26\"]}, \"31\": {\"type\": \"OS::TripleO::Services::NeutronApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"27\"]}, \"32\": {\"type\": \"OS::TripleO::Services::NeutronCorePlugin\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"28\"]}, \"33\": {\"type\": \"OS::TripleO::Services::NovaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"29\"]}, \"34\": {\"type\": \"OS::TripleO::Services::NovaConductor\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"30\"]}, \"35\": {\"type\": \"OS::TripleO::Services::NovaMetadata\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"31\"]}, \"36\": {\"type\": \"OS::TripleO::Services::NovaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"32\"]}, \"37\": {\"type\": \"OS::TripleO::Services::NovaVncProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"33\"]}, \"38\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"34\"]}, \"39\": {\"type\": \"OS::TripleO::Services::OVNDBs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"35\"]}, \"40\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"36\"]}, \"41\": {\"type\": \"OS::TripleO::Services::Pacemaker\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"37\"]}, \"42\": {\"type\": \"OS::TripleO::Services::PlacementApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"38\"]}, \"43\": {\"type\": \"OS::TripleO::Services::OsloMessagingRpc\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"39\"]}, \"44\": {\"type\": \"OS::TripleO::Services::OsloMessagingNotify\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"40\"]}, \"45\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"41\"]}, \"46\": {\"type\": \"OS::TripleO::Services::Redis\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"42\"]}, \"47\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"43\"]}, \"48\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"44\"]}, \"49\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"45\"]}, \"50\": {\"type\": \"OS::TripleO::Services::SwiftProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"46\"]}, \"51\": {\"type\": \"OS::TripleO::Services::SwiftRingBuilder\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"47\"]}, \"52\": {\"type\": \"OS::TripleO::Services::SwiftStorage\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"48\"]}, \"53\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"49\"]}, \"54\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"50\"]}, \"55\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"51\"]}, \"56\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"52\"]}, \"57\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"53\"]}}, \"outputs\": {\"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"57\", \"role_data\", \"docker_config\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"57\", \"role_data\", \"service_names\"]}]}, \"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"26\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"27\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"28\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"29\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"30\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"31\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"32\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"33\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"34\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"35\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"36\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"37\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"38\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"39\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"40\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"41\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"42\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"43\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"44\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"45\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"46\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"47\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"48\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"49\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"50\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"51\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"52\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"53\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"54\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"55\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"56\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"57\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"26\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"27\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"28\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"29\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"30\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"31\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"32\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"33\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"34\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"35\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"36\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"37\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"38\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"39\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"40\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"41\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"42\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"43\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"44\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"45\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"46\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"47\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"48\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"49\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"50\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"51\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"52\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"53\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"54\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"55\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"56\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"57\", \"role_data\", \"config_settings\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"57\", \"role_data\", \"service_name\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}, {\"get_attr\": [\"26\", \"role_data\"]}, {\"get_attr\": [\"27\", \"role_data\"]}, {\"get_attr\": [\"28\", \"role_data\"]}, {\"get_attr\": [\"29\", \"role_data\"]}, {\"get_attr\": [\"30\", \"role_data\"]}, {\"get_attr\": [\"31\", \"role_data\"]}, {\"get_attr\": [\"32\", \"role_data\"]}, {\"get_attr\": [\"33\", \"role_data\"]}, {\"get_attr\": [\"34\", \"role_data\"]}, {\"get_attr\": [\"35\", \"role_data\"]}, {\"get_attr\": [\"36\", \"role_data\"]}, {\"get_attr\": [\"37\", \"role_data\"]}, {\"get_attr\": [\"38\", \"role_data\"]}, {\"get_attr\": [\"39\", \"role_data\"]}, {\"get_attr\": [\"40\", \"role_data\"]}, {\"get_attr\": [\"41\", \"role_data\"]}, {\"get_attr\": [\"42\", \"role_data\"]}, {\"get_attr\": [\"43\", \"role_data\"]}, {\"get_attr\": [\"44\", \"role_data\"]}, {\"get_attr\": [\"45\", \"role_data\"]}, {\"get_attr\": [\"46\", \"role_data\"]}, {\"get_attr\": [\"47\", \"role_data\"]}, {\"get_attr\": [\"48\", \"role_data\"]}, {\"get_attr\": [\"49\", \"role_data\"]}, {\"get_attr\": [\"50\", \"role_data\"]}, {\"get_attr\": [\"51\", \"role_data\"]}, {\"get_attr\": [\"52\", \"role_data\"]}, {\"get_attr\": [\"53\", \"role_data\"]}, {\"get_attr\": [\"54\", \"role_data\"]}, {\"get_attr\": [\"55\", \"role_data\"]}, {\"get_attr\": [\"56\", \"role_data\"]}, {\"get_attr\": [\"57\", \"role_data\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"57\", \"role_data\", \"step_config\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (35,'2026-06-13 07:56:57',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(36,'2026-06-13 07:56:57',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, docker_config\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(37,'2026-06-13 07:56:57',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::ComputeCeilometerAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::CeilometerAgentIpmi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::IpaClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::NovaCompute\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::NovaLibvirt\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::NovaLibvirtGuests\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::NovaMigrationTarget\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::OVNMetadataAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"21\"]}}, \"outputs\": {\"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}]}, \"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (38,'2026-06-13 07:56:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CellController server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(39,'2026-06-13 07:56:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a ObjectStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(40,'2026-06-13 07:56:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a BlockStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(41,'2026-06-13 07:56:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CellControllerCompute server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(42,'2026-06-13 07:57:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(43,'2026-06-13 07:57:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a Networker server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"internal_api\", \"tenant\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(44,'2026-06-13 07:57:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CephStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(45,'2026-06-13 07:57:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(46,'2026-06-13 07:57:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Compute service\\n\", \"parameters\": {\"ContainerCeilometerComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerCompute\": {\"default\": \"overcloud-ceilometer-agent-compute\", \"type\": \"string\"}, \"InstanceDiscoveryMethod\": {\"default\": \"libvirt_metadata\", \"description\": \"Method used to discover instances running on compute node\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"naive\", \"libvirt_metadata\", \"workload_partitioning\"]}]}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"0plrFXAbintMcjJGm66MGfoQJ\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerComputeImage\": \"ContainerCeilometerComputeImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerComputeImage\": {\"get_param\": \"ContainerCeilometerComputeImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Compute role.\", \"value\": {\"service_name\": \"ceilometer_agent_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::polling::instance_discovery_method\": {\"get_param\": \"InstanceDiscoveryMethod\"}}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"compute_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"ceilometer_agent_compute\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerComputeImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_libvirt.target\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(47,'2026-06-13 07:57:02',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"external_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"tenant_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (48,'2026-06-13 07:57:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(49,'2026-06-13 07:57:02',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"ansible_host_vars_map\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(50,'2026-06-13 07:57:02',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"external_ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(51,'2026-06-13 07:57:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Add services and subhosts to IPA server\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"PythonInterpreter\": {\"type\": \"string\", \"description\": \"The python interpreter to use for python and ansible actions\", \"default\": \"$(command -v python3 || command -v python)\"}, \"IdMDomain\": {\"default\": \"ooo.test\", \"description\": \"IDM domain to register IDM client. Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"string\"}, \"IdMServer\": {\"default\": \"ipa.ooo.test\", \"description\": \"FQDN for the FreeIPA server.  If you set this value, IdMDomain also has to be provided.  Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"comma_delimited_list\"}, \"IdMNovaKeytab\": {\"default\": \"FILE:/etc/novajoin/krb5.keytab\", \"description\": \"keytab for the nova/[host fqdn] user on the FreeIPA server.\", \"type\": \"string\"}, \"IdMNovaCredentialCache\": {\"default\": \"/etc/novajoin/krb5.cache\", \"description\": \"credential cache for nova/[host fqdn] user\", \"type\": \"string\"}, \"MakeHomeDir\": {\"type\": \"boolean\", \"description\": \"Configure PAM to create a users home directory if it does not exist.\", \"default\": false}, \"IdMNoNtpSetup\": {\"default\": false, \"description\": \"Set to true to add --no-ntp to the IDM client install call. This will cause IDM client install not to set up NTP.\", \"type\": \"boolean\"}, \"IdMEnrollBaseServer\": {\"default\": true, \"description\": \"Set to true to enroll the base server (computes, controllers)\", \"type\": \"boolean\"}, \"IdMInstallClientPackages\": {\"default\": false, \"description\": \"Set to True to have ansible-freeipa install ipa client packages on the overcloud node.\", \"type\": \"boolean\"}, \"IdMModifyDNS\": {\"default\": true, \"description\": \"Set to false to disable DNS records manipulation in the FreeIPA server.\", \"type\": \"boolean\"}, \"IdMZoneSplitIPv4\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}, \"IdMZoneSplitIPv6\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}}, \"conditions\": {\"idm_server_provided\": {\"not\": {\"equals\": [{\"get_param\": \"IdMServer\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ipaservice service\", \"value\": {\"service_name\": \"ipaservice\", \"upgrade_tasks\": [], \"step_config\": \"\", \"ipa_registration_tasks\": [{\"name\": \"Get undercloud FQDN\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"set_fact\": {\"undercloud_fqdn\": \"{{ ansible_facts[\'fqdn\'] }}\"}}, {\"include_role\": {\"name\": \"tripleo_ipa_registration\", \"apply\": {\"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ undercloud_fqdn }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}}, \"vars\": {\"tripleo_ipa_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}, \"tripleo_ipa_delegate_server\": \"{{ inventory_hostname }}\", \"tripleo_ipa_base_server_fqdn\": \"{{ fqdn_canonical }}\", \"tripleo_ipa_server_metadata\": \"{{ service_metadata_settings | to_json }}\"}, \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}, {\"name\": \"Enroll the node as an ipa client\", \"vars\": {\"ipaclient_install_packages\": {\"get_param\": \"IdMInstallClientPackages\"}, \"idm_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}}, \"block\": [{\"name\": \"check if default.conf exists\", \"stat\": {\"path\": \"/etc/ipa/default.conf\"}, \"register\": \"ipa_conf_exists\"}, {\"name\": \"install openssl-perl\", \"become\": true, \"package\": {\"name\": \"openssl-perl\", \"state\": \"present\"}, \"when\": [\"ipaclient_install_packages|bool\"]}, {\"name\": \"register as an ipa client\", \"include_role\": {\"name\": \"ipaclient\", \"apply\": {\"become\": true}}, \"vars\": {\"map_merge\": [{\"state\": \"present\", \"ipaclient_otp\": \"{{ ipa_host_otp }}\", \"ipaclient_mkhomedir\": {\"get_param\": \"MakeHomeDir\"}, \"ipaclient_no_ntp\": {\"get_param\": \"IdMNoNtpSetup\"}, \"ipaclient_force\": true, \"ipaclient_hostname\": \"{{ fqdn_canonical }}\", \"ansible_fqdn\": \"{{ ipaclient_hostname }}\", \"ipaclients\": [\"ipaclient_hostname\"], \"ansible_distribution\": \"{{ ansible_facts[\'distribution\'] }}\", \"ansible_distribution_major_version\": \"{{ ansible_facts[\'distribution_major_version\'] }}\", \"ansible_distribution_release\": \"{{ ansible_facts[\'distribution_release\'] }}\", \"ansible_distribution_version\": \"{{ ansible_facts[\'distribution_version\'] }}\", \"ansible_os_family\": \"{{ ansible_facts[\'os_family\'] }}\"}, {\"if\": [\"idm_server_provided\", {\"ipaclient_servers\": {\"get_param\": \"IdMServer\"}, \"ipaclient_domain\": {\"get_param\": \"IdMDomain\"}}]}]}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"restart certmonger service\", \"become\": true, \"systemd\": {\"state\": \"restarted\", \"daemon_reload\": true, \"name\": \"certmonger.service\"}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"set discovered ipa realm\", \"set_fact\": {\"idm_realm\": {\"str_replace\": {\"template\": \"{{ lookup(\'ini\', \'realm default=DEFAULT section=global file=/etc/ipa/default.conf\')}}\", \"params\": {\"DEFAULT\": {\"yaql\": {\"expression\": \"$.data.toUpper()\", \"data\": {\"get_param\": \"IdMDomain\"}}}}}}}}], \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}], \"external_deploy_tasks\": [{\"name\": \"add the DNS entries into IPA in step 1\", \"when\": \"step|int == 1\", \"block\": [{\"include_role\": {\"name\": \"tripleo_ipa_dns\"}, \"vars\": {\"tripleo_ipa_ptr_zone_split_ipv4\": {\"get_param\": \"IdMZoneSplitIPv4\"}, \"tripleo_ipa_ptr_zone_split_ipv6\": {\"get_param\": \"IdMZoneSplitIPv6\"}}, \"when\": {\"get_param\": \"IdMModifyDNS\"}}], \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ ansible_facts[\'fqdn\'] }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}], \"scale_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"down\", \"block\": [{\"name\": \"unregister node from ipa server\", \"import_role\": {\"name\": \"tripleo_ipa_cleanup\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"vars\": {\"tripleo_ipa_keytab\": {\"get_param\": \"IdMNovaKeytab\"}, \"tripleo_ipa_hosts_to_delete\": [\"{{ fqdn_canonical }}\"]}}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"check if ipa server has required permissions\", \"import_role\": {\"name\": \"tls_everywhere\", \"tasks_from\": \"ipa-server-check\"}, \"tags\": [\"opendev-validation\", \"opendev-validation-tls-everywhere\"]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(52,'2026-06-13 07:57:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"FKQdo7NuIE9RbMdjCuC9b8sG\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(53,'2026-06-13 07:57:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Notification service\\n\", \"parameters\": {\"ContainerCeilometerNotificationImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentNotificationLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.notification\", \"file\": \"/var/log/containers/ceilometer/agent-notification.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerNotification\": {\"default\": \"overcloud-ceilometer-agent-notification\", \"type\": \"string\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"CeilometerQdrPublishEvents\": {\"default\": false, \"description\": \"Whether to send events to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrPublishMetrics\": {\"default\": false, \"description\": \"Whether to send telemetry data to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrEventsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"event\"}, \"description\": \"Configuration for notifier publisher for events.\", \"type\": \"json\"}, \"CeilometerQdrMetricsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"metering\"}, \"description\": \"Configuration for notifier publisher for metrics.\", \"type\": \"json\"}, \"ManageEventPipeline\": {\"default\": true, \"description\": \"Whether to manage event_pipeline.yaml.\", \"type\": \"boolean\"}, \"EventPipelinePublishers\": {\"default\": [], \"description\": \"A list of publishers to put in event_pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManageEventPipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}, \"ManagePipeline\": {\"default\": false, \"description\": \"Whether to manage pipeline.yaml.\", \"type\": \"boolean\"}, \"PipelinePublishers\": {\"default\": [], \"description\": \"A list of publishers to put in pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManagePipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerNotificationImage\": \"ContainerCeilometerNotificationImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerNotificationImage\": {\"get_param\": \"ContainerCeilometerNotificationImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"conditions\": {\"ceilometer_qdr_publish\": {\"or\": [{\"get_param\": \"CeilometerQdrPublishEvents\"}, {\"get_param\": \"CeilometerQdrPublishMetrics\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Notification role.\", \"value\": {\"service_name\": \"ceilometer_agent_notification\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerNotification\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::notification::manage_event_pipeline\": {\"get_param\": \"ManageEventPipeline\"}, \"ceilometer::agent::notification::manage_pipeline\": {\"get_param\": \"ManagePipeline\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_enabled\": {\"get_param\": \"CeilometerQdrPublishMetrics\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_events_enabled\": {\"get_param\": \"CeilometerQdrPublishEvents\"}, \"tripleo::profile::base::ceilometer::agent::notification::pipeline_publishers\": {\"get_param\": \"PipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::event_pipeline_publishers\": {\"get_param\": \"EventPipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_params\": {\"get_param\": \"CeilometerQdrMetricsConfig\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_event_params\": {\"get_param\": \"CeilometerQdrEventsConfig\"}}, {\"if\": [\"ceilometer_qdr_publish\", {\"tripleo::profile::base::ceilometer::agent::notification::notifier_host_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_host_port\": {\"get_param\": \"MetricsQdrPort\"}}]}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_notification\": [{\"get_param\": \"CeilometerAgentNotificationLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::notification\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_notification.json\": {\"command\": \"/usr/bin/ceilometer-agent-notification --logfile /var/log/ceilometer/agent-notification.log\", \"config_files\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]]}}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_notification\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_notification.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent notification container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_notification\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_notification\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(54,'2026-06-13 07:57:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Iscsid service\\n\", \"parameters\": {\"ContainerIscsidImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"ContainerIscsidConfigImage\": {\"description\": \"The container image to use for the iscsid config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LVMFilterEnabled\": {\"default\": false, \"description\": \"Enables configuration of LVM2 with a filter so that devices not in use on the host or explicitly allowed are ignored by LVM2. Can be configured per-role. When disabled, the proposed lvm.conf file will be created regardless and left in /tmp/tripleo_lvmfilter.conf for debugging purposes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"LVMFilterAllowlist\": {\"default\": [], \"description\": \"A list of block devices which should be allowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role. Any block device in use at boot time will be automatically allowed.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LVMFilterDenylist\": {\"default\": [\".*\"], \"description\": \"A list of block devices which should be disallowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"IscsidCHAPAlgorithms\": {\"default\": \"SHA3-256,SHA256,SHA1,MD5\", \"description\": \"A comma separated list of algorithms to be used for the CHAP algorithm.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo_tripleo_lvmfilter_enabled\": \"LVMFilterEnabled\", \"tripleo_tripleo_lvmfilter_devices_allowlist\": \"LVMFilterAllowlist\", \"tripleo_tripleo_lvmfilter_devices_denylist\": \"LVMFilterDenylist\", \"ContainerIscsidImage\": \"ContainerIscsidImage\", \"ContainerIscsidConfigImage\": \"ContainerIscsidConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"LVMFilterEnabled\": {\"get_param\": \"LVMFilterEnabled\"}, \"LVMFilterAllowlist\": {\"get_param\": \"LVMFilterAllowlist\"}, \"LVMFilterDenylist\": {\"get_param\": \"LVMFilterDenylist\"}, \"ContainerIscsidImage\": {\"get_param\": \"ContainerIscsidImage\"}, \"ContainerIscsidConfigImage\": {\"get_param\": \"ContainerIscsidConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Iscsid role.\", \"value\": {\"service_name\": \"iscsid\", \"config_settings\": {\"tripleo::profile::base::iscsid::chap_algs\": {\"get_param\": \"IscsidCHAPAlgorithms\"}}, \"service_config_settings\": {}, \"deploy_steps_tasks\": [{\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}], \"ansible_group_vars\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidConfigImage\"]}, \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"iscsid\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}], \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(55,'2026-06-13 07:57:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (56,'2026-06-13 07:57:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(57,'2026-06-13 07:57:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(58,'2026-06-13 07:57:03',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"ExternalIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant,external\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(59,'2026-06-13 07:57:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(60,'2026-06-13 07:57:03',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"ExternalIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant,external\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(61,'2026-06-13 07:57:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"0plrFXAbintMcjJGm66MGfoQJ\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": false, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(62,'2026-06-13 07:57:03',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"ansible_host_vars_map\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(63,'2026-06-13 07:57:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"FKQdo7NuIE9RbMdjCuC9b8sG\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(64,'2026-06-13 07:57:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (65,'2026-06-13 07:57:04',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(66,'2026-06-13 07:57:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(67,'2026-06-13 07:57:04',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"ansible_host_vars_map\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(68,'2026-06-13 07:57:04',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(69,'2026-06-13 07:57:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Ipmi service\\n\", \"parameters\": {\"ContainerCeilometerIpmiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentIpmiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.ipmi\", \"file\": \"/var/log/containers/ceilometer/ipmi.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"0plrFXAbintMcjJGm66MGfoQJ\"}, \"MonitoringSubscriptionCeilometerIpmi\": {\"default\": \"overcloud-ceilometer-agent-ipmi\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CeilometerAgentCentralBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerIpmiImage\": \"ContainerCeilometerIpmiImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerIpmiImage\": {\"get_param\": \"ContainerCeilometerIpmiImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Ipmi role.\", \"value\": {\"service_name\": \"ceilometer_agent_ipmi\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerIpmi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"ipmi_namespace\": true}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_ipmi\": [{\"get_param\": \"CeilometerAgentIpmiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_ipmi\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(70,'2026-06-13 07:57:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(71,'2026-06-13 07:57:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"0plrFXAbintMcjJGm66MGfoQJ\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": false, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(72,'2026-06-13 07:57:05',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"tenant_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(73,'2026-06-13 07:57:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (74,'2026-06-13 07:57:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"FKQdo7NuIE9RbMdjCuC9b8sG\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(75,'2026-06-13 07:57:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Compute service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"DockerNovaComputeUlimit\": {\"default\": [\"nofile=131072\", \"memlock=67108864\"], \"description\": \"ulimit for Nova Compute Container\", \"type\": \"comma_delimited_list\"}, \"NovaComputeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.compute\", \"file\": \"/var/log/containers/nova/nova-compute.log\"}}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"NovaComputeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaComputeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"NovaComputeStartupDelay\": {\"default\": 0, \"description\": \"Delays the startup of nova-compute service after compute node is booted. This is to give a chance to ceph to get back healthy before booting instances after and overcloud reboot.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 0, \"max\": 600}}], \"tags\": [\"role_specific\"]}, \"EnableInstanceHA\": {\"default\": false, \"description\": \"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\", \"type\": \"boolean\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"NovaMkisofsCmd\": {\"default\": \"mkisofs\", \"description\": \"Name or path of the tool used for ISO image creation.\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsEnabled\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Nova\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsOptions\": {\"default\": \"context=system_u:object_r:nfs_t:s0\", \"description\": \"NFS mount options for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsVersion\": {\"default\": \"4.2\", \"description\": \"NFS version used for nova storage (when NovaNfsEnabled is true). Since NFSv3 does not support full locking a NFSv4 version need to be used.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^4.?[0-9]?\"}], \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeForceRawImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to convert non-raw cached base images to raw format.\\nSet to \\\"False\\\" if you have a system with slow I/O or low available space,\\ntrading the higher CPU requirements of compression for that of minimized input\\nbandwidth.\\nNotes::\\n- The Compute service removes any compression from the base image during\\n  compression, to avoid CPU bottlenecks. Converted images cannot have backing\\n  files, which might be a security issue.\\n- The raw image format uses more space than other image formats, for example,\\n  qcow2.\\n  Raw base images are always used with libvirt_images_type=lvm.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeUseCowImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to use CoW (Copy on Write) images in cqow2 format for libvirt\\ninstance disks. With CoW, depending on the backing store and host caching,\\nthere might be better concurrency achieved by having each instance operate\\non its own copy.\\nSet to \\\"False\\\" to use the raw format. Raw format uses more space for common\\nparts of the disk image.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtPreAllocateImages\": {\"default\": \"none\", \"description\": \"Specifies the preallocation mode for libvirt instance disks.\\nSet to one of the following valid values::\\n- none - No storage is provisioned at instance start.\\n- space - Storage is fully allocated at instance start using fallocate,\\n          which can help with both space guarantees and I/O performance.\\n\\nEven when not using CoW instance disks, the copy each instance gets is sparse\\nand so the instance might fail unexpectedly at run time with ENOSPC. By\\nrunning fallocate(1) on the instance disk images, the Compute service\\nimmediately and efficiently allocates the space for them in the file system,\\nif supported. Run time performance should also be improved because the file\\nsystem does not have to dynamically allocate blocks at run time, which reduces\\nCPU overhead and file fragmentation.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"space\"]}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheManagerInterval\": {\"default\": 2400, \"description\": \"Specifies the number of seconds to wait between runs of the image cache\\nmanager, which impacts base image caching on Compute nodes. This period\\nis used in the auto removal of unused cached images configured with\\nremove_unused_base_images and remove_unused_original_minimum_age_seconds.\\n\\nSet to \\\"0\\\" to run at the default interval of 60 seconds (not recommended)\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": -1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to automatically remove unused base images from the cache\\nat intervals configured by using image_cache_manager_interval. Images\\nare defined as unused if they have not been accessed during the time\\nspecified by using remove_unused_original_minimum_age_seconds.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"default\": 3600, \"description\": \"Specifies the minimum age that an unused resized base image must be to\\nbe removed from the cache, in seconds. Unused unresized base images\\nyounger than this will not be removed.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCachePrecacheConcurrency\": {\"default\": 1, \"description\": \"Maximum number of Compute nodes to trigger image precaching in parallel.\\nWhen an image precache request is made, Compute nodes are contacted {by\\nwho/which service} to initiate the download.\\n\\nHigher numbers will cause more computes to work in parallel and may result\\nin reduced time to complete the operation, but may also DDoS the image\\nservice. Lower numbers will result in more sequential operation, lower\\nimage service load, but likely longer runtime to completion.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaPCIPassthrough\": {\"description\": \"List of PCI Passthrough whitelist parameters. Example - NovaPCIPassthrough:\\n  - vendor_id: \\\"8086\\\"\\n    product_id: \\\"154c\\\"\\n    address: \\\"0000:05:00.0\\\"\\n    physical_network: \\\"datacentre\\\"\\nFor different formats, refer to the nova.conf documentation for pci_passthrough_whitelist configuration\\n\", \"type\": \"json\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeCpuSharedSet\": {\"description\": \"The behavior of this option depends on the deprecated `NovaVcpuPinSet` option:\\n\\n* `NovaVcpuPinSet` is not set: `NovaComputeCpuSharedSet` is set to a\\n  comma-separated list or range of physical host CPU numbers used to:\\n\\n  - provide vCPU inventory\\n  - determine the host CPUs that unpinned instances can be scheduled to\\n  - determine the host CPUS that instance emulator threads should be\\n    offloaded to for instances configured with the share emulator thread\\n    policy, `hw:emulator_threads_policy=share`\\n\\n* `NovaVcpuPinSet` is set: `NovaComputeCpuSharedSet` is set to a list or\\n  range of host CPU cores used to determine the host CPUs that instance\\n  emulator threads should be offloaded to for instances configured with\\n  the share emulator thread policy (`hw:emulator_threads_policy=share`).\\n  In this case, `NovaVcpuPinSet` is used to provide vCPU inventory and to\\n  determine the host CPUs that both pinned and unpinned instances can be\\n  scheduled to.\\n\\nEx. NovaComputeCpuSharedSet: [4-12,^8,15] will reserve cores from 4-12\\nand 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaComputeCpuDedicatedSet\": {\"description\": \"A list or range of host CPU cores to which processes for pinned instance CPUs (PCPUs) can be scheduled. Ex. NovaComputeCpuDedicatedSet: [4-12,^8,15] will reserve cores from 4-12 and 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaReservedHostMemory\": {\"description\": \"Reserved RAM for host processes.\\n\", \"type\": \"number\", \"default\": 512, \"constraints\": [{\"range\": {\"min\": 512}}], \"tags\": [\"role_specific\"]}, \"NovaReservedHugePages\": {\"description\": \"A list of valid key=value which reflect NUMA node ID, page size (Default unit is KiB) and number of pages to be reserved. Example - NovaReservedHugePages: [\\\"node:0,size:2048,count:64\\\",\\\"node:1,size:1GB,count:1\\\"] will reserve on NUMA node 0 64 pages of 2MiB and on NUMA node 1 1 page of 1GiB\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"OvsDpdkSocketMemory\": {\"default\": \"\", \"description\": \"Sets the amount of hugepage memory to assign per NUMA node. It is recommended to use the socket closest to the PCIe slot used for the desired DPDK NIC.  The format should be in \\\"<socket 0 mem>, <socket 1 mem>, <socket n mem>\\\", where the value is specified in MB.  For example: \\\"1024,0\\\".\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"MonitoringSubscriptionNovaCompute\": {\"default\": \"overcloud-nova-compute\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"VerifyGlanceSignatures\": {\"default\": false, \"description\": \"Whether to verify image signatures.\", \"type\": \"boolean\"}, \"NovaAutoDisabling\": {\"default\": \"10\", \"description\": \"Max number of consecutive build failures before the nova-compute will disable itself.\", \"type\": \"string\"}, \"NeutronPhysnetNUMANodesMapping\": {\"description\": \"Map of physnet name as key and NUMA nodes as value.\\nEx. NeutronPhysnetNUMANodesMapping: {\'foo\': [0, 1], \'bar\': [1]} where `foo` and `bar` are\\nphysnet names and corresponding values are list of associated numa_nodes.\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NeutronTunnelNUMANodes\": {\"description\": \"Used to configure NUMA affinity for all tunneled networks.\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtRxQueueSize\": {\"description\": \"virtio-net RX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtTxQueueSize\": {\"description\": \"virtio-net TX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtFileBackedMemory\": {\"description\": \"Available capacity in MiB for file-backed memory. When configured, the ``NovaRAMAllocationRatio`` and ``NovaReservedHostMemory`` parameters must be set to 0.\\n\", \"default\": 0, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtVolumeUseMultipath\": {\"default\": false, \"description\": \"Whether to enable or not the multipath connection of the volumes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaHWMachineType\": {\"description\": \"To specify a default machine type per host architecture.\\n\", \"default\": \"x86_64=pc-q35-rhel9.0.0\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaComputeEnableKsm\": {\"default\": false, \"description\": \"Whether to enable KSM on compute nodes or not. Especially in NFV use case one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"FTS40yQUd1tjPXxKb5UK1sScA\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NovaLibvirtNumPciePorts\": {\"description\": \"Set `num_pcie_ports` to specify the number of PCIe ports an instance will get. Libvirt allows a custom number of PCIe ports (pcie-root-port controllers) a target instance will get. Some will be used by default, rest will be available for hotplug use.\\n\", \"default\": 16, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"description\": \"A number of seconds to memory usage statistics period, zero or negative value mean to disable memory usage statistics.\\n\", \"default\": 10, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationWaitForVIFPlug\": {\"description\": \"Whether to wait for `network-vif-plugged` events before starting guest transfer.\", \"default\": true, \"type\": \"boolean\"}, \"NovaLiveMigrationPermitPostCopy\": {\"description\": \"If \\\"True\\\" activates the instance on the destination node before migration is complete, and to set an upper bound on the memory that needs to be transferred. Post copy gets enabled per default if the compute roles is not a realtime role or disabled by this parameter.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationPermitAutoConverge\": {\"description\": \"Defaults to \\\"True\\\" to slow down the instance CPU until the memory copy process is faster than the instance\'s memory writes when the migration performance is slow and might not complete. Auto converge will only be used if this flag is set to True and post copy is not permitted or post copy is unavailable due to the version of libvirt and QEMU.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"NovaCPUAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual CPU to physical CPU allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaRAMAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual RAM to physical RAM allocation ratio.\", \"default\": 1.0, \"tags\": [\"role_specific\"]}, \"NovaDiskAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual disk to physical disk allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaEnableVTPM\": {\"type\": \"boolean\", \"description\": \"Whether to enable support for enumlated Trusted Platform Module (TPM) devices.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaMaxDiskDevicesToAttach\": {\"type\": \"number\", \"description\": \"Maximum number of disk devices allowed to attach to a single server. Note that the number of disks supported by an server depends on the bus used. For example, the ide disk bus is limited to 4 attached devices. The configured maximum is enforced during server create, rebuild, evacuate, unshelve, live migrate, and attach volume. Operators changing this parameter on a compute service that is hosting servers should be aware that it could cause rebuilds to fail, if the maximum is decreased lower than the number of devices already attached to servers. Operators should also be aware that during a cold migration, the configured maximum is only enforced in-place and the destination is not checked before the move. -1 means unlimited\\n\", \"default\": -1, \"tags\": [\"role_specific\"]}, \"NovaPMEMMappings\": {\"type\": \"string\", \"description\": \"PMEM namespace mappings as backend for vPMEM feature. This parameter sets Nova\'s `pmem_namespaces` configuration options. PMEM namespaces needs to be create manually or with conjunction with `NovaPMEMNamespaces` parameter. Requires format: $LABEL:$NSNAME[|$NSNAME][,$LABEL:$NSNAME[|$NSNAME]].\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaPMEMNamespaces\": {\"type\": \"string\", \"description\": \"Creates PMEM namespaces on the host server using `ndctl` tool through Ansible. Requires format: $SIZE:$NSNAME[,$SIZE:$NSNAME...]. $SIZE supports the suffixes \\\"k\\\" or \\\"K\\\" for KiB, \\\"m\\\" or \\\"M\\\" for MiB, \\\"g\\\" or \\\"G\\\" for GiB and \\\"t\\\" or \\\"T\\\" for TiB. NOTE: This requires properly configured NVDIMM regions and enough space for requested namespaces.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaImageCacheTTL\": {\"type\": \"number\", \"description\": \"Time in seconds that nova compute should continue caching an image once it is no longer used by any instances on the host\\n\", \"default\": 86400, \"tags\": [\"role_specific\"]}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"type\": \"json\", \"description\": \"Map of vgpu type(s) the instances can get as key and list of corresponding device addresses as value. Ex. NovaVGPUTypesDeviceAddressesMapping: {\'nvidia-35\': [\'0000:84:00.0\', \'0000:85:00.0\'],\\n                                  \'nvidia-36\': [\'0000:86:00.0\']}\\nwhere `nvidia-35` and `nvidia-36` are vgpu types and corresponding values are list of associated device addresses.\\n\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NovaComputeDisableIrqBalance\": {\"default\": false, \"description\": \"Whether to disable irqbalance on compute nodes or not. Especially in Realtime Compute role one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUMode\": {\"type\": \"string\", \"description\": \"The libvirt CPU mode to configure. Defaults to \'host-model\' if virt_type is set to kvm, otherwise defaults to \'none\'\\n\", \"default\": \"host-model\", \"constraints\": [{\"allowed_values\": [\"custom\", \"host-model\", \"none\", \"host-passthrough\"]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModels\": {\"type\": \"comma_delimited_list\", \"description\": \"The named libvirt CPU model (see names listed in /usr/share/libvirt/cpu_map.xml). Only has effect if cpu_mode=\\\"custom\\\" and virt_type=\\\"kvm|qemu\\\"\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModelExtraFlags\": {\"type\": \"string\", \"description\": \"This allows specifying granular CPU feature flags when specifying CPU models. Only has effect if cpu_mode is not set to \'none\'.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaDisableImageDownloadToRbd\": {\"type\": \"boolean\", \"description\": \"Refuse to boot an instance if it would require downloading from glance and uploading to ceph instead of a COW clone.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaDisableComputeServiceCheckForFfu\": {\"type\": \"boolean\", \"description\": \"Facilitate a Fast-Forward upgrade where new control services are being started before compute nodes have been able to update their service record.\\n\", \"default\": false}, \"NovaStatedirOwnershipSkip\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths relative to nova_statedir to ignore when recursively setting the ownership and selinux context.\\n\", \"default\": [\"triliovault-mounts\"]}, \"NovaImageTypeExcludeList\": {\"type\": \"comma_delimited_list\", \"description\": \"List of image formats that should not be advertised as supported by the compute service.\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtMaxQueues\": {\"type\": \"number\", \"description\": \"Add parameter to configure the libvirt max_queues. The maximum number of virtio queue pairs that can be enabled when creating a multiqueue guest. The number of virtio queues allocated will be the lesser of the CPUs requested by the guest and the max value defined. Default 0 corresponds to not set\\n\", \"default\": 0, \"tags\": [\"role_specific\"]}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"NovaGlanceEnableRbdDownload\": {\"type\": \"boolean\", \"description\": \"Enable download of Glance images directly via RBD.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdDownloadMultistoreID\": {\"type\": \"string\", \"description\": \"The hash key, which is the backend ID, of the GlanceMultistoreConfig to be used for the role where NovaGlanceEnableRbdDownload is enabled and defaults should be overridden. If CephClientUserName or GlanceRbdPoolName are not set in the GlanceMultistoreConfig, the global values of those parameters will be used.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"NovaGlanceRbdCopyPollInterval\": {\"type\": \"number\", \"description\": \"The interval in seconds with which to poll Glance after asking for it to copy an image to the local rbd store.\\n\", \"default\": 15, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdCopyTimeout\": {\"type\": \"number\", \"description\": \"The overall maximum time we will wait for Glance to complete an image copy to our local rbd store.\\n\", \"default\": 600, \"tags\": [\"role_specific\"]}, \"CustomProviderInventories\": {\"description\": \"Array of hashes describing the custom providers for the compute role.\\nFormat:\\nname/uuid - Resource providers to target can be identified by either\\nUUID or name. In addition, the value $COMPUTE_NODE can be used in\\nthe UUID field to identify all nodes managed by the service.\\nExactly one of uuid or name is mandatory. If neither uuid or name\\nis provided, the special uuid $COMPUTE_NODE gets set in the template.\\n\\ninventories - (Optional) Hash of custom provider inventories. \'total\' is\\na mandatory property. Any other optional properties not populated will\\nbe given a default value by placement. If overriding a pre-existing\\nprovider values will not be preserved from the existing inventory.\\n\\ntraits - (Optional) Array of additional traits.\\nExample:\\nComputeParameters:\\n  CustomProviderInventories:\\n    - uuid: $COMPUTE_NODE\\n      inventories:\\n        CUSTOM_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n          reserved: 0\\n          min_unit: 1\\n          max_unit: 10\\n          step_size: 1\\n          allocation_ratio: 1.0\\n        CUSTOM_ANOTHER_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n      traits:\\n        - CUSTOM_P_STATE_ENABLED\\n        - CUSTOM_C_STATE_ENABLED\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaVcpuPinSet\": {\"description\": \"A list or range of host CPU cores to which processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is set, or to which both emulator threads and processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is unset. Ex. NovaVcpuPinSet: [\'4-12\',\'^8\'] will reserve cores from 4-12 excluding 8\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenstack mailing list.\\n\", \"parameters\": [\"NovaVcpuPinSet\"]}], \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"compute_startup_delay\": {\"and\": [{\"not\": {\"get_param\": \"EnableInstanceHA\"}}, {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaComputeStartupDelay\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, \"\"]}]}]}}]}, \"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"enable_live_migration_tunnelled\": {\"and\": [{\"or\": [{\"and\": [{\"get_param\": \"NovaNfsEnabled\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, true]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}]}, {\"not\": \"use_tls_for_live_migration\"}]}, \"libvirt_file_backed_memory_enabled\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtFileBackedMemory\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, \"\"]}]}]}}, \"reserved_huge_pages_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaReservedHugePages\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaReservedHugePages\"}, []]}]}}, \"is_realtime\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"TunedProfileName\"]}, \"realtime-virtual-host\"]}, \"ovs_dpdk_socket_memory_not_set\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"OvsDpdkSocketMemory\"}, \"\"]}]}, \"nova_libvirt_max_queues_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtMaxQueues\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, 0]}]}]}}, \"glance_enable_rbd_download_set\": {\"or\": [{\"and\": [{\"get_param\": \"NovaGlanceEnableRbdDownload\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, true]}]}, \"nova_glance_rbd_download_multistore_id_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceRbdDownloadMultistoreID\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"\"]}]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"NovaComputeCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"NovaServiceName\": \"compute\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::vcpu_pin_set\": \"NovaVcpuPinSet\", \"nova::compute::cpu_shared_set\": \"NovaComputeCpuSharedSet\", \"nova::compute::cpu_dedicated_set\": \"NovaComputeCpuDedicatedSet\", \"nova::compute::reserved_host_memory\": \"NovaReservedHostMemory\", \"nova::compute::reserved_huge_pages\": \"NovaReservedHugePages\", \"nova::compute::neutron_physnets_numa_nodes_mapping\": \"NeutronPhysnetNUMANodesMapping\", \"nova::compute::neutron_tunnel_numa_nodes\": \"NeutronTunnelNUMANodes\", \"nova::compute::resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt::rx_queue_size\": \"NovaLibvirtRxQueueSize\", \"nova::compute::libvirt::tx_queue_size\": \"NovaLibvirtTxQueueSize\", \"nova::compute::libvirt::file_backed_memory\": \"NovaLibvirtFileBackedMemory\", \"nova::compute::libvirt::volume_use_multipath\": \"NovaLibvirtVolumeUseMultipath\", \"nova::compute::libvirt::hw_machine_type\": \"NovaHWMachineType\", \"nova::compute::mkisofs_cmd\": \"NovaMkisofsCmd\", \"compute_enable_ksm\": \"NovaComputeEnableKsm\", \"nova::compute::rbd::libvirt_images_rbd_pool\": \"NovaRbdPoolName\", \"tripleo::profile::base::nova::compute::nova_nfs_enabled\": \"NovaNfsEnabled\", \"nfs_backend_enable\": \"NovaNfsEnabled\", \"nfs_share\": \"NovaNfsShare\", \"nfs_options\": \"NovaNfsOptions\", \"nfs_vers\": \"NovaNfsVersion\", \"nova::compute::libvirt::num_pcie_ports\": \"NovaLibvirtNumPciePorts\", \"nova::compute::libvirt::mem_stats_period_seconds\": \"NovaLibvirtMemStatsPeriodSeconds\", \"nova::compute::rbd::ephemeral_storage\": \"NovaEnableRbdBackend\", \"resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::cpu_allocation_ratio\": \"NovaCPUAllocationRatio\", \"nova::ram_allocation_ratio\": \"NovaRAMAllocationRatio\", \"nova::disk_allocation_ratio\": \"NovaDiskAllocationRatio\", \"nova::compute::max_disk_devices_to_attach\": \"NovaMaxDiskDevicesToAttach\", \"nova::compute::libvirt::pmem_namespaces\": \"NovaPMEMMappings\", \"nova_pmem_namespaces\": \"NovaPMEMNamespaces\", \"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\": \"NovaImageCacheTTL\", \"nova::compute::libvirt::swtpm_enabled\": \"NovaEnableVTPM\", \"nova::compute::vgpu::vgpu_types_device_addresses_mapping\": \"NovaVGPUTypesDeviceAddressesMapping\", \"compute_disable_irqbalance\": \"NovaComputeDisableIrqBalance\", \"nova::compute::libvirt::cpu_mode\": \"NovaLibvirtCPUMode\", \"nova::compute::libvirt::cpu_models\": \"NovaLibvirtCPUModels\", \"nova::compute::libvirt::cpu_model_extra_flags\": \"NovaLibvirtCPUModelExtraFlags\", \"nova_compute_opt_volumes\": \"NovaComputeOptVolumes\", \"nova_compute_startup_delay\": \"NovaComputeStartupDelay\", \"nova_compute_opt_env_vars\": \"NovaComputeOptEnvVars\", \"nova::workarounds::never_download_image_if_on_rbd\": \"NovaDisableImageDownloadToRbd\", \"nova::compute::image_type_exclude_list\": \"NovaImageTypeExcludeList\", \"nova_permit_post_copy\": \"NovaLiveMigrationPermitPostCopy\", \"nova_permit_auto_converge\": \"NovaLiveMigrationPermitAutoConverge\", \"nova_libvirt_max_queues\": \"NovaLibvirtMaxQueues\", \"nova_glance_enable_rbd_download\": \"NovaGlanceEnableRbdDownload\", \"nova_glance_rbd_download_multistore_id\": \"NovaGlanceRbdDownloadMultistoreID\", \"nova::compute::force_raw_images\": \"NovaComputeForceRawImages\", \"nova::compute::use_cow_images\": \"NovaComputeUseCowImages\", \"nova::compute::libvirt::preallocate_images\": \"NovaComputeLibvirtPreAllocateImages\", \"nova::compute::image_cache::manager_interval\": \"NovaComputeImageCacheManagerInterval\", \"nova::compute::image_cache::remove_unused_base_images\": \"NovaComputeImageCacheRemoveUnusedBaseImages\", \"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\", \"nova::compute::image_cache::precache_concurrency\": \"NovaComputeImageCachePrecacheConcurrency\", \"nova::compute::provider::custom_inventories\": \"CustomProviderInventories\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\": \"NovaGlanceRbdCopyPollInterval\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\": \"NovaGlanceRbdCopyTimeout\", \"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaVcpuPinSet\": {\"get_param\": \"NovaVcpuPinSet\"}, \"NovaComputeCpuSharedSet\": {\"get_param\": \"NovaComputeCpuSharedSet\"}, \"NovaComputeCpuDedicatedSet\": {\"get_param\": \"NovaComputeCpuDedicatedSet\"}, \"NovaReservedHostMemory\": {\"get_param\": \"NovaReservedHostMemory\"}, \"NovaReservedHugePages\": {\"if\": [\"reserved_huge_pages_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"if\": [\"ovs_dpdk_socket_memory_not_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"repeat\": {\"for_each\": {\"<%node%>\": {\"yaql\": {\"expression\": \"range(0,len($.data.dpdk_p)).join(\\\",\\\").split(\\\",\\\")\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}}}}, \"<%size%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\")) -> [$hz]*len($.data.dpdk_p)\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}, \"<%count%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>int(switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\"))) -> $.data.dpdk_p.select(int($)*1024/$hz).join(\\\",\\\").split(\',\')\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}}, \"template\": \"node:<%node%>,size:<%size%>,count:<%count%>\", \"permutations\": false}}]}]}, \"NeutronPhysnetNUMANodesMapping\": {\"get_param\": \"NeutronPhysnetNUMANodesMapping\"}, \"NeutronTunnelNUMANodes\": {\"get_param\": \"NeutronTunnelNUMANodes\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaLibvirtRxQueueSize\": {\"get_param\": \"NovaLibvirtRxQueueSize\"}, \"NovaLibvirtTxQueueSize\": {\"get_param\": \"NovaLibvirtTxQueueSize\"}, \"NovaLibvirtFileBackedMemory\": {\"get_param\": \"NovaLibvirtFileBackedMemory\"}, \"NovaLibvirtVolumeUseMultipath\": {\"get_param\": \"NovaLibvirtVolumeUseMultipath\"}, \"NovaHWMachineType\": {\"get_param\": \"NovaHWMachineType\"}, \"NovaComputeEnableKsm\": {\"get_param\": \"NovaComputeEnableKsm\"}, \"NovaRbdPoolName\": {\"get_param\": \"NovaRbdPoolName\"}, \"NovaMkisofsCmd\": {\"get_param\": \"NovaMkisofsCmd\"}, \"NovaNfsEnabled\": {\"get_param\": \"NovaNfsEnabled\"}, \"NovaNfsShare\": {\"get_param\": \"NovaNfsShare\"}, \"NovaNfsOptions\": {\"get_param\": \"NovaNfsOptions\"}, \"NovaNfsVersion\": {\"get_param\": \"NovaNfsVersion\"}, \"NovaLibvirtNumPciePorts\": {\"get_param\": \"NovaLibvirtNumPciePorts\"}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"get_param\": \"NovaLibvirtMemStatsPeriodSeconds\"}, \"NovaEnableRbdBackend\": {\"get_param\": \"NovaEnableRbdBackend\"}, \"NovaCPUAllocationRatio\": {\"get_param\": \"NovaCPUAllocationRatio\"}, \"NovaRAMAllocationRatio\": {\"get_param\": \"NovaRAMAllocationRatio\"}, \"NovaDiskAllocationRatio\": {\"get_param\": \"NovaDiskAllocationRatio\"}, \"NovaEnableVTPM\": {\"get_param\": \"NovaEnableVTPM\"}, \"NovaMaxDiskDevicesToAttach\": {\"get_param\": \"NovaMaxDiskDevicesToAttach\"}, \"NovaPMEMMappings\": {\"get_param\": \"NovaPMEMMappings\"}, \"NovaPMEMNamespaces\": {\"get_param\": \"NovaPMEMNamespaces\"}, \"NovaImageCacheTTL\": {\"get_param\": \"NovaImageCacheTTL\"}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"get_param\": \"NovaVGPUTypesDeviceAddressesMapping\"}, \"NovaComputeDisableIrqBalance\": {\"get_param\": \"NovaComputeDisableIrqBalance\"}, \"NovaLibvirtCPUMode\": {\"get_param\": \"NovaLibvirtCPUMode\"}, \"NovaLibvirtCPUModels\": {\"get_param\": \"NovaLibvirtCPUModels\"}, \"NovaLibvirtCPUModelExtraFlags\": {\"get_param\": \"NovaLibvirtCPUModelExtraFlags\"}, \"NovaComputeOptVolumes\": {\"get_param\": \"NovaComputeOptVolumes\"}, \"NovaComputeStartupDelay\": {\"get_param\": \"NovaComputeStartupDelay\"}, \"NovaComputeOptEnvVars\": {\"get_param\": \"NovaComputeOptEnvVars\"}, \"NovaDisableImageDownloadToRbd\": {\"get_param\": \"NovaDisableImageDownloadToRbd\"}, \"NovaImageTypeExcludeList\": {\"get_param\": \"NovaImageTypeExcludeList\"}, \"NovaLiveMigrationPermitPostCopy\": {\"get_param\": \"NovaLiveMigrationPermitPostCopy\"}, \"NovaLiveMigrationPermitAutoConverge\": {\"get_param\": \"NovaLiveMigrationPermitAutoConverge\"}, \"NovaLibvirtMaxQueues\": {\"get_param\": \"NovaLibvirtMaxQueues\"}, \"NovaGlanceEnableRbdDownload\": {\"get_param\": \"NovaGlanceEnableRbdDownload\"}, \"NovaGlanceRbdDownloadMultistoreID\": {\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"NovaComputeForceRawImages\": {\"get_param\": \"NovaComputeForceRawImages\"}, \"NovaComputeUseCowImages\": {\"get_param\": \"NovaComputeUseCowImages\"}, \"NovaComputeLibvirtPreAllocateImages\": {\"get_param\": \"NovaComputeLibvirtPreAllocateImages\"}, \"NovaComputeImageCacheManagerInterval\": {\"get_param\": \"NovaComputeImageCacheManagerInterval\"}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedBaseImages\"}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\"}, \"NovaComputeImageCachePrecacheConcurrency\": {\"get_param\": \"NovaComputeImageCachePrecacheConcurrency\"}, \"CustomProviderInventories\": {\"get_param\": \"CustomProviderInventories\"}, \"NovaGlanceRbdCopyPollInterval\": {\"get_param\": \"NovaGlanceRbdCopyPollInterval\"}, \"NovaGlanceRbdCopyTimeout\": {\"get_param\": \"NovaGlanceRbdCopyTimeout\"}, \"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"nova_compute_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for nova_compute\", \"value\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}, \"role_data\": {\"description\": \"Role data for the Nova Compute service.\", \"value\": {\"service_name\": \"nova_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"nova::compute::pci::passthrough\": {\"str_replace\": {\"template\": \"JSON_PARAM\", \"params\": {\"map_replace\": [{\"map_replace\": [{\"JSON_PARAM\": \"NovaPCIPassthrough\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaPCIPassthrough\": {\"get_param\": \"NovaPCIPassthrough\"}}}]}}}, \"nova::compute::libvirt::migration_support\": false, \"tripleo::profile::base::nova::migration::client::nova_compute_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::rbd::libvirt_images_rbd_glance_store_name\": {\"get_param\": \"GlanceBackendID\"}, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"tripleo::profile::base::nova::compute::cinder_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::cinder::username\": \"cinder\", \"nova::cinder::auth_type\": \"v3password\", \"nova::cinder::project_name\": \"service\", \"nova::cinder::password\": {\"get_param\": \"CinderPassword\"}, \"nova::cinder::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::cinder::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"nova::compute::instance_usage_audit\": true, \"nova::compute::instance_usage_audit_period\": \"hour\", \"nova::compute::consecutive_build_service_disable_threshold\": {\"get_param\": \"NovaAutoDisabling\"}, \"nova::compute::live_migration_wait_for_vif_plug\": {\"get_param\": \"NovaLiveMigrationWaitForVIFPlug\"}, \"nova::migration::libvirt::live_migration_permit_post_copy\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_post_copy\"]}]}, \"nova::migration::libvirt::live_migration_permit_auto_converge\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_auto_converge\"]}]}, \"nova::migration::libvirt::live_migration_tunnelled\": false, \"nova::compute::vncserver_proxyclient_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"protocol\"]}, \"nova::vncproxy::common::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"port\"]}, \"nova::compute::verify_glance_signatures\": {\"get_param\": [\"VerifyGlanceSignatures\"]}, \"nova::ram_allocation_ratio\": {\"if\": [\"libvirt_file_backed_memory_enabled\", \"1.0\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::ram_allocation_ratio\"]}]}, \"nova::compute::libvirt::max_queues\": {\"if\": [\"nova_libvirt_max_queues_set\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_max_queues\"]}]}, \"nova::workarounds::disable_compute_service_check_for_ffu\": {\"get_param\": \"NovaDisableComputeServiceCheckForFfu\"}}, {\"if\": [\"glance_enable_rbd_download_set\", {\"nova::glance::enable_rbd_download\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_enable_rbd_download\"]}, \"nova::glance::rbd_user\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_ceph_client_user_name) -> $.data.multistore.get($k).get(\\\"CephClientUserName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_ceph_client_user_name\": {\"get_param\": \"CephClientUserName\"}}}}, {\"get_param\": \"CephClientUserName\"}]}, \"nova::glance::rbd_pool\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_glance_rbd_pool_name) -> $.data.multistore.get($k).get(\\\"GlanceRbdPoolName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_glance_rbd_pool_name\": {\"get_param\": \"GlanceRbdPoolName\"}}}}, {\"get_param\": \"GlanceRbdPoolName\"}]}, \"nova::glance::rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key) -> list(coalesce($.data.multistore, {}).get($k)).flatten().select($.get(\\\"CephClusterName\\\"))\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}, {\"get_param\": \"CephClusterName\"}]}, \".conf\"]]}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_nova_compute\": [{\"get_param\": \"NovaComputeLoggingSource\"}]}, \"collectd\": {\"tripleo.collectd.plugins.nova_compute\": [\"virt\"], \"collectd::plugin::virt::connection\": \"qemu:///system\"}}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"nova_config\", \"step_config\": \"# TODO(emilien): figure how to deal with libvirt profile.\\n# We\'ll probably treat it like we do with Neutron plugins.\\n# Until then, just include it in the default nova-compute role.\\ninclude tripleo::profile::base::nova::compute::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_compute.json\": {\"command\": {\"list_join\": [\" \", [{\"if\": [\"compute_startup_delay\", {\"str_replace\": {\"template\": \"/var/lib/nova/delay-nova-compute --delay DELAY --nova-binary\", \"params\": {\"DELAY\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}}]}, \"/usr/bin/nova-compute\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}, {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\": {\"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"get_attr\": [\"NovaComputeCommon\", \"container_config_scripts\"]}]}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"nova_statedir_owner\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"none\", \"user\": \"root\", \"security_opt\": [\"label=disable\"], \"privileged\": false, \"detach\": false, \"volumes\": [\"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\", \"/var/lib/container-config-scripts:/container-config-scripts:z\"], \"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\", \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}, \"NOVA_STATEDIR_OWNERSHIP_SKIP\": {\"list_join\": [\":\", {\"get_param\": \"NovaStatedirOwnershipSkip\"}]}}}}, \"step_5\": {\"map_merge\": [{\"nova_compute\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"ulimit\": {\"get_param\": \"DockerNovaComputeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"nova\", \"restart\": \"always\", \"depends_on\": {\"list_concat\": [[\"tripleo_nova_libvirt.target\"], {\"if\": [{\"get_param\": \"NovaNfsEnabled\"}, [\"var-lib-nova-instances.mount\"]]}]}, \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_volumes\"]}, [\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/run/nova:/run/nova:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/sys/class/net:/sys/class/net\", \"/sys/bus/pci:/sys/bus/pci\", \"/boot:/boot:ro\", \"/var/lib/nova:/var/lib/nova:shared\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_env_vars\"]}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, {\"LIBGUESTFS_BACKEND\": \"direct\"}]}}}, {\"if\": [{\"not\": {\"get_param\": \"NovaAdditionalCell\"}}, {\"nova_wait_for_compute_service\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/nova:/var/log/nova\", \"/var/lib/container-config-scripts:/container-config-scripts\"]]}, \"user\": \"nova\", \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}}}}]}]}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check for /var/lib/nova/instances directory exitance\", \"stat\": {\"path\": \"/var/lib/nova/instances\"}, \"register\": \"check_nova_instances_result\"}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/_nova_secontext\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/nova/instances\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/tmpfiles.d\"}]}, {\"name\": \"ensure /run/nova is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-nova.conf\", \"content\": \"d /run/nova 0777 root root - -\\n\"}}, {\"name\": \"create tempfiles\", \"command\": \"systemd-tmpfiles --create\"}], [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}], [{\"name\": \"delay installation of systemd-container\", \"when\": \"check_nova_instances_result.stat.exists\", \"block\": [{\"name\": \"check systemd-container package installed or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\", \"failed_when\": false}, {\"name\": \"get latest package from downloaded package versions\", \"shell\": \"ls -1t /var/tmp/systemd-container* | head -1\", \"register\": \"latest_systemd_container_package\", \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"], \"failed_when\": false}, {\"name\": \"Install systemd-container package on boot\", \"copy\": {\"dest\": \"/etc/systemd/system/install-systemd-container.service\", \"content\": \"[Unit]\\nDescription=Install systemd container package on system boot\\nBefore=tripleo_nova_virtqemud.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\nExecStartPost=rm -f /var/tmp/systemd-container*\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": [\"latest_systemd_container_package is defined\", \"(\'stdout\' in latest_systemd_container_package)\", \"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"enable install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"state\": \"stopped\", \"enabled\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"check if install-systemd-container service exists\", \"stat\": {\"path\": \"/etc/systemd/system/install-systemd-container.service\"}, \"register\": \"install_systemd_container_result\"}, {\"name\": \"disable and mask install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"not is_systemd_container_package.changed\", \"install_systemd_container_result.stat.exists\"]}]}, {\"name\": \"is Nova Resume Guests State On Host Boot enabled\", \"set_fact\": {\"resume_guests_state_on_host_boot_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"resume_guests_state_on_host_boot\"]}}}, {\"name\": \"install libvirt-guests systemd unit file (docker)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'docker\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs\", \"copy\": {\"dest\": \"/etc/systemd/system/libvirt-guests.service\", \"content\": \"[Unit]\\nDescription=Suspend/Resume Running libvirt Guests\\nAfter=network.target\\nAfter=time-sync.target\\nAfter=virt-guest-shutdown.target\\nAfter=docker.service\\nAfter=tripleo-container-shutdown.service\\nAfter=rhel-push-plugin.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\n# Hack just call traditional service until we factor\\n# out the code\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\nExecStop=/bin/{{container_cli}} stop nova_compute\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"libvirt-guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"libvirt-guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"install tripleo_nova_libvirt_guests systemd unit file (podman)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'podman\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\"}, {\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\"}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"tripleo_nova_libvirt_guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Do we prepend nova startup with a delay\", \"set_fact\": {\"nova_compute_delay\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}, {\"name\": \"install nova-compute delay wrapper script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/scripts/delay-nova-compute\"}, \"dest\": \"/var/lib/nova/delay-nova-compute\", \"mode\": 493}, \"when\": \"nova_compute_delay|int > 0\"}, {\"name\": \"Is irqbalance enabled\", \"set_fact\": {\"compute_irqbalance_disabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_disable_irqbalance\"]}}}, {\"name\": \"disable irqbalance service on compute\", \"when\": \"compute_irqbalance_disabled|bool\", \"service\": {\"name\": \"irqbalance.service\", \"state\": \"stopped\", \"enabled\": false}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"deploy_steps_tasks\": [{\"name\": \"install systemd-container for a greenfield\", \"when\": [\"step|int == 1\", \"not check_nova_instances_result.stat.exists\"], \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}}, {\"name\": \"validate nova-compute container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_compute\"}, \"register\": \"nova_compute_infos\", \"failed_when\": [\"nova_compute_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 6\"]}, {\"name\": \"manage PMEM namespaces for vPMEM\", \"include_role\": {\"name\": \"tripleo_nvdimm\"}, \"vars\": {\"tripleo_nvdimm_pmem_namespaces\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_pmem_namespaces\"]}}, \"when\": [\"step|int == 1\", \"tripleo_nvdimm_pmem_namespaces != \'\'\"]}, {\"name\": \"manage OS version 9 specific sysctls\", \"when\": [\"step|int == 1\", \"ansible_facts[\'os_family\'] == \'RedHat\'\", \"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"], \"block\": [{\"name\": \"Enable post-copy by setting unprivileged_userfaultfd\", \"sysctl\": {\"name\": \"vm.unprivileged_userfaultfd\", \"value\": 1, \"sysctl_set\": true, \"sysctl_file\": \"/etc/sysctl.d/99-tripleo-postcopy.conf\", \"state\": \"present\", \"reload\": true}}]}, {\"name\": \"enable/disable ksm\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"is KSM enabled\", \"set_fact\": {\"compute_ksm_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_enable_ksm\"]}}}, {\"name\": \"disable KSM on compute\", \"when\": \"not compute_ksm_enabled|bool\", \"block\": [{\"name\": \"Check for ksm\", \"shell\": \"systemctl is-active ksm.service || systemctl is-enabled ksm.service\", \"become\": true, \"failed_when\": false, \"register\": \"ksm_service_check\"}, {\"name\": \"disable KSM services\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"], \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\"], \"register\": \"ksmdisabled\"}, {\"name\": \"delete PageKSM after disable ksm on compute\", \"command\": \"echo 2 >/sys/kernel/mm/ksm/run\", \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\", \"ksmdisabled is changed\"]}]}, {\"name\": \"enable KSM on compute\", \"when\": \"compute_ksm_enabled|bool\", \"block\": [{\"name\": \"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\", \"package\": {\"name\": \"qemu-kvm-common\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"]}, {\"name\": \"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\", \"package\": {\"name\": \"ksmtuned\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"]}, {\"name\": \"enable ksmtunded\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"started\", \"enabled\": true}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"]}]}]}], \"external_post_deploy_tasks\": {\"get_attr\": [\"NovaComputeCommon\", \"nova_compute_common_deploy_steps_tasks\"]}, \"upgrade_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}, {\"name\": \"nova_compute pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"absent\", \"fstype\": \"nfs4\"}, \"when\": \"nfs_backend_enable|bool\"}]}, {\"name\": \"nova_compute post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}], \"update_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}], \"post_update_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"post_upgrade_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get nova-compute service ID\", \"command\": \"openstack compute service list --service nova-compute --column ID --column Host --format yaml\", \"register\": \"nova_compute_service_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"is additional Cell?\", \"set_fact\": {\"is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"Set fact for nova_compute services\", \"set_fact\": {\"nova_compute_service\": \"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Check search output\", \"fail\": {\"msg\": \"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\"}, \"when\": [\"(nova_compute_service | length) > 1\"]}, {\"name\": \"Disable nova services\", \"when\": [\"(nova_compute_service | length) == 1\"], \"block\": [{\"name\": \"Disable nova-compute service\", \"command\": \"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"when\": [\"not is_additional_cell|bool\"]}, {\"name\": \"Stop nova-compute container\", \"service\": {\"name\": \"tripleo_nova_compute\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_nova_compute\", \"failed_when\": \"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\"}, {\"name\": \"Delete nova-compute service\", \"command\": \"openstack compute service delete {{ nova_compute_service[0].ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(76,'2026-06-13 07:57:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Migration Target service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DockerNovaMigrationSshdPort\": {\"default\": 2022, \"description\": \"Port that dockerized nova migration target sshd service binds to.\", \"type\": \"number\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"SshdBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Migration Target service.\", \"value\": {\"service_name\": \"nova_migration_target\", \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept libvirt subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept api subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"SshdBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\": [{\"get_param\": [\"MigrationSshKey\", \"public_key\"]}], \"tripleo::profile::base::nova::migration::target::ssh_localaddrs\": [\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\", \"%{hiera(\'live_migration_ssh_inbound_addr\')}\"], \"live_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"cold_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"tripleo::profile::base::sshd::port\": [22]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"SshdBase\", \"role_data\", \"step_config\"]}, \"include tripleo::profile::base::nova::migration::target\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova-migration-target.json\": {\"command\": {\"str_replace\": {\"template\": \"dumb-init --single-child -- /usr/sbin/sshd -D -p SSHDPORT\", \"params\": {\"SSHDPORT\": {\"get_param\": \"DockerNovaMigrationSshdPort\"}}}}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/host-ssh/ssh_host_*_key\", \"dest\": \"/etc/ssh/\", \"owner\": \"root\", \"perm\": \"0600\"}]}}, \"host_prep_tasks\": [{\"name\": \"Create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"loop\": [{\"path\": \"/run/libvirt\", \"setype\": \"virt_var_run_t\"}]}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}], \"docker_config\": {\"step_4\": {\"nova_migration_target\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/etc/ssh:/host-ssh:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"validate nova-migration-target container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_migration_target\"}, \"register\": \"nova_migration_target_infos\", \"failed_when\": [\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], \"update_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}], \"upgrade_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(77,'2026-06-13 07:57:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(78,'2026-06-13 07:57:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(79,'2026-06-13 07:57:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"ynYFMrrhBYym7oMTANCe2Hdxj\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": true, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(80,'2026-06-13 07:57:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Load kernel modules with kmod and configure kernel options with sysctl.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelPidMax\": {\"default\": 1048576, \"description\": \"Configures sysctl kernel.pid_max key\", \"type\": \"number\"}, \"KernelDisableIPv6\": {\"default\": 0, \"description\": \"Configures sysctl net.ipv6.{default/all}.disable_ipv6 keys\", \"type\": \"number\"}, \"KernelIpForward\": {\"default\": 1, \"description\": \"Configures net.ipv4.ip_forward key\", \"type\": \"number\"}, \"KernelIpv6ConfAllForwarding\": {\"default\": 0, \"description\": \"Configures the net.ipv6.conf.all.forwarding key\", \"type\": \"number\"}, \"KernelIpv4ConfAllRpFilter\": {\"default\": 1, \"description\": \"Configures the net.ipv4.conf.all.rp_filter key\", \"type\": \"number\"}, \"KernelIpNonLocalBind\": {\"default\": 1, \"description\": \"Configures net.ipv{4,6}.ip_nonlocal_bind key\", \"type\": \"number\"}, \"NeighbourGcThreshold1\": {\"default\": 1024, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh1 value. This is the minimum number of entries to keep in the ARP cache. The garbage collector will not run if there are fewer than this number of entries in the cache.\", \"type\": \"number\"}, \"NeighbourGcThreshold2\": {\"default\": 2048, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh2 value. This is the soft maximum number of entries to keep in the ARP cache. The garbage collector will  allow the number of entries to exceed this for 5 seconds before collection will be performed.\", \"type\": \"number\"}, \"NeighbourGcThreshold3\": {\"default\": 4096, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh3 value. This is the hard maximum number of entries to keep in the ARP cache. The garbage collector will always run if there are more than this number of entries in the cache.\", \"type\": \"number\"}, \"InotifyInstancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}, \"BridgeNfCallArpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-arptables key\", \"type\": \"number\"}, \"BridgeNfCallIpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-iptables key\", \"type\": \"number\"}, \"BridgeNfCallIp6Tables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-ip6tables key\", \"type\": \"number\"}, \"ExtraKernelModules\": {\"default\": {}, \"description\": \"Hash of extra Kernel modules to load.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraKernelPackages\": {\"default\": {}, \"description\": \"List of extra kernel related packages to install.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraSysctlSettings\": {\"default\": {}, \"description\": \"Hash of extra sysctl settings to apply.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"FsAioMaxNumber\": {\"default\": 0, \"description\": \"The kernel allocates aio memory on demand, and this number limits the number of parallel aio requests; the only drawback of a larger limit is that a malicious guest could issue parallel requests to cause the kernel to set aside memory.  Set this number at least as large as\\n  128 * (number of virtual disks on the host)\\nLibvirt uses a default of 1M requests to allow 8k disks, with at most 64M of kernel memory if all disks hit an aio request at the same time.\\n\", \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"InotifyIntancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"InotifyIntancesMax\"]}], \"conditions\": {\"ipv6_disabled\": {\"equals\": [{\"get_param\": \"KernelDisableIPv6\"}, 1]}, \"is_inotify_intances_max_default\": {\"equals\": [{\"get_param\": \"InotifyIntancesMax\"}, 1024]}, \"fs_aio_max_number_set\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, 0]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, \"\"]}}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_kernel_modules\": \"ExtraKernelModules\", \"extra_kernel_packages\": \"ExtraKernelPackages\", \"extra_sysctl_settings\": \"ExtraSysctlSettings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraKernelModules\": {\"get_param\": \"ExtraKernelModules\"}, \"ExtraKernelPackages\": {\"get_param\": \"ExtraKernelPackages\"}, \"ExtraSysctlSettings\": {\"get_param\": \"ExtraSysctlSettings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Kernel modules\", \"value\": {\"service_name\": \"kernel\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_kernel\"}}], \"ansible_group_vars\": {\"hieradata_localhost_address\": {\"if\": [\"ipv6_disabled\", \"127.0.0.1\", \"localhost\"]}, \"tripleo_kernel_extra_modules\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_modules\"]}, \"tripleo_kernel_extra_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_packages\"]}, \"tripleo_kernel_sysctl_extra_settings\": {\"map_merge\": [{\"net.ipv6.conf.default.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv4.ip_local_reserved_ports\": {\"value\": \"35357,49000-49001\"}, \"net.ipv6.conf.all.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv6.conf.lo.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_forward\": {\"value\": {\"get_param\": \"KernelIpForward\"}}, \"net.ipv4.conf.all.rp_filter\": {\"value\": {\"get_param\": \"KernelIpv4ConfAllRpFilter\"}}, \"net.ipv6.conf.all.forwarding\": {\"value\": {\"get_param\": \"KernelIpv6ConfAllForwarding\"}}, \"net.ipv4.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"net.ipv6.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"kernel.pid_max\": {\"value\": {\"get_param\": \"KernelPidMax\"}}, \"net.ipv4.neigh.default.gc_thresh1\": {\"value\": {\"get_param\": \"NeighbourGcThreshold1\"}}, \"net.ipv4.neigh.default.gc_thresh2\": {\"value\": {\"get_param\": \"NeighbourGcThreshold2\"}}, \"net.ipv4.neigh.default.gc_thresh3\": {\"value\": {\"get_param\": \"NeighbourGcThreshold3\"}}, \"net.bridge.bridge-nf-call-arptables\": {\"value\": {\"get_param\": \"BridgeNfCallArpTables\"}}, \"net.bridge.bridge-nf-call-iptables\": {\"value\": {\"get_param\": \"BridgeNfCallIpTables\"}}, \"net.bridge.bridge-nf-call-ip6tables\": {\"value\": {\"get_param\": \"BridgeNfCallIp6Tables\"}}, \"fs.inotify.max_user_instances\": {\"value\": {\"if\": [\"is_inotify_intances_max_default\", {\"get_param\": \"InotifyInstancesMax\"}, {\"get_param\": \"InotifyIntancesMax\"}]}}}, {\"if\": [\"fs_aio_max_number_set\", {\"fs.aio-max-nr\": {\"value\": {\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}}}]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_sysctl_settings\"]}]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (81,'2026-06-13 07:57:06',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(82,'2026-06-13 07:57:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"CinderBackupBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBackupBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"CinderBackupBackend\": {\"get_param\": \"CinderBackupBackend\"}, \"CinderBackupRbdPoolName\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"CephClientUserName\": {\"get_param\": \"CephClientUserName\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::cinder::backup_bundle::cinder_backup_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::backup_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::backup::manage_service\": false, \"cinder::backup::enabled\": false}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"puppet_config\", \"step_config\"]}, \"include tripleo::profile::pacemaker::cinder::backup_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Backup tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Backup HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-backup temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-backup\", \"tripleo_ha_image_update_new_image\": \"{{cinder_backup_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_backup_image}}\"}, \"when\": [\"(pcmk_cinder_backup_image != \\\"\\\")\", \"(pcmk_cinder_backup_image != cinder_backup_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-backup container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_backup_image == cinder_backup_image_latest\", \"fail_msg\": \"cinder-backup image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder-backup container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"cinder_backup fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder backup bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA cinder_backup container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"Prepare switch of cinder_backup image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_backup image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-backup | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_backup_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_backup image facts\", \"set_fact\": {\"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_backup_image_current\": \"{{cinder_backup_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_backup image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image_current}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}, {\"name\": \"Create cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_backup_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_backup_bootstrap_node={{cinder_backup_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_backup retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_backup_bootstrap_node\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Update the cinder_backup bundle to use the new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-backup container image={{cinder_backup_image_latest}}\"}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_backup retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}, {\"name\": \"Retag the pacemaker image for cinder_backup\", \"when\": [\"step|int == 3\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step3\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(83,'2026-06-13 07:57:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"FKQdo7NuIE9RbMdjCuC9b8sG\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(84,'2026-06-13 07:57:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(85,'2026-06-13 07:57:06',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(86,'2026-06-13 07:57:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::pacemaker::cinder::volume_bundle::cinder_volume_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::volume_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::volume::manage_service\": false, \"cinder::volume::enabled\": false, \"cinder::backend_host\": \"hostgroup\"}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\"], [\"include tripleo::profile::pacemaker::cinder::volume_bundle\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Volume tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Volume HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-volume temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-volume\", \"tripleo_ha_image_update_new_image\": \"{{cinder_volume_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_volume_image}}\"}, \"when\": [\"(pcmk_cinder_volume_image != \\\"\\\")\", \"(pcmk_cinder_volume_image != cinder_volume_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-volume container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_volume_image == cinder_volume_image_latest\", \"fail_msg\": \"cinder-volume image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"cinder_volume fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder volume bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"Prepare switch of cinder_volume image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_volume image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-volume | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_volume_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_volume image facts\", \"set_fact\": {\"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_volume_image_current\": \"{{cinder_volume_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_volume image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image_current}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}, {\"name\": \"Create cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_volume_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_volume_bootstrap_node={{cinder_volume_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_volume retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_volume_bootstrap_node\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"pcs resource bundle update cinder_volume for new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-volume container image={{cinder_volume_image_latest}}\"}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_volume retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}, {\"name\": \"Retag pacemaker cinder_volume\", \"when\": [\"step|int == 3\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"absent\"}}]}], {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}]}, \"post_upgrade_tasks\": [{\"name\": \"Start cinder_volume service (pacemaker)\", \"become\": true, \"when\": \"step|int == 1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(87,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(88,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (89,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for nova-compute containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"nova_statedir_ownership.py\": {\"mode\": \"0700\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_statedir_ownership.py\"}}, \"nova_wait_for_compute_service.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_wait_for_compute_service.py\"}}}}, \"nova_compute_common_deploy_steps_tasks\": {\"description\": \"Common host prep tasks for nova-compute services (compute + ironic)\", \"value\": [{\"block\": [{\"name\": \"is additonal Cell?\", \"set_fact\": {\"nova_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"check if discover hosts is required\", \"when\": [\"not nova_additional_cell|bool\", \"nova_cellv2_discovery_done is not defined\"], \"block\": [{\"name\": \"discover via nova_manager?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_manager\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_manager\"}, \"when\": [\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\"]}, {\"name\": \"discover via nova_api?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_api\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_api\"}, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\", \"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\"]}, {\"name\": \"Warn if no discovery host available\", \"fail\": {\"msg\": \"No hosts available to run nova cell_v2 host discovery.\"}, \"ignore_errors\": true, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\"]}, {\"name\": \"Discovering nova hosts\", \"command\": \"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\", \"become\": true, \"changed_when\": false, \"delegate_to\": \"{{ nova_cellv2_discovery_delegate_host }}\", \"when\": [\"nova_cellv2_discovery_delegate_host is defined\"]}, {\"set_fact\": {\"nova_cellv2_discovery_done\": true}}]}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(90,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(91,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder API service\\n\", \"parameters\": {\"ContainerCinderApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.api\", \"file\": \"/var/log/containers/cinder/cinder-api.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"CinderDefaultVolumeType\": {\"default\": \"tripleo\", \"description\": \"The name of Cinder\'s default volume type.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \".*\\\\S.*\", \"description\": \"The default volume type name cannot be empty.\\n\"}]}, \"CinderEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Cinder database.\\n\", \"type\": \"boolean\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"FTS40yQUd1tjPXxKb5UK1sScA\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionCinderApi\": {\"default\": \"overcloud-cinder-api\", \"type\": \"string\"}, \"CinderWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for cinder::wsgi::apache\", \"default\": 1}, \"CinderApiPolicies\": {\"description\": \"A hash of policies to configure for Cinder API.\\ne.g. { cinder-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"CinderApiWsgiTimeout\": {\"default\": 60, \"description\": \"The number of seconds until a Cinder API WSGI connection times out.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderApiImage\": \"ContainerCinderApiImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderApiImage\": {\"get_param\": \"ContainerCinderApiImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder API role.\", \"value\": {\"service_name\": \"cinder_api\", \"firewall_rules\": {\"119 cinder\": {\"dport\": [8776]}}, \"firewall_frontend_rules\": {\"100 cinder_haproxy_frontend\": {\"dport\": [8776]}}, \"firewall_ssl_frontend_rules\": {\"100 cinder_haproxy_frontend_ssl\": {\"dport\": [13776]}}, \"keystone_resources\": {\"cinder\": {\"users\": {\"cinder\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}}, \"cinderv3\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"CinderV3Public\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"CinderV3Internal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"CinderV3Admin\", \"uri\"]}}, \"users\": {\"cinderv3\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"volumev3\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"keystone_resources_managed\": false}, {\"cinder::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::authtoken::project_name\": \"service\", \"cinder::keystone::authtoken::user_domain_name\": \"Default\", \"cinder::keystone::authtoken::project_domain_name\": \"Default\", \"cinder::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::keystone::authtoken::interface\": \"internal\", \"cinder::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"cinder::policy::policies\": {\"get_param\": \"CinderApiPolicies\"}, \"cinder::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"cinder::api::default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}, \"cinder::api::enable_proxy_headers_parsing\": true, \"tripleo::profile::base::cinder::cinder_enable_db_purge\": {\"get_param\": \"CinderEnableDBPurge\"}, \"cinder::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"cinder::api::service_name\": \"httpd\", \"cinder::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::vhost_custom_fragment\": {\"str_replace\": {\"template\": \"Timeout TIMEOUT\", \"params\": {\"TIMEOUT\": {\"get_param\": \"CinderApiWsgiTimeout\"}}}}, \"cinder::wsgi::apache::workers\": {\"get_param\": \"CinderWorkers\"}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_api\": [{\"get_param\": \"CinderApiLoggingSource\"}]}, \"mysql\": {\"cinder::db::mysql::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::db::mysql::user\": \"cinder\", \"cinder::db::mysql::host\": \"%\", \"cinder::db::mysql::dbname\": \"cinder\"}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line,cinder_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec cinder_api su cinder -s /bin/bash -c \'cinder-manage db sync --bump-versions\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"cinder_api_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_3\": {\"cinder_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"cinder_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"cinder_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron cinder\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/cinder-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}, {\"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_api\", \"cinder_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}], \"external_deploy_tasks\": [{\"name\": \"Clean up legacy Cinder keystone catalog entries\", \"become\": true, \"openstack.cloud.catalog_service\": {\"cloud\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}, \"name\": \"{{ item.service_name }}\", \"service_type\": \"{{ item.service_type }}\", \"state\": \"absent\"}, \"loop\": [{\"service_name\": \"cinderv2\", \"service_type\": \"volumev2\"}, {\"service_name\": \"cinderv3\", \"service_type\": \"volume\"}], \"loop_control\": {\"index_var\": \"cinder_api_service\"}, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"]}, {\"name\": \"Manage Cinder\'s default volume type\", \"become\": true, \"vars\": {\"default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}}, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"when\": [\"step|int == 5\", \"not ansible_check_mode|bool\"], \"shell\": \"if ! openstack volume type show \\\"{{ default_volume_type }}\\\"; then\\n    openstack volume type create --public \\\"{{ default_volume_type }}\\\"\\nfi\\neval $(openstack volume type show __DEFAULT__ -f shell -c id -c description)\\nif [ -n \\\"$id\\\" ]; then\\n    if ! openstack volume type delete $id ; then\\n        tripleo_descr=\\\"For internal use, \'{{ default_volume_type }}\' is the default volume type\\\"\\n        if [ \\\"$description\\\" != \\\"$tripleo_descr\\\" ]; then\\n            openstack volume type set $id --description \\\"$tripleo_descr\\\"\\n        fi\\n    fi\\nfi\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"changed_when\": false}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(92,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Scheduler service\\n\", \"parameters\": {\"ContainerCinderSchedulerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderSchedulerLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.scheduler\", \"file\": \"/var/log/containers/cinder/cinder-scheduler.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCinderScheduler\": {\"default\": \"overcloud-cinder-scheduler\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderSchedulerImage\": \"ContainerCinderSchedulerImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderSchedulerImage\": {\"get_param\": \"ContainerCinderSchedulerImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Scheduler role.\", \"value\": {\"service_name\": \"cinder_scheduler\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderScheduler\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::scheduler::scheduler_driver\": \"cinder.scheduler.filter_scheduler.FilterScheduler\"}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_scheduler\": [{\"get_param\": \"CinderSchedulerLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::scheduler\"], [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_scheduler.json\": {\"command\": \"/usr/bin/cinder-scheduler --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}}, \"docker_config\": {\"step_2\": {\"cinder_scheduler_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_scheduler\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_common_volumes\"]}, [\"/var/lib/kolla/config_files/cinder_scheduler.json:/var/lib/kolla/config_files/config.json:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder scheduler container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_scheduler\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_scheduler\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(93,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(94,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(95,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CinderBackupBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupWorkers\": {\"type\": \"number\", \"default\": 1, \"description\": \"The number of cinder-backup processes to launch.\"}, \"CinderBackupMaxOperations\": {\"type\": \"number\", \"default\": 15, \"description\": \"The maximum number of concurrent cinder backup/restore operations (0 means unlimited).\"}, \"CinderBackupCompressionAlgorithm\": {\"default\": \"zlib\", \"description\": \"The compression algorithm used by Cinder Backup backends that are based on Cinder\'s \\\"chunked\\\" backup driver. This includes the swift, nfs, gcs and s3 backends. The ceph backend does not support the feature.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"zlib\", \"bzip2\", \"zstd\"]}]}, \"CinderBackupRbdClusterName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The Ceph cluster where backups are to be stored. If no value is specified then the CephClusterName value is used.\"}, \"CinderBackupRbdClientUserName\": {\"default\": \"\", \"type\": \"string\", \"description\": \"The Ceph client name used by the backup service. If no value is specified then the CephClientUserName value is used.\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CinderBackupNfsShare\": {\"default\": \"\", \"description\": \"NFS share to be mounted\", \"type\": \"string\"}, \"CinderBackupNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options passed to the NFS client. See NFS man page for details.\", \"type\": \"string\"}, \"CinderBackupGcsCredentials\": {\"default\": {}, \"description\": \"The GCS service account credentials, in JSON format.\", \"type\": \"json\"}, \"CinderBackupGcsProjectId\": {\"default\": \"\", \"description\": \"The GCS project ID.\", \"type\": \"string\"}, \"CinderBackupGcsBucket\": {\"default\": \"volumebackups\", \"description\": \"The GCS bucket where backups are to be stored.\", \"type\": \"string\"}, \"CinderBackupGcsBucketLocation\": {\"default\": \"\", \"description\": \"If set, it specifies the location where the GCS bucket should be created.\", \"type\": \"string\"}, \"CinderBackupS3EndpointUrl\": {\"default\": \"\", \"description\": \"The URL where the S3 server is listening.\", \"type\": \"string\"}, \"CinderBackupS3AccessKey\": {\"default\": \"\", \"description\": \"The S3 query token access key.\", \"type\": \"string\"}, \"CinderBackupS3SecretKey\": {\"default\": \"\", \"description\": \"The S3 query token secret key.\", \"type\": \"string\"}, \"CinderBackupS3Bucket\": {\"default\": \"volumebackups\", \"description\": \"The S3 bucket where backups are to be stored.\", \"type\": \"string\"}, \"MonitoringSubscriptionCinderBackup\": {\"default\": \"overcloud-cinder-backup\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderBackup\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::backup::backup_workers\": {\"get_param\": \"CinderBackupWorkers\"}, \"cinder::backup::backup_max_operations\": {\"get_param\": \"CinderBackupMaxOperations\"}}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, {\"cinder::backup::ceph::backup_ceph_user\": {\"str_replace\": {\"template\": \"USERNAME\", \"params\": {\"USERNAME\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClientUserName\"}, \"\"]}, {\"get_param\": \"CephClientUserName\"}, {\"get_param\": \"CinderBackupRbdClientUserName\"}]}}}}, \"cinder::backup::ceph::backup_ceph_pool\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"cinder::backup::ceph::backup_ceph_conf\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.conf\", \"params\": {\"CLUSTER\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClusterName\"}, \"\"]}, {\"get_param\": \"CephClusterName\"}, {\"get_param\": \"CinderBackupRbdClusterName\"}]}}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"swift\"]}, {\"cinder::backup::swift::backup_swift_container\": \"volumebackups\", \"cinder::backup::swift::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}, \"cinder::backup::swift::swift_catalog_info\": \"object-store:swift:internalURL\"}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"nfs\"]}, {\"cinder::backup::nfs::backup_share\": {\"get_param\": \"CinderBackupNfsShare\"}, \"cinder::backup::nfs::backup_mount_options\": {\"get_param\": \"CinderBackupNfsMountOptions\"}, \"cinder::backup::nfs::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"gcs\"]}, {\"tripleo::profile::base::cinder::backup::gcs::credentials\": {\"get_param\": \"CinderBackupGcsCredentials\"}, \"cinder::backup::google::backup_gcs_project_id\": {\"get_param\": \"CinderBackupGcsProjectId\"}, \"cinder::backup::google::backup_gcs_bucket\": {\"get_param\": \"CinderBackupGcsBucket\"}, \"cinder::backup::google::backup_gcs_bucket_location\": {\"get_param\": \"CinderBackupGcsBucketLocation\"}, \"cinder::config::cinder_config\": {\"DEFAULT/backup_compression_algorithm\": {\"value\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"s3\"]}, {\"cinder::backup::s3::backup_s3_endpoint_url\": {\"get_param\": \"CinderBackupS3EndpointUrl\"}, \"cinder::backup::s3::backup_s3_store_access_key\": {\"get_param\": \"CinderBackupS3AccessKey\"}, \"cinder::backup::s3::backup_s3_store_secret_key\": {\"get_param\": \"CinderBackupS3SecretKey\"}, \"cinder::backup::s3::backup_s3_store_bucket\": {\"get_param\": \"CinderBackupS3Bucket\"}, \"cinder::backup::s3::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_backup\": [{\"get_param\": \"DockerCinderBackupLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"str_replace\": {\"template\": \"include tripleo::profile::base::cinder::backup::DRIVER\", \"params\": {\"DRIVER\": {\"get_param\": \"CinderBackupBackend\"}}}}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_backup\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"deploy_steps_tasks\": [{\"name\": \"Clean up when switching cinder-backup from pcmk to active-active\", \"when\": [\"step|int == 1\"], \"become\": true, \"block\": [{\"name\": \"Check if cinder-backup is running under pacemaker\", \"command\": \"pcs status\", \"register\": \"cinder_backup_pcs_status\", \"check_mode\": false, \"failed_when\": false, \"changed_when\": false}, {\"when\": [\"\\\"cinder-backup\\\" in cinder_backup_pcs_status.stdout\"], \"block\": [{\"name\": \"Remove the openstack-cinder-backup pcs resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"delete\"}, \"run_once\": true}, {\"name\": \"Identify the cinder-backup pcmklatest container image\", \"shell\": \"{{container_cli}} images | awk \'$1 ~ \\\"cinder-backup\\\" && $2 == \\\"pcmklatest\\\" {print $1\\\":\\\"$2}\'\", \"register\": \"cinder_backup_pcmklatest_image\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Remove the cinder-backup pcmklatest container image\", \"command\": \"{{container_cli}} rmi {{cinder_backup_pcmklatest_image.stdout}}\", \"when\": [\"cinder_backup_pcmklatest_image.stdout|length > 0\"]}]}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder backup container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_backup\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_backup\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"CephClientUserName\": \"openstack\", \"CinderBackupBackend\": \"swift\", \"CinderBackupRbdPoolName\": \"backups\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (96,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Modular Libvirt Service\\n\", \"parameters\": {\"ContainerNovaLibvirtImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtUlimit\": {\"default\": [\"nofile=131072\", \"nproc=126960\"], \"description\": \"ulimit for Nova Libvirt Container\", \"type\": \"comma_delimited_list\"}, \"ContainerNovaLibvirtPidsLimit\": {\"default\": 65536, \"description\": \"Tune nova_libvirt container PID limit (set to 0 for unlimited) (defaults to 65536)\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"UseCustomGnuTlsQemuCryptoPolicy\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If set to true, will use CustomGnuTlsQemuCryptoPolicy in crypto policy.\"}, \"CustomGnuTlsQemuCryptoPolicy\": {\"default\": \"QEMU=NONE:+ECDHE-RSA:+ECDHE-ECDSA:+RSA:+DHE-RSA:+GROUP-X25519:+GROUP-X448:+GROUP-SECP256R1:+GROUP-SECP384R1:+GROUP-SECP521R1:+GROUP-FFDHE2048:+GROUP-FFDHE3072:+GROUP-FFDHE4096:+GROUP-FFDHE6144:+GROUP-FFDHE8192:+CHACHA20-POLY1305:+AEAD:+SHA1:+SHA512:+SIGN-ECDSA-SHA256:+SIGN-ECDSA-SECP256R1-SHA256:+SIGN-ECDSA-SHA384:+SIGN-ECDSA-SECP384R1-SHA384:+SIGN-ECDSA-SHA512:+SIGN-ECDSA-SECP521R1-SHA512:+SIGN-EdDSA-Ed25519:+SIGN-EdDSA-Ed448:+SIGN-RSA-PSS-SHA256:+SIGN-RSA-PSS-SHA384:+SIGN-RSA-PSS-SHA512:+SIGN-RSA-PSS-RSAE-SHA256:+SIGN-RSA-PSS-RSAE-SHA384:+SIGN-RSA-PSS-RSAE-SHA512:+SIGN-RSA-SHA256:+SIGN-RSA-SHA384:+SIGN-RSA-SHA512:+VERS-TLS1.3:+VERS-TLS1.2:+VERS-DTLS1.2\", \"description\": \"Custom GnuTls Crypto Policy for QEMU\", \"type\": \"string\"}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"UseTLSTransportForVnc\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\"}, \"UseTLSTransportForNbd\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt NBD and configure the relevant keys for libvirt.\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"LibvirtCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuServerCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuClientCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"LibvirtCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for TLS in libvirt. This file will be symlinked to the default CA path in libvirt, which is /etc/pki/CA/cacert.pem. Note that due to limitations GNU TLS, which is the TLS backend for libvirt, the file must be less than 65K (so we can\'t use the system\'s CA bundle). This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"QemuCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for qemu. This file will be symlinked to the default CA path, which is /etc/pki/qemu/ca-cert.pem. This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"VhostuserSocketGroup\": {\"default\": \"qemu\", \"description\": \"The vhost-user socket directory group name. Defaults to \'qemu\'. When vhostuser mode is \'dpdkvhostuserclient\' (which is the default mode), the vhost socket is created by qemu.\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtType\": {\"type\": \"string\", \"default\": \"qemu\"}, \"LibvirtEnabledPerfEvents\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"This is a performance event list which could be used as monitor. For example - ``enabled_perf_events = cmt, mbml, mbmt`` The supported events list can be found in https://libvirt.org/html/libvirt-libvirt-domain.html , which you may need to search key words ``VIR_PERF_PARAM_*``\"}, \"MonitoringSubscriptionNovaLibvirt\": {\"default\": \"overcloud-nova-libvirt\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"LibvirtTLSPassword\": {\"description\": \"The password for the libvirt service when TLS is enabled\", \"type\": \"string\", \"hidden\": true, \"default\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\"}, \"QemuDefaultTLSVerify\": {\"description\": \"Whether to enable or disable TLS client certificate verification. Enabling this option will reject any client who does not have a certificate signed by the CA in /etc/pki/qemu/ca-cert.pem\\n\", \"default\": true, \"type\": \"boolean\"}, \"LibvirtLogFilters\": {\"description\": \"Defines a filter in libvirt daemon to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\"}, \"LibvirtVirtlogdLogFilters\": {\"description\": \"Defines a filter in virtlogd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:logging 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtsecretdLogFilters\": {\"description\": \"Defines a filter in virtsecretd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtnodedevdLogFilters\": {\"description\": \"Defines a filter in virtnodedevd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtstoragedLogFilters\": {\"description\": \"Defines a filter in virtstoraged to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtqemudLogFilters\": {\"description\": \"Defines a filter in virtqemud to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtproxydLogFilters\": {\"description\": \"Defines a filter in virtproxyd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtTLSPriority\": {\"description\": \"Override the compile time default TLS priority string.\\n\", \"type\": \"string\", \"default\": \"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\"}, \"NovaLibvirtOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaEnableVirtlogdContainerWrapper\": {\"description\": \"Generate a virtlogd wrapper script so that virtlogd launches in a separate container and won\'t get restarted e.g. on minor updates.\", \"type\": \"boolean\", \"default\": true}, \"VirtlogdWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}}, \"conditions\": {\"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"libvirt_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCACert\"}, \"\"]}}, \"need_libvirt_secret\": {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaEnableRbdBackend\"}, true]}]}, {\"get_param\": \"CinderEnableRbdBackend\"}]}, \"use_tls_for_vnc\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForVnc\"}]}, \"libvirt_vnc_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtVncCACert\"}, \"\"]}}, \"use_tls_for_nbd\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForNbd\"}]}, \"qemu_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuCACert\"}, \"\"]}}, \"key_size_libvirt_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_client_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuClientCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_server_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuServerCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"vhostuser_socket_group\": \"VhostuserSocketGroup\", \"nova_libvirt_opt_volumes\": \"NovaLibvirtOptVolumes\", \"ContainerNovaLibvirtImage\": \"ContainerNovaLibvirtImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"VhostuserSocketGroup\": {\"get_param\": \"VhostuserSocketGroup\"}, \"NovaLibvirtOptVolumes\": {\"get_param\": \"NovaLibvirtOptVolumes\"}, \"ContainerNovaLibvirtImage\": {\"get_param\": \"ContainerNovaLibvirtImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}, \"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NovaLibvirtLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaLibvirt\"}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLibvirtCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Libvirt service.\", \"value\": {\"service_name\": \"nova_libvirt\", \"firewall_rules\": {\"200 nova_libvirt\": {\"dport\": [16514, \"61152-61215\", \"5900-6923\"]}}, \"ansible_group_vars\": {\"tripleo_nova_libvirt_virsh_container\": \"nova_virtproxyd\"}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaLibvirt\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"config_settings\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\": {\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\": \"/var/lib/container-config-scripts/virtlogd_wrapper\", \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"tripleo::profile::base::nova::virtlogd_wrapper::debug\": {\"if\": [{\"get_param\": \"VirtlogdWrapperDebug\"}, true, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}]}, \"nova::compute::libvirt::migration_support\": false, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::nova::migration::client::libvirt_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::libvirt::services::libvirt_virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::enabled_perf_events\": {\"get_param\": \"LibvirtEnabledPerfEvents\"}, \"nova::compute::libvirt::qemu::configure_qemu\": true, \"nova::compute::libvirt::qemu::max_files\": 32768, \"nova::compute::libvirt::qemu::max_processes\": 131072, \"nova::migration::qemu::configure_qemu\": true, \"nova::migration::qemu::migration_port_min\": 61152, \"nova::migration::qemu::migration_port_max\": 61215, \"nova::compute::libvirt::vncserver_listen\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::libvirt::log_filters\": {\"get_param\": \"LibvirtLogFilters\"}, \"nova::compute::libvirt::virtlogd::log_filters\": {\"get_param\": \"LibvirtVirtlogdLogFilters\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::compute::libvirt::virtsecretd::log_filters\": {\"get_param\": \"LibvirtVirtsecretdLogFilters\"}, \"nova::compute::libvirt::virtnodedevd::log_filters\": {\"get_param\": \"LibvirtVirtnodedevdLogFilters\"}, \"nova::compute::libvirt::virtstoraged::log_filters\": {\"get_param\": \"LibvirtVirtstoragedLogFilters\"}, \"nova::compute::libvirt::virtqemud::log_filters\": {\"get_param\": \"LibvirtVirtqemudLogFilters\"}, \"nova::compute::libvirt::virtproxyd::log_filters\": {\"get_param\": \"LibvirtVirtproxydLogFilters\"}, \"tripleo::profile::base::nova::libvirt::modular_libvirt\": true, \"nova::compute::libvirt::services::modular_libvirt\": true, \"nova::compute::libvirt::modular_libvirt\": true, \"nova::migration::libvirt::modular_libvirt\": true}, {\"if\": [\"use_tls_for_live_migration\", {\"tripleo::profile::base::nova::migration::client::libvirt_tls\": true, \"tripleo::profile::base::nova::libvirt::tls_password\": {\"get_param\": [\"LibvirtTLSPassword\"]}, \"nova::compute::libvirt::qemu::default_tls_verify\": {\"get_param\": \"QemuDefaultTLSVerify\"}, \"nova::compute::libvirt::tls_priority\": {\"get_param\": \"LibvirtTLSPriority\"}, \"nova::migration::libvirt::listen_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}, {\"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}]}, {\"if\": [\"use_tls_for_vnc\", {\"nova::compute::libvirt::qemu::vnc_tls\": true, \"nova::compute::libvirt::qemu::vnc_tls_verify\": true}]}, {\"if\": [\"use_tls_for_nbd\", {\"nova::compute::libvirt::qemu::nbd_tls\": true, \"nova::migration::libvirt::live_migration_with_native_tls\": true}]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_virtlogd.json\": {\"command\": {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"/usr/local/bin/virtlogd_wrapper\", \"/usr/sbin/virtlogd --config /etc/libvirt/virtlogd.conf\"]}, \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtsecretd.json\": {\"command\": \"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtnodedevd.json\": {\"command\": \"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtstoraged.json\": {\"command\": \"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtqemud.json\": {\"command\": \"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtproxyd.json\": {\"command\": \"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}}, \"container_config_scripts\": {\"nova_libvirt_init_secret.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_libvirt_init_secret.sh\"}}}, \"docker_config\": {\"step_2\": {\"nova_virtqemud_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"net\": \"none\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"user\": \"root\", \"volumes\": [\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R tss:tss /var/log/swtpm\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"create_virtlogd_wrapper\": {\"start_order\": 1, \"detach\": false, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::nova::virtlogd_wrapper\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_3\": {\"map_merge\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, {\"nova_virtlogd_wrapper\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {\"nova_virtlogd\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}, {\"nova_virtsecretd\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtnodedevd\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtstoraged\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtqemud\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\", {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, \"/etc/crypto-policies:/etc/crypto-policies:ro\"]}]]}}}, {\"nova_virtproxyd\": {\"start_order\": 5, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}]}, \"step_4\": {\"if\": [\"need_libvirt_secret\", {\"nova_libvirt_init_secret\": {\"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"security_opt\": [\"label=disable\"], \"privileged\": false, \"user\": \"root\", \"cgroupns\": \"host\", \"net\": \"host\", \"environment\": {\"LIBVIRT_DEFAULT_URI\": \"qemu:///system\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/nova_libvirt/etc/nova:/etc/nova\", \"/etc/libvirt:/etc/libvirt\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/lib/container-config-scripts/nova_libvirt_init_secret.sh:/nova_libvirt_init_secret.sh:ro\", {\"str_replace\": {\"template\": \"HOST_CEPH:/etc/ceph:ro\", \"params\": {\"HOST_CEPH\": {\"get_param\": \"CephConfigPath\"}}}}]]}, \"command\": {\"list_join\": [\" \", [{\"str_replace\": {\"template\": \"/nova_libvirt_init_secret.sh CLUSTER:USER\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}], {\"repeat\": {\"template\": \"<%ceph_info%>\", \"for_each\": {\"<%ceph_info%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\":\\\" + $.get(\\\"CephClientUserName\\\", $u))\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Ensure recovery of containerized virtqemud\", \"when\": \"step|int == 4\", \"become\": true, \"block\": [{\"name\": \"Create virtqemud recovery script\", \"copy\": {\"dest\": \"/usr/libexec/recover_tripleo_nova_virtqemud.sh\", \"mode\": \"0755\", \"content\": \"#!/bin/bash\\npgrep -f /sbin/virtqemud\\n[ $? -eq 0 ] && exit 0\\nkill -9 $(cat /run/nova_virtqemud.pid)\\n\"}}, {\"name\": \"Create virtqemud recovery trigger service\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud\\nAfter=tripleo_nova_virtqemud.service\\nRequisite=tripleo_nova_virtqemud.service\\n[Service]\\nType=oneshot\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Create virtqemud recovery trigger timer\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\nPartOf=tripleo_nova_virtqemud.service\\n[Timer]\\nOnCalendar=*:5/10\\nOnActiveSec=120\\nOnUnitActiveSec=60\\nRandomizedDelaySec=1m\\n[Install]\\nWantedBy=timers.target\\n\"}}, {\"name\": \"Enable virtqemud recovery trigger service\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.service\", \"enabled\": true, \"daemon_reload\": true}}, {\"name\": \"Enable virtqemud recovery trigger timer\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.timer\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"register\": \"virtqemud_recover_timer_result\"}, {\"name\": \"Really enable virtqemud recovery trigger timer\", \"shell\": {\"cmd\": \"systemctl enable --now tripleo_nova_virtqemud_recover.timer\"}, \"when\": \"virtqemud_recover_timer_result.status.UnitFileState != \\\"enabled\\\"\"}]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/libvirt\", \"/etc/pki/libvirt/private\", \"/etc/pki/qemu\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"libvirt-server-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to libvirt dirs\\ncp CACERT /etc/pki/CA/cacert.pem\\nchown root:root /etc/pki/CA/cacert.pem\\nchmod 644 /etc/pki/CA/cacert.pem\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"params\": {\"CACERT\": {\"if\": [\"libvirt_specific_ca_set\", {\"get_param\": \"LibvirtCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"libvirt-client-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to libvirt dirs\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-server-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to qemu dir\\ncp CACERT /etc/pki/qemu/ca-cert.pem\\nchown root:root /etc/pki/qemu/ca-cert.pem\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\nchgrp qemu /etc/pki/qemu/server-*\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\nchmod 0640 /etc/pki/qemu/server-key.pem\\n\", \"params\": {\"CACERT\": {\"if\": [\"qemu_specific_ca_set\", {\"get_param\": \"QemuCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_qemu_server_override_set\", {\"get_param\": \"QemuServerCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-client-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to qemu dir\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\nchgrp qemu /etc/pki/qemu/client-*\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\nchmod 0640 /etc/pki/qemu/client-key.pem\\n\", \"key_size\": {\"if\": [\"key_size_qemu_client_override_set\", {\"get_param\": \"QemuClientCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]]}, [{\"name\": \"Set up systemd target for libvirt services\", \"when\": \"step|int == 4\", \"block\": [{\"name\": \"Create systemd file\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt.target\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"[Unit]\\nWants=tripleo_nova_virtsecretd.service\\nWants=tripleo_nova_virtnodedevd.service\\nWants=tripleo_nova_virtstoraged.service\\nWants=tripleo_nova_virtproxyd.service\\nWants=tripleo_nova_virtqemud.service\\nAfter=tripleo_nova_virtsecretd.service\\nAfter=tripleo_nova_virtnodedevd.service\\nAfter=tripleo_nova_virtstoraged.service\\nAfter=tripleo_nova_virtproxyd.service\\nAfter=tripleo_nova_virtqemud.service\\n\"}, \"become\": true, \"register\": \"libvirt_target_result\"}, {\"name\": \"Reload systemd\", \"systemd\": {\"name\": \"tripleo_nova_libvirt.target\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"become\": true, \"when\": \"libvirt_target_result.changed\"}]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\", \"mode\": \"{{ item.mode | default(omit) }}\"}, \"with_items\": [{\"path\": \"/etc/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/secrets\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/qemu\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/cache/libvirt\"}, {\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/run/libvirt\"}, {\"path\": \"/var/log/containers/libvirt/swtpm\", \"setype\": \"container_file_t\", \"mode\": \"0770\"}]}, {\"name\": \"ensure qemu group is present on the host\", \"group\": {\"name\": \"qemu\", \"gid\": 107, \"state\": \"present\"}}, {\"name\": \"ensure qemu user is present on the host\", \"user\": {\"name\": \"qemu\", \"uid\": 107, \"group\": \"qemu\", \"state\": \"present\", \"shell\": \"/sbin/nologin\", \"comment\": \"qemu user\"}}, {\"name\": \"create directory for vhost-user sockets with qemu ownership\", \"file\": {\"path\": \"/var/lib/vhost_sockets\", \"state\": \"directory\", \"owner\": \"qemu\", \"group\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"vhostuser_socket_group\"]}, \"setype\": \"virt_cache_t\", \"seuser\": \"system_u\"}}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"with_items\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": \"libvirt_installed.rc == 0\"}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}, {\"name\": \"Enable os_enable_vtpm SELinux boolean for vTPM\", \"seboolean\": {\"name\": \"os_enable_vtpm\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, [{\"name\": \"set gnutls_qemu_config_crypto_policy fact\", \"set_fact\": {\"gnutls_qemu_config_crypto_policy\": {\"get_param\": \"CustomGnuTlsQemuCryptoPolicy\"}}}, {\"name\": \"create gnutls-qemu.config\", \"copy\": {\"dest\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"{{ gnutls_qemu_config_crypto_policy }}\\n\"}, \"register\": \"update_gnutls_config\"}], [{\"name\": \"remove gnutls-qemu.config\", \"file\": {\"path\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"state\": \"absent\"}, \"register\": \"update_gnutls_config\"}]]}, {\"name\": \"update crypto policies\", \"command\": \"update-crypto-policies\", \"when\": \"update_gnutls_config.changed\"}]]}, \"metadata_settings\": {\"list_concat\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"libvirt\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"qemu\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"libvirt-vnc\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}]]}]}, \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Fail if we are on RHEL8 as this is monolithic libvirt deployment\", \"when\": [\"step|int == 0\", \"\'system_upgrade\' not in ansible_run_tags\", \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"], \"fail\": {\"msg\": \"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\"}}, {\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Get container virtlogd image\", \"when\": \"step|int == 1\", \"tags\": \"always\", \"set_fact\": {\"virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}}}, {\"name\": \"Force pull image novalibvirt\", \"when\": [\"step|int == 1\"], \"containers.podman.podman_image\": {\"name\": \"{{ virtlogd_image }}\", \"force\": true}}, {\"name\": \"Diff OS release in container image and baremetal\", \"when\": \"step|int == 1\", \"shell\": \"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"failed_when\": false, \"register\": \"libvirt_ubi_diff\"}, {\"name\": \"Fail if UBI of the container does not match RHEL of running host\", \"when\": [\"\'system_upgrade\' not in ansible_run_tags\", \"step|int == 1\", \"libvirt_ubi_diff.rc == 1\"], \"fail\": {\"msg\": \"The host operating system versus container UBI does not match.\\n{{ libvirt_ubi_diff.stdout }}\\nMost likely container passed to NovaLibvirt was EL8 one.\\nYou have to pass the correct container for container-image-prepare.\\nIf you would continue all running workloads would get destroyed.\\n\"}}], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [{\"name\": \"Switch virtlogd image before system upgrade\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade\"], \"block\": [{\"name\": \"Get running image version\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"old_virtlogd_image\"}, {\"name\": \"Switch running image to new image in wrapper script\", \"shell\": \"set -o pipefail\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\n\", \"when\": [\"old_virtlogd_image.stdout != virtlogd_image\", \"old_virtlogd_image.stdout != \'\'\"]}]}]]}]}, \"update_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtCommon\", \"update_tasks\"]}, [{\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(97,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"FTS40yQUd1tjPXxKb5UK1sScA\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(98,'2026-06-13 07:57:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(99,'2026-06-13 07:57:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(100,'2026-06-13 07:57:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"FKQdo7NuIE9RbMdjCuC9b8sG\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(101,'2026-06-13 07:57:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"yes\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}}, \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"config_settings\": {\"tripleo::profile::base::sshd::bannertext\": {\"get_param\": \"BannerText\"}, \"tripleo::profile::base::sshd::motd\": {\"get_param\": \"MessageOfTheDay\"}, \"tripleo::profile::base::sshd::options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo::profile::base::sshd::password_authentication\": {\"get_param\": \"PasswordAuthentication\"}}, \"step_config\": \"include tripleo::profile::base::sshd\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(102,'2026-06-13 07:57:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"NovaServiceName\": \"compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(103,'2026-06-13 07:57:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (104,'2026-06-13 07:57:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(105,'2026-06-13 07:57:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(106,'2026-06-13 07:57:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(107,'2026-06-13 07:57:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(108,'2026-06-13 07:57:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(109,'2026-06-13 07:57:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(110,'2026-06-13 07:57:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"ynYFMrrhBYym7oMTANCe2Hdxj\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": true, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(111,'2026-06-13 07:57:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(112,'2026-06-13 07:57:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (113,'2026-06-13 07:57:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"SNMP client configured with Puppet, to facilitate Ceilometer Hardware monitoring in the undercloud. This service is required to enable hardware monitoring.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"FKQdo7NuIE9RbMdjCuC9b8sG\"}, \"SnmpdBindHost\": {\"description\": \"An array of bind host addresses on which SNMP daemon will listen.\", \"type\": \"comma_delimited_list\", \"default\": [\"udp:161\", \"udp6:[::1]:161\"]}, \"SnmpdOptions\": {\"description\": \"A string containing the commandline options passed to snmpd\", \"type\": \"string\", \"default\": \"-LS0-5d\"}, \"SnmpdIpSubnet\": {\"default\": \"\", \"description\": \"IP address/subnet on the snmpd network. If empty (default), SnmpdNetwork will be taken.\", \"type\": \"string\"}}, \"conditions\": {\"snmpd_network_unset\": {\"equals\": [{\"get_param\": \"SnmpdIpSubnet\"}, \"\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the SNMP services\", \"value\": {\"service_name\": \"snmp\", \"firewall_rules\": {\"if\": [\"snmpd_network_unset\", {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"SnmpdNetwork\"]}]}}, \"template\": {\"124 snmp <%net_cidr%>\": {\"dport\": 161, \"proto\": \"udp\", \"source\": \"<%net_cidr%>\"}}}}}, {\"124 snmp\": {\"dport\": 161, \"proto\": \"udp\", \"source\": {\"get_param\": \"SnmpdIpSubnet\"}}}]}, \"config_settings\": {\"tripleo::profile::base::snmp::snmpd_user\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"tripleo::profile::base::snmp::snmpd_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"snmp::agentaddress\": {\"get_param\": \"SnmpdBindHost\"}, \"snmp::snmpd_options\": {\"get_param\": \"SnmpdOptions\"}}, \"step_config\": \"include tripleo::profile::base::snmp\\n\", \"upgrade_tasks\": [{\"when\": \"step|int == 0\", \"block\": [{\"name\": \"Check if snmpd is enabled\", \"command\": \"systemctl is-enabled --quiet snmpd\", \"failed_when\": false, \"register\": \"snmpd_enabled_result\"}, {\"name\": \"Set fact snmpd_enabled\", \"set_fact\": {\"snmpd_enabled\": \"{{ snmpd_enabled_result.rc == 0 }}\"}}]}, {\"name\": \"Stop snmp service\", \"when\": [\"step|int == 1\", \"snmpd_enabled|bool\"], \"service\": \"name=snmpd state=stopped\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(114,'2026-06-13 07:57:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(115,'2026-06-13 07:57:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Firewall settings\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ExtraFirewallRules\": {\"default\": {}, \"description\": \"Mapping of firewall rules.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_firewall_rules\": \"ExtraFirewallRules\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraFirewallRules\": {\"get_param\": \"ExtraFirewallRules\"}}}]}}}}, \"conditions\": {\"no_ctlplane\": {\"equals\": [{\"get_params\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}, null]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO firewall settings\", \"value\": {\"service_name\": \"tripleo_firewall\", \"config_settings\": {\"tripleo::firewall::manage_firewall\": false, \"tripleo::firewall::purge_firewall_rules\": false}, \"ansible_group_vars\": {\"tripleo_nftables_debug\": {\"get_param\": \"Debug\"}}, \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"003 accept ssh from ctlplane subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": 22}}}}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_firewall_rules\"]}]}, \"host_prep_tasks\": [{\"if\": [\"no_ctlplane\", {\"name\": \"Failure - ctlplane subnet is unset\", \"fail\": {\"msg\": \"No CIDRs found in the ctlplane network tags.\\nPlease refer to the documentation in order to\\nset the correct network tags in DeployedServerPortMap.\\n\"}}, {\"name\": \"Notice - ctlplane subnet is set\", \"debug\": {\"msg\": \"CIDRs found in the ctlplane network tags.\\n\"}}]}], \"host_firewall_tasks\": [{\"name\": \"Run firewall role\", \"include_role\": {\"name\": \"tripleo_firewall\"}}], \"update_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}], \"upgrade_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"when\": [\"(step | int) == 3\"], \"block\": [{\"name\": \"blank ipv6 rule before activating ipv6 firewall.\", \"shell\": \"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\", \"args\": {\"creates\": \"/etc/sysconfig/ip6tables.n-o-upgrade\"}}, {\"name\": \"cleanup unmanaged rules pushed by iptables-services\", \"shell\": \"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\n\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -d fe80::\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(116,'2026-06-13 07:57:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(117,'2026-06-13 07:57:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(118,'2026-06-13 07:57:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova libvirt service\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"LibvirtDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Set to True to enable debugging libvirt services.\"}, \"LibvirtLogLevel\": {\"default\": 3, \"description\": \"Defines log level in libvirt to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtlogdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtlogd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtsecretdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtsecretd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtnodedevdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtnodedevd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtqemudLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtqemud to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtproxydLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtproxyd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtstoragedLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtstoraged to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": {\"nova::compute::libvirt::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/libvirtd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtLogLevel\"}]}}}}, \"nova::compute::libvirt::virtlogd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtlogd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtlogdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtsecretd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtsecretd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtsecretdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtnodedevd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtnodedevd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtnodedevdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtqemud::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtqemud.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtqemudLogLevel\"}]}}}}, \"nova::compute::libvirt::virtproxyd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtproxyd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtproxydLogLevel\"}]}}}}, \"nova::compute::libvirt::virtstoraged::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtstoraged.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtstoragedLogLevel\"}]}}}}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to file in the host.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/libvirt\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(119,'2026-06-13 07:57:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Qpid dispatch router service for metrics and monitoring purposes\\n\", \"parameters\": {\"ContainerMetricsQdrImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ContainerMetricsQdrConfigImage\": {\"description\": \"The container image to use for the qdrouterd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MonitoringSubscriptionQdr\": {\"default\": \"overcloud-qdr\", \"type\": \"string\"}, \"MetricsQdrLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.consoleauth\", \"file\": \"/var/log/containers/metrics_qdr/metrics_qdr.log\", \"startmsg.regex\": \"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\([a-z]+\\\\\\\\) \"}}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MetricsQdrConnectors\": {\"default\": [], \"description\": \"Connectors configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrSSLProfiles\": {\"default\": [{\"name\": \"sslProfile\"}], \"description\": \"SSL Profiles for the connectors (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAddresses\": {\"default\": [{\"prefix\": \"collectd\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/metering.sample\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/event.sample\", \"distribution\": \"multicast\"}], \"description\": \"Addresses configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAutoLinks\": {\"default\": [], \"description\": \"AutoLinks for the Configured Addresses\", \"type\": \"json\"}, \"MetricsQdrUseSSL\": {\"default\": false, \"description\": \"Set to true if it is required to use SSL or TLS on the connection for the local listener. !WARNING! Currently breaks connections from collectd and ceilometer.\", \"type\": \"boolean\"}, \"MetricsQdrUseEncryption\": {\"default\": false, \"description\": \"Set to true if it is required to encrypt connection to the peer for listener. Not currently implemented, use EnableInternalTLS instead. This option can be ignored.\", \"type\": \"boolean\"}, \"MetricsQdrSaslMechanisms\": {\"default\": \"ANONYMOUS\", \"description\": \"List of accepted SASL auth mechanisms for listener in format of comma separated list.\", \"type\": \"string\"}, \"MetricsQdrSslCertDb\": {\"default\": \"/etc/ipa/ca.crt\", \"description\": \"Path to SSL certificate db for listener.\", \"type\": \"string\"}, \"MetricsQdrSslCertFile\": {\"default\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"description\": \"Path to SSL certificate file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslKeyFile\": {\"default\": \"/etc/pki/tls/private/metrics_qdr.key\", \"description\": \"Path to SSL private key file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPwFile\": {\"default\": \"\", \"description\": \"Path to SSL password file for certificate key for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPassword\": {\"default\": \"\", \"description\": \"SSL password to be supplied for listener.\", \"type\": \"string\"}, \"MetricsQdrTrustedCerts\": {\"default\": \"\", \"description\": \"Path to file containing trusted certificates for listener.\", \"type\": \"string\"}, \"MetricsQdrAuthenticateClient\": {\"default\": false, \"description\": \"Authenticate the client using SSL/TLS\", \"type\": \"boolean\"}, \"MetricsQdrExternalEndpoint\": {\"default\": false, \"description\": \"Whether QDR should listen on external network interface. To enable listening on external network one must deploy QDRs in mesh mode.\", \"type\": \"boolean\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableSTF\": {\"default\": false, \"description\": \"Set to true to enable configuration for STF client.\", \"type\": \"boolean\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"QdrCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"listener_ssl_enabled\": {\"equals\": [{\"get_param\": \"MetricsQdrUseSSL\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"QdrCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMetricsQdrImage\": \"ContainerMetricsQdrImage\", \"ContainerMetricsQdrConfigImage\": \"ContainerMetricsQdrConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMetricsQdrImage\": {\"get_param\": \"ContainerMetricsQdrImage\"}, \"ContainerMetricsQdrConfigImage\": {\"get_param\": \"ContainerMetricsQdrConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the metrics Qdr role.\", \"value\": {\"service_name\": \"metrics_qdr\", \"firewall_rules\": {\"map_merge\": [{\"109 metrics qdr\": {\"dport\": [{\"get_param\": \"MetricsQdrPort\"}]}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"109 accept internal metrics qdr ctlplane subnet <%net_cidr%>\": {\"dport\": [5667, 5668]}}}}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionQdr\"}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_metrics_qdr\": [{\"get_param\": \"MetricsQdrLoggingSource\"}]}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::qdr::listener_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::haproxy::metrics_qdr\": {\"get_param\": \"MetricsQdrExternalEndpoint\"}, \"tripleo::profile::base::metrics::qdr::listener_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::qdr::username\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::qdr::password\": {\"get_param\": \"MetricsQdrPassword\"}, \"tripleo::profile::base::metrics::qdr::connectors\": {\"get_param\": \"MetricsQdrConnectors\"}, \"tripleo::profile::base::metrics::qdr::addresses\": {\"get_param\": \"MetricsQdrAddresses\"}, \"tripleo::profile::base::metrics::qdr::autolink_addresses\": {\"get_param\": \"MetricsQdrAutoLinks\"}, \"tripleo::profile::base::metrics::qdr::listener_require_ssl\": {\"if\": [\"listener_ssl_enabled\", true, false]}, \"tripleo::profile::base::metrics::qdr::listener_require_encrypt\": {\"get_param\": \"MetricsQdrUseEncryption\"}, \"tripleo::profile::base::metrics::qdr::listener_sasl_mech\": {\"get_param\": \"MetricsQdrSaslMechanisms\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\": {\"get_param\": \"MetricsQdrSslCertDb\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\": {\"get_param\": \"MetricsQdrSslCertFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\": {\"get_param\": \"MetricsQdrSslKeyFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\": {\"get_param\": \"MetricsQdrSslPwFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_password\": {\"get_param\": \"MetricsQdrSslPassword\"}, \"tripleo::profile::base::metrics::qdr::listener_trusted_certs\": {\"get_param\": \"MetricsQdrTrustedCerts\"}, \"qdr::log_enable\": \"info+\", \"qdr::log_output\": \"/var/log/qdrouterd/metrics_qdr.log\", \"qdr::listener_auth_peer\": {\"get_param\": \"MetricsQdrAuthenticateClient\"}}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"list_concat\": [{\"get_param\": \"MetricsQdrSSLProfiles\"}, [{\"name\": \"tlsProfile\", \"certFile\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"keyFile\": \"/etc/pki/tls/private/metrics_qdr.key\", \"caCertFile\": {\"get_param\": \"InternalTLSCAFile\"}}]]}}, {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"get_param\": \"MetricsQdrSSLProfiles\"}}]}, {\"if\": [\"enable_stf\", {\"tripleo::profile::base::metrics::qdr::interior_mesh_nodes\": \"\", \"tripleo::profile::base::metrics::qdr::router_mode\": \"edge\"}, null]}]}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"metrics_qdr\", \"network\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}, \"type\": \"node\"}], null]}, \"puppet_config\": {\"config_volume\": \"metrics_qdr\", \"step_config\": \"include tripleo::profile::base::metrics::qdr\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/metrics_qdr.json\": {\"command\": \"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/qdrouterd\", \"owner\": \"qdrouterd:qdrouterd\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/metrics_qdr.key\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"metrics_qdr_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\"]}, \"metrics_qdr\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"host\", \"user\": \"qdrouterd\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\", \"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\", \"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\", \"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"metrics_qdr\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"principal\": {\"str_replace\": {\"template\": \"metrics_qdr/{{fqdn_NETWORK}}@{{idm_realm}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep metrics_qdr)\\nservice_crt=\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/metrics_qdr.key\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_key\\\"\\n# Trigger a container restart to read the new certificate\\n{{container_cli}} restart \\\"$container_name\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"QdrCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/metrics_qdr\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/metrics_qdr\", \"setype\": \"container_file_t\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(120,'2026-06-13 07:57:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (121,'2026-06-13 07:57:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"DockerCinderVolumeUlimit\": {\"default\": [\"nofile=131072\"], \"description\": \"ulimit for Cinder Volume Container\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CinderISCSIAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the Iscsi Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderISCSIHelper\": {\"default\": \"lioadm\", \"description\": \"The iSCSI helper to use with cinder.\", \"type\": \"string\"}, \"CinderISCSIProtocol\": {\"default\": \"iscsi\", \"description\": \"Whether to use TCP (\'iscsi\') or iSER RDMA (\'iser\') for iSCSI\", \"type\": \"string\"}, \"CinderNfsAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NFS Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options for NFS mounts used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNfsServers\": {\"default\": \"\", \"description\": \"NFS servers used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderNfsSnapshotSupport\": {\"default\": false, \"description\": \"Whether to enable support for snapshots in the NFS driver. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"boolean\"}, \"CinderNasSecureFileOperations\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file operations are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNasSecureFilePermissions\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file permissions are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderRbdBackendName\": {\"type\": \"comma_delimited_list\", \"default\": \"tripleo_ceph\", \"description\": \"A list of Cinder RBD backend names.\"}, \"CinderRbdAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the RBD Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderRbdFlattenVolumeFromSnapshot\": {\"default\": false, \"description\": \"Whether RBD volumes created from a snapshot should be flattened in order to remove a dependency on the snapshot.\\n\", \"type\": \"boolean\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\"}, \"MonitoringSubscriptionCinderVolume\": {\"default\": \"overcloud-cinder-volume\", \"type\": \"string\"}, \"CinderEtcdLocalConnect\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When running Cinder A/A, whether to connect to Etcd via the local IP for the Etcd network. If set to true, the ip on the local node will be used. If set to false, the VIP on the Etcd network will be used instead. Defaults to false.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"120 iscsi initiator\": {\"dport\": 3260}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderVolume\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"CinderCommon\", \"cinder_volume_config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::base::cinder::volume::cinder_enable_iscsi_backend\": {\"get_param\": \"CinderEnableIscsiBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_rbd_backend\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_volume_cluster\": {\"get_param\": \"CinderVolumeCluster\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_mount_options\": {\"get_param\": \"CinderNfsMountOptions\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_servers\": {\"get_param\": \"CinderNfsServers\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_snapshot_support\": {\"get_param\": \"CinderNfsSnapshotSupport\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_operations\": {\"get_param\": \"CinderNasSecureFileOperations\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_permissions\": {\"get_param\": \"CinderNasSecureFilePermissions\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_helper\": {\"get_param\": \"CinderISCSIHelper\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_protocol\": {\"get_param\": \"CinderISCSIProtocol\"}, \"tripleo::profile::base::cinder::volume::rbd::backend_name\": {\"get_param\": \"CinderRbdBackendName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_pool_name\": {\"get_param\": \"CinderRbdPoolName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_user_name\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_flatten_volume_from_snapshot\": {\"get_param\": \"CinderRbdFlattenVolumeFromSnapshot\"}, \"tripleo::profile::base::cinder::volume::rbd::multi_config\": {\"get_param\": \"CinderRbdMultiConfig\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderISCSIAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::iscsi::backend_availability_zone\": {\"get_param\": \"CinderISCSIAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNfsAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nfs::backend_availability_zone\": {\"get_param\": \"CinderNfsAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderRbdAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::rbd::backend_availability_zone\": {\"get_param\": \"CinderRbdAvailabilityZone\"}}]}, {\"if\": [{\"get_param\": \"CinderEtcdLocalConnect\"}, {\"tripleo::profile::base::cinder::volume::etcd_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"EtcdNetwork\"]}}}}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_volume\": [{\"get_param\": \"CinderVolumeLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\", \"include tripleo::profile::base::cinder::volume\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_volume\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"ulimit\": {\"get_param\": \"DockerCinderVolumeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"upgrade_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder volume container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_volume\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_volume\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(122,'2026-06-13 07:57:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(123,'2026-06-13 07:57:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"FTS40yQUd1tjPXxKb5UK1sScA\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(124,'2026-06-13 07:57:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(125,'2026-06-13 07:57:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(126,'2026-06-13 07:57:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(127,'2026-06-13 07:57:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized OVN Metadata agent\\n\", \"parameters\": {\"ContainerOvnMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\"}, \"ContainerNeutronConfigImage\": {\"description\": \"The container image to use for the neutron config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"OvnMetadataAgentLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.neutron.agent.ovn-metadata\", \"file\": \"/var/log/containers/neutron/networking-ovn-metadata-agent.log\"}}, \"OVNEnableHaproxyDockerWrapper\": {\"description\": \"Generate a wrapper script so that haproxy is launched in a separate container.\", \"type\": \"boolean\", \"default\": true}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"OVNWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NeutronMetadataProxySharedSecret\": {\"description\": \"Shared secret to prevent spoofing\", \"type\": \"string\", \"hidden\": true, \"default\": \"9YON7EEIL9wZNadx52fLDIzpR\"}, \"NeutronMetadataWorkers\": {\"default\": 1, \"description\": \"Sets the number of worker processes for the neutron OVN metadata agent.\\nThe default value results in the configuration being left unset and a\\nsystem-dependent default will be chosen (usually the number of\\nprocessors). Please note that this can result in a large number of\\nprocesses and memory consumption on systems with a large core count. On\\nsuch systems it is recommended that a non-default value be selected that\\nmatches the load requirements.\\n\", \"type\": \"string\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"ynYFMrrhBYym7oMTANCe2Hdxj\"}, \"OVNNorthboundServerPort\": {\"description\": \"Port of the OVN Northbound DB server\", \"type\": \"number\", \"default\": 6641}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the OVN Southbound DB server\", \"type\": \"number\", \"default\": 6642}, \"OVNDbConnectionTimeout\": {\"description\": \"Timeout in seconds for the OVSDB connection transaction\", \"type\": \"number\", \"default\": 180}, \"OVNOvsdbProbeInterval\": {\"description\": \"Probe interval in ms for the OVSDB session\", \"type\": \"number\", \"default\": 60000}, \"MonitoringSubscriptionOvnMetadata\": {\"default\": \"overcloud-ovn-metadata\", \"type\": \"string\"}, \"OvnMetadataAgentDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging for OVN Metadata agent.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"DockerAdditionalSockets\": {\"default\": [\"/var/lib/openstack/docker.sock\"], \"description\": \"Additional domain sockets for the docker daemon to bind to (useful for mounting into containers that launch other containers)\", \"type\": \"comma_delimited_list\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"OvnMetadataCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OvnHardwareOffloadedQos\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable the QoS support for hardware offloaded ports\"}, \"OVNMetadataImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNMetadataUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}}, \"conditions\": {\"haproxy_wrapper_enabled\": {\"equals\": [{\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"neutron_metadata_workers_unset\": {\"equals\": [{\"get_param\": \"NeutronMetadataWorkers\"}, \"\"]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"OvnMetadataCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NeutronBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NeutronLogging\": {\"type\": \"OS::TripleO::Services::Logging::NeutronCommon\", \"properties\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerOvnMetadataImage\": \"ContainerOvnMetadataImage\", \"ContainerNeutronConfigImage\": \"ContainerNeutronConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerOvnMetadataImage\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"ContainerNeutronConfigImage\": {\"get_param\": \"ContainerNeutronConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for OVNMetadata agent\", \"value\": {\"service_name\": \"ovn_metadata\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionOvnMetadata\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NeutronLogging\", \"config_settings\"]}, {\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\": \"/var/lib/neutron/ovn_metadata_haproxy_wrapper\", \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo::profile::base::neutron::container_cli\": {\"get_param\": \"ContainerCli\"}, \"neutron::agents::ovn_metadata::shared_secret\": {\"get_param\": \"NeutronMetadataProxySharedSecret\"}, \"neutron::agents::ovn_metadata::auth_password\": {\"get_param\": \"NeutronPassword\"}, \"neutron::agents::ovn_metadata::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"neutron::agents::ovn_metadata::auth_tenant\": \"service\", \"neutron::agents::ovn_metadata::metadata_host\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataCellInternal\", \"host_nobrackets\"]}, \"neutron::agents::ovn_metadata::ovsdb_connection_timeout\": {\"get_param\": \"OVNDbConnectionTimeout\"}, \"neutron::agents::ovn_metadata::ovsdb_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}, \"neutron::agents::ovn_metadata::hwol_qos_enabled\": {\"get_param\": \"OvnHardwareOffloadedQos\"}, \"ovn::northbound::port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"neutron::agents::ovn_metadata::debug\": {\"if\": [{\"get_param\": \"OvnMetadataAgentDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::agents::ovn_metadata::metadata_protocol\": {\"if\": [\"internal_tls_enabled\", \"https\", \"http\"]}}, {\"if\": [\"neutron_metadata_workers_unset\", {}, {\"neutron::agents::ovn_metadata::metadata_workers\": {\"get_param\": \"NeutronMetadataWorkers\"}}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::protocol\": \"ssl\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\"}, {}]}]}, \"puppet_config\": {\"puppet_tags\": \"neutron_config,ovn_metadata_agent_config\", \"config_volume\": \"neutron\", \"step_config\": \"include tripleo::profile::base::neutron::ovn_metadata\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_metadata_agent.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini\", {\"get_attr\": [\"NeutronLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/var/lib/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/ovn_metadata.key\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_2\": {\"create_haproxy_wrapper\": {\"start_order\": 1, \"detach\": false, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\"]]}}}, \"step_4\": {\"setup_ovs_manager\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"exec\", \"include tripleo::profile::base::neutron::ovn_metadata\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_metadata_agent\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"cgroupns\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NeutronLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\", \"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\", \"/run/netns:/run/netns:shared\", \"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\"], {\"if\": [\"docker_enabled\", [\"/var/lib/openstack:/var/lib/openstack\"], null]}, {\"if\": [\"haproxy_wrapper_enabled\", [\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\"], null]}, {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\", \"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"metadata_settings\"]}, {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_metadata\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_metadata\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_metadata/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_metadata_agent\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"OvnMetadataCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NeutronLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create /run/netns with temp namespace\", \"command\": \"ip netns add ns_temp\", \"register\": \"ipnetns_add_result\", \"failed_when\": false}, {\"name\": \"remove temp namespace\", \"command\": \"ip netns delete ns_temp\", \"failed_when\": false, \"when\": [\"ipnetns_add_result.rc is defined\", \"ipnetns_add_result.rc == 0\"]}, {\"name\": \"create /var/lib/neutron\", \"file\": {\"path\": \"/var/lib/neutron\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"name\": \"set conditions\", \"set_fact\": {\"haproxy_wrapper_enabled\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"debug_enabled\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"docker_additional_sockets\": {\"get_param\": \"DockerAdditionalSockets\"}}}, {\"name\": \"create kill_scripts directory within /var/lib/neutron\", \"file\": {\"state\": \"directory\", \"path\": \"/var/lib/neutron/kill_scripts\"}}, {\"name\": \"create haproxy kill script\", \"when\": \"haproxy_wrapper_enabled|bool\", \"copy\": {\"dest\": \"/var/lib/neutron/kill_scripts/haproxy-kill\", \"mode\": 493, \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/kill-script\"}}}]]}, \"upgrade_tasks\": [], \"external_update_tasks\": [{\"name\": \"Check if python3-openvswitch3.1 workaround is needed\", \"delegate_to\": \"{{ item }}\", \"become\": true, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": \"step|int == 1\", \"shell\": \"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\n\", \"register\": \"metadata_python_ovs_3_1\", \"failed_when\": false, \"loop\": \"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\"}, {\"name\": \"Update ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"become\": true, \"loop\": \"{{ hosts_to_update_metadata }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_metadata_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_metadata_agent image pull successful.\", \"when\": [\"\'results\' in ovn_metadata_image_update\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_metadata_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"tags\": [\"ovn_metadata_parallel\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0}]}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"never\", \"ovn_metadata_serial\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"loop_control\": {\"pause\": 1}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(128,'2026-06-13 07:57:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (129,'2026-06-13 07:57:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(130,'2026-06-13 07:57:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Neutron base service. Shared for all Neutron agents.\\n\", \"parameters\": {\"DatabaseSyncTimeout\": {\"default\": 900, \"description\": \"DB Sync Timeout default\", \"type\": \"number\"}, \"NeutronDhcpAgentsPerNetwork\": {\"type\": \"number\", \"default\": 0, \"description\": \"The number of neutron dhcp agents to schedule per network\"}, \"DhcpAgentNotification\": {\"default\": false, \"description\": \"Whether or not to enable DHCP agent notifications.\", \"type\": \"boolean\"}, \"NeutronDnsDomain\": {\"type\": \"string\", \"default\": \"ooo.test\", \"description\": \"Domain to use for building the hostnames.\"}, \"NeutronCorePlugin\": {\"default\": \"ml2\", \"description\": \"The core plugin for Neutron. The value should be the entrypoint to be loaded\\nfrom neutron.core_plugins namespace.\\n\", \"type\": \"string\"}, \"NeutronServicePlugins\": {\"default\": \"qos,ovn-router,trunk,segments,port_forwarding,log\", \"description\": \"Comma-separated list of service plugin entrypoints to be loaded from the\\nneutron.service_plugins namespace.\\n\", \"type\": \"comma_delimited_list\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NeutronDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Neutron services.\", \"type\": \"boolean\"}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"NeutronGlobalPhysnetMtu\": {\"type\": \"number\", \"default\": 1350, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(If this is not changed TenantNetPhysnetMtu will be used.)\\n\"}, \"TenantNetPhysnetMtu\": {\"type\": \"number\", \"default\": 1500, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(The mtu setting of the Tenant network in network_data.yaml\\ncontrol\'s this parameter.)\\n\"}, \"NeutronDBSyncExtraParams\": {\"default\": \"\", \"description\": \"String of extra command line parameters to append to the neutron-db-manage\\nupgrade head command.\\n\", \"type\": \"string\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"NeutronGlobalReportInterval\": {\"default\": 300, \"description\": \"Seconds between nodes reporting state to server; should be less than NeutronAgentDownTime, best if it is half or less than NeutronAgentDownTime.\\n\", \"type\": \"number\"}}, \"conditions\": {\"dhcp_agents_zero\": {\"equals\": [{\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}, 0]}, \"global_physnet_mtu_unset\": {\"equals\": [{\"get_param\": \"NeutronGlobalPhysnetMtu\"}, 0]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron base service.\", \"value\": {\"service_name\": \"neutron_base\", \"config_settings\": {\"map_merge\": [{\"neutron::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"neutron::core_plugin\": {\"get_param\": \"NeutronCorePlugin\"}, \"neutron::service_plugins\": {\"get_param\": \"NeutronServicePlugins\"}, \"neutron::report_interval\": {\"get_param\": \"NeutronGlobalReportInterval\"}, \"neutron::logging::debug\": {\"if\": [{\"get_param\": \"NeutronDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"neutron::allow_overlapping_ips\": true, \"neutron::dhcp_agent_notification\": {\"get_param\": \"DhcpAgentNotification\"}, \"neutron::dns_domain\": {\"get_param\": \"NeutronDnsDomain\"}, \"neutron::rabbit_heartbeat_timeout_threshold\": 60, \"neutron::host\": \"%{hiera(\'fqdn_canonical\')}\", \"neutron::db::database_db_max_retries\": -1, \"neutron::db::database_max_retries\": -1, \"neutron::db::sync::db_sync_timeout\": {\"get_param\": \"DatabaseSyncTimeout\"}, \"neutron::global_physnet_mtu\": {\"if\": [\"global_physnet_mtu_unset\", {\"get_param\": \"TenantNetPhysnetMtu\"}, {\"get_param\": \"NeutronGlobalPhysnetMtu\"}]}, \"neutron::db::sync::extra_params\": {\"get_param\": \"NeutronDBSyncExtraParams\"}, \"neutron::vlan_transparent\": {\"get_param\": \"EnableVLANTransparency\"}, \"neutron::rabbit_heartbeat_in_pthread\": false}, {\"if\": [\"dhcp_agents_zero\", {}, {\"tripleo::profile::base::neutron::dhcp_agents_per_network\": {\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(131,'2026-06-13 07:57:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(132,'2026-06-13 07:57:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(133,'2026-06-13 07:57:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"FTS40yQUd1tjPXxKb5UK1sScA\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(134,'2026-06-13 07:57:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(135,'2026-06-13 07:57:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.  This mapping overrides those in ServiceNetMapDefaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}}, \"conditions\": {\"memory_backing_dir_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"QemuMemoryBackingDir\"}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"QemuMemoryBackingDir\"]}, \"\"]}]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::libvirt::qemu::memory_backing_dir\": \"QemuMemoryBackingDir\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"QemuMemoryBackingDir\": {\"get_param\": \"QemuMemoryBackingDir\"}}}]}}}}, \"outputs\": {\"kolla_config_files\": {\"description\": \"Common kolla config_files.\", \"value\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}]]}}, \"kolla_permissions\": {\"description\": \"Common kolla permissions.\", \"value\": {\"list_concat\": [[{\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"config_settings\": {\"description\": \"Extra hieradata for all modular virt daemons.\", \"value\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}}, \"volumes\": {\"description\": \"Common volumes for all modular virt daemons.\", \"value\": {\"list_concat\": [[\"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\", \"/etc/pki/libvirt:/etc/pki/libvirt:ro\", \"/etc/pki/qemu:/etc/pki/qemu:ro\"]]}, {\"if\": [\"memory_backing_dir_set\", [{\"str_replace\": {\"template\": \"MEMORY_BACKING_DIR:MEMORY_BACKING_DIR\", \"params\": {\"MEMORY_BACKING_DIR\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::compute::libvirt::qemu::memory_backing_dir\"]}}}}]]}]}}, \"update_tasks\": {\"description\": \"Common update tasks for modular virt daemons\", \"value\": [{\"name\": \"check systemd-container package present or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\"}, {\"name\": \"download systemd-container package if not present\", \"yum\": {\"name\": \"systemd-container\", \"state\": \"present\", \"download_only\": true, \"download_dir\": \"/var/tmp/\"}, \"when\": \"is_systemd_container_package.changed\"}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(136,'2026-06-13 07:57:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(137,'2026-06-13 07:57:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"FTS40yQUd1tjPXxKb5UK1sScA\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (138,'2026-06-13 07:57:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized logrotate with crond for containerized service logs rotation\\n\", \"parameters\": {\"ContainerCrondImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"ContainerCrondConfigImage\": {\"description\": \"The container image to use for the crond config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LogrotateMaxsize\": {\"description\": \"Configures the maxsize param for containerized logrotate.\", \"type\": \"string\", \"default\": \"10M\"}, \"LogrotateRotationInterval\": {\"description\": \"Configures rotation interval for containerized logrotate.\", \"type\": \"string\", \"default\": \"daily\", \"constraints\": [{\"allowed_values\": [\"hourly\", \"daily\", \"weekly\", \"monthly\"]}]}, \"LogrotateRotate\": {\"description\": \"Configures the rotate param for containerized logrotate.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotatePurgeAfterDays\": {\"description\": \"Enforces life time (days) of rotated and compressed files.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotateDateExt\": {\"description\": \"Enable/disable dateext parameter.\", \"type\": \"boolean\", \"default\": false}, \"LogrotateDateFormat\": {\"description\": \"Configures dateformat strings for containerized logrotate. This is valid when LogrotateDateExt is true. The allowed specifiers are only %Y %m %d %H %M %S %V and %s.\", \"type\": \"string\", \"default\": \"-%Y%m%d\", \"constraints\": [{\"allowed_pattern\": \"-(%[YmdHMSVs])+$\"}]}, \"LogrotateDateYesterday\": {\"description\": \"Configures dateyesterday paramter for containerized logrotate. This is valid when LogrotateDateExt is true.\", \"type\": \"boolean\", \"default\": false}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCrondImage\": \"ContainerCrondImage\", \"ContainerCrondConfigImage\": \"ContainerCrondConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCrondImage\": {\"get_param\": \"ContainerCrondImage\"}, \"ContainerCrondConfigImage\": {\"get_param\": \"ContainerCrondConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the crond role.\", \"value\": {\"service_name\": \"logrotate_crond\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::logging::logrotate::maxsize\": {\"get_param\": \"LogrotateMaxsize\"}, \"tripleo::profile::base::logging::logrotate::rotation\": {\"get_param\": \"LogrotateRotationInterval\"}, \"tripleo::profile::base::logging::logrotate::rotate\": {\"get_param\": \"LogrotateRotate\"}, \"tripleo::profile::base::logging::logrotate::purge_after_days\": {\"get_param\": \"LogrotatePurgeAfterDays\"}, \"tripleo::profile::base::logging::logrotate::dateext\": {\"get_param\": \"LogrotateDateExt\"}}, {\"if\": [{\"get_param\": \"LogrotateDateExt\"}, {\"tripleo::profile::base::logging::logrotate::dateformat\": {\"get_param\": \"LogrotateDateFormat\"}, \"tripleo::profile::base::logging::logrotate::dateyesterday\": {\"get_param\": \"LogrotateDateYesterday\"}}]}]}, \"host_prep_tasks\": [{\"name\": \"allow logrotate to read inside containers\", \"seboolean\": {\"name\": \"logrotate_read_inside_containers\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"deploy_steps_tasks\": [{\"name\": \"configure tmpwatch on the host\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Push script\", \"copy\": {\"dest\": \"/usr/local/sbin/containers-tmpwatch\", \"owner\": \"root\", \"group\": \"root\", \"mode\": 493, \"content\": \"#!/bin/sh\\ntmpwatch --nodirs \\\\\\n  -X \\\"/var/log/containers/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*err\\\" \\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\n\"}, \"vars\": {\"LogrotatePurgeAfterDays\": {\"get_param\": \"LogrotatePurgeAfterDays\"}}}, {\"name\": \"Insert cronjob in root crontab\", \"cron\": {\"name\": \"Remove old logs\", \"special_time\": \"daily\", \"user\": \"root\", \"job\": \"/usr/local/sbin/containers-tmpwatch\"}}]}], \"update_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"upgrade_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"puppet_config\": {\"config_volume\": \"crond\", \"step_config\": \"include tripleo::profile::base::logging::logrotate\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/logrotate-crond.json\": {\"command\": \"/usr/sbin/crond -s -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"logrotate_crond\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondImage\"]}, \"net\": \"none\", \"pid\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop logrotate container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"logrotate_crond\"], \"tripleo_delegate_to\": \"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(139,'2026-06-13 07:57:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(140,'2026-06-13 07:57:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(141,'2026-06-13 07:57:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(142,'2026-06-13 07:57:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(143,'2026-06-13 07:57:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure libvirt-guests\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsShutdownTimeout\": {\"default\": 300, \"description\": \"Number of seconds we\'re willing to wait for a guest to shut down. If this is 0, then there is no time out (use with caution, as guests might not respond to a shutdown request). The default value is 300 seconds (5 minutes).\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt_guests::shutdown_timeout\": \"NovaResumeGuestsShutdownTimeout\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaResumeGuestsShutdownTimeout\": {\"get_param\": \"NovaResumeGuestsShutdownTimeout\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for libvirt-guests\", \"value\": {\"service_name\": \"nova_libvirt_guests\", \"config_settings\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::compute::libvirt_guests\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(144,'2026-06-13 07:57:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(145,'2026-06-13 07:57:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(146,'2026-06-13 07:57:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (147,'2026-06-13 07:57:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(148,'2026-06-13 07:57:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Neutron service\\n\", \"parameters\": {\"NeutronServiceName\": {\"description\": \"service name\", \"type\": \"string\"}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": {\"str_replace\": {\"template\": \"--log-file=/var/log/neutron/SERVICE.log\", \"params\": {\"SERVICE\": {\"get_param\": \"NeutronServiceName\"}}}}}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/neutron:/var/log/neutron:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/neutron\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(149,'2026-06-13 07:57:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized rsyslogd service for purposes of centralized log collection of OpenStack services\' logs.\\n\", \"parameters\": {\"ContainerRsyslogImage\": {\"description\": \"The container image to use for container\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"ContainerRsyslogConfigImage\": {\"description\": \"The container image to use for the rsyslog config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RsyslogReopenOnTruncate\": {\"default\": true, \"description\": \"Rsyslog imfile reopenOnTruncate parameter\", \"type\": \"boolean\"}, \"RsyslogElasticsearchSetting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-elasticsearch plugin\", \"type\": \"json\"}, \"RsyslogElasticsearchTlsCACert\": {\"default\": \"\", \"description\": \"Contains content of the CA cert for the CA that issued Elasticsearch server cert.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientCert\": {\"default\": \"\", \"description\": \"Contains content of the client cert for doing client cert auth against Elasticsearch.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientKey\": {\"default\": \"\", \"description\": \"Contains content of the private key corresponding to the cert RsyslogElasticsearchTlsClientCert.\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RsyslogAmqp1Setting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-omamqp1 plugin\", \"type\": \"json\"}, \"RsyslogAmqp1Local\": {\"default\": true, \"description\": \"Set to false to disable prefilling host connection value to local QDR in RsyslogAmqp1Setting.\", \"type\": \"boolean\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"RsyslogMaxMessageSize\": {\"default\": \"32k\", \"description\": \"Maximum supported message size (both for sending and receiving) for rsyslogd.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRsyslogImage\": \"ContainerRsyslogImage\", \"ContainerRsyslogConfigImage\": \"ContainerRsyslogConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRsyslogImage\": {\"get_param\": \"ContainerRsyslogImage\"}, \"ContainerRsyslogConfigImage\": {\"get_param\": \"ContainerRsyslogConfigImage\"}}}]}}}}, \"conditions\": {\"use_tls\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}, \"\"]}]}}, \"use_elasticsearch\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {}]}}, \"use_amqp1\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {}]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the rsyslog role.\", \"value\": {\"service_name\": \"rsyslog\", \"config_settings\": {\"map_merge\": [{\"rsyslog::server::global_config\": {\"WorkDirectory\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"/var/lib/rsyslog\"}, \"MaxMessageSize\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": {\"get_param\": \"RsyslogMaxMessageSize\"}}}, \"rsyslog::confdir\": \"/etc/rsyslog.d\", \"rsyslog::package_name\": \"rsyslog\", \"rsyslog::package_version\": \"installed\", \"rsyslog::manage_package\": true, \"rsyslog::manage_confdir\": true, \"rsyslog::purge_config_files\": true, \"rsyslog::override_default_config\": true, \"rsyslog::config_file\": \"/etc/rsyslog.conf\", \"rsyslog::manage_service\": true, \"rsyslog::service_name\": \"rsyslog\", \"rsyslog::service_status\": \"running\", \"rsyslog::service_enabled\": true, \"rsyslog::external_service\": false, \"rsyslog::use_upstream_repo\": false, \"rsyslog::feature_packages\": [\"rsyslog-elasticsearch\", \"rsyslog-mmnormalize\"], \"rsyslog::global_config_priority\": 10, \"rsyslog::module_load_priority\": 20, \"rsyslog::input_priority\": 30, \"rsyslog::main_queue_priority\": 40, \"rsyslog::parser_priority\": 45, \"rsyslog::template_priority\": 50, \"rsyslog::filter_priority\": 55, \"rsyslog::action_priority\": 60, \"rsyslog::ruleset_priority\": 65, \"rsyslog::lookup_table_priority\": 70, \"rsyslog::legacy_config_priority\": 80, \"rsyslog::custom_priority\": 90, \"rsyslog::target_file\": \"50_openstack_logs.conf\", \"rsyslog::server::modules\": {\"imfile\": {}, \"omelasticsearch\": {}, \"omamqp1\": {}}, \"rsyslog::server::templates\": {\"rsyslog-node-index\": {\"type\": \"list\", \"list_descriptions\": [{\"constant\": {\"value\": \"%{hiera(\'fqdn_canonical\')}-\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"year\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"month\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"day\"}}]}, \"rsyslog-record\": {\"type\": \"list\", \"options\": {\"jsonf\": \"on\"}, \"list_descriptions\": [{\"property\": {\"outname\": \"@timestamp\", \"name\": \"timereported\", \"dateFormat\": \"rfc3339\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"host\", \"name\": \"hostname\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"severity\", \"name\": \"syslogseverity\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"facility\", \"name\": \"syslogfacility-text\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"tag\", \"name\": \"syslogtag\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"source\", \"name\": \"app-name\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"message\", \"name\": \"msg\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"file\", \"name\": \"$!metadata!filename\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"cloud\", \"value\": {\"get_param\": \"CloudName\"}, \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"region\", \"value\": {\"get_param\": \"KeystoneRegion\"}, \"format\": \"jsonf\"}}]}}}, {\"if\": [\"use_elasticsearch\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch\": {\"map_merge\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {\"template\": \"rsyslog-record\", \"searchIndex\": \"rsyslog-node-index\", \"dynSearchIndex\": \"on\", \"errorfile\": \"/var/log/rsyslog/omelasticsearch.log\"}]}}, {}]}, {\"if\": [\"use_amqp1\", {\"tripleo::profile::base::logging::rsyslog::amqp1\": {\"map_merge\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {\"template\": \"rsyslog-record\"}, {\"if\": [{\"get_param\": \"RsyslogAmqp1Local\"}, {\"host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}:$PORT\", \"params\": {\"$PORT\": {\"get_param\": \"MetricsQdrPort\"}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}}]}]}}, {}]}, {\"if\": [{\"get_param\": \"RsyslogReopenOnTruncate\"}, {\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\": \"on\"}, {}]}, {\"if\": [\"use_tls\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_ca_cert\": {\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_cert\": {\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_key\": {\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}}]}]}, \"puppet_config\": {\"config_volume\": \"rsyslog\", \"puppet_tags\": \"rsyslog::generate_concat,concat::fragment\", \"step_config\": \"include tripleo::profile::base::logging::rsyslog\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rsyslog.json\": {\"command\": \"/usr/sbin/rsyslogd -n -iNONE\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"docker_config\": {\"step_3\": {\"rsyslog\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:ro\", \"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\", \"/var/log:/var/log/host:ro\", \"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent logs directory for rsyslog\", \"file\": {\"path\": \"/var/log/containers/rsyslog\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}}, {\"name\": \"create persistent state directory for rsyslog\", \"file\": {\"path\": \"/var/lib/rsyslog.container\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(150,'2026-06-13 07:57:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL HA clustercheck service deployment using puppet This service is used by HAProxy in a HA scenario to report whether the local galera node is synced\\n\", \"parameters\": {\"ContainerClustercheckImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerClustercheckConfigImage\": {\"description\": \"The container image to use for the clustercheck config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ClustercheckListener\": {\"default\": \"socat\", \"description\": \"How to expose the clustercheck service over TCP\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"socat\", \"xinetd\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlPuppetBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerClustercheckImage\": \"ContainerClustercheckImage\", \"ContainerClustercheckConfigImage\": \"ContainerClustercheckConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerClustercheckImage\": {\"get_param\": \"ContainerClustercheckImage\"}, \"ContainerClustercheckConfigImage\": {\"get_param\": \"ContainerClustercheckConfigImage\"}}}]}}}}, \"conditions\": {\"socat_listener\": {\"equals\": [{\"get_param\": \"ClustercheckListener\"}, \"socat\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service clustercheck using composable services.\", \"value\": {\"service_name\": \"clustercheck\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlPuppetBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::clustercheck::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$FQDN$NETWORK\')}\", \"params\": {\"$FQDN\": {\"if\": [\"socat_listener\", \"\", \"fqdn_\"]}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}}]}, \"puppet_config\": {\"config_volume\": \"clustercheck\", \"puppet_tags\": \"file\", \"step_config\": \"include tripleo::profile::pacemaker::clustercheck\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/clustercheck.json\": {\"command\": {\"if\": [\"socat_listener\", \"bash -c $* -- eval source /etc/sysconfig/clustercheck; exec socat -T\\\"${TRIPLEO_HEALTHCHECK_TIMEOUT:-2}\\\" \\\"$TRIPLEO_SOCAT_BIND\\\" system:\\\"grep -qPe \\\\\\\"^\\\\\\\\r\\\\$\\\\\\\" && /usr/bin/clustercheck\\\"\", \"/usr/sbin/xinetd -dontfork\"]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"clustercheck\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckImage\"]}, \"restart\": \"always\", \"net\": \"host\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/clustercheck.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/clustercheck:/var/lib/kolla/config_files/src:ro\", \"/var/lib/mysql:/var/lib/mysql\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": null, \"upgrade_tasks\": null, \"update_tasks\": null, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop clustercheck container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"clustercheck\"], \"tripleo_delegate_to\": \"{{ groups[\'clustercheck\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(151,'2026-06-13 07:57:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(152,'2026-06-13 07:57:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Prepare container images\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImagePrepare\": {\"default\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images.\", \"type\": \"json\"}, \"ContainerImagePrepareLogFile\": {\"default\": \"/var/log/tripleo-container-image-prepare.log\", \"type\": \"string\", \"description\": \"Used to store outputs of \\\"openstack tripleo container image prepare\\\".\"}, \"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NeutronMechanismDrivers\": {\"default\": \"ovn\", \"description\": \"The mechanism drivers for the Neutron tenant network.\\n\", \"type\": \"comma_delimited_list\"}, \"DockerRegistryMirror\": {\"description\": \"Optional. Mirror to use for registry docker.io\", \"default\": \"\", \"type\": \"string\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ContainerImagePrepareDebug\": {\"default\": false, \"description\": \"Whether or not we want to activate --debug in tripleo container image prepare.\", \"type\": \"boolean\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"AdditionalArchitectures\": {\"default\": [], \"description\": \"List of additional architectures to enable.\", \"type\": \"comma_delimited_list\"}, \"ControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 3}, \"CellControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CellControllerComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 3}, \"BlockStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for container image prepare\", \"value\": {\"service_name\": \"container_image_prepare\", \"external_deploy_tasks\": [{\"name\": \"Run tripleo-container-image-prepare role\", \"import_role\": {\"name\": \"tripleo_container_image_prepare\"}, \"vars\": {\"tripleo_container_image_prepare_log_file\": {\"get_param\": \"ContainerImagePrepareLogFile\"}, \"tripleo_container_image_prepare_debug\": {\"if\": [{\"get_param\": \"ContainerImagePrepareDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo_container_image_prepare_roles\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"tripleo_container_image_prepare_content\": {\"parameter_defaults\": {\"ContainerImagePrepare\": {\"get_param\": \"ContainerImagePrepare\"}, \"DockerInsecureRegistryAddress\": {\"get_param\": \"DockerInsecureRegistryAddress\"}, \"NeutronMechanismDrivers\": {\"get_param\": \"NeutronMechanismDrivers\"}, \"DockerRegistryMirror\": {\"get_param\": \"DockerRegistryMirror\"}, \"ContainerImageRegistryCredentials\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"AdditionalArchitectures\": {\"get_param\": \"AdditionalArchitectures\"}, \"ControllerContainerImagePrepare\": {\"get_param\": \"ControllerContainerImagePrepare\"}, \"ControllerServices\": {\"get_param\": \"ControllerServices\"}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerContainerImagePrepare\": {\"get_param\": \"CellControllerContainerImagePrepare\"}, \"CellControllerServices\": {\"get_param\": \"CellControllerServices\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeContainerImagePrepare\": {\"get_param\": \"CellControllerComputeContainerImagePrepare\"}, \"CellControllerComputeServices\": {\"get_param\": \"CellControllerComputeServices\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeContainerImagePrepare\": {\"get_param\": \"ComputeContainerImagePrepare\"}, \"ComputeServices\": {\"get_param\": \"ComputeServices\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageContainerImagePrepare\": {\"get_param\": \"BlockStorageContainerImagePrepare\"}, \"BlockStorageServices\": {\"get_param\": \"BlockStorageServices\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageContainerImagePrepare\": {\"get_param\": \"ObjectStorageContainerImagePrepare\"}, \"ObjectStorageServices\": {\"get_param\": \"ObjectStorageServices\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageContainerImagePrepare\": {\"get_param\": \"CephStorageContainerImagePrepare\"}, \"CephStorageServices\": {\"get_param\": \"CephStorageServices\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerContainerImagePrepare\": {\"get_param\": \"NetworkerContainerImagePrepare\"}, \"NetworkerServices\": {\"get_param\": \"NetworkerServices\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}}}}, \"when\": [\"(step | int) == 1\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(153,'2026-06-13 07:57:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Chrony time service deployment using ansible, this YAML file creates the interface between the HOT template and the ansible role that actually installs and configure chronyd.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"ChronyGlobalServerOptions\": {\"default\": \"\", \"description\": \"Default server options for the configured NTP servers in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"ChronyGlobalPoolOptions\": {\"default\": \"\", \"description\": \"Default pool options for the configured NTP pools in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"NtpIburstEnable\": {\"default\": true, \"description\": \"Specifies whether to enable the iburst option for every NTP peer. If iburst is enabled, when the ntp server is unreachable ntp will send a burst of eight packages instead of one. This is designed to speed up the initial syncrhonization.\", \"type\": \"boolean\"}, \"MaxPoll\": {\"description\": \"Specify maximum poll interval of upstream servers for NTP messages, in seconds to the power of two. The maximum poll interval defaults to 10 (1,024 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 10, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"MinPoll\": {\"description\": \"Specify minimum poll interval of upstream servers for NTP messages, in seconds to the power of two. The minimum poll interval defaults to 6 (64 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 6, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"ChronyAclRules\": {\"default\": [\"deny all\"], \"description\": \"Access Control List of NTP clients.  By default no clients are permitted.\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"chrony_global_server_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalServerOptions\"}, \"\"]}, \"chrony_global_pool_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalPoolOptions\"}, \"\"]}, \"ntp_iburst\": {\"equals\": [{\"get_param\": \"NtpIburstEnable\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role chrony using composable timesync services.\", \"value\": {\"service_name\": \"chrony\", \"firewall_rules\": {\"105 ntp\": {\"dport\": 123, \"proto\": \"udp\"}}, \"host_prep_tasks\": [{\"name\": \"Check for NTP service\", \"shell\": \"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\", \"failed_when\": false, \"become\": true, \"register\": \"ntp_service_check\"}, {\"name\": \"Disable NTP before configuring Chrony\", \"service\": {\"name\": \"ntpd\", \"state\": \"stopped\", \"enabled\": false}, \"when\": [\"ntp_service_check.rc is defined\", \"ntp_service_check.rc == 0\"]}, {\"name\": \"Install, Configure and Run Chrony\", \"include_role\": {\"name\": \"chrony\"}}, {\"name\": \"Force NTP sync\", \"command\": \"chronyc makestep\"}, {\"name\": \"Ensure system is NTP time synced\", \"command\": \"chronyc waitsync 30\"}], \"ansible_group_vars\": {\"chrony_role_action\": \"all\", \"chrony_ntp_servers\": {\"get_param\": \"NtpServer\"}, \"chrony_ntp_pools\": {\"get_param\": \"NtpPool\"}, \"chrony_global_server_settings\": {\"if\": [\"chrony_global_server_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalServerOptions\"}]}, \"chrony_global_pool_settings\": {\"if\": [\"chrony_global_pool_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalPoolOptions\"}]}, \"chrony_manage_package\": {\"get_param\": \"EnablePackageInstall\"}, \"chrony_acl_rules\": {\"get_param\": \"ChronyAclRules\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(154,'2026-06-13 07:57:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"yes\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"SshServerOptionsOverrides\"]}], \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}, \"ssh_banner_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"BannerText\"}, \"\"]}}, \"ssh_motd_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"MessageOfTheDay\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_sshd\"}, \"vars\": {\"tripleo_sshd_server_options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo_sshd_password_authentication\": {\"get_param\": \"PasswordAuthentication\"}, \"tripleo_sshd_banner_enabled\": {\"if\": [\"ssh_banner_text_set\", true, false]}, \"tripleo_sshd_banner_text\": {\"get_param\": \"BannerText\"}, \"tripleo_sshd_motd_enabled\": {\"if\": [\"ssh_motd_text_set\", true, false]}, \"tripleo_sshd_message_of_the_day\": {\"get_param\": \"MessageOfTheDay\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (155,'2026-06-13 07:57:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"parameters\": {\"ContainerHeatApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"ContainerHeatApiConfigImage\": {\"description\": \"The container image to use for the heat_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"HeatApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api\", \"file\": \"/var/log/containers/heat/heat_api.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"HeatApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"HeatApiOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApi\": {\"default\": \"overcloud-heat-api\", \"type\": \"string\"}, \"HeatStackDomainAdminPassword\": {\"description\": \"Password for heat_stack_domain_admin user.\", \"type\": \"string\", \"hidden\": true, \"default\": \"PRAvvytqJJ4jsEaDgx88UWuGA\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiImage\": \"ContainerHeatApiImage\", \"ContainerHeatApiConfigImage\": \"ContainerHeatApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiImage\": {\"get_param\": \"ContainerHeatApiImage\"}, \"ContainerHeatApiConfigImage\": {\"get_param\": \"ContainerHeatApiConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API role.\", \"value\": {\"service_name\": \"heat_api\", \"firewall_rules\": {\"125 heat_api\": {\"dport\": [8004]}}, \"firewall_frontend_rules\": {\"100 heat_api_haproxy_frontend\": {\"dport\": [8004]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_haproxy_frontend_ssl\": {\"dport\": [13004]}}, \"keystone_resources\": {\"heat\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"uri\"]}}, \"users\": {\"heat\": {\"password\": {\"get_param\": \"HeatPassword\"}}, \"heat_stack_domain_admin\": {\"password\": {\"get_param\": \"HeatStackDomainAdminPassword\"}, \"roles\": [\"admin\"], \"domain\": \"heat_stack\"}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"orchestration\", \"roles\": [\"heat_stack_user\"], \"domains\": [\"heat_stack\"]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiLogging\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::wsgi::apache_api::vhost_custom_fragment\": \"Timeout 600\", \"heat::api::service_name\": \"httpd\", \"heat::wsgi::apache_api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api\": [{\"get_param\": \"HeatApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api\", \"puppet_tags\": \"heat_config,file,concat,file_line,heat_api_paste_ini\", \"step_config\": \"include tripleo::profile::base::heat::api\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/heat_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, {\"get_param\": \"HeatApiOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatApiOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"heat_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron heat\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api\", \"heat_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(156,'2026-06-13 07:57:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(157,'2026-06-13 07:57:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(158,'2026-06-13 07:57:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(159,'2026-06-13 07:57:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Package installation settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"UpgradeLeappEnabled\": {\"description\": \"Use Leapp for operating system upgrade\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDebug\": {\"description\": \"Print debugging output when running Leapp\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDevelSkip\": {\"description\": \"Skip Leapp checks by setting env variables when running Leapp in\\ndevelopment/testing. For example, LEAPP_DEVEL_SKIP_RHSM=1.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappCommandOptions\": {\"description\": \"In case or using UpgradeLeappDevelSkip with LEAPP_NO_RHSM=1 user\\ncan specify --enablerepo <repo1> --enablerepo <repo2> options for\\nleapp to use these repositories for the upgrade process.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappRebootTimeout\": {\"description\": \"Timeout (seconds) for the OS upgrade phase via Leapp\", \"type\": \"number\", \"default\": 3600}, \"UpgradeLeappPostRebootDelay\": {\"description\": \"Maximum (seconds) to wait for machine to reboot and respond to a test\\ncommand.\\n\", \"type\": \"number\", \"default\": 120}, \"UpgradeLeappToRemove\": {\"default\": [], \"description\": \"List of packages to remove during Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappToInstall\": {\"default\": [], \"description\": \"List of packages to install after Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappUnloadKernelDrivers\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of modules to unload from the system due to being incompatible\\nwith the next RHEL version. If not being unloaded Leapp will\\ninhibit the upgrade.\\n\"}, \"LeappActorsToRemove\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of actors to remove from the leapp process to prevent them\\nfrom inhibiting the upgrade.\\n\"}, \"LeappRepoInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the Leapp process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds to get Leapp working.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NICsPrefixesToUdev\": {\"default\": [], \"description\": \"List of NIC prefixes to hardcode into udev in order to prevent\\nrenaming.\\n\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappPreRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds before rebooting into Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappPostRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds after rebooting from Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"SkipPackageUpdate\": {\"default\": false, \"description\": \"Set to true to skip the update all packages\", \"type\": \"boolean\"}, \"SkipRhelEnforcement\": {\"default\": false, \"description\": \"Whether to avoid or not RHEL/OSP policies enforcement on Red Hat. Mainly for CI purpose.  It shouldn\'t matter on other distributions where it\'s disabled in the role. Set to true to skip the enforcement.\", \"type\": \"boolean\"}, \"DnfStreams\": {\"default\": [], \"description\": \"List of streams to be configured before updating packages. Each list element contains a dictionary with the following values defined module[mandatory], stream[mandatory], distribution_version[mandatory] and profile[optional]. If the profile is not specified \'common\' will be used instead.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"BaseTripleoPackages\": {\"default\": [], \"description\": \"List of packages to install.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"dnf_module_list\": \"DnfStreams\", \"upgrade_leapp_devel_skip\": \"UpgradeLeappDevelSkip\", \"upgrade_leapp_command_options\": \"UpgradeLeappCommandOptions\", \"upgrade_leapp_to_remove\": \"UpgradeLeappToRemove\", \"upgrade_leapp_to_install\": \"UpgradeLeappToInstall\", \"leapp_repo_init_command\": \"LeappRepoInitCommand\", \"leapp_init_command\": \"LeappInitCommand\", \"nics_prefixes_to_keep\": \"NICsPrefixesToUdev\", \"upgrade_leapp_modules_to_unload\": \"LeappUnloadKernelDrivers\", \"upgrade_leapp_actors_to_remove\": \"LeappActorsToRemove\", \"upgrade_init_command\": \"UpgradeInitCommand\", \"base_tripleo_packages\": \"BaseTripleoPackages\", \"leapp_pre_reboot_command\": \"LeappPreRebootCommand\", \"leapp_post_reboot_command\": \"LeappPostRebootCommand\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"DnfStreams\": {\"get_param\": \"DnfStreams\"}, \"UpgradeLeappDevelSkip\": {\"get_param\": \"UpgradeLeappDevelSkip\"}, \"UpgradeLeappCommandOptions\": {\"get_param\": \"UpgradeLeappCommandOptions\"}, \"UpgradeLeappToRemove\": {\"get_param\": \"UpgradeLeappToRemove\"}, \"UpgradeLeappToInstall\": {\"get_param\": \"UpgradeLeappToInstall\"}, \"LeappUnloadKernelDrivers\": {\"get_param\": \"LeappUnloadKernelDrivers\"}, \"LeappPreRebootCommand\": {\"get_param\": \"LeappPreRebootCommand\"}, \"LeappPostRebootCommand\": {\"get_param\": \"LeappPostRebootCommand\"}, \"LeappActorsToRemove\": {\"get_param\": \"LeappActorsToRemove\"}, \"UpgradeInitCommand\": {\"get_param\": \"UpgradeInitCommand\"}, \"LeappRepoInitCommand\": {\"get_param\": \"LeappRepoInitCommand\"}, \"LeappInitCommand\": {\"get_param\": \"LeappInitCommand\"}, \"NICsPrefixesToUdev\": {\"get_param\": \"NICsPrefixesToUdev\"}, \"BaseTripleoPackages\": {\"get_param\": \"BaseTripleoPackages\"}}}]}}}, \"Podman\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"conditions\": {\"podman_requires_login\": {\"equals\": [{\"get_param\": \"ContainerImageRegistryLogin\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO package settings\", \"value\": {\"service_name\": \"tripleo_packages\", \"config_settings\": {\"tripleo::packages::enable_install\": {\"get_param\": \"EnablePackageInstall\"}}, \"step_config\": \"include ::tripleo::packages\\n\", \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Gather missing facts\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"distribution\"]}, \"tags\": [\"always\"]}, {\"name\": \"Set leapp facts\", \"set_fact\": {\"upgrade_leapp_enabled\": \"{{ _upgradeLeappEnabled | bool and\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\", \"upgrade_leapp_debug\": {\"get_param\": \"UpgradeLeappDebug\"}, \"upgrade_leapp_devel_skip\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_devel_skip\"]}, \"upgrade_leapp_command_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_command_options\"]}, \"upgrade_leapp_reboot_timeout\": {\"get_param\": \"UpgradeLeappRebootTimeout\"}, \"upgrade_leapp_post_reboot_delay\": {\"get_param\": \"UpgradeLeappPostRebootDelay\"}}, \"vars\": {\"_upgradeLeappEnabled\": {\"get_param\": \"UpgradeLeappEnabled\"}}, \"tags\": [\"always\"]}, {\"name\": \"system_upgrade_prepare step 3\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Run LeappRepoInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_repo_init_command\"]}]]}}, {\"name\": \"Remove firewalld bindings\", \"package\": {\"name\": \"python3-firewall\", \"state\": \"absent\"}}, {\"name\": \"install leapp\", \"package\": {\"name\": \"leapp-repository-openstack\", \"state\": \"latest\"}}, {\"name\": \"Run LeappInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_init_command\"]}]]}}, {\"name\": \"Remove vdo\", \"package\": {\"name\": \"vdo\", \"state\": \"absent\"}}, {\"name\": \"add packages into Leapp\'s to_remove file\", \"vars\": {\"pkg_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_remove\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_remove\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_remove }}\"}, {\"name\": \"add packages into Leapp\'s to_install file\", \"vars\": {\"pkg_to_install\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_install\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_install\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_install }}\"}, {\"name\": \"check sshd_config file\", \"stat\": {\"path\": \"/etc/ssh/sshd_config\"}, \"register\": \"sshd_config_result\"}, {\"name\": \"add PermitRootLogin option for leapp\", \"lineinfile\": {\"path\": \"/etc/ssh/sshd_config\", \"regexp\": \"^(# *)?PermitRootLogin\", \"line\": \"PermitRootLogin without-password\"}}, {\"name\": \"Remove paunch-services\", \"package\": {\"name\": \"paunch-services\", \"state\": \"absent\"}}, {\"name\": \"tripleo_container_manage reconfiguration\", \"import_role\": {\"name\": \"tripleo_container_manage\", \"tasks_from\": \"shutdown.yml\"}}]}, {\"name\": \"system_upgrade_prepare step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\", \"vars\": {\"modules_to_unload\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_modules_to_unload\"]}}, \"shell\": \"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\"{{ item }}\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\n\", \"loop\": \"{{ modules_to_unload }}\"}, {\"name\": \"Remove leapp actors to prevent them inhibiting the upgrade\", \"vars\": {\"actors_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_actors_to_remove\"]}}, \"command\": {\"cmd\": \"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\"{}\\\" +\"}, \"loop\": \"{{ actors_to_remove }}\"}, {\"name\": \"set leapp required answers\", \"shell\": \"leapp answer --add --section check_vdo.confirm=True\\n\"}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}, {\"name\": \"Keep nics with prefix in NICsPrefixesToUdev from renaming\", \"vars\": {\"nics_prefixes_to_keep\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nics_prefixes_to_keep\"]}}, \"shell\": \"ip -j link show | \\\\ jq -r --arg prefix \\\"{{ item }}\\\" \'.[] |\\n  select((.ifname | startswith($prefix)) and\\n  (.ifname | test(\\\"^.*v[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*_[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*\\\\\\\\..*$\\\") | not)) |\\n  if .permaddr? then .address=.permaddr else . end |\\n  \\\"SUBSYSTEM==\\\\\\\"net\\\\\\\",ACTION==\\\\\\\"add\\\\\\\",DRIVERS==\\\\\\\"?*\\\\\\\",\\\" + \\\"NAME=\\\\\\\"\\\" + .ifname +\\\"\\\\\\\" ,ATTR{address}==\\\\\\\"\\\" + .address + \\\"\\\\\\\"\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\n\", \"loop\": \"{{ nics_prefixes_to_keep|list }}\"}, {\"name\": \"run leapp upgrade (download packages)\", \"shell\": \"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\n\", \"when\": \"upgrade_leapp_enabled\"}]}, {\"name\": \"system_upgrade_run step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_reboot\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\", \"\'Undercloud\' not in group_names\"], \"block\": [{\"name\": \"Run LeappPreRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_pre_reboot_command\"]}]]}}, {\"name\": \"Check that nova_libvirt is running\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"is_virtlogd_image_running\"}, {\"name\": \"Remove systemd files to disable them\", \"file\": {\"path\": \"/etc/systemd/system/{{ item }}\", \"state\": \"absent\"}, \"with_items\": [\"tripleo_nova_libvirt.service\", \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_libvirt.target\"], \"when\": \"is_virtlogd_image_running.stdout != \'\'\"}, {\"name\": \"reboot to perform the upgrade\", \"reboot\": {\"reboot_timeout\": \"{{upgrade_leapp_reboot_timeout}}\", \"test_command\": \"source /etc/os-release; [ \\\"${VERSION_ID%.*}\\\" -ge \\\"8\\\" ] && systemctl is-system-running | grep -qE \\\"running|degraded\\\" || exit 1\", \"post_reboot_delay\": \"{{ upgrade_leapp_post_reboot_delay }}\"}}, {\"name\": \"Set selinux back to enforcing after leapp reboot\", \"selinux\": {\"policy\": \"targeted\", \"state\": \"enforcing\"}}, {\"name\": \"Run LeappPostRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_post_reboot_command\"]}]]}}]}, {\"name\": \"Host packages setup step0\", \"tags\": \"setup_packages\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Package and repo update tasks\", \"block\": [{\"name\": \"Run UpgradeInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", \"if [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_init_command\"]}]]}}, {\"name\": \"Run UpgradeInitCommonCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_param\": \"UpgradeInitCommonCommand\"}]]}}, {\"name\": \"Ensure DNF modules have the right stream\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"dnf\": {\"name\": \"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\", \"state\": \"present\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Ensure TripleO prerequisite packages are installed\", \"package\": {\"name\": [\"jq\", \"lvm2\", \"openstack-selinux\", \"os-net-config\", \"puppet-tripleo\", \"python3-heat-agent*\", \"rsync\"], \"state\": \"present\"}, \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}, {\"name\": \"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\", \"vars\": {\"base_tripleo_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"base_tripleo_packages\"]}}, \"package\": {\"name\": \"{{ base_tripleo_packages }}\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\", \"base_tripleo_packages|length > 0\"]}, {\"name\": \"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\", \"shell\": \"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\ndo\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\"signatures\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\ndone\\n\", \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}]}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"loop\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": [\"libvirt_installed.rc == 0\"]}]}, {\"name\": \"Host packages setup step2\", \"tags\": \"setup_packages\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_upgrade.changed|bool\"]}]}, {\"name\": \"Host packages setup step3\", \"tags\": \"setup_packages\", \"when\": \"step|int == 3\", \"block\": [{\"name\": \"Check for os-net-config upgrade\", \"shell\": \"yum check-upgrade | awk \'/os-net-config/{print}\'\", \"register\": \"os_net_config_need_upgrade\"}, {\"name\": \"Check that os-net-config has legacy configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.json\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_json\"}, {\"name\": \"Check that os-net-config has new configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.yaml\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_yaml\"}, {\"name\": \"Slurp the os-net-config config.json\", \"slurp\": {\"src\": \"/etc/os-net-config/config.json\"}, \"register\": \"os_config_json\", \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Write updated /etc/os-net-config/config.yaml\", \"copy\": {\"content\": \"{{ os_config_json.content | b64decode | from_json | to_yaml }}\", \"dest\": \"/etc/os-net-config/config.yaml\"}, \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Remove legacy os-net-config configuration\", \"command\": \"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\", \"when\": [\"stat_config_json.stat.exists\"]}, {\"block\": [{\"name\": \"Upgrade os-net-config\", \"package\": \"name=os-net-config state=latest\"}, {\"name\": \"take new os-net-config parameters into account now\", \"command\": \"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\", \"register\": \"os_net_config_upgrade\", \"failed_when\": \"os_net_config_upgrade.rc not in [0,2]\", \"changed_when\": \"os_net_config_upgrade.rc == 2\"}], \"when\": [\"os_net_config_need_upgrade.stdout\", \"stat_config_yaml.stat.exists or stat_config_json.stat.exists\"]}, {\"name\": \"Update all packages\", \"when\": [\"not skip_package_update|bool\"], \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}, \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Check whether openvswitch exits\", \"command\": \"systemctl status openvswitch.service\", \"register\": \"ovs_service\", \"ignore_errors\": true}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_service.stderr != \\\"Unit openvswitch.service could not be found.\\\"\"]}]}], {\"if\": [\"podman_requires_login\", {\"get_attr\": [\"Podman\", \"role_data\", \"workaround_upgrade_tasks\"]}, []]}]}, \"external_upgrade_tasks\": [{\"name\": \"Clean up upgrade artifacts\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_cleanup\"], \"block\": [{\"name\": \"cleanup tripleo_persist\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"cleanup.yml\"}}]}], \"update_tasks\": [{\"name\": \"Enforce RHOSP rules regarding subscription.\", \"include_role\": {\"name\": \"tripleo_redhat_enforce\"}, \"vars\": {\"skip_rhel_enforcement\": {\"get_param\": \"SkipRhelEnforcement\"}}, \"when\": [\"step|int == 0\", \"ansible_facts[\'distribution\'] == \'RedHat\'\", \"not (skip_rhel_enforcement | bool)\"]}, {\"name\": \"Ensure DNF modules have the right stream enabled\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"tripleo_dnf_stream\": {\"name\": \"{{ item.module }}:{{ item.stream }}\", \"state\": \"enabled\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"step|int == 0\", \"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Check for existing yum.pid\", \"stat\": \"path=/run/yum.pid\", \"register\": \"yum_pid_file\", \"when\": \"step|int == 0 or step|int == 3\"}, {\"name\": \"Exit if existing yum process\", \"fail\": \"msg=\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\"\", \"when\": \"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\"}, {\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"when\": [\"step|int == 2\"], \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"step|int == 2\", \"ovs_upgrade.changed|bool\"]}, {\"name\": \"Update packages and EFI grub.cfg\", \"when\": [\"step|int == 3\", \"not skip_package_update|bool\"], \"block\": [{\"name\": \"Update all packages\", \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}], \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Ensure openvswitch is running after update\", \"when\": \"step|int == 3\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"ignore_errors\": true}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(160,'2026-06-13 07:57:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(161,'2026-06-13 07:57:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure tuned\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"TunedCustomProfile\": {\"default\": \"\", \"description\": \"The definition of a new tuned profile in INI format which will be named after the TunedProfileName and applied to the host. E.g. if TunedProfileName is \'my_profile\', it creates the file \'/etc/tuned/my_profile/tuned.conf\' on host whose content is the value of TunedCustomProfile, e.g. \\\"[main]\\\\n include=throughput-performance\\\\n[sysctl]\\\\nvm.dirty_ratio=10\\\"\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"description\": \"Tuned Profile to apply to the host\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"tuned_custom_profile\": \"TunedCustomProfile\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"TunedCustomProfile\": {\"get_param\": \"TunedCustomProfile\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for tuned\", \"value\": {\"service_name\": \"tuned\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tuned\"}}], \"ansible_group_vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_custom_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_custom_profile\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (162,'2026-06-13 07:57:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment with pacemaker bundle\\n\", \"parameters\": {\"ContainerMysqlImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerMysqlConfigImage\": {\"description\": \"The container image to use for the mysql config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"pEuTysnhbk\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"LOZ9ZtUAwfPALS7L80T4luRla\"}, \"MysqlUpgradePersist\": {\"type\": \"boolean\", \"default\": false}, \"MysqlUpgradeTransfer\": {\"type\": \"boolean\", \"default\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"MysqlGaleraSSTMethod\": {\"type\": \"string\", \"default\": \"rsync\", \"description\": \"Method used by galera to perform State Snapshot Transfers\", \"constraints\": [{\"allowed_values\": [\"rsync\", \"mariabackup\"]}]}, \"MysqlMariabackupUser\": {\"type\": \"string\", \"default\": \"mariabackup\", \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\"}, \"MysqlMariabackupPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\", \"default\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\"}, \"MysqlGaleraSSLCipher\": {\"type\": \"string\", \"default\": \"AES128-SHA256\", \"description\": \"Symmetric cipher to use.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMysqlImage\": \"ContainerMysqlImage\", \"ContainerMysqlConfigImage\": \"ContainerMysqlConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMysqlImage\": {\"get_param\": \"ContainerMysqlImage\"}, \"ContainerMysqlConfigImage\": {\"get_param\": \"ContainerMysqlConfigImage\"}}}]}}}}, \"conditions\": {\"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service MySQL using composable services.\", \"value\": {\"service_name\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"104 mysql galera-bundle\": {\"dport\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \"firewall_frontend_rules\": {\"100 mysql_haproxy\": {\"dport\": [3306]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::ca_file\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::control_port\": 3123, \"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\": {\"get_param\": \"MysqlGaleraSSTMethod\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\": {\"get_param\": \"MysqlMariabackupUser\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\": {\"get_param\": \"MysqlMariabackupPassword\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\": true, \"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\": {\"get_param\": \"MysqlGaleraSSLCipher\"}}]}, \"puppet_config\": {\"config_volume\": \"mysql\", \"puppet_tags\": \"file\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\", \"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/mysql.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/mysql\", \"owner\": \"mysql:mysql\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/mysql.crt\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/mysql.key\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"mysql_data_ownership\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"chown\", \"-R\", \"mysql:\", \"/var/lib/mysql\"], \"volumes\": [\"/var/lib/mysql:/var/lib/mysql:z\"]}, \"mysql_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\", \"echo -e \\\"\\\\n[mysqld]\\\\nwsrep_provider=none\\\" >> /etc/my.cnf\", \"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\", \"kolla_set_configs\", \"sudo -u mysql -E kolla_extend_start\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\", \"mysqld_safe --skip-networking --wsrep-on=OFF &\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" ping 2>/dev/null; do sleep 1; done\'\"], {\"if\": [{\"equals\": [{\"get_param\": \"MysqlGaleraSSTMethod\"}, \"mariabackup\"]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\"\"]]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\"\", \"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" shutdown\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"DB_MAX_TIMEOUT\": 60, \"DB_MARIABACKUP_USER\": {\"get_param\": \"MysqlMariabackupUser\"}, \"DB_MARIABACKUP_PASSWORD\": {\"get_param\": \"MysqlMariabackupPassword\"}}}}, \"step_2\": {\"mysql_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"], {\"if\": [{\"get_param\": \"ConfigDebug\"}, [\"--debug\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"]]}]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/mysql\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/mysql\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/mariadb\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"metadata_settings\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"MySQL tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"MySQL HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"MySQL temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"galera-bundle\", \"tripleo_ha_image_update_new_image\": \"{{galera_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_galera_image}}\"}, \"when\": [\"(pcmk_galera_image != \\\"\\\")\", \"(pcmk_galera_image != galera_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of galera container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_galera_image == galera_image_latest\", \"fail_msg\": \"galera image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"Mariadb fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Ensure mariadb-server is not installed on the host\", \"when\": \"step|int == 2\", \"yum\": {\"name\": \"mariadb-server*\", \"state\": \"absent\"}}], \"post_update_tasks\": [{\"name\": \"Mysql bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}], [{\"name\": \"set mysql container name fact\", \"when\": [\"step|int == 1\"], \"set_fact\": {\"mysql_container_name\": \"galera-bundle\"}}], {\"get_attr\": [\"MysqlBase\", \"mysql_drop_unused_users\"]}, [{\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 3\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"block\": [{\"name\": \"Persist mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"persist.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 5\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"block\": [{\"name\": \"Restore mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"restore.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"name\": \"Prepare switch of galera image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get galera image id currently used by pacemaker\", \"shell\": \"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"galera_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for galera\", \"set_fact\": {\"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"galera_image_current\": \"{{galera_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current galera image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image_current}}\", \"container_image_latest\": \"{{galera_image_latest}}\", \"pull_image\": false}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}, {\"name\": \"Create galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"touch\"}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}]}, {\"name\": \"Update galera pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_mysql_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}]}, {\"name\": \"Update galera pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_mysql_bootstrap_node|bool\", \"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the galera cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move Mysql logging to /var/log/containers\", \"block\": [{\"name\": \"Check Mysql logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'mysql-log\']\\\"\", \"failed_when\": false, \"register\": \"mysql_logs_moved\"}, {\"name\": \"Change Mysql logging configuration in pacemaker\", \"when\": \"mysql_logs_moved.rc == 6\", \"block\": [{\"name\": \"Add a bind mount for logging in the galera bundle\", \"command\": \"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\"}, {\"name\": \"Reconfigure Mysql log file in the galera resource agent\", \"command\": \"pcs resource update galera log=/var/log/mysql/mysqld.log\"}]}]}, {\"name\": \"Update the galera bundle to use the new container image name\", \"command\": \"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\"}, {\"name\": \"Enable the galera cluster resource\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Upgrade galera in step3\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Bind mounts for temporary container\", \"set_fact\": {\"mysql_upgrade_db_bind_mounts\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], [\"/var/log/containers/mysql:/var/log/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}}}, {\"name\": \"Check if Galera needs upgrade\", \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"kolla_set_configs\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\nelse\\n    echo \\\"${upgraded_ver} VS ${mysql_ver}\\\"\\nfi\\n\"}, \"register\": \"mysql_upgrade_needed\"}, {\"name\": \"Set fact upgrade_mysql\", \"set_fact\": {\"upgrade_mysql\": \"{{ (mysql_upgrade_needed.stdout != \\\"mysql already upgraded\\\") | bool }}\"}}, {\"debug\": {\"msg\": \"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\"}}, {\"name\": \"Disable the galera cluster resource before container upgrade\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}]}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Remove galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"absent\"}}, {\"name\": \"Mysql upgrade script\", \"when\": [\"upgrade_mysql|bool\"], \"set_fact\": {\"mysql_upgrade_script\": {\"list_join\": [\"\\n\", [\"kolla_set_configs\\nif mysqladmin ping --silent; then exit 0; fi\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\n    exit 0\\nfi\\nchown -R mysql:mysql /var/lib/mysql\\nchown -R mysql:mysql /var/log/mysql\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\n\", {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}, \"mysqladmin shutdown\"]]}}}, {\"name\": \"Upgrade Mysql database from a temporary container\", \"when\": [\"upgrade_mysql|bool\"], \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"{{ mysql_upgrade_script }}\"}}, {\"name\": \"Enable the galera cluster resource\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}]]}, \"external_upgrade_tasks\": [{\"vars\": {\"mysql_upgrade_transfer\": {\"get_param\": \"MysqlUpgradeTransfer\"}}, \"when\": [\"step|int == 2\", \"mysql_upgrade_transfer\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Transfer mysql data\", \"include_role\": {\"name\": \"tripleo_transfer\"}, \"vars\": {\"tripleo_transfer_src_dir\": \"/var/lib/mysql\", \"tripleo_transfer_src_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\", \"tripleo_transfer_dest_dir\": \"/var/lib/mysql\", \"tripleo_transfer_dest_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\", \"tripleo_transfer_flag_file\": \"/var/lib/tripleo/transfer-flags/var-lib-mysql\", \"tripleo_transfer_sync_options\": \"--whole-file --ignore-times --inplace --archive --delete\", \"tripleo_transfer_include\": [\"/ibdata*\", \"/ib_lru_dump\", \"/ib_logfile[0-9]*\", \"/undo*\", \"/*/\"], \"tripleo_transfer_exclude\": \"/*\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(163,'2026-06-13 07:57:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(164,'2026-06-13 07:57:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(165,'2026-06-13 07:57:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(166,'2026-06-13 07:57:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Composable Timezone service\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Timezone role using composable services.\", \"value\": {\"service_name\": \"timezone\", \"host_prep_tasks\": [{\"name\": \"Run timezone role\", \"include_role\": {\"name\": \"tripleo_timezone\"}, \"vars\": {\"tripleo_timezone\": {\"get_param\": \"TimeZone\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(167,'2026-06-13 07:57:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(168,'2026-06-13 07:57:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service for pacemaker\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"monitoring_subscription\"]}, \"ansible_group_vars\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"ansible_group_vars\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::mysql_clustercheck\": true, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, {\"haproxy_docker\": true, \"tripleo::profile::pacemaker::haproxy_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping_init_bundle\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_certs_directory\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_keys_directory\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::haproxy_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"class tripleo::firewall(){}; define tripleo::firewall::rule( $port = undef, $dport = undef, $sport = undef, $proto = undef, $action = undef, $state = undef, $source = undef, $iniface = undef, $chain = undef, $destination = undef, $extras = undef){}\", \"[\'pcmk_bundle\', \'pcmk_resource\', \'pcmk_property\', \'pcmk_constraint\', \'pcmk_resource_default\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::pacemaker::haproxy_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"yaql\": {\"expression\": \"$.data.select($+\\\":\\\"+$+\\\":ro\\\")\", \"data\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}}}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"register\": \"puppet_host_outputs\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"if hiera(\'enable_load_balancer\', true) { class {\'::tripleo::haproxy\': use_internal_certificates => false, manage_firewall => hiera(\'tripleo::firewall::manage_firewall\', true), }}\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}]]}, \"metadata_settings\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container managed by Pacemaker\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"HAproxy tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"HAproxy HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}, []]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"haproxy temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"haproxy-bundle\", \"tripleo_ha_image_update_new_image\": \"{{haproxy_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_haproxy_image}}\"}, \"when\": [\"(pcmk_haproxy_image != \\\"\\\")\", \"(pcmk_haproxy_image != haproxy_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of haproxy container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_haproxy_image == haproxy_image_latest\", \"fail_msg\": \"haproxy image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Set HAProxy upgrade facts\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_haproxy_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}]}, {\"name\": \"Mount TLS cert if needed\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node\"], \"block\": [{\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Disable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": \"haproxy_cert_mounted.rc == 6 and haproxy_public_tls_enabled|bool\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}]}, {\"name\": \"Haproxy fetch and retag container image for pacemaker\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 2\"], \"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Move virtual IPs to another node before stopping pacemaker\", \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"], \"shell\": \"CLUSTER_NODE=$(crm_node -n)\\necho \\\"Retrieving all the VIPs which are hosted on this node\\\"\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\"ocf:heartbeat:IPaddr2\\\" and @role = \\\"Started\\\" and @managed = \\\"true\\\" and ./node[@name = \\\"\'${CLUSTER_NODE}\'\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\"//g\')\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Moving VIP $v on another node\\\"\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\ndone\\necho \\\"Removing the location constraints that were created to move the VIPs\\\"\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Removing location ban for VIP $v\\\"\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\"\'${v}\'\\\" and @node=\\\"\'${CLUSTER_NODE}\'\\\" and @score=\\\"-INFINITY\\\"]/@id)\' -)\\n    if [ -n \\\"$ban_id\\\" ]; then\\n        pcs constraint remove ${ban_id}\\n    else\\n        echo \\\"Could not retrieve and clear location constraint for VIP $v\\\" 2>&1\\n    fi\\ndone\\n\"}, {\"name\": \"Wait for 10s to settle connections on new VIPs\", \"wait_for\": {\"timeout\": 10}, \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"]}, {\"name\": \"Block local INPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"# server controller-0.storage.redhat.local 172.17.3.93:8080 check fall 5 inter 2000 rise 2\\n# server controller-0.internalapi.redhat.local fd00:fd00:fd00:2000::176:9292 check fall 5 inter 2000 rise 2\\nset -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\necho \\\"insert rule $PROTOCOL filter INPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time\\\"\\ndone | xargs -i nft {} $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\"\\n\"}, {\"name\": \"Generate block for other nodes OUTPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\n echo \\\"nft insert rule $PROTOCOL \\\\$TABLE OUTPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\\\\\" \\\"\\ndone\\n\", \"register\": \"haproxy_iptables_block\"}, {\"name\": \"Block OUTPUT SYN packets to this node on other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"delegate_to\": \"{{ item }}\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | head -n 1 \\\\\\nawk \'{print $3}\' | while read BACKEND; do\\n    IP=${BACKEND%:*}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\ndone\\nTABLE=$(nft list tables | grep -q \\\"$PROTOCOL raw\\\" && echo raw || echo filter )\\necho \\\"{{ haproxy_iptables_block.stdout}}\\\" | while read i; do bash -c \\\"$i\\\"; done\\n\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\"}], \"post_update_tasks\": [{\"name\": \"HAProxy bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}, {\"name\": \"Cleanup local SYN DROP rules\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"shell\": \"nft -a list chain filter INPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule filter INPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}, {\"name\": \"Cleanup SYN DROP rules from other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"delegate_to\": \"{{ item }}\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\", \"shell\": \"nft -a list chain raw OUTPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule raw OUTPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Prepare switch of haproxy image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get haproxy image id currently used by pacemaker\", \"shell\": \"pcs resource config haproxy-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"haproxy_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for haproxy\", \"set_fact\": {\"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"haproxy_image_current\": \"{{haproxy_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current haproxy image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image_current}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\", \"pull_image\": false}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}, {\"name\": \"Create haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"touch\"}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set upgrade haproxy facts\", \"set_fact\": {\"is_haproxy_bootstrap_node\": \"{{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}}, {\"name\": \"Check for haproxy retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\"}, \"register\": \"haproxy_retag_state_file\"}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node|bool\", \"haproxy_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the haproxy cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Expose HAProxy stats socket on the host and mount TLS cert if needed\", \"block\": [{\"name\": \"Check haproxy stats socket configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-var-lib\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_stats_exposed\"}, {\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Add a bind mount for stats socket in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-var-lib source-dir=/var/lib/haproxy target-dir=/var/lib/haproxy options=rw\", \"when\": \"haproxy_stats_exposed.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": [\"haproxy_cert_mounted.rc == 6\", \"haproxy_public_tls_enabled|bool\"]}]}, {\"name\": \"Update the haproxy bundle to use the new container image name\", \"command\": \"pcs resource bundle update haproxy-bundle container image={{haproxy_image_latest}}\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"absent\"}}]}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"step|int == 3\"], \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Ensure config works for the new config\", \"shell\": \"set -o pipefail\\nawk -i inplace -v INPLACE_SUFFIX=.bak \'/  rsprep/ {print \\\"  http-response replace-header Location \\\" $3\\\" \\\"$5; next;}; {print} \' /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (169,'2026-06-13 07:57:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment using puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MysqlMaxConnections\": {\"description\": \"Configures MySQL max_connections config setting\", \"type\": \"number\", \"default\": 4096}, \"MysqlIncreaseFileLimit\": {\"description\": \"Flag to increase MySQL open-files-limit to 16384\", \"type\": \"boolean\", \"default\": true}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"pEuTysnhbk\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"LOZ9ZtUAwfPALS7L80T4luRla\"}, \"EnableGalera\": {\"default\": true, \"description\": \"Whether to use Galera instead of regular MariaDB.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableMysqlAuthEd25519\": {\"type\": \"boolean\", \"description\": \"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\", \"default\": false}, \"MysqlIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in MySQL\", \"type\": \"boolean\"}, \"MysqlInnodbBufferPoolSize\": {\"type\": \"string\", \"description\": \"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\", \"default\": \"128M\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MysqlCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MysqlIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, 6]}, \"innodb_buffer_pool_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlInnodbBufferPoolSize\"}, \"\"]}}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlCertificateKeySize\"}, \"\"]}}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"mysql_upgrade_db.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}}}}, \"mysql_drop_unused_users\": {\"description\": \"Ansible block to clean up unusued Openstack DB users\", \"value\": [{\"name\": \"Drop unused OpenStack DB users\", \"when\": [\"step|int == 1\", \"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\"], \"block\": [{\"name\": \"mysql container id\", \"command\": \"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\", \"register\": \"mysql_container_id\"}, {\"name\": \"set mysql container id fact\", \"set_fact\": {\"mysql_container\": \"{{ mysql_container_id.stdout }}\"}}, {\"name\": \"Mysql script to drop unused DB users\", \"when\": \"( mysql_container | length ) > 0\", \"block\": [{\"name\": \"Get the list of all OpenStack DB users\", \"shell\": \"jq -r \'to_entries[] | select(.key|endswith(\\\"::db::mysql::user\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\", \"register\": \"openstack_db_users\"}, {\"name\": \"List all DB users that match the DB users to be dropped\", \"shell\": \"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \\\"select concat(\'\\\\`\',user,\'\\\\`@\\\\`\',host,\'\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\"; done\", \"register\": \"mysql_db_users\"}, {\"name\": \"resulting DB users to be dropped\", \"debug\": {\"msg\": \"{{ mysql_db_users.stdout_lines }}\"}}, {\"name\": \"Drop all unneeded Openstack DB users\", \"shell\": \"podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \'drop user {{ item }};\'\", \"loop\": \"{{ mysql_db_users.stdout_lines }}\"}]}]}]}, \"role_data\": {\"description\": \"Service MySQL using composable services.\", \"value\": {\"service_name\": \"mysql\", \"config_settings\": {\"mysql::server::package_name\": \"mariadb-galera-server\", \"mysql::server::manage_config_file\": true, \"mysql_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"mysql_max_connections\": {\"get_param\": \"MysqlMaxConnections\"}, \"mysql::server::root_password\": {\"get_param\": \"MysqlRootPassword\"}, \"mysql_clustercheck_password\": {\"get_param\": \"MysqlClustercheckPassword\"}, \"enable_galera\": {\"get_param\": \"EnableGalera\"}, \"mysql_auth_ed25519\": {\"get_param\": \"EnableMysqlAuthEd25519\"}, \"mysql_bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::generate_dropin_file_limit\": {\"get_param\": \"MysqlIncreaseFileLimit\"}, \"tripleo::profile::base::database::mysql::certificate_specs\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"service_certificate\": \"/etc/pki/tls/certs/mysql.crt\", \"service_key\": \"/etc/pki/tls/private/mysql.key\"}]}, \"innodb_buffer_pool_size\": {\"if\": [\"innodb_buffer_pool_set\", {\"get_param\": \"MysqlInnodbBufferPoolSize\"}]}}, \"step_config\": \"include tripleo::profile::base::database::mysql\\n\", \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"vip\"}, {\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"mysql\", \"dns\": [{\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}], \"principal\": {\"str_replace\": {\"template\": \"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MysqlCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(170,'2026-06-13 07:57:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"CertmongerCA\": {\"type\": \"string\", \"default\": \"\", \"description\": \"CA to use for certmonger\"}, \"HAProxyCertificateDNSNames\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Override the default HAProxy Certificate DNS Names\"}, \"HAProxyCertificatePrincipal\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the default HAProxy Certificate Principal\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}, \"principal_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificatePrincipal\"}, \"\"]}}, \"dnsnames_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateDNSNames\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_public_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::service_certificate\": {\"get_param\": \"DeployedSSLCertificatePath\"}}, \"certificates_specs\": {\"haproxy-external\": {\"service_pem\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}, \"metadata_settings\": [{\"service\": \"haproxy\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"type\": \"vip\"}], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"vars\": {\"certmonger_ca\": {\"get_param\": \"CertmongerCA\"}}, \"block\": [{\"name\": \"make sure certmonger is installed\", \"package\": {\"name\": \"certmonger\", \"state\": \"present\"}}, {\"name\": \"make sure certmonger service is started\", \"systemd\": {\"state\": \"started\", \"enabled\": true, \"masked\": false, \"name\": \"certmonger.service\"}}, {\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"name\": \"Extract and trust certmonger\'s local CA\", \"shell\": \"set -e\\nca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\nopenssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\nchmod 0644 ${ca_pem}\\nupdate-ca-trust extract\\ntest -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n\", \"retries\": 5, \"delay\": 1, \"register\": \"local_ca_extract_result\", \"until\": \"local_ca_extract_result.rc == 0\", \"when\": \"certmonger_ca != \'IPA\' and (ipa_realm is not defined)\"}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"haproxy-external-cert\", \"dns\": {\"if\": [\"dnsnames_override_set\", {\"get_param\": \"HAProxyCertificateDNSNames\"}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"ip\": {\"if\": [\"dnsnames_override_set\", {\"str_replace\": {\"template\": \"{{DNSNAMES|ipaddr}}\", \"params\": {\"DNSNAMES\": {\"get_param\": \"HAProxyCertificateDNSNames\"}}}}, {\"str_replace\": {\"template\": \"{{[cloud_names.cloud_name_NETWORK]|ipaddr}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"principal\": {\"if\": [\"principal_override_set\", {\"get_param\": \"HAProxyCertificatePrincipal\"}, {\"str_replace\": {\"template\": \"haproxy/{{cloud_names.cloud_name_NETWORK}}@{{idm_realm|default(\'UNDERCLOUD\')}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-external-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-external-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\n\\nca_type=CATYPE\\nif [ \\\"$ca_type\\\" = \\\"self-sign\\\" ]; then\\n  # refresh the ca cert just in case the ca cert has been renewed\\n  ca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\n  openssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\n  chmod 0644 ${ca_pem}\\n  update-ca-trust extract\\n  test -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n  openssl x509 -in ${ca_pem} -out /tmp/cm-local-ca.pem\\n  ca_path=\\\"/tmp/cm-local-ca.pem\\\"\\nelse\\n  ca_path=\\\"/etc/ipa/ca.crt\\\"\\nfi\\n\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\nservice_pem=\\\"PEMPATH\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CATYPE\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\", \"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"PEMPATH\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(171,'2026-06-13 07:57:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/heat:/var/log/heat:z\", \"/var/log/containers/httpd/heat-api:/var/log/httpd:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/heat\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/heat-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(172,'2026-06-13 07:57:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(173,'2026-06-13 07:57:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(174,'2026-06-13 07:57:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ovn Controller agent.\\n\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ContainerOvnControllerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"ContainerOvnControllerConfigImage\": {\"description\": \"The container image to use for the ovn_controller config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the Southbound DB Server\", \"type\": \"number\", \"default\": 6642}, \"NeutronBridgeMappings\": {\"description\": \"The OVS logical->physical bridge mappings to use. See the Neutron documentation for details. Defaults to mapping br-ex - the external bridge on hosts - to a physical name \'datacentre\' which can be used to create provider networks (and we use this for the default floating network) - if changing this either use different post-install network scripts or be sure to keep \'datacentre\' as a mapping network name.\\n\", \"type\": \"comma_delimited_list\", \"default\": \"datacentre:br-ex\", \"tags\": [\"role_specific\"]}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"OVNEncapType\": {\"description\": \"Type of encapsulation used in OVN. It can be \\\"geneve\\\" or \\\"vxlan\\\".\\n\", \"type\": \"string\", \"default\": \"geneve\", \"constraints\": [{\"allowed_values\": [\"geneve\", \"vxlan\"]}]}, \"OVNIntegrationBridge\": {\"description\": \"Name of the OVS bridge to use as integration bridge by OVN Controller.\\n\", \"type\": \"string\", \"default\": \"br-int\"}, \"OVNMetadataEnabled\": {\"description\": \"Whether Metadata Service has to be enabled\", \"type\": \"boolean\", \"default\": true}, \"OVNAvailabilityZone\": {\"description\": \"The az options to configure in ovs db. eg. [\'az-0\', \'az-1\', \'az-2\']\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"OVNCMSOptions\": {\"description\": \"The CMS options to configure in ovs db\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNEncapTos\": {\"description\": \"The value to be applied to OVN tunnel interface\'s option:tos as specified in the Open_vSwitch database Interface table. This feature is supported from OVN v21.12.0.\\n\", \"type\": \"string\", \"default\": \"0\", \"tags\": [\"role_specific\"]}, \"OvsHwOffload\": {\"default\": false, \"description\": \"Enable OVS Hardware Offload. This feature supported from OVS 2.8.0\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"OVNRemoteProbeInterval\": {\"description\": \"Probe interval in ms\", \"type\": \"number\", \"default\": 60000}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"OVNOpenflowProbeInterval\": {\"description\": \"The inactivity probe interval of the OpenFlow connection to the OpenvSwitch integration bridge, in seconds.\\n\", \"type\": \"number\", \"default\": 60}, \"OVNOfctrlWaitBeforeClear\": {\"description\": \"Sets the time ovn-controller will wait on startup before clearing all openflow rules and installing the new ones, in ms.\\n\", \"type\": \"number\", \"default\": 8000}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ContainerOvnCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OVNContainerCpusetCpus\": {\"description\": \"Limit the specific CPUs or cores a container can use. It can be specified as a single core (ex. 0), as a comma-separated list (ex. 0,1), as a range (ex. 0-3) or a combination if previous methods (ex 0-3,7,11-15).  The selected cores should be isolated from guests and hypervisor in order to obtain best possible performance.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNStaticBridgeMacMappings\": {\"type\": \"json\", \"default\": {}, \"description\": \"Static OVN Bridge MAC address mappings. Unique OVN bridge mac addresses\\nis dynamically allocated by creating neutron ports. When neutron isn\'t\\navailable, for instance in the standalone deployment, use this parameter\\nto provide static OVN bridge mac addresses. For example:\\n   controller-0:\\n     datacenter: 00:00:5E:00:53:00\\n     provider: 00:00:5E:00:53:01\\n   compute-0:\\n     datacenter: 00:00:5E:00:54:00\\n     provider: 00:00:5E:00:54:01\\n\", \"tags\": [\"role_specific\"]}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}, \"OVNControllerImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerGarpMaxTimeout\": {\"description\": \"When used, this configuration value specifies the maximum timeout (in seconds) between two consecutive GARP packets sent by ovn-controller.\\n\", \"type\": \"number\", \"default\": 0}}, \"conditions\": {\"force_config_drive\": {\"equals\": [{\"get_param\": \"OVNMetadataEnabled\"}, false]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}, \"enable_vlan_transparency\": {\"equals\": [{\"get_param\": \"EnableVLANTransparency\"}, true]}, \"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"ovn_cpu_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"OVNContainerCpusetCpus\"}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNContainerCpusetCpus\"]}, \"\"]}}]}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}}, \"az_ovn_unset\": {\"and\": [{\"equals\": [{\"get_param\": \"OVNAvailabilityZone\"}, []]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn::controller::ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn::controller::ovn_cms_options\": {\"if\": [\"az_ovn_unset\", \"OVNCMSOptions\", \"OVNCMSOptionsMerged\"]}, \"ovn::controller::ovn_encap_tos\": \"OVNEncapTos\", \"vswitch::ovs::enable_hw_offload\": \"OvsHwOffload\", \"container_cpuset_cpus\": \"OVNContainerCpusetCpus\", \"ContainerOvnControllerImage\": \"ContainerOvnControllerImage\", \"ContainerOvnControllerConfigImage\": \"ContainerOvnControllerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}, \"OVNCMSOptionsMerged\": {\"list_join\": [\"\", [{\"str_replace\": {\"template\": \"$OVNCMSOptions\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}, \"\"]}}, {\"$OVNCMSOptions\": {\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}}, {\"$OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}}]}}}, {\"str_replace\": {\"template\": \",availability-zones=$OVNAvailabilityZone\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}}, {\"$OVNAvailabilityZone\": {\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}}, {\"$OVNAvailabilityZone\": {\"list_join\": [\",\", {\"get_param\": \"OVNAvailabilityZone\"}]}}]}}}]]}, \"OVNEncapTos\": {\"get_param\": \"OVNEncapTos\"}, \"OvsHwOffload\": {\"get_param\": \"OvsHwOffload\"}, \"OVNContainerCpusetCpus\": {\"get_param\": \"OVNContainerCpusetCpus\"}, \"ContainerOvnControllerImage\": {\"get_param\": \"ContainerOvnControllerImage\"}, \"ContainerOvnControllerConfigImage\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}}]}}}, \"OVNBridgeMappingsValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn_static_bridge_mac_mappings\": \"OVNStaticBridgeMacMappings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNStaticBridgeMacMappings\": {\"get_param\": \"OVNStaticBridgeMacMappings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ovn Controller agent.\", \"value\": {\"service_name\": \"ovn_controller\", \"firewall_rules\": {\"118 neutron vxlan networks\": {\"proto\": \"udp\", \"dport\": 4789, \"state\": []}, \"119 neutron geneve networks\": {\"proto\": \"udp\", \"dport\": 6081, \"state\": []}, \"120 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"OUTPUT\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}, \"121 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"PREROUTING\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"ovn::controller::ovn_encap_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronTenantNetwork\"]}}}}, \"ovn::controller::ovn_encap_type\": {\"get_param\": \"OVNEncapType\"}, \"ovn::controller::ovn_bridge\": {\"get_param\": \"OVNIntegrationBridge\"}, \"ovn::controller::hostname\": \"%{hiera(\'fqdn_canonical\')}\", \"ovn::controller::ovn_remote_probe_interval\": {\"get_param\": \"OVNRemoteProbeInterval\"}, \"ovn::controller::ovn_openflow_probe_interval\": {\"get_param\": \"OVNOpenflowProbeInterval\"}, \"ovn::controller::ovn_ofctrl_wait_before_clear\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}, \"ovn::controller::garp_max_timeout_sec\": {\"get_param\": \"OVNControllerGarpMaxTimeout\"}, \"ovn::controller::ovn_monitor_all\": true}, {\"if\": [\"force_config_drive\", {\"nova::compute::force_config_drive\": true}, {}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::agents::ovn::protocol\": \"ssl\"}, {}]}, {\"if\": [\"enable_vlan_transparency\", {\"vswitch::ovs::vlan_limit\": 0}, {}]}]}, \"service_config_settings\": {}, \"puppet_config\": {\"puppet_tags\": \"vs_config,exec\", \"config_volume\": \"ovn_controller\", \"step_config\": \"include tripleo::profile::base::neutron::agents::ovn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/etc/sysconfig/modules:/etc/sysconfig/modules\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_controller.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock\", {\"if\": [\"internal_tls_enabled\", {\"list_join\": [\" \", [\"-p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C\", {\"get_param\": \"InternalTLSCAFile\"}]]}, \"\"]}]]}, \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_controller\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}, \"docker_config\": {\"step_4\": {\"configure_cms_options\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\"$CMS_OPTS\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\"], \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_controller\": {\"map_merge\": [{\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"depends_on\": [\"openvswitch.service\"]}, {\"if\": [\"ovn_cpu_set\", {\"cpuset_cpus\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"container_cpuset_cpus\"]}}]}, {\"healthcheck\": {\"test\": {\"list_join\": [\" \", [\"/openstack/healthcheck\", {\"yaql\": {\"expression\": \"str($.data.port)\", \"data\": {\"port\": {\"get_param\": \"OVNSouthboundServerPort\"}}}}]]}}, \"volumes\": {\"list_concat\": [[\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}, \"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\", \"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_controller\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_controller/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_controller\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"ContainerOvnCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/openvswitch\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/openvswitch/ovn\", \"setype\": \"container_file_t\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Copy in cleanup script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup\"}, \"dest\": \"/usr/libexec/neutron-cleanup\", \"force\": true, \"mode\": \"0755\"}}, {\"name\": \"Copy in cleanup service\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup.service\"}, \"dest\": \"/usr/lib/systemd/system/neutron-cleanup.service\", \"force\": true}}, {\"name\": \"Enabling the cleanup service\", \"service\": {\"name\": \"neutron-cleanup\", \"enabled\": true}, \"when\": \"not (ansible_check_mode|bool)\"}], \"external_deploy_tasks\": [{\"when\": [\"step|int == 0\"], \"name\": \"ovn_controller_external_deploy_init\", \"block\": [{\"name\": {\"str_replace\": {\"template\": \"create ovn mac address for $ROLE_NAME role nodes\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"tripleo_ovn_mac_addresses\": {\"playbook_dir\": \"{{ playbook_dir }}\", \"stack_name\": {\"get_param\": \"RootStackName\"}, \"role_name\": {\"get_param\": \"RoleName\"}, \"server_resource_names\": {\"str_replace\": {\"template\": \"{{ groups[\\\"$ROLE_NAME\\\"] }}\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"ovn_bridge_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_bridge_mappings\"]}, \"ovn_static_bridge_mac_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_static_bridge_mac_mappings\"]}}}]}], \"external_update_tasks\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 1\", \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_controller image pull successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_image_update\"], \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"OVN Container image used\", \"debug\": {\"msg\": \"ovn container will be using {{ image }}\"}, \"vars\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovs_vsctl\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Was the update of OVN OVS related parameter successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovs_vsctl\"], \"become\": true, \"tags\": [\"ovn\"], \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovs_vsctl.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"set_fact\": {\"any_ovn_host\": \"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\"}, \"tags\": \"ovn\", \"when\": \"step|int == 1\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"delegate_to\": \"{{ any_ovn_host }}\", \"when\": \"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\", \"tags\": [\"ovn\"], \"become\": true}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\", \"query\": \"results[?item == \'{{item}}\'].stdout\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\", \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_update\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile | json_query(query) | first }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Was the ovn_controller successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_update\"], \"tags\": \"ovn\", \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 1\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}], \"upgrade_tasks\": [{\"name\": \"Fetch running ovn_controller image\", \"shell\": \"set -e\\npodman inspect --format \\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\" ovn_controller\\n\", \"register\": \"running_ovn_image\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\", \"ovn_image\"]}, {\"name\": \"Run ovn_controller upgrade\", \"tags\": [\"ovn\", \"ovn_image\"], \"vars\": {\"ovn_controller_image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": [\"step|int == 4\", \"running_ovn_image.stdout != ovn_controller_image\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 4\", \"tags\": [\"ovn\", \"ovn_image\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"]}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile.stdout }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 4\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get neutron agents ID\", \"command\": \"openstack network agent list --column ID --column Host --column Binary --format yaml\", \"register\": \"neutron_agents_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Filter only current host\", \"set_fact\": {\"neutron_agents\": \"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Deleting OVN agents\", \"block\": [{\"name\": \"Stop OVN containers\", \"loop\": [\"tripleo_ovn_controller\", \"tripleo_ovn_metadata_agent\"], \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_containers\", \"failed_when\": \"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\"}, {\"name\": \"Delete neutron agents\", \"loop\": \"{{ neutron_agents }}\", \"loop_control\": {\"loop_var\": \"agent\", \"label\": \"{{ agent.Host }}/{{ agent.Binary }}\"}, \"command\": \"openstack network agent delete {{ agent.ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(175,'2026-06-13 07:57:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyStatsPassword\": {\"description\": \"Password for HAProxy stats endpoint\", \"hidden\": true, \"type\": \"string\", \"default\": \"uV80OdWAFFrCjeW3b3kCveIzm\"}, \"HAProxyStatsUser\": {\"description\": \"User for HAProxy stats endpoint\", \"default\": \"admin\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"0plrFXAbintMcjJGm66MGfoQJ\"}, \"MonitoringSubscriptionHaproxy\": {\"default\": \"overcloud-haproxy\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"EnableLoadBalancer\": {\"default\": true, \"description\": \"Whether to deploy a LoadBalancer, set to false when an external load balancer is used.\", \"type\": \"boolean\"}, \"HAProxyStatsEnabled\": {\"default\": true, \"description\": \"Whether or not to enable the HAProxy stats interface.\", \"type\": \"boolean\"}, \"InternalTLSCRLPEMFile\": {\"default\": \"/etc/pki/CA/crl/overcloud-crl.pem\", \"type\": \"string\", \"description\": \"Specifies the default CRL PEM file to use for revocation if TLS is used for services in the internal network.\"}, \"InternalTLSCRLPEMDir\": {\"default\": \"/etc/pki/CA/crl/\", \"type\": \"string\", \"description\": \"The directory of the CRL PEM file to be mounted.\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyLogging\": {\"type\": \"OS::TripleO::Services::Logging::HAProxy\"}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"107 haproxy stats\": {\"dport\": 1993}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHaproxy\"}, \"ansible_group_vars\": {\"tripleo_firewall_frontend_enabled\": true, \"tripleo_firewall_ssl_frontend_enabled\": {\"if\": [\"public_tls_enabled\", true]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}, \"tripleo::haproxy::haproxy_stats_user\": {\"get_param\": \"HAProxyStatsUser\"}, \"tripleo::haproxy::haproxy_stats_password\": {\"get_param\": \"HAProxyStatsPassword\"}, \"tripleo::haproxy::haproxy_stats_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HaproxyNetwork\"]}}}}, \"tripleo::haproxy::redis_password\": {\"get_param\": \"RedisPassword\"}, \"tripleo::haproxy::crl_file\": null, \"tripleo::haproxy::haproxy_stats\": {\"get_param\": \"HAProxyStatsEnabled\"}, \"enable_load_balancer\": {\"get_param\": \"EnableLoadBalancer\"}, \"tripleo::profile::base::haproxy::certificates_specs\": {\"map_merge\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"certificates_specs\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"certificates_specs\"]}]}, \"tripleo::haproxy::service_certificate\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"DeployedSSLCertificatePath\"}]}, \"tripleo::haproxy::ca_bundle\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}, {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": \"class {\'tripleo::profile::base::haproxy\': manage_firewall => false}\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"get_param\": \"DeployedSSLCertificatePath\"}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro,shared\"]]}, {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro,shared\"]]}]]}]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true, \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"docker_config\", \"step_1\"]}, {\"haproxy\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HAProxyLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/haproxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/haproxy:/var/lib/kolla/config_files/src:ro\", \"/var/lib/haproxy:/var/lib/haproxy:rw,z\"], {\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"list_join\": [\"\", [\"/var/lib/kolla/config_files/src-tls\", {\"get_param\": \"DeployedSSLCertificatePath\"}]]}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro\"]]}]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"when\": \"step|int == 1\", \"register\": \"puppet_host_outputs\", \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"include tripleo::profile::base::haproxy\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"upgrade_tasks\": [{\"name\": \"ensure we have haproxy log dir with the correct setype\", \"file\": {\"path\": \"/var/log/containers/haproxy\", \"state\": \"directory\", \"setype\": \"var_log_t\", \"recurse\": true}, \"when\": \"step|int == 1\"}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop haproxy container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"haproxy\"], \"tripleo_delegate_to\": \"{{ groups[\'haproxy\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/haproxy\", \"setype\": \"var_log_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/haproxy\", \"setype\": \"container_file_t\"}]}]]}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"metadata_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"metadata_settings\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(176,'2026-06-13 07:57:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (177,'2026-06-13 07:57:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(178,'2026-06-13 07:57:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(179,'2026-06-13 07:57:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"CertmongerCA\": {\"type\": \"string\", \"default\": \"\", \"description\": \"CA to use for certmonger\"}, \"HAProxyCertificateDNSNames\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Override the default HAProxy Certificate DNS Names\"}, \"HAProxyCertificatePrincipal\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the default HAProxy Certificate Principal\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}, \"principal_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificatePrincipal\"}, \"\"]}}, \"dnsnames_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateDNSNames\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_public_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::service_certificate\": {\"get_param\": \"DeployedSSLCertificatePath\"}}, \"certificates_specs\": {\"haproxy-external\": {\"service_pem\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}, \"metadata_settings\": [{\"service\": \"haproxy\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"type\": \"vip\"}], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"vars\": {\"certmonger_ca\": {\"get_param\": \"CertmongerCA\"}}, \"block\": [{\"name\": \"make sure certmonger is installed\", \"package\": {\"name\": \"certmonger\", \"state\": \"present\"}}, {\"name\": \"make sure certmonger service is started\", \"systemd\": {\"state\": \"started\", \"enabled\": true, \"masked\": false, \"name\": \"certmonger.service\"}}, {\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"name\": \"Extract and trust certmonger\'s local CA\", \"shell\": \"set -e\\nca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\nopenssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\nchmod 0644 ${ca_pem}\\nupdate-ca-trust extract\\ntest -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n\", \"retries\": 5, \"delay\": 1, \"register\": \"local_ca_extract_result\", \"until\": \"local_ca_extract_result.rc == 0\", \"when\": \"certmonger_ca != \'IPA\' and (ipa_realm is not defined)\"}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"haproxy-external-cert\", \"dns\": {\"if\": [\"dnsnames_override_set\", {\"get_param\": \"HAProxyCertificateDNSNames\"}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"ip\": {\"if\": [\"dnsnames_override_set\", {\"str_replace\": {\"template\": \"{{DNSNAMES|ipaddr}}\", \"params\": {\"DNSNAMES\": {\"get_param\": \"HAProxyCertificateDNSNames\"}}}}, {\"str_replace\": {\"template\": \"{{[cloud_names.cloud_name_NETWORK]|ipaddr}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"principal\": {\"if\": [\"principal_override_set\", {\"get_param\": \"HAProxyCertificatePrincipal\"}, {\"str_replace\": {\"template\": \"haproxy/{{cloud_names.cloud_name_NETWORK}}@{{idm_realm|default(\'UNDERCLOUD\')}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-external-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-external-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\n\\nca_type=CATYPE\\nif [ \\\"$ca_type\\\" = \\\"self-sign\\\" ]; then\\n  # refresh the ca cert just in case the ca cert has been renewed\\n  ca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\n  openssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\n  chmod 0644 ${ca_pem}\\n  update-ca-trust extract\\n  test -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n  openssl x509 -in ${ca_pem} -out /tmp/cm-local-ca.pem\\n  ca_path=\\\"/tmp/cm-local-ca.pem\\\"\\nelse\\n  ca_path=\\\"/etc/ipa/ca.crt\\\"\\nfi\\n\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\nservice_pem=\\\"PEMPATH\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CATYPE\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\", \"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"PEMPATH\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(180,'2026-06-13 07:57:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(181,'2026-06-13 07:57:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(182,'2026-06-13 07:57:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"HAProxyNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellController\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"Compute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"internal_api\"]}}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"CephStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}, \"Networker\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"internal_api\"]}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy internal TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_internal_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::use_internal_certificates\": true}, \"certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"haproxy-NETWORK\": {\"service_pem\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/overcloud-haproxy-NETWORK.pem\"]]}}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}, \"metadata_settings\": {\"repeat\": {\"template\": [{\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"vip\"}, {\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"haproxy-NETWORK-cert\", \"dns\": [\"{{fqdn_NETWORK}}\", \"{{cloud_names.cloud_name_NETWORK}}\"], \"principal\": \"haproxy/{{fqdn_NETWORK}}@{{idm_realm}}\", \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-NETWORK-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-NETWORK-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\n\\nca_path=\\\"/etc/ipa/ca.crt\\\"\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\nservice_pem=\\\"CERTSDIR/overcloud-haproxy-NETWORK.pem\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(183,'2026-06-13 07:57:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(184,'2026-06-13 07:57:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Horizon service\\n\", \"parameters\": {\"ContainerHorizonImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\"}, \"ContainerHorizonConfigImage\": {\"description\": \"The container image to use for the horizon config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HorizonDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Horizon service.\", \"type\": \"boolean\"}, \"HorizonAllowedHosts\": {\"default\": \"*\", \"description\": \"A list of IP/Hostname for the server Horizon is running on. Used for header checks.\", \"type\": \"comma_delimited_list\"}, \"HorizonPasswordValidator\": {\"description\": \"Regex for password validation\", \"type\": \"string\", \"default\": \"\"}, \"HorizonPasswordValidatorHelp\": {\"description\": \"Help text for password validation\", \"type\": \"string\", \"default\": \"\"}, \"HorizonSecret\": {\"description\": \"Secret key for Django\", \"type\": \"string\", \"hidden\": true, \"default\": \"YJSs8dHdzh\"}, \"HorizonSecureCookies\": {\"description\": \"Set CSRF_COOKIE_SECURE / SESSION_COOKIE_SECURE in Horizon\", \"type\": \"boolean\", \"default\": false}, \"HorizonSessionTimeout\": {\"description\": \"Set session timeout for horizon in seconds\", \"type\": \"number\", \"default\": 1800}, \"MemcachedIPv6\": {\"default\": false, \"description\": \"Enable IPv6 features in Memcached.\", \"type\": \"boolean\"}, \"MonitoringSubscriptionHorizon\": {\"default\": \"overcloud-horizon\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HorizonVhostExtraParams\": {\"default\": {\"add_listen\": true, \"priority\": 10, \"access_log_format\": \"%a %l %u %t \\\\\\\"%r\\\\\\\" %>s %b \\\\\\\"%%{}{Referer}i\\\\\\\" \\\\\\\"%%{}{User-Agent}i\\\\\\\"\", \"options\": [\"FollowSymLinks\", \"MultiViews\"]}, \"description\": \"Extra parameters for Horizon vhost configuration\", \"type\": \"json\"}, \"HorizonCustomizationModule\": {\"default\": \"\", \"description\": \"Horizon has a global overrides mechanism available to perform customizations\", \"type\": \"string\"}, \"HorizonHelpURL\": {\"default\": \"http://docs.openstack.org\", \"description\": \"On top of dashboard there is a Help button. This button could be used to re-direct user to vendor documentation or dedicated help portal.\", \"type\": \"string\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}, \"WebSSOEnable\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Enable support for Web Single Sign-On\"}, \"WebSSOInitialChoice\": {\"default\": \"OIDC\", \"type\": \"string\", \"description\": \"The initial authentication choice to select by default\"}, \"WebSSOChoicesHideKeystone\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Hide Keystone crednetials login when WebSSO is enabled.\"}, \"WebSSOChoices\": {\"default\": [[\"OIDC\", \"OpenID Connect\"]], \"type\": \"json\", \"description\": \"Specifies the list of SSO authentication choices to present. Each item is a list of an SSO choice identifier and a display message.\"}, \"WebSSOIDPMapping\": {\"default\": {\"OIDC\": [\"myidp\", \"openid\"]}, \"type\": \"json\", \"description\": \"Specifies a mapping from SSO authentication choice to identity provider and protocol.  The identity provider and protocol names must match the resources defined in keystone.\"}, \"HorizonDomainChoices\": {\"default\": [], \"type\": \"json\", \"description\": \"Specifies available domains to choose from. We expect an array of hashes, and the hashes should have two items each (name, display) containing Keystone domain name and a human-readable description of the domain respectively.\"}, \"HorizonLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.horizon\", \"file\": \"/var/log/containers/horizon/horizon.log\"}}, \"HorizonHstsHeaderValue\": {\"default\": [], \"description\": \"Enables HTTP Strict-Transport-Security header in response.\", \"type\": \"comma_delimited_list\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MemcachedIPv6\"]}], \"conditions\": {\"horizon_domain_choices_set\": {\"not\": {\"equals\": [{\"get_param\": \"HorizonDomainChoices\"}, []]}}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}]}, 6]}, \"horizon_logger_debug\": {\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"HorizonDebug\"}]}, \"horizon_hsts_header_value_set\": {\"not\": {\"equals\": [{\"get_param\": \"HorizonHstsHeaderValue\"}, []]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHorizonImage\": \"ContainerHorizonImage\", \"ContainerHorizonConfigImage\": \"ContainerHorizonConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHorizonImage\": {\"get_param\": \"ContainerHorizonImage\"}, \"ContainerHorizonConfigImage\": {\"get_param\": \"ContainerHorizonConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Horizon API role.\", \"value\": {\"service_name\": \"horizon\", \"firewall_rules\": {\"126 horizon\": {\"dport\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, 443, 80]}]}}, \"firewall_frontend_rules\": {\"100 horizon_haproxy_frontend\": {\"dport\": [80]}}, \"firewall_ssl_frontend_rules\": {\"100 horizon_haproxy_frontend_ssl\": {\"dport\": [443]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHorizon\"}, \"config_settings\": {\"map_merge\": [{\"horizon::allowed_hosts\": {\"get_param\": \"HorizonAllowedHosts\"}, \"horizon::enable_secure_proxy_ssl_header\": true, \"horizon::secure_proxy_addr_header\": \"HTTP_X_FORWARDED_FOR\", \"horizon::disable_password_reveal\": true, \"horizon::enforce_password_check\": true, \"horizon::disallow_iframe_embed\": true, \"horizon::cache_backend\": \"django.core.cache.backends.memcached.MemcachedCache\", \"horizon::django_session_engine\": \"django.contrib.sessions.backends.cache\", \"horizon::vhost_extra_params\": {\"get_param\": \"HorizonVhostExtraParams\"}, \"horizon::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}}}}, \"horizon::keystone_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Public\", \"uri\"]}, \"horizon::password_validator\": {\"get_param\": [\"HorizonPasswordValidator\"]}, \"horizon::password_validator_help\": {\"get_param\": [\"HorizonPasswordValidatorHelp\"]}, \"horizon::secret_key\": {\"get_param\": \"HorizonSecret\"}, \"horizon::secure_cookies\": {\"get_param\": [\"HorizonSecureCookies\"]}, \"horizon::session_timeout\": {\"get_param\": \"HorizonSessionTimeout\"}, \"memcached_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"horizon::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}}}}, \"horizon::listen_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"horizon::customization_module\": {\"get_param\": \"HorizonCustomizationModule\"}, \"horizon::timezone\": {\"get_param\": \"TimeZone\"}, \"horizon::file_upload_temp_dir\": \"/var/tmp\", \"horizon::help_url\": {\"get_param\": \"HorizonHelpURL\"}, \"horizon::enable_user_pass\": \"UNSET\"}, {\"if\": [{\"get_param\": \"WebSSOEnable\"}, {\"horizon::websso_enabled\": {\"get_param\": \"WebSSOEnable\"}, \"horizon::websso_initial_choice\": {\"get_param\": \"WebSSOInitialChoice\"}, \"horizon::websso_choices\": {\"get_param\": \"WebSSOChoices\"}, \"horizon::websso_idp_mapping\": {\"get_param\": \"WebSSOIDPMapping\"}, \"horizon::websso_choices_hide_keystone\": {\"get_param\": \"WebSSOChoicesHideKeystone\"}}]}, {\"if\": [{\"get_param\": \"HorizonDebug\"}, {\"horizon::django_debug\": true}, {\"horizon::django_debug\": {\"get_param\": \"Debug\"}}]}, {\"if\": [\"horizon_logger_debug\", {\"horizon::log_level\": \"DEBUG\"}]}, {\"if\": [\"horizon_domain_choices_set\", {\"horizon::keystone_domain_choices\": {\"get_param\": \"HorizonDomainChoices\"}}]}]}, \"ansible_group_vars\": {\"keystone_enable_member\": true}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_horizon\": {\"yaql\": {\"expression\": \"$.data.sources.flatten()\", \"data\": {\"sources\": [{\"get_param\": \"HorizonLoggingSource\"}]}}}}, \"haproxy\": {\"if\": [\"horizon_hsts_header_value_set\", {\"tripleo::profile::base::horizon::hsts_header_value\": {\"get_param\": \"HorizonHstsHeaderValue\"}}]}}, \"puppet_config\": {\"config_volume\": \"horizon\", \"puppet_tags\": \"horizon_config\", \"step_config\": \"include tripleo::profile::base::horizon\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/horizon.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/horizon/\", \"owner\": \"apache:apache\", \"recurse\": true}, {\"path\": \"/etc/openstack-dashboard/\", \"owner\": \"apache:apache\", \"recurse\": true}, {\"path\": \"/usr/share/openstack-dashboard/openstack_dashboard/local/\", \"owner\": \"apache:apache\", \"recurse\": false}, {\"path\": \"/usr/share/openstack-dashboard/openstack_dashboard/local/local_settings.d/\", \"owner\": \"apache:apache\", \"recurse\": false}]}}, \"docker_config\": {\"step_2\": {\"horizon_fix_perms\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"touch /var/log/horizon/horizon.log ; chown -R apache:apache /var/log/horizon && chmod -R a+rx /etc/openstack-dashboard\"], \"volumes\": [\"/var/log/containers/horizon:/var/log/horizon:z\", \"/var/log/containers/httpd/horizon:/var/log/httpd:z\", \"/var/lib/config-data/puppet-generated/horizon/etc/openstack-dashboard:/etc/openstack-dashboard\"]}}, \"step_3\": {\"horizon\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/horizon.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/horizon:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/horizon:/var/log/horizon:z\", \"/var/log/containers/httpd/horizon:/var/log/httpd:z\", \"/var/tmp/horizon:/var/tmp:z\", \"/var/www:/var/www:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"ENABLE_DESIGNATE\": \"yes\", \"ENABLE_HEAT\": \"yes\", \"ENABLE_IRONIC\": \"yes\", \"ENABLE_MANILA\": \"yes\", \"ENABLE_OCTAVIA\": \"yes\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/horizon\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/horizon\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/www\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/tmp/horizon\", \"setype\": \"container_file_t\", \"mode\": \"01777\"}]}, {\"name\": \"ensure /var/tmp/horizon exists on boot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/var-tmp-horizon.conf\", \"content\": \"d /var/tmp/horizon 01777 root root - -\\n\"}}], \"upgrade_tasks\": [{\"name\": \"Anchor for upgrade and update tasks\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Reset selinux label on /var/tmp\", \"file\": {\"path\": \"/var/tmp\", \"state\": \"directory\", \"setype\": \"tmp_t\", \"mode\": 1023}}]}], \"update_tasks\": [{\"name\": \"Anchor for upgrade and update tasks\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Reset selinux label on /var/tmp\", \"file\": {\"path\": \"/var/tmp\", \"state\": \"directory\", \"setype\": \"tmp_t\", \"mode\": 1023}}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop horizon container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"horizon\"], \"tripleo_delegate_to\": \"{{ groups[\'horizon\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (185,'2026-06-13 07:57:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance internal service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"GlanceApiInternalLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api_internal.log\"}}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiInternalConfigImage\": {\"description\": \"The container image to use for the glance_api_internal config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"GlanceApi\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiInternalConfigImage\": \"ContainerGlanceApiInternalConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiInternalConfigImage\": {\"get_param\": \"ContainerGlanceApiInternalConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the internal Glance API.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\"]}, {\"service_name\": \"glance_api_internal\", \"firewall_rules\": {\"112 glance_api_internal\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 glance_api_internal_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"keystone_resources\": {}, \"config_settings\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_glance_api_internal\": [{\"get_param\": \"GlanceApiInternalLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"glance_api_internal\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [{\"str_replace\": {\"template\": \"class { \'tripleo::profile::base::glance::api\':\\n  bind_port => PORT,\\n  tls_proxy_port => PORT,\\n  log_file => \'/var/log/glance/api_internal.log\',\\n  show_image_direct_url => true,\\n  show_multiple_locations => true,\\n}\\n\", \"params\": {\"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiInternalConfigImage\"]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"glance_api_internal\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\", \"volumes\"]}}}}}]}, \"glance_api_internal_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\", \"volumes\"]}}}}}]}]}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api internal container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api_internal\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api_internal\'] | default([]) }}\"}}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(186,'2026-06-13 07:57:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"HAProxyNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellController\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"Compute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"internal_api\"]}}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"CephStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}, \"Networker\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"internal_api\"]}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy internal TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_internal_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::use_internal_certificates\": true}, \"certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"haproxy-NETWORK\": {\"service_pem\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/overcloud-haproxy-NETWORK.pem\"]]}}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}, \"metadata_settings\": {\"repeat\": {\"template\": [{\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"vip\"}, {\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"haproxy-NETWORK-cert\", \"dns\": [\"{{fqdn_NETWORK}}\", \"{{cloud_names.cloud_name_NETWORK}}\"], \"principal\": \"haproxy/{{fqdn_NETWORK}}@{{idm_realm}}\", \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-NETWORK-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-NETWORK-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\n\\nca_path=\\\"/etc/ipa/ca.crt\\\"\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\nservice_pem=\\\"CERTSDIR/overcloud-haproxy-NETWORK.pem\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(187,'2026-06-13 07:57:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(188,'2026-06-13 07:57:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(189,'2026-06-13 07:57:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(190,'2026-06-13 07:57:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(191,'2026-06-13 07:57:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAProxy API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_1\": {}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": null}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(192,'2026-06-13 07:57:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(193,'2026-06-13 07:57:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (194,'2026-06-13 07:57:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(195,'2026-06-13 07:57:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a Compute server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[{\\\"service_name\\\": \\\"boot_params_service\\\", \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Configure tuned before reboot\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tuned\\\"}, \\\"vars\\\": {\\\"tuned_profile\\\": \\\"throughput-performance\\\", \\\"tuned_isolated_cores\\\": \\\"\\\"}}, {\\\"name\\\": \\\"Configure kernel args and reboot\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"kernelargs.yml\\\"}, \\\"vars\\\": {\\\"tripleo_kernel_args\\\": \\\"\\\", \\\"tripleo_kernel_hugepages\\\": {}, \\\"tripleo_kernel_hugepages_remove\\\": false, \\\"tripleo_kernel_defer_reboot\\\": false, \\\"tripleo_kernel_reboot_timeout\\\": 900}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"upgrade prepare for leapp to align kernel arg shortcommings in leapp\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"fix grub entries to have name start with GRUB_\\\", \\\"replace\\\": {\\\"path\\\": \\\"/etc/default/grub\\\", \\\"regexp\\\": \\\"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\\\", \\\"replace\\\": \\\"GRUB_\\\\\\\\1\\\\\\\\2\\\"}}, {\\\"name\\\": \\\"fix grub entries in append statement\\\", \\\"replace\\\": {\\\"path\\\": \\\"/etc/default/grub\\\", \\\"regexp\\\": \\\"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\\\", \\\"replace\\\": \\\"\\\\\\\\1{GRUB_\\\\\\\\2}\\\\\\\\3\\\"}}]}]}, {\\\"service_name\\\": \\\"ca_certs\\\", \\\"config_settings\\\": {\\\"tripleo::trusted_cas::ca_map\\\": {}}, \\\"step_config\\\": \\\"include tripleo::trusted_cas\\\"}, {\\\"service_name\\\": \\\"collectd\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::metrics::collectd::enable_file_logging\\\": true, \\\"collectd::plugin::logfile::log_file\\\": \\\"/var/log/collectd/collectd.log\\\", \\\"collectd::manage_repo\\\": false, \\\"collectd::purge\\\": true, \\\"collectd::recurse\\\": true, \\\"collectd::purge_config\\\": true, \\\"collectd::minimum_version\\\": \\\"5.7\\\", \\\"collectd::interval\\\": 120, \\\"collectd::plugin::unixsock::socketgroup\\\": \\\"root\\\", \\\"collectd::plugin::unixsock::socketfile\\\": \\\"/run/collectd-socket\\\", \\\"collectd::plugin::unixsock::deletesocket\\\": true, \\\"collectd::plugin::cpu::reportbycpu\\\": true, \\\"collectd::plugin::cpu::reportbystate\\\": true, \\\"collectd::plugin::cpu::reportnumcpu\\\": false, \\\"collectd::plugin::cpu::valuespercentage\\\": true, \\\"collectd::plugin::df::ignoreselected\\\": true, \\\"collectd::plugin::df::reportbydevice\\\": true, \\\"collectd::plugin::df::fstypes\\\": [\\\"xfs\\\"], \\\"collectd::plugin::load::reportrelative\\\": true, \\\"collectd::plugin::virt::connection\\\": \\\"qemu:///system\\\", \\\"collectd::plugin::virt::extra_stats\\\": \\\"pcpu cpu_util vcpu memory disk disk_err disk_allocation disk_capacity disk_physical domain_state job_stats_background perf\\\", \\\"collectd::plugin::virt::hostname_format\\\": \\\"hostname\\\", \\\"tripleo.collectd.plugins.collectd\\\": [\\\"cpu\\\", \\\"df\\\", \\\"disk\\\", \\\"hugepages\\\", \\\"interface\\\", \\\"load\\\", \\\"memory\\\", \\\"unixsock\\\", \\\"uptime\\\"], \\\"tripleo::profile::base::metrics::collectd::amqp_transport_name\\\": \\\"metrics\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_address\\\": \\\"collectd\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_instances\\\": {}, \\\"tripleo::profile::base::metrics::collectd::amqp_retry_delay\\\": 1, \\\"tripleo::profile::base::metrics::collectd::amqp_host\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_port\\\": 5666, \\\"tripleo::profile::base::metrics::collectd::amqp_user\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_password\\\": \\\"guest\\\"}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_collectd\\\": [{\\\"tag\\\": \\\"collectd\\\", \\\"file\\\": \\\"/var/log/containers/collectd/collectd.log\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"collectd\\\", \\\"puppet_tags\\\": \\\"collectd_client_config,exec\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::metrics::collectd\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/collectd.json\\\": {\\\"command\\\": \\\"/usr/sbin/collectd -f\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/collectd.d\\\", \\\"dest\\\": \\\"/etc/\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/collectd\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/scripts\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/config-scripts\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"collectd_check_health.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2022 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n\\\\nimport json\\\\nimport os\\\\nimport re\\\\nimport shutil\\\\nimport subprocess\\\\nimport sys\\\\n\\\\nfrom pkg_resources import packaging\\\\n\\\\n\\\\nSOCKET = \\\\\\\"unix:/run/podman/podman.sock\\\\\\\"\\\\nPS_FORMAT = (\'{\\\\\\\"service\\\\\\\": \\\\\\\"{{.Names}}\\\\\\\", \\\\\\\"container\\\\\\\": \\\\\\\"{{.ID}}\\\\\\\", \'\\\\n             \'\\\\\\\"status\\\\\\\": \\\\\\\"{{.State}}\\\\\\\", \\\\\\\"healthy\\\\\\\": \\\\\\\"{{.Status}}\\\\\\\"},\')\\\\nBASE_FORMAT = \\\\\\\"{service: .Name, container: .Id, status: .State.Running, \\\\\\\"\\\\nRUNNING_REX = re.compile(r\\\\\\\"Up .*(?P<health>\\\\\\\\(u?n?healthy\\\\\\\\))\\\\\\\")\\\\nSKIP_LIST = [\'.*_bootstrap\', \'container-puppet-.*\', \'.*_db_sync\',\\\\n             \'.*_cron\', \'create_.*_wrapper\', \'.*_wait_bundle\',\\\\n             \'configure_.*\', \'.*_fix_perms\', \'.*_init_logs?\',\\\\n             \'.*_init_perm\', \'(nova|placement)_wait_for_.*\', \'nova_.*ensure_\',\\\\n             \'(swift_)?setup_.*\', \'mysql_data_ownership\', \'swift_copy_rings\',\\\\n             \'nova_statedir_owner\']\\\\n\\\\n\\\\nclass ExecuteError(Exception):\\\\n    def __init__(self, rc, msg):\\\\n        self.rc = rc\\\\n        self.msg = msg\\\\n        super().__init__()\\\\n\\\\n\\\\ndef execute(cmd, workdir: str = None,\\\\n            prev_proc: subprocess.Popen = None) -> subprocess.Popen:\\\\n    # Note(mmagr): When this script is executed by collectd-sensubility started\\\\n    #              via collectd the script has non-root permission but inherits\\\\n    #              environment from collectd with root permission. We need\\\\n    #              to avoid sensubility access /root when using podman-remote.\\\\n    #              See https://bugzilla.redhat.com/show_bug.cgi?id=2091076 for\\\\n    #              more info.\\\\n    proc_env = os.environ.copy()\\\\n    proc_env[\\\\\\\"HOME\\\\\\\"] = \\\\\\\"/tmp\\\\\\\"\\\\n    if type(cmd[0]) is list:  # multiple piped commands\\\\n        last = prev_proc\\\\n        for c in cmd:\\\\n            last = execute(c, workdir, last)\\\\n        return last\\\\n    else:  # single command\\\\n        inpipe = prev_proc.stdout if prev_proc is not None else None\\\\n        proc = subprocess.Popen(cmd, cwd=workdir, env=proc_env, stdin=inpipe,\\\\n                                stdout=subprocess.PIPE, stderr=subprocess.PIPE)\\\\n        if prev_proc is not None:\\\\n            prev_proc.stdout.close()\\\\n            prev_proc.stderr.close()\\\\n        return proc\\\\n\\\\n\\\\ndef get_health_from_status(status):\\\\n    healthy = status in (\'healthy\', \'running\')\\\\n    return int(healthy)\\\\n\\\\n\\\\ndef fetch_state_from_inspect(cont, fmt):\\\\n    proc = execute([\\\\n        [shutil.which(\'podman-remote\'),\\\\n           \'--url\', SOCKET, \'inspect\', cont[\\\\\\\"container\\\\\\\"]],\\\\n        [shutil.which(\'jq\'), \'.[] | %s\' % fmt]\\\\n    ])\\\\n    o, e = proc.communicate()\\\\n    if proc.returncode != 0:\\\\n        msg = \\\\\\\"Failed to fetch status of %s: %s\\\\\\\" % (cont, e.decode())\\\\n        raise ExecuteError(proc.returncode, msg)\\\\n\\\\n    item = json.loads(o.decode())\\\\n    item[\'status\'] = \'running\' if item[\'status\'] else \'stopped\'\\\\n    if len(item[\'healthy\']) > 0 and item[\'status\'] != \'stopped\':\\\\n        item[\'status\'] = item[\'healthy\']\\\\n\\\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\\\n    return item\\\\n\\\\n\\\\ndef fetch_state(item):\\\\n    if \'up \' in item[\'status\'].lower():\\\\n        item[\'status\'] = \'running\'\\\\n    if item[\'status\'] != \'running\':\\\\n        item[\'status\'] = \'stopped\'\\\\n\\\\n    match = RUNNING_REX.match(item[\'healthy\'])\\\\n    if match:\\\\n        health = match.group(\'health\')\\\\n    else:\\\\n        health = \'\'\\\\n    if health:\\\\n        item[\'status\'] = health.strip(\\\\\\\"()\\\\\\\")\\\\n\\\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\\\n    return item\\\\n\\\\n\\\\ndef fetch_container_health(ps_result, inspect_fmt):\\\\n\\\\n    def container_filter(item):\\\\n        for rx in [re.compile(i) for i in SKIP_LIST]:\\\\n            if rx.match(item[\\\\\\\"service\\\\\\\"]):\\\\n                return False\\\\n        return True\\\\n    try:\\\\n        containers = filter(container_filter, json.loads(ps_result))\\\\n    except json.decoder.JSONDecodeError:\\\\n        return 1, \\\\\\\"%s\\\\\\\\nFailed to parse above output.\\\\\\\" % ps_result\\\\n\\\\n    out = []\\\\n    for cont in containers:\\\\n        try:\\\\n            out.append(fetch_state(cont))\\\\n        except Exception:\\\\n            # fallback to slow inspect way in case of any error\\\\n            try:\\\\n                out.append(fetch_state_from_inspect(cont, inspect_fmt))\\\\n            except ExecuteError as ex:\\\\n                return ex.rc, ex.msg\\\\n    return 0, out\\\\n\\\\n\\\\nif __name__ == \\\\\\\"__main__\\\\\\\":\\\\n    proc = execute([shutil.which(\'podman-remote\'),\\\\n                    \'--url\', SOCKET, \'version\',\\\\n                    \'--format\', r\'{{.Server.Version}}\'])\\\\n    o, e = proc.communicate()\\\\n    try:\\\\n        if packaging.version.parse(o.decode().strip()) >= packaging.version.parse(\\\\\\\"4.0.0\\\\\\\"):\\\\n            inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Health.Status}\\\\\\\"\\\\n        else:\\\\n            inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Healthcheck.Status}\\\\\\\"\\\\n    except Exception:\\\\n        # keep podman-4.0.0+ format in case of version decoding error\\\\n        inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Health.Status}\\\\\\\"\\\\n\\\\n    proc = execute([shutil.which(\'podman-remote\'), \'--url\', SOCKET,\\\\n                    \'ps\', \'--all\', \'--format\', PS_FORMAT])\\\\n    o, e = proc.communicate()\\\\n    if proc.returncode != 0:\\\\n        print(\\\\\\\"Failed to list containers:\\\\\\\\n%s\\\\\\\\n%s\\\\\\\" % (o.decode(), e.decode()))\\\\n        sys.exit(1)\\\\n\\\\n    rc, status = fetch_container_health(\\\\\\\"[%s]\\\\\\\" % o.decode().strip(\\\\\\\"\\\\\\\\n,\\\\\\\"), inspect_fmt)\\\\n    if rc != 0:\\\\n        print(\\\\\\\"Failed to inspect containers:\\\\\\\\n%s\\\\\\\" % status)\\\\n        sys.exit(rc)\\\\n    print(json.dumps(status))\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"collectd\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"memory\\\": \\\"512m\\\", \\\"cap_add\\\": [\\\"IPC_LOCK\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\\\", \\\"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/collectd:/var/log/collectd:rw,z\\\", \\\"/var/lib/container-config-scripts:/config-scripts:ro\\\", \\\"/var/lib/container-user-scripts:/scripts:z\\\", \\\"/run:/run:rw\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/collectd\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/container-user-scripts/\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0755\\\"}]}, {\\\"name\\\": \\\"import provision_mcelog\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_provision_mcelog\\\"}, \\\"when\\\": false}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"set enable_sensubility fact\\\", \\\"set_fact\\\": {\\\"enable_sensubility\\\": false}}, {\\\"name\\\": \\\"create podman socket for sensubility purposes\\\", \\\"block\\\": [{\\\"name\\\": \\\"create podman socket and appropriate systemd service\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_service\\\"}, \\\"vars\\\": {\\\"tripleo_podman_socket_path\\\": \\\"/var/lib/tripleo-podman/collectd/podman.sock\\\"}}, {\\\"name\\\": \\\"create systemd service for ensuring socket file ACL contains collectd\\\", \\\"become\\\": true, \\\"ansible.builtin.copy\\\": {\\\"content\\\": \\\"[Unit]\\\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\\\nRequires=tripleo_collectd.service\\\\nAfter=tripleo_podman.service\\\\nAfter=tripleo_collectd.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\", \\\"dest\\\": \\\"/etc/systemd/system/tripleo_podman_collectd_acl.service\\\", \\\"mode\\\": 420}}, {\\\"name\\\": \\\"enable podman.sock ACL service\\\", \\\"ansible.builtin.service\\\": {\\\"name\\\": \\\"tripleo_podman_collectd_acl.service\\\", \\\"enabled\\\": true}}, {\\\"name\\\": \\\"create directory for downloads of users\' scripts\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/container-user-scripts\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0755\\\"}}, {\\\"name\\\": \\\"download exec scripts\\\", \\\"ansible.builtin.get_url\\\": {\\\"url\\\": \\\"{{ item.source }}\\\", \\\"checksum\\\": \\\"{{ item.checksum }}\\\", \\\"dest\\\": \\\"/var/lib/container-user-scripts/{{ item.name }}\\\", \\\"mode\\\": \\\"0755\\\"}, \\\"with_items\\\": []}], \\\"when\\\": [\\\"enable_sensubility|bool\\\", \\\"step|int == 1\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"remove rsyslog configuration for podman healthcheck log\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_rsyslog_cleanup\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"remove rsyslog configuration for podman healthcheck log\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_rsyslog_cleanup\\\"}}, {\\\"name\\\": \\\"Force pull image collectd\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 3\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"UBI8 to UBI9 switch of collectd\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 5\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Update collectd to UBI9\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_3\\\", \\\"config_patterns\\\": \\\"collectd.json\\\", \\\"config_id\\\": [\\\"tripleo_step3\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\"collectd\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\"}}}}]}]}, {\\\"service_name\\\": \\\"ceilometer_agent_compute\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ceilometer-agent-compute\\\", \\\"config_settings\\\": {\\\"ceilometer::logging::debug\\\": true, \\\"ceilometer::agent::polling::manage_polling\\\": false, \\\"ceilometer::agent::service_credentials::password\\\": \\\"GX4yCM0w7B4kiWgXu5CvQui7Y\\\", \\\"ceilometer::agent::service_credentials::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"ceilometer::agent::service_credentials::region_name\\\": \\\"regionOne\\\", \\\"ceilometer::agent::service_credentials::project_name\\\": \\\"service\\\", \\\"ceilometer::agent::service_credentials::user_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::auth_project_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::interface\\\": \\\"internalURL\\\", \\\"ceilometer::notification_driver\\\": [\\\"noop\\\"], \\\"ceilometer::amqp_rpc_address_prefix\\\": \\\"\\\", \\\"ceilometer::amqp_notify_address_prefix\\\": \\\"\\\", \\\"ceilometer::telemetry_secret\\\": \\\"yqhKYusTcTIo9QJ6Mn8tKY3cT\\\", \\\"ceilometer::snmpd_readonly_username\\\": \\\"ro_snmp_user\\\", \\\"ceilometer::snmpd_readonly_user_password\\\": \\\"FKQdo7NuIE9RbMdjCuC9b8sG\\\", \\\"ceilometer::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ceilometer::rabbit_heartbeat_in_pthread\\\": false, \\\"ceilometer::cache::enabled\\\": true, \\\"ceilometer::cache::tls_enabled\\\": true, \\\"ceilometer::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"ceilometer::cache::enable_socket_keepalive\\\": true, \\\"ceilometer::agent::polling::instance_discovery_method\\\": \\\"libvirt_metadata\\\", \\\"ceilometer_redis_password\\\": \\\"0plrFXAbintMcjJGm66MGfoQJ\\\", \\\"compute_namespace\\\": true, \\\"ceilometer::agent::polling::tenant_name_discovery\\\": false}, \\\"service_config_settings\\\": {\\\"keystone\\\": {\\\"tripleo::profile::base::keystone::ceilometer_notification_topics\\\": [\\\"notifications\\\"]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"ceilometer_agent_compute\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_libvirt.target\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}]}, {\\\"service_name\\\": \\\"ceilometer_agent_ipmi\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ceilometer-agent-ipmi\\\", \\\"config_settings\\\": {\\\"ceilometer::logging::debug\\\": true, \\\"ceilometer::agent::polling::manage_polling\\\": false, \\\"ceilometer::agent::service_credentials::password\\\": \\\"GX4yCM0w7B4kiWgXu5CvQui7Y\\\", \\\"ceilometer::agent::service_credentials::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"ceilometer::agent::service_credentials::region_name\\\": \\\"regionOne\\\", \\\"ceilometer::agent::service_credentials::project_name\\\": \\\"service\\\", \\\"ceilometer::agent::service_credentials::user_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::auth_project_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::interface\\\": \\\"internalURL\\\", \\\"ceilometer::notification_driver\\\": [\\\"noop\\\"], \\\"ceilometer::amqp_rpc_address_prefix\\\": \\\"\\\", \\\"ceilometer::amqp_notify_address_prefix\\\": \\\"\\\", \\\"ceilometer::telemetry_secret\\\": \\\"yqhKYusTcTIo9QJ6Mn8tKY3cT\\\", \\\"ceilometer::snmpd_readonly_username\\\": \\\"ro_snmp_user\\\", \\\"ceilometer::snmpd_readonly_user_password\\\": \\\"FKQdo7NuIE9RbMdjCuC9b8sG\\\", \\\"ceilometer::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ceilometer::rabbit_heartbeat_in_pthread\\\": false, \\\"ceilometer::cache::enabled\\\": true, \\\"ceilometer::cache::tls_enabled\\\": true, \\\"ceilometer::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"ceilometer::cache::enable_socket_keepalive\\\": true, \\\"ceilometer_redis_password\\\": \\\"0plrFXAbintMcjJGm66MGfoQJ\\\", \\\"ipmi_namespace\\\": true}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_ceilometer_agent_ipmi\\\": [{\\\"tag\\\": \\\"openstack.ceilometer.agent.ipmi\\\", \\\"file\\\": \\\"/var/log/containers/ceilometer/ipmi.log\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"ceilometer_init_log\\\": {\\\"start_order\\\": 0, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R ceilometer:ceilometer /var/log/ceilometer\\\"], \\\"volumes\\\": [\\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]}}, \\\"step_4\\\": {\\\"ceilometer_agent_ipmi\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}, {\\\"service_name\\\": \\\"ipaservice\\\", \\\"upgrade_tasks\\\": [], \\\"step_config\\\": \\\"\\\", \\\"ipa_registration_tasks\\\": [{\\\"name\\\": \\\"Get undercloud FQDN\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"set_fact\\\": {\\\"undercloud_fqdn\\\": \\\"{{ ansible_facts[\'fqdn\'] }}\\\"}}, {\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_ipa_registration\\\", \\\"apply\\\": {\\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"environment\\\": {\\\"IPA_USER\\\": \\\"nova/{{ undercloud_fqdn }}\\\", \\\"KRB5_CLIENT_KTNAME\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"KRB5CCNAME\\\": \\\"/etc/novajoin/krb5.cache\\\", \\\"IPA_HOST\\\": \\\"ipa.ooo.test\\\"}}}, \\\"vars\\\": {\\\"tripleo_ipa_enroll_base_server\\\": true, \\\"tripleo_ipa_delegate_server\\\": \\\"{{ inventory_hostname }}\\\", \\\"tripleo_ipa_base_server_fqdn\\\": \\\"{{ fqdn_canonical }}\\\", \\\"tripleo_ipa_server_metadata\\\": \\\"{{ service_metadata_settings | to_json }}\\\"}, \\\"when\\\": \\\"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\\\"}, {\\\"name\\\": \\\"Enroll the node as an ipa client\\\", \\\"vars\\\": {\\\"ipaclient_install_packages\\\": false, \\\"idm_enroll_base_server\\\": true}, \\\"block\\\": [{\\\"name\\\": \\\"check if default.conf exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/ipa/default.conf\\\"}, \\\"register\\\": \\\"ipa_conf_exists\\\"}, {\\\"name\\\": \\\"install openssl-perl\\\", \\\"become\\\": true, \\\"package\\\": {\\\"name\\\": \\\"openssl-perl\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ipaclient_install_packages|bool\\\"]}, {\\\"name\\\": \\\"register as an ipa client\\\", \\\"include_role\\\": {\\\"name\\\": \\\"ipaclient\\\", \\\"apply\\\": {\\\"become\\\": true}}, \\\"vars\\\": {\\\"state\\\": \\\"present\\\", \\\"ipaclient_otp\\\": \\\"{{ ipa_host_otp }}\\\", \\\"ipaclient_mkhomedir\\\": false, \\\"ipaclient_no_ntp\\\": false, \\\"ipaclient_force\\\": true, \\\"ipaclient_hostname\\\": \\\"{{ fqdn_canonical }}\\\", \\\"ansible_fqdn\\\": \\\"{{ ipaclient_hostname }}\\\", \\\"ipaclients\\\": [\\\"ipaclient_hostname\\\"], \\\"ansible_distribution\\\": \\\"{{ ansible_facts[\'distribution\'] }}\\\", \\\"ansible_distribution_major_version\\\": \\\"{{ ansible_facts[\'distribution_major_version\'] }}\\\", \\\"ansible_distribution_release\\\": \\\"{{ ansible_facts[\'distribution_release\'] }}\\\", \\\"ansible_distribution_version\\\": \\\"{{ ansible_facts[\'distribution_version\'] }}\\\", \\\"ansible_os_family\\\": \\\"{{ ansible_facts[\'os_family\'] }}\\\", \\\"ipaclient_servers\\\": [\\\"ipa.ooo.test\\\"], \\\"ipaclient_domain\\\": \\\"ooo.test\\\"}, \\\"when\\\": [\\\"idm_enroll_base_server|bool\\\", \\\"not ipa_conf_exists.stat.exists\\\"]}, {\\\"name\\\": \\\"restart certmonger service\\\", \\\"become\\\": true, \\\"systemd\\\": {\\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true, \\\"name\\\": \\\"certmonger.service\\\"}, \\\"when\\\": [\\\"idm_enroll_base_server|bool\\\", \\\"not ipa_conf_exists.stat.exists\\\"]}, {\\\"name\\\": \\\"set discovered ipa realm\\\", \\\"set_fact\\\": {\\\"idm_realm\\\": \\\"{{ lookup(\'ini\', \'realm default=OOO.TEST section=global file=/etc/ipa/default.conf\')}}\\\"}}], \\\"when\\\": \\\"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\\\"}], \\\"external_deploy_tasks\\\": [{\\\"name\\\": \\\"add the DNS entries into IPA in step 1\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_ipa_dns\\\"}, \\\"vars\\\": {\\\"tripleo_ipa_ptr_zone_split_ipv4\\\": \\\"1\\\", \\\"tripleo_ipa_ptr_zone_split_ipv6\\\": \\\"1\\\"}, \\\"when\\\": true}], \\\"environment\\\": {\\\"IPA_USER\\\": \\\"nova/{{ ansible_facts[\'fqdn\'] }}\\\", \\\"KRB5_CLIENT_KTNAME\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"KRB5CCNAME\\\": \\\"/etc/novajoin/krb5.cache\\\", \\\"IPA_HOST\\\": \\\"ipa.ooo.test\\\"}}], \\\"scale_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"down\\\", \\\"block\\\": [{\\\"name\\\": \\\"unregister node from ipa server\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ipa_cleanup\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"vars\\\": {\\\"tripleo_ipa_keytab\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"tripleo_ipa_hosts_to_delete\\\": [\\\"{{ fqdn_canonical }}\\\"]}}]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"check if ipa server has required permissions\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tls_everywhere\\\", \\\"tasks_from\\\": \\\"ipa-server-check\\\"}, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-tls-everywhere\\\"]}]}]}, {\\\"service_name\\\": \\\"iscsid\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::iscsid::chap_algs\\\": \\\"SHA3-256,SHA256,SHA1,MD5\\\"}, \\\"service_config_settings\\\": {}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Run lvmfilter role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_lvmfilter\\\"}, \\\"when\\\": [\\\"step|int == 1\\\"]}], \\\"ansible_group_vars\\\": {\\\"tripleo_tripleo_lvmfilter_enabled\\\": false, \\\"tripleo_tripleo_lvmfilter_devices_allowlist\\\": [], \\\"tripleo_tripleo_lvmfilter_devices_denylist\\\": [\\\".*\\\"], \\\"ContainerIscsidImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"ContainerIscsidConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"iscsid\\\", \\\"puppet_tags\\\": \\\"iscsid_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::iscsid\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"volumes\\\": [\\\"/etc/iscsi:/tmp/iscsi.host:z\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/iscsid.json\\\": {\\\"command\\\": \\\"/usr/sbin/iscsid -f\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"iscsid\\\": {\\\"start_order\\\": 2, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys:/sys\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/etc/target:/etc/target:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create fcontext entry for iscsi\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"{{ item.path }}(/.*)?\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/target\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/target\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"stat /lib/systemd/system/iscsid.socket\\\", \\\"stat\\\": \\\"path=/lib/systemd/system/iscsid.socket\\\", \\\"register\\\": \\\"stat_iscsid_socket\\\"}, {\\\"name\\\": \\\"Stop and disable iscsid.socket service\\\", \\\"service\\\": \\\"name=iscsid.socket state=stopped enabled=no\\\", \\\"when\\\": \\\"stat_iscsid_socket.stat.exists\\\"}, {\\\"name\\\": \\\"Check if iscsi.service is enabled\\\", \\\"command\\\": \\\"systemctl is-enabled --quiet iscsi.service\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"iscsi_service_enabled_result\\\"}, {\\\"name\\\": \\\"Stop iscsi.service\\\", \\\"service\\\": \\\"name=iscsi.service state=stopped enabled=no\\\", \\\"when\\\": [\\\"iscsi_service_enabled_result is changed\\\", \\\"iscsi_service_enabled_result.rc == 0\\\"]}], \\\"upgrade_tasks\\\": []}, {\\\"service_name\\\": \\\"kernel\\\", \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\"}}], \\\"ansible_group_vars\\\": {\\\"hieradata_localhost_address\\\": \\\"localhost\\\", \\\"tripleo_kernel_extra_modules\\\": {}, \\\"tripleo_kernel_extra_packages\\\": {}, \\\"tripleo_kernel_sysctl_extra_settings\\\": {\\\"net.ipv6.conf.default.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_local_reserved_ports\\\": {\\\"value\\\": \\\"35357,49000-49001\\\"}, \\\"net.ipv6.conf.all.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv6.conf.lo.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_forward\\\": {\\\"value\\\": 1}, \\\"net.ipv4.conf.all.rp_filter\\\": {\\\"value\\\": 1}, \\\"net.ipv6.conf.all.forwarding\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_nonlocal_bind\\\": {\\\"value\\\": 1}, \\\"net.ipv6.ip_nonlocal_bind\\\": {\\\"value\\\": 1}, \\\"kernel.pid_max\\\": {\\\"value\\\": 1048576}, \\\"net.ipv4.neigh.default.gc_thresh1\\\": {\\\"value\\\": 1024}, \\\"net.ipv4.neigh.default.gc_thresh2\\\": {\\\"value\\\": 2048}, \\\"net.ipv4.neigh.default.gc_thresh3\\\": {\\\"value\\\": 4096}, \\\"net.bridge.bridge-nf-call-arptables\\\": {\\\"value\\\": 1}, \\\"net.bridge.bridge-nf-call-iptables\\\": {\\\"value\\\": 1}, \\\"net.bridge.bridge-nf-call-ip6tables\\\": {\\\"value\\\": 1}, \\\"fs.inotify.max_user_instances\\\": {\\\"value\\\": 1024}, \\\"fs.aio-max-nr\\\": {\\\"value\\\": 1048576}}}}, {\\\"service_name\\\": \\\"metrics_qdr\\\", \\\"firewall_rules\\\": {\\\"109 metrics qdr\\\": {\\\"dport\\\": [5666]}, \\\"109 accept internal metrics qdr ctlplane subnet 192.168.122.0/24\\\": {\\\"dport\\\": [5667, 5668]}}, \\\"monitoring_subscription\\\": \\\"overcloud-qdr\\\", \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_metrics_qdr\\\": [{\\\"tag\\\": \\\"openstack.nova.consoleauth\\\", \\\"file\\\": \\\"/var/log/containers/metrics_qdr/metrics_qdr.log\\\", \\\"startmsg.regex\\\": \\\"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\\\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\\\\\\\\\([a-z]+\\\\\\\\\\\\\\\\) \\\"}]}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::metrics::qdr::listener_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::haproxy::metrics_qdr\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_port\\\": 5666, \\\"tripleo::profile::base::metrics::qdr::username\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::qdr::password\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::qdr::connectors\\\": [], \\\"tripleo::profile::base::metrics::qdr::addresses\\\": [{\\\"prefix\\\": \\\"collectd\\\", \\\"distribution\\\": \\\"multicast\\\"}, {\\\"prefix\\\": \\\"ceilometer/metering.sample\\\", \\\"distribution\\\": \\\"multicast\\\"}, {\\\"prefix\\\": \\\"ceilometer/event.sample\\\", \\\"distribution\\\": \\\"multicast\\\"}], \\\"tripleo::profile::base::metrics::qdr::autolink_addresses\\\": [], \\\"tripleo::profile::base::metrics::qdr::listener_require_ssl\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_require_encrypt\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_sasl_mech\\\": \\\"ANONYMOUS\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\\\": \\\"\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_password\\\": \\\"\\\", \\\"tripleo::profile::base::metrics::qdr::listener_trusted_certs\\\": \\\"\\\", \\\"qdr::log_enable\\\": \\\"info+\\\", \\\"qdr::log_output\\\": \\\"/var/log/qdrouterd/metrics_qdr.log\\\", \\\"qdr::listener_auth_peer\\\": false, \\\"tripleo::profile::base::metrics::qdr::ssl_profiles\\\": [{\\\"name\\\": \\\"sslProfile\\\"}, {\\\"name\\\": \\\"tlsProfile\\\", \\\"certFile\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"keyFile\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"caCertFile\\\": \\\"/etc/ipa/ca.crt\\\"}]}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"metrics_qdr\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"metrics_qdr\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::metrics::qdr\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/metrics_qdr.json\\\": {\\\"command\\\": \\\"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/qdrouterd\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"optional\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"metrics_qdr_init_logs\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\\\"]}, \\\"metrics_qdr\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"qdrouterd\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\\\", \\\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\\\", \\\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\\\", \\\"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"metrics_qdr\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"metrics_qdr/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep metrics_qdr)\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/metrics_qdr.key\\\\n# Copy the new cert from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n# Copy the new key from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown qdrouterd:qdrouterd \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown qdrouterd:qdrouterd \\\\\\\"$service_key\\\\\\\"\\\\n# Trigger a container restart to read the new certificate\\\\n{{container_cli}} restart \\\\\\\"$container_name\\\\\\\"\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent logs directory\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/metrics_qdr\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/metrics_qdr\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}]}, {\\\"service_name\\\": \\\"mysql_client\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::database::mysql::client::enable_ssl\\\": true, \\\"tripleo::profile::base::database::mysql::client::ssl_ca\\\": \\\"/etc/ipa/ca.crt\\\"}, \\\"step_config\\\": \\\"include tripleo::profile::base::database::mysql::client\\\"}, {\\\"service_name\\\": \\\"nova_compute\\\", \\\"monitoring_subscription\\\": \\\"overcloud-nova-compute\\\", \\\"config_settings\\\": {\\\"nova::my_ip\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::rabbit_use_ssl\\\": \\\"True\\\", \\\"nova::keystone::service_user::send_service_user_token\\\": true, \\\"nova::keystone::service_user::project_name\\\": \\\"service\\\", \\\"nova::keystone::service_user::password\\\": \\\"QEj61Nsh9s8dBHEcrZuvWC9pV\\\", \\\"nova::keystone::service_user::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::keystone::service_user::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::project_name\\\": \\\"service\\\", \\\"nova::placement::password\\\": \\\"hEpTmySNpG4wGJSvCTrv5Aa7a\\\", \\\"nova::placement::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::placement::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::valid_interfaces\\\": \\\"internal\\\", \\\"nova::os_region_name\\\": \\\"regionOne\\\", \\\"nova::logging::debug\\\": true, \\\"nova::purge_config\\\": false, \\\"nova::network::neutron::project_name\\\": \\\"service\\\", \\\"nova::network::neutron::username\\\": \\\"neutron\\\", \\\"nova::network::neutron::region_name\\\": \\\"regionOne\\\", \\\"nova::dhcp_domain\\\": \\\"\\\", \\\"nova::network::neutron::password\\\": \\\"ynYFMrrhBYym7oMTANCe2Hdxj\\\", \\\"nova::network::neutron::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::network::neutron::valid_interfaces\\\": \\\"internal\\\", \\\"nova::glance::valid_interfaces\\\": \\\"internal\\\", \\\"nova::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"nova::cinder_catalog_info\\\": \\\"volumev3:cinderv3:internalURL\\\", \\\"nova::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"nova::notify_on_state_change\\\": \\\"vm_and_task_state\\\", \\\"nova::notification_driver\\\": [\\\"noop\\\"], \\\"nova::notification_format\\\": \\\"unversioned\\\", \\\"nova::network::neutron::auth_type\\\": \\\"v3password\\\", \\\"nova::db::database_db_max_retries\\\": -1, \\\"nova::db::database_max_retries\\\": -1, \\\"nova::network::neutron::ovs_bridge\\\": \\\"br-int\\\", \\\"nova::compute::sync_power_state_interval\\\": 600, \\\"nova_is_additional_cell\\\": false, \\\"nova::cross_az_attach\\\": true, \\\"nova::cache::enabled\\\": true, \\\"nova::cache::tls_enabled\\\": true, \\\"nova::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"nova::rabbit_heartbeat_in_pthread\\\": false, \\\"nova::ovsdb_connection\\\": \\\"\\\", \\\"nova::compute::vcpu_pin_set\\\": [], \\\"nova::compute::cpu_shared_set\\\": [], \\\"nova::compute::cpu_dedicated_set\\\": [], \\\"nova::compute::reserved_host_memory\\\": 512, \\\"nova::compute::reserved_huge_pages\\\": [], \\\"nova::compute::neutron_physnets_numa_nodes_mapping\\\": {}, \\\"nova::compute::neutron_tunnel_numa_nodes\\\": [], \\\"nova::compute::resume_guests_state_on_host_boot\\\": false, \\\"nova::compute::libvirt::rx_queue_size\\\": 512, \\\"nova::compute::libvirt::tx_queue_size\\\": 512, \\\"nova::compute::libvirt::file_backed_memory\\\": 0, \\\"nova::compute::libvirt::volume_use_multipath\\\": false, \\\"nova::compute::libvirt::hw_machine_type\\\": \\\"x86_64=pc-q35-rhel9.0.0\\\", \\\"nova::compute::mkisofs_cmd\\\": \\\"mkisofs\\\", \\\"compute_enable_ksm\\\": false, \\\"nova::compute::rbd::libvirt_images_rbd_pool\\\": \\\"vms\\\", \\\"tripleo::profile::base::nova::compute::nova_nfs_enabled\\\": false, \\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\", \\\"nova::compute::libvirt::num_pcie_ports\\\": 16, \\\"nova::compute::libvirt::mem_stats_period_seconds\\\": 10, \\\"nova::compute::rbd::ephemeral_storage\\\": false, \\\"resume_guests_state_on_host_boot\\\": false, \\\"nova::cpu_allocation_ratio\\\": 0.0, \\\"nova::ram_allocation_ratio\\\": 1.0, \\\"nova::disk_allocation_ratio\\\": 0.0, \\\"nova::compute::max_disk_devices_to_attach\\\": -1, \\\"nova::compute::libvirt::pmem_namespaces\\\": \\\"\\\", \\\"nova_pmem_namespaces\\\": \\\"\\\", \\\"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\\\": 86400, \\\"nova::compute::libvirt::swtpm_enabled\\\": false, \\\"nova::compute::vgpu::vgpu_types_device_addresses_mapping\\\": {}, \\\"compute_disable_irqbalance\\\": false, \\\"nova::compute::libvirt::cpu_mode\\\": \\\"host-model\\\", \\\"nova::compute::libvirt::cpu_models\\\": [], \\\"nova::compute::libvirt::cpu_model_extra_flags\\\": \\\"\\\", \\\"nova_compute_opt_volumes\\\": [], \\\"nova_compute_startup_delay\\\": 0, \\\"nova_compute_opt_env_vars\\\": {}, \\\"nova::workarounds::never_download_image_if_on_rbd\\\": false, \\\"nova::compute::image_type_exclude_list\\\": [], \\\"nova_permit_post_copy\\\": true, \\\"nova_permit_auto_converge\\\": true, \\\"nova_libvirt_max_queues\\\": 0, \\\"nova_glance_enable_rbd_download\\\": false, \\\"nova_glance_rbd_download_multistore_id\\\": \\\"\\\", \\\"nova::compute::force_raw_images\\\": true, \\\"nova::compute::use_cow_images\\\": true, \\\"nova::compute::libvirt::preallocate_images\\\": \\\"none\\\", \\\"nova::compute::image_cache::manager_interval\\\": 2400, \\\"nova::compute::image_cache::remove_unused_base_images\\\": true, \\\"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\\\": 3600, \\\"nova::compute::image_cache::precache_concurrency\\\": 1, \\\"nova::compute::provider::custom_inventories\\\": {}, \\\"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\\\": 15, \\\"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\\\": 600, \\\"ContainerNovaComputeImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"nova::compute::pci::passthrough\\\": \\\"\\\", \\\"nova::compute::libvirt::migration_support\\\": false, \\\"tripleo::profile::base::nova::migration::client::nova_compute_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": \\\"-----BEGIN RSA PRIVATE KEY-----\\\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\\\n-----END RSA PRIVATE KEY-----\\\\n\\\", \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": 2022, \\\"nova::compute::rbd::libvirt_images_rbd_glance_store_name\\\": \\\"default_backend\\\", \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": \\\"/etc/ceph/ceph.conf\\\", \\\"nova::compute::rbd::libvirt_rbd_user\\\": \\\"openstack\\\", \\\"nova::compute::rbd::rbd_keyring\\\": \\\"client.openstack\\\", \\\"tripleo::profile::base::nova::compute::cinder_nfs_backend\\\": false, \\\"rbd_persistent_storage\\\": false, \\\"rbd_disk_cachemodes\\\": [\\\"network=writeback\\\"], \\\"nova::cinder::username\\\": \\\"cinder\\\", \\\"nova::cinder::auth_type\\\": \\\"v3password\\\", \\\"nova::cinder::project_name\\\": \\\"service\\\", \\\"nova::cinder::password\\\": \\\"FTS40yQUd1tjPXxKb5UK1sScA\\\", \\\"nova::cinder::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::cinder::region_name\\\": \\\"regionOne\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": \\\"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": \\\"b5752d85-3538-4992-bfb2-0baef5c2e05b\\\", \\\"nova::compute::instance_usage_audit\\\": true, \\\"nova::compute::instance_usage_audit_period\\\": \\\"hour\\\", \\\"nova::compute::consecutive_build_service_disable_threshold\\\": \\\"10\\\", \\\"nova::compute::live_migration_wait_for_vif_plug\\\": true, \\\"nova::migration::libvirt::live_migration_permit_post_copy\\\": true, \\\"nova::migration::libvirt::live_migration_permit_auto_converge\\\": true, \\\"nova::migration::libvirt::live_migration_tunnelled\\\": false, \\\"nova::compute::vncserver_proxyclient_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::compute::vncproxy_host\\\": \\\"overcloud.ooo.test\\\", \\\"nova::vncproxy::common::vncproxy_protocol\\\": \\\"https\\\", \\\"nova::vncproxy::common::vncproxy_host\\\": \\\"overcloud.ooo.test\\\", \\\"nova::vncproxy::common::vncproxy_port\\\": \\\"13080\\\", \\\"nova::compute::verify_glance_signatures\\\": false, \\\"nova::workarounds::disable_compute_service_check_for_ffu\\\": false}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_nova_compute\\\": [{\\\"tag\\\": \\\"openstack.nova.compute\\\", \\\"file\\\": \\\"/var/log/containers/nova/nova-compute.log\\\"}]}, \\\"collectd\\\": {\\\"tripleo.collectd.plugins.nova_compute\\\": [\\\"virt\\\"], \\\"collectd::plugin::virt::connection\\\": \\\"qemu:///system\\\"}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"nova_config\\\", \\\"step_config\\\": \\\"# TODO(emilien): figure how to deal with libvirt profile.\\\\n# We\'ll probably treat it like we do with Neutron plugins.\\\\n# Until then, just include it in the default nova-compute role.\\\\ninclude tripleo::profile::base::nova::compute::libvirt\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_compute.json\\\": {\\\"command\\\": \\\"/usr/bin/nova-compute \\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/*\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\\\": {\\\"command\\\": \\\"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"nova_statedir_ownership.py\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\nimport logging\\\\nimport os\\\\nimport pwd\\\\nimport selinux\\\\nimport stat\\\\nimport sys\\\\n\\\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\\\n\\\\nif debug.lower() == \'true\':\\\\n    loglevel = logging.DEBUG\\\\nelse:\\\\n    loglevel = logging.INFO\\\\n\\\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\\\nLOG = logging.getLogger(\'nova_statedir\')\\\\n\\\\n\\\\nclass PathManager(object):\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"Helper class to manipulate ownership of a given path\\\\\\\"\\\\\\\"\\\\\\\"\\\\n    def __init__(self, path):\\\\n        self.path = path\\\\n        self.uid = None\\\\n        self.gid = None\\\\n        self.is_dir = None\\\\n        self.secontext = None\\\\n        self._update()\\\\n\\\\n    def _update(self):\\\\n        try:\\\\n            statinfo = os.stat(self.path)\\\\n            self.is_dir = stat.S_ISDIR(statinfo.st_mode)\\\\n            self.uid = statinfo.st_uid\\\\n            self.gid = statinfo.st_gid\\\\n            self.secontext = selinux.lgetfilecon(self.path)[1]\\\\n        except Exception:\\\\n            LOG.exception(\'Could not update metadata for %s\', self.path)\\\\n            raise\\\\n\\\\n    def __str__(self):\\\\n        return \\\\\\\"uid: {} gid: {} path: {}{}\\\\\\\".format(\\\\n            self.uid,\\\\n            self.gid,\\\\n            self.path,\\\\n            \'/\' if self.is_dir else \'\'\\\\n        )\\\\n\\\\n    def has_owner(self, uid, gid):\\\\n        return self.uid == uid and self.gid == gid\\\\n\\\\n    def has_either(self, uid, gid):\\\\n        return self.uid == uid or self.gid == gid\\\\n\\\\n    def chown(self, uid, gid):\\\\n        target_uid = -1\\\\n        target_gid = -1\\\\n        if self.uid != uid:\\\\n            target_uid = uid\\\\n        if self.gid != gid:\\\\n            target_gid = gid\\\\n        if (target_uid, target_gid) != (-1, -1):\\\\n            LOG.info(\'Changing ownership of %s from %d:%d to %d:%d\',\\\\n                     self.path,\\\\n                     self.uid,\\\\n                     self.gid,\\\\n                     self.uid if target_uid == -1 else target_uid,\\\\n                     self.gid if target_gid == -1 else target_gid)\\\\n            try:\\\\n                os.chown(self.path, target_uid, target_gid)\\\\n                self._update()\\\\n            except Exception:\\\\n                LOG.exception(\'Could not change ownership of %s: \',\\\\n                              self.path)\\\\n                raise\\\\n        else:\\\\n            LOG.info(\'Ownership of %s already %d:%d\',\\\\n                     self.path,\\\\n                     uid,\\\\n                     gid)\\\\n\\\\n    def chcon(self, context):\\\\n        # If dir returns whether to recusively set context\\\\n        try:\\\\n            try:\\\\n                selinux.lsetfilecon(self.path, context)\\\\n                LOG.info(\'Setting selinux context of %s to %s\',\\\\n                     self.path, context)\\\\n                return True\\\\n            except OSError as e:\\\\n                if self.is_dir and e.errno == 95:\\\\n                    # Operation not supported, assume NFS mount and skip\\\\n                    LOG.info(\'Setting selinux context not supported for %s\',\\\\n                             self.path)\\\\n                    return False\\\\n                else:\\\\n                    raise\\\\n        except Exception:\\\\n            LOG.exception(\'Could not set selinux context of %s to %s:\',\\\\n                          self.path, context)\\\\n            raise\\\\n\\\\n\\\\nclass NovaStatedirOwnershipManager(object):\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"Class to manipulate the ownership of the nova statedir (/var/lib/nova).\\\\n\\\\n       The nova uid/gid differ on the host and container images. An upgrade\\\\n       that switches from host systemd services to docker requires a change in\\\\n       ownership. Previously this was a naive recursive chown, however this\\\\n       causes issues if nova instance are shared via an NFS mount: any open\\\\n       filehandles in qemu/libvirt fail with an I/O error (LP1778465).\\\\n\\\\n       Instead the upgrade/FFU ansible tasks now lay down a marker file when\\\\n       stopping and disabling the host systemd services. We use this file to\\\\n       determine the host nova uid/gid. We then walk the tree and update any\\\\n       files that have the host uid/gid to the docker nova uid/gid. As files\\\\n       owned by root/qemu etc... are ignored this avoids the issues with open\\\\n       filehandles. The marker is removed once the tree has been walked.\\\\n\\\\n       For subsequent runs, or for a new deployment, we simply ensure that the\\\\n       docker nova user/group owns all directories. This is required as the\\\\n       directories are created with root ownership in host_prep_tasks (the\\\\n       docker nova uid/gid is not known in this context).\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"\\\\n    def __init__(self, statedir, upgrade_marker=\'upgrade_marker\',\\\\n                 nova_user=\'nova\', secontext_marker=\'../_nova_secontext\',\\\\n                 exclude_paths=None):\\\\n        self.statedir = statedir\\\\n        self.nova_user = nova_user\\\\n\\\\n        self.upgrade_marker_path = os.path.join(statedir, upgrade_marker)\\\\n        self.secontext_marker_path = os.path.normpath(os.path.join(statedir, secontext_marker))\\\\n        self.upgrade = os.path.exists(self.upgrade_marker_path)\\\\n\\\\n        self.exclude_paths = [self.upgrade_marker_path]\\\\n        if exclude_paths is not None:\\\\n            for p in exclude_paths:\\\\n                if not p.startswith(os.path.sep):\\\\n                    p = os.path.join(self.statedir, p)\\\\n                self.exclude_paths.append(p)\\\\n\\\\n        self.target_uid, self.target_gid = self._get_nova_ids()\\\\n        self.previous_uid, self.previous_gid = self._get_previous_nova_ids()\\\\n        self.id_change = (self.target_uid, self.target_gid) != \\\\\\\\\\\\n            (self.previous_uid, self.previous_gid)\\\\n        self.target_secontext = self._get_secontext()\\\\n\\\\n    def _get_nova_ids(self):\\\\n        nova_uid, nova_gid = pwd.getpwnam(self.nova_user)[2:4]\\\\n        return nova_uid, nova_gid\\\\n\\\\n    def _get_previous_nova_ids(self):\\\\n        if self.upgrade:\\\\n            statinfo = os.stat(self.upgrade_marker_path)\\\\n            return statinfo.st_uid, statinfo.st_gid\\\\n        else:\\\\n            return self._get_nova_ids()\\\\n\\\\n    def _get_secontext(self):\\\\n        if os.path.exists(self.secontext_marker_path):\\\\n            return selinux.lgetfilecon(self.secontext_marker_path)[1]\\\\n        else:\\\\n            return None\\\\n\\\\n    def _walk(self, top, chcon=True):\\\\n        for f in os.listdir(top):\\\\n            pathname = os.path.join(top, f)\\\\n\\\\n            if pathname in self.exclude_paths:\\\\n                continue\\\\n\\\\n            try:\\\\n                pathinfo = PathManager(pathname)\\\\n                LOG.info(\\\\\\\"Checking %s\\\\\\\", pathinfo)\\\\n                if pathinfo.is_dir:\\\\n                    # Always chown the directories\\\\n                    pathinfo.chown(self.target_uid, self.target_gid)\\\\n                    chcon_r = chcon\\\\n                    if chcon:\\\\n                        chcon_r = pathinfo.chcon(self.target_secontext)\\\\n                    self._walk(pathname, chcon_r)\\\\n                elif self.id_change:\\\\n                    # Only chown files if it\'s an upgrade and the file is owned by\\\\n                    # the host nova uid/gid\\\\n                    pathinfo.chown(\\\\n                        self.target_uid if pathinfo.uid == self.previous_uid\\\\n                        else pathinfo.uid,\\\\n                        self.target_gid if pathinfo.gid == self.previous_gid\\\\n                        else pathinfo.gid\\\\n                    )\\\\n                    if chcon:\\\\n                        pathinfo.chcon(self.target_secontext)\\\\n            except Exception:\\\\n                # Likely to have been caused by external systems\\\\n                # interacting with this directory tree,\\\\n                # especially on NFS e.g snapshot dirs.\\\\n                # Just ignore it and continue on to the next entry\\\\n                continue\\\\n\\\\n    def run(self):\\\\n        LOG.info(\'Applying nova statedir ownership\')\\\\n        LOG.info(\'Target ownership for %s: %d:%d\',\\\\n                 self.statedir,\\\\n                 self.target_uid,\\\\n                 self.target_gid)\\\\n\\\\n        pathinfo = PathManager(self.statedir)\\\\n        LOG.info(\\\\\\\"Checking %s\\\\\\\", pathinfo)\\\\n        pathinfo.chown(self.target_uid, self.target_gid)\\\\n        chcon = self.target_secontext is not None\\\\n\\\\n        if chcon:\\\\n            pathinfo.chcon(self.target_secontext)\\\\n\\\\n        self._walk(self.statedir, chcon)\\\\n\\\\n        if self.upgrade:\\\\n            LOG.info(\'Removing upgrade_marker %s\',\\\\n                     self.upgrade_marker_path)\\\\n            os.unlink(self.upgrade_marker_path)\\\\n\\\\n        LOG.info(\'Nova statedir ownership complete\')\\\\n\\\\n\\\\ndef get_exclude_paths():\\\\n    exclude_paths = os.environ.get(\'NOVA_STATEDIR_OWNERSHIP_SKIP\')\\\\n    if exclude_paths is not None:\\\\n        exclude_paths = exclude_paths.split(os.pathsep)\\\\n    return exclude_paths\\\\n\\\\n\\\\nif __name__ == \'__main__\':\\\\n    NovaStatedirOwnershipManager(\'/var/lib/nova\', exclude_paths=get_exclude_paths()).run()\\\\n\\\"}, \\\"nova_wait_for_compute_service.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\nimport argparse\\\\nimport logging\\\\nimport os\\\\nimport six\\\\nimport socket\\\\nimport sys\\\\nimport time\\\\n\\\\n\\\\nfrom keystoneauth1 import loading\\\\nfrom keystoneauth1 import session\\\\n\\\\nfrom novaclient import client\\\\n\\\\n# In python3 SafeConfigParser was renamed to ConfigParser and the default\\\\n# for duplicate options default to true. In case of nova it is valid to\\\\n# have duplicate option lines, e.g. passthrough_whitelist which leads to\\\\n# issues reading the nova.conf\\\\n# https://bugs.launchpad.net/tripleo/+bug/1827775\\\\nif six.PY3:\\\\n    from six.moves.configparser import ConfigParser\\\\n    config = ConfigParser(strict=False)\\\\nelse:\\\\n    from six.moves.configparser import SafeConfigParser\\\\n    config = SafeConfigParser()\\\\n\\\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\\\n\\\\nif debug.lower() == \'true\':\\\\n    loglevel = logging.DEBUG\\\\nelse:\\\\n    loglevel = logging.INFO\\\\n\\\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\\\nLOG = logging.getLogger(\'nova_wait_for_compute_service\')\\\\n\\\\niterations = 60\\\\ntimeout = 10\\\\nnova_cfg = \'/etc/nova/nova.conf\'\\\\n\\\\nif __name__ == \'__main__\':\\\\n    parser = argparse.ArgumentParser(usage=\'%(prog)s [options]\')\\\\n    parser.add_argument(\'-k\', \'--insecure\',\\\\n                        action=\\\\\\\"store_false\\\\\\\",\\\\n                        dest=\'insecure\',\\\\n                        default=True,\\\\n                        help=\'Allow insecure connection when using SSL\')\\\\n\\\\n    args = parser.parse_args()\\\\n    LOG.debug(\'Running with parameter insecure = %s\',\\\\n              args.insecure)\\\\n\\\\n    if os.path.isfile(nova_cfg):\\\\n        try:\\\\n            config.read(nova_cfg)\\\\n        except Exception:\\\\n            LOG.exception(\'Error while reading nova.conf:\')\\\\n    else:\\\\n        LOG.error(\'Nova configuration file %s does not exist\', nova_cfg)\\\\n        sys.exit(1)\\\\n\\\\n    my_host = config.get(\'DEFAULT\', \'host\')\\\\n    if not my_host:\\\\n        # If host isn\'t set nova defaults to this\\\\n        my_host = socket.gethostname()\\\\n\\\\n    loader = loading.get_plugin_loader(\'password\')\\\\n    auth = loader.load_from_options(\\\\n        auth_url=config.get(\'neutron\',\\\\n                            \'auth_url\'),\\\\n        username=config.get(\'neutron\',\\\\n                            \'username\'),\\\\n        password=config.get(\'neutron\',\\\\n                            \'password\'),\\\\n        project_name=config.get(\'neutron\',\\\\n                                \'project_name\'),\\\\n        project_domain_name=config.get(\'neutron\',\\\\n                                       \'project_domain_name\'),\\\\n        user_domain_name=config.get(\'neutron\',\\\\n                                    \'user_domain_name\'))\\\\n    sess = session.Session(auth=auth, verify=args.insecure)\\\\n    nova = client.Client(\'2.11\', session=sess, endpoint_type=\'internal\',\\\\n                         region_name=config.get(\'neutron\', \'region_name\'))\\\\n\\\\n    # Wait until this host is listed in the service list\\\\n    for i in range(iterations):\\\\n        try:\\\\n            service_list = nova.services.list(binary=\'nova-compute\')\\\\n            for entry in service_list:\\\\n                host = getattr(entry, \'host\', \'\')\\\\n                zone = getattr(entry, \'zone\', \'\')\\\\n                if host == my_host and zone != \'internal\':\\\\n                    LOG.info(\'Nova-compute service registered\')\\\\n                    sys.exit(0)\\\\n            LOG.info(\'Waiting for nova-compute service to register\')\\\\n        except Exception:\\\\n            LOG.exception(\\\\n                \'Error while waiting for nova-compute service to register\')\\\\n        time.sleep(timeout)\\\\nsys.exit(1)\\\\n\\\\n# vim: set et ts=4 sw=4 :\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"nova_compute_init_log\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/nova:/var/log/nova:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R nova:nova /var/log/nova\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781337374\\\"}}}, \\\"step_3\\\": {\\\"nova_statedir_owner\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"privileged\\\": false, \\\"detach\\\": false, \\\"volumes\\\": [\\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts:z\\\"], \\\"command\\\": \\\"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\\\", \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781337374\\\", \\\"__OS_DEBUG\\\": \\\"true\\\", \\\"NOVA_STATEDIR_OWNERSHIP_SKIP\\\": \\\"triliovault-mounts\\\"}}}, \\\"step_5\\\": {\\\"nova_compute\\\": {\\\"start_order\\\": 3, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"memlock=67108864\\\"], \\\"ipc\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"nova\\\", \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_libvirt.target\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck 5672\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/nova:/var/log/nova\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/dev:/dev\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run:/run\\\", \\\"/run/nova:/run/nova:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/sys/class/net:/sys/class/net\\\", \\\"/sys/bus/pci:/sys/bus/pci\\\", \\\"/boot:/boot:ro\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"LIBGUESTFS_BACKEND\\\": \\\"direct\\\"}}, \\\"nova_wait_for_compute_service\\\": {\\\"start_order\\\": 4, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/nova:/var/log/nova\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts\\\"], \\\"user\\\": \\\"nova\\\", \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"__OS_DEBUG\\\": \\\"true\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/nova\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"Check for /var/lib/nova/instances directory exitance\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/nova/instances\\\"}, \\\"register\\\": \\\"check_nova_instances_result\\\"}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/_nova_secontext\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/nova/instances\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/tmpfiles.d\\\"}]}, {\\\"name\\\": \\\"ensure /run/nova is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-nova.conf\\\", \\\"content\\\": \\\"d /run/nova 0777 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"create tempfiles\\\", \\\"command\\\": \\\"systemd-tmpfiles --create\\\"}, {\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\"}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}, {\\\"name\\\": \\\"delay installation of systemd-container\\\", \\\"when\\\": \\\"check_nova_instances_result.stat.exists\\\", \\\"block\\\": [{\\\"name\\\": \\\"check systemd-container package installed or not\\\", \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}, \\\"check_mode\\\": true, \\\"register\\\": \\\"is_systemd_container_package\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"get latest package from downloaded package versions\\\", \\\"shell\\\": \\\"ls -1t /var/tmp/systemd-container* | head -1\\\", \\\"register\\\": \\\"latest_systemd_container_package\\\", \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"], \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Install systemd-container package on boot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/install-systemd-container.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Install systemd container package on system boot\\\\nBefore=tripleo_nova_virtqemud.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\\\nExecStartPost=rm -f /var/tmp/systemd-container*\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": [\\\"latest_systemd_container_package is defined\\\", \\\"(\'stdout\' in latest_systemd_container_package)\\\", \\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"]}, {\\\"name\\\": \\\"enable install-systemd-container on compute boot\\\", \\\"systemd\\\": {\\\"name\\\": \\\"install-systemd-container\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"]}, {\\\"name\\\": \\\"check if install-systemd-container service exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/systemd/system/install-systemd-container.service\\\"}, \\\"register\\\": \\\"install_systemd_container_result\\\"}, {\\\"name\\\": \\\"disable and mask install-systemd-container on compute boot\\\", \\\"systemd\\\": {\\\"name\\\": \\\"install-systemd-container\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"not is_systemd_container_package.changed\\\", \\\"install_systemd_container_result.stat.exists\\\"]}]}, {\\\"name\\\": \\\"is Nova Resume Guests State On Host Boot enabled\\\", \\\"set_fact\\\": {\\\"resume_guests_state_on_host_boot_enabled\\\": false}}, {\\\"name\\\": \\\"install libvirt-guests systemd unit file (docker)\\\", \\\"when\\\": [\\\"resume_guests_state_on_host_boot_enabled|bool\\\", \\\"container_cli == \'docker\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/libvirt-guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend/Resume Running libvirt Guests\\\\nAfter=network.target\\\\nAfter=time-sync.target\\\\nAfter=virt-guest-shutdown.target\\\\nAfter=docker.service\\\\nAfter=tripleo-container-shutdown.service\\\\nAfter=rhel-push-plugin.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\\\n# Hack just call traditional service until we factor\\\\n# out the code\\\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\\\nExecStop=/bin/{{container_cli}} stop nova_compute\\\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}}, {\\\"name\\\": \\\"Making sure virt-guest-shutdown.target is present\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/virt-guest-shutdown.target\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Libvirt guests shutdown\\\\nDocumentation=https://libvirt.org\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\n\\\"}}, {\\\"name\\\": \\\"libvirt-guests enable VM shutdown on compute reboot/shutdown\\\", \\\"systemd\\\": {\\\"name\\\": \\\"libvirt-guests\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}, {\\\"name\\\": \\\"install tripleo_nova_libvirt_guests systemd unit file (podman)\\\", \\\"when\\\": [\\\"resume_guests_state_on_host_boot_enabled|bool\\\", \\\"container_cli == \'podman\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt_guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend libvirt Guests in tripleo\\\\nRequires=virt-guest-shutdown.target\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": \\\"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\\\"}, {\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt_guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend libvirt Guests in tripleo\\\\nRequires=virt-guest-shutdown.target\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": \\\"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\\\"}, {\\\"name\\\": \\\"Making sure virt-guest-shutdown.target is present\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/virt-guest-shutdown.target\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Libvirt guests shutdown\\\\nDocumentation=https://libvirt.org\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\n\\\"}}, {\\\"name\\\": \\\"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt_guests\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"name\\\": \\\"Do we prepend nova startup with a delay\\\", \\\"set_fact\\\": {\\\"nova_compute_delay\\\": 0}}, {\\\"name\\\": \\\"install nova-compute delay wrapper script\\\", \\\"copy\\\": {\\\"content\\\": \\\"#!/usr/libexec/platform-python\\\\n\\\\\\\"\\\\\\\"\\\\\\\"\\\\nThis wrapper was created to add an optional delay to the startup of nova-compute.\\\\nWe know that instances will fail to boot, after a compute reboot, if ceph is not\\\\nhealthy.\\\\n\\\\nIdeally, we would poll ceph to get its health, but it\'s not guaranteed that the\\\\ncompute node will have access to the keys.\\\\n\\\\\\\"\\\\\\\"\\\\\\\"\\\\n\\\\nimport os\\\\nimport sys\\\\nimport time\\\\nimport logging\\\\nimport argparse\\\\n\\\\nparser = argparse.ArgumentParser(description=\'Process some integers.\')\\\\nparser.add_argument(\'--config-file\', dest=\'nova_config\', action=\'store\',\\\\n                    default=\\\\\\\"/etc/nova/nova.conf\\\\\\\",\\\\n                    help=\'path to nova configuration (default: /etc/nova/nova.conf)\')\\\\nparser.add_argument(\'--nova-binary\', dest=\'nova_binary\', action=\'store\',\\\\n                    default=\\\\\\\"/usr/bin/nova-compute\\\\\\\",\\\\n                    help=\'path to nova compute binary (default: /usr/bin/nova-compute)\')\\\\nparser.add_argument(\'--delay\', dest=\'delay\', action=\'store\',\\\\n                    default=120, type=int,\\\\n                    help=\'Number of seconds to wait until nova-compute is started\')\\\\nparser.add_argument(\'--state-dir\', dest=\'state_dir\', action=\'store\',\\\\n                    default=\\\\\\\"/run/nova/startup\\\\\\\", help=\'state-file directory\')\\\\nparser.add_argument(\'--state-file\', dest=\'state_file\', action=\'store\',\\\\n                    default=\\\\\\\"nova-compute-delayed\\\\\\\",\\\\n                    help=\'file exists if we already delayed nova-compute startup\')\\\\n\\\\n\\\\nsections = {}\\\\n(args, remaining) = parser.parse_known_args(sys.argv)\\\\n\\\\nreal_args = [args.nova_binary, \'--config-file\', args.nova_config]\\\\nreal_args.extend(remaining[1:])\\\\n\\\\nif not os.path.isdir(args.state_dir):\\\\n  os.makedirs(args.state_dir, mode = 0o751)\\\\n\\\\nstate_file_name = os.path.join(args.state_dir, args.state_file)\\\\n\\\\nif not os.path.isfile(state_file_name):\\\\n    logging.info(\\\\\\\"Delaying nova-compute startup by %s seconds\\\\\\\" % args.delay)\\\\n    time.sleep(args.delay)\\\\n    open(state_file_name, \'a\').close()\\\\n\\\\nlogging.info(\\\\\\\"Executing %s\\\\\\\" % real_args)\\\\nos.execv(args.nova_binary, real_args)\\\\n\\\", \\\"dest\\\": \\\"/var/lib/nova/delay-nova-compute\\\", \\\"mode\\\": 493}, \\\"when\\\": \\\"nova_compute_delay|int > 0\\\"}, {\\\"name\\\": \\\"Is irqbalance enabled\\\", \\\"set_fact\\\": {\\\"compute_irqbalance_disabled\\\": false}}, {\\\"name\\\": \\\"disable irqbalance service on compute\\\", \\\"when\\\": \\\"compute_irqbalance_disabled|bool\\\", \\\"service\\\": {\\\"name\\\": \\\"irqbalance.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"install systemd-container for a greenfield\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"not check_nova_instances_result.stat.exists\\\"], \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"validate nova-compute container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_compute\\\"}, \\\"register\\\": \\\"nova_compute_infos\\\", \\\"failed_when\\\": [\\\"nova_compute_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 6\\\"]}, {\\\"name\\\": \\\"manage PMEM namespaces for vPMEM\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_nvdimm\\\"}, \\\"vars\\\": {\\\"tripleo_nvdimm_pmem_namespaces\\\": \\\"\\\"}, \\\"when\\\": [\\\"step|int == 1\\\", \\\"tripleo_nvdimm_pmem_namespaces != \'\'\\\"]}, {\\\"name\\\": \\\"manage OS version 9 specific sysctls\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"ansible_facts[\'os_family\'] == \'RedHat\'\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Enable post-copy by setting unprivileged_userfaultfd\\\", \\\"sysctl\\\": {\\\"name\\\": \\\"vm.unprivileged_userfaultfd\\\", \\\"value\\\": 1, \\\"sysctl_set\\\": true, \\\"sysctl_file\\\": \\\"/etc/sysctl.d/99-tripleo-postcopy.conf\\\", \\\"state\\\": \\\"present\\\", \\\"reload\\\": true}}]}, {\\\"name\\\": \\\"enable/disable ksm\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"is KSM enabled\\\", \\\"set_fact\\\": {\\\"compute_ksm_enabled\\\": false}}, {\\\"name\\\": \\\"disable KSM on compute\\\", \\\"when\\\": \\\"not compute_ksm_enabled|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check for ksm\\\", \\\"shell\\\": \\\"systemctl is-active ksm.service || systemctl is-enabled ksm.service\\\", \\\"become\\\": true, \\\"failed_when\\\": false, \\\"register\\\": \\\"ksm_service_check\\\"}, {\\\"name\\\": \\\"disable KSM services\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"with_items\\\": [\\\"ksm.service\\\", \\\"ksmtuned.service\\\"], \\\"when\\\": [\\\"ksm_service_check.rc is defined\\\", \\\"ksm_service_check.rc == 0\\\"], \\\"register\\\": \\\"ksmdisabled\\\"}, {\\\"name\\\": \\\"delete PageKSM after disable ksm on compute\\\", \\\"command\\\": \\\"echo 2 >/sys/kernel/mm/ksm/run\\\", \\\"when\\\": [\\\"ksm_service_check.rc is defined\\\", \\\"ksm_service_check.rc == 0\\\", \\\"ksmdisabled is changed\\\"]}]}, {\\\"name\\\": \\\"enable KSM on compute\\\", \\\"when\\\": \\\"compute_ksm_enabled|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\\\", \\\"package\\\": {\\\"name\\\": \\\"qemu-kvm-common\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"]}, {\\\"name\\\": \\\"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\\\", \\\"package\\\": {\\\"name\\\": \\\"ksmtuned\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"]}, {\\\"name\\\": \\\"enable ksmtunded\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"started\\\", \\\"enabled\\\": true}, \\\"with_items\\\": [\\\"ksm.service\\\", \\\"ksmtuned.service\\\"]}]}]}], \\\"external_post_deploy_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"is additonal Cell?\\\", \\\"set_fact\\\": {\\\"nova_additional_cell\\\": false}}, {\\\"name\\\": \\\"check if discover hosts is required\\\", \\\"when\\\": [\\\"not nova_additional_cell|bool\\\", \\\"nova_cellv2_discovery_done is not defined\\\"], \\\"block\\\": [{\\\"name\\\": \\\"discover via nova_manager?\\\", \\\"set_fact\\\": {\\\"nova_cellv2_discovery_delegate_host\\\": \\\"{{ groups[\'nova_manager\'][0] }}\\\", \\\"nova_cellv2_discovery_container\\\": \\\"nova_manager\\\"}, \\\"when\\\": [\\\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\\\"]}, {\\\"name\\\": \\\"discover via nova_api?\\\", \\\"set_fact\\\": {\\\"nova_cellv2_discovery_delegate_host\\\": \\\"{{ groups[\'nova_api\'][0] }}\\\", \\\"nova_cellv2_discovery_container\\\": \\\"nova_api\\\"}, \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is not defined\\\", \\\"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\\\"]}, {\\\"name\\\": \\\"Warn if no discovery host available\\\", \\\"fail\\\": {\\\"msg\\\": \\\"No hosts available to run nova cell_v2 host discovery.\\\"}, \\\"ignore_errors\\\": true, \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is not defined\\\"]}, {\\\"name\\\": \\\"Discovering nova hosts\\\", \\\"command\\\": \\\"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\\\", \\\"become\\\": true, \\\"changed_when\\\": false, \\\"delegate_to\\\": \\\"{{ nova_cellv2_discovery_delegate_host }}\\\", \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is defined\\\"]}, {\\\"set_fact\\\": {\\\"nova_cellv2_discovery_done\\\": true}}]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Remove openstack-nova-compute and python-nova package during upgrade\\\", \\\"package\\\": {\\\"name\\\": [\\\"openstack-nova-compute\\\", \\\"python-nova\\\"], \\\"state\\\": \\\"removed\\\"}, \\\"failed_when\\\": false, \\\"when\\\": \\\"step|int == 2\\\"}, {\\\"name\\\": \\\"nova_compute pre system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Unmount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"absent\\\", \\\"fstype\\\": \\\"nfs4\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}, {\\\"name\\\": \\\"nova_compute post system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 5\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\"}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Remove openstack-nova-compute and python-nova package during upgrade\\\", \\\"package\\\": {\\\"name\\\": [\\\"openstack-nova-compute\\\", \\\"python-nova\\\"], \\\"state\\\": \\\"removed\\\"}, \\\"failed_when\\\": false, \\\"when\\\": \\\"step|int == 2\\\"}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Ensure instanceha directory is purged\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"become\\\": true, \\\"file\\\": {\\\"path\\\": \\\"/var/lib/nova/instanceha\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure instanceha directory is purged\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"become\\\": true, \\\"file\\\": {\\\"path\\\": \\\"/var/lib/nova/instanceha\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": \\\"overcloud\\\"}, \\\"block\\\": [{\\\"name\\\": \\\"Get nova-compute service ID\\\", \\\"command\\\": \\\"openstack compute service list --service nova-compute --column ID --column Host --format yaml\\\", \\\"register\\\": \\\"nova_compute_service_result\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"is additional Cell?\\\", \\\"set_fact\\\": {\\\"is_additional_cell\\\": false}}, {\\\"name\\\": \\\"Set fact for nova_compute services\\\", \\\"set_fact\\\": {\\\"nova_compute_service\\\": \\\"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"Check search output\\\", \\\"fail\\\": {\\\"msg\\\": \\\"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\\\"}, \\\"when\\\": [\\\"(nova_compute_service | length) > 1\\\"]}, {\\\"name\\\": \\\"Disable nova services\\\", \\\"when\\\": [\\\"(nova_compute_service | length) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable nova-compute service\\\", \\\"command\\\": \\\"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"when\\\": [\\\"not is_additional_cell|bool\\\"]}, {\\\"name\\\": \\\"Stop nova-compute container\\\", \\\"service\\\": {\\\"name\\\": \\\"tripleo_nova_compute\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"become\\\": true, \\\"register\\\": \\\"stop_nova_compute\\\", \\\"failed_when\\\": \\\"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\\\"}, {\\\"name\\\": \\\"Delete nova-compute service\\\", \\\"command\\\": \\\"openstack compute service delete {{ nova_compute_service[0].ID }}\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}]}]}]}, {\\\"service_name\\\": \\\"nova_libvirt\\\", \\\"firewall_rules\\\": {\\\"200 nova_libvirt\\\": {\\\"dport\\\": [16514, \\\"61152-61215\\\", \\\"5900-6923\\\"]}}, \\\"ansible_group_vars\\\": {\\\"tripleo_nova_libvirt_virsh_container\\\": \\\"nova_virtproxyd\\\"}, \\\"monitoring_subscription\\\": \\\"overcloud-nova-libvirt\\\", \\\"config_settings\\\": {\\\"nova::my_ip\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::rabbit_use_ssl\\\": \\\"True\\\", \\\"nova::keystone::service_user::send_service_user_token\\\": true, \\\"nova::keystone::service_user::project_name\\\": \\\"service\\\", \\\"nova::keystone::service_user::password\\\": \\\"QEj61Nsh9s8dBHEcrZuvWC9pV\\\", \\\"nova::keystone::service_user::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::keystone::service_user::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::project_name\\\": \\\"service\\\", \\\"nova::placement::password\\\": \\\"hEpTmySNpG4wGJSvCTrv5Aa7a\\\", \\\"nova::placement::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::placement::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::valid_interfaces\\\": \\\"internal\\\", \\\"nova::os_region_name\\\": \\\"regionOne\\\", \\\"nova::logging::debug\\\": true, \\\"nova::purge_config\\\": false, \\\"nova::network::neutron::project_name\\\": \\\"service\\\", \\\"nova::network::neutron::username\\\": \\\"neutron\\\", \\\"nova::network::neutron::region_name\\\": \\\"regionOne\\\", \\\"nova::dhcp_domain\\\": \\\"\\\", \\\"nova::network::neutron::password\\\": \\\"ynYFMrrhBYym7oMTANCe2Hdxj\\\", \\\"nova::network::neutron::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::network::neutron::valid_interfaces\\\": \\\"internal\\\", \\\"nova::glance::valid_interfaces\\\": \\\"internal\\\", \\\"nova::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"nova::cinder_catalog_info\\\": \\\"volumev3:cinderv3:internalURL\\\", \\\"nova::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"nova::notify_on_state_change\\\": \\\"vm_and_task_state\\\", \\\"nova::notification_driver\\\": [\\\"noop\\\"], \\\"nova::notification_format\\\": \\\"unversioned\\\", \\\"nova::network::neutron::auth_type\\\": \\\"v3password\\\", \\\"nova::db::database_db_max_retries\\\": -1, \\\"nova::db::database_max_retries\\\": -1, \\\"nova::network::neutron::ovs_bridge\\\": \\\"br-int\\\", \\\"nova::compute::sync_power_state_interval\\\": 600, \\\"nova_is_additional_cell\\\": false, \\\"nova::cross_az_attach\\\": true, \\\"nova::cache::enabled\\\": true, \\\"nova::cache::tls_enabled\\\": true, \\\"nova::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"nova::rabbit_heartbeat_in_pthread\\\": false, \\\"nova::ovsdb_connection\\\": \\\"\\\", \\\"vhostuser_socket_group\\\": \\\"qemu\\\", \\\"nova_libvirt_opt_volumes\\\": [], \\\"ContainerNovaLibvirtImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"nova::compute::libvirt::log_outputs\\\": \\\"1:file:/var/log/libvirt/libvirtd.log\\\", \\\"nova::compute::libvirt::virtlogd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtlogd.log\\\", \\\"nova::compute::libvirt::virtsecretd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtsecretd.log\\\", \\\"nova::compute::libvirt::virtnodedevd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtnodedevd.log\\\", \\\"nova::compute::libvirt::virtqemud::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtqemud.log\\\", \\\"nova::compute::libvirt::virtproxyd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtproxyd.log\\\", \\\"nova::compute::libvirt::virtstoraged::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtstoraged.log\\\", \\\"nova::compute::libvirt::qemu::memory_backing_dir\\\": \\\"\\\", \\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\\\": true, \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\\\": \\\"/var/lib/container-config-scripts/virtlogd_wrapper\\\", \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"tripleo::profile::base::nova::virtlogd_wrapper::debug\\\": true, \\\"nova::compute::libvirt::migration_support\\\": false, \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": \\\"/etc/ceph/ceph.conf\\\", \\\"nova::compute::rbd::libvirt_rbd_user\\\": \\\"openstack\\\", \\\"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"nova::compute::rbd::rbd_keyring\\\": \\\"client.openstack\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": \\\"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": \\\"b5752d85-3538-4992-bfb2-0baef5c2e05b\\\", \\\"tripleo::profile::base::nova::migration::client::libvirt_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": \\\"-----BEGIN RSA PRIVATE KEY-----\\\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\\\n-----END RSA PRIVATE KEY-----\\\\n\\\", \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": 2022, \\\"nova::compute::libvirt::services::libvirt_virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::enabled_perf_events\\\": [], \\\"nova::compute::libvirt::qemu::configure_qemu\\\": true, \\\"nova::compute::libvirt::qemu::max_files\\\": 32768, \\\"nova::compute::libvirt::qemu::max_processes\\\": 131072, \\\"nova::migration::qemu::configure_qemu\\\": true, \\\"nova::migration::qemu::migration_port_min\\\": 61152, \\\"nova::migration::qemu::migration_port_max\\\": 61215, \\\"nova::compute::libvirt::vncserver_listen\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::compute::libvirt::log_filters\\\": \\\"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\\\", \\\"nova::compute::libvirt::virtlogd::log_filters\\\": \\\"1:logging 4:object 4:json 4:event 1:util\\\", \\\"rbd_persistent_storage\\\": false, \\\"rbd_disk_cachemodes\\\": [\\\"network=writeback\\\"], \\\"nova::compute::libvirt::virtsecretd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtnodedevd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtstoraged::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtqemud::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtproxyd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"tripleo::profile::base::nova::libvirt::modular_libvirt\\\": true, \\\"nova::compute::libvirt::services::modular_libvirt\\\": true, \\\"nova::compute::libvirt::modular_libvirt\\\": true, \\\"nova::migration::libvirt::modular_libvirt\\\": true, \\\"tripleo::profile::base::nova::migration::client::libvirt_tls\\\": true, \\\"tripleo::profile::base::nova::libvirt::tls_password\\\": \\\"5vV3yOn6qpexwWmJwHuYNQL1Q\\\", \\\"nova::compute::libvirt::qemu::default_tls_verify\\\": true, \\\"nova::compute::libvirt::tls_priority\\\": \\\"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\\\", \\\"nova::migration::libvirt::listen_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::migration::libvirt::live_migration_inbound_addr\\\": \\\"%{hiera(\'fqdn_internal_api\')}\\\", \\\"nova::compute::libvirt::qemu::vnc_tls\\\": true, \\\"nova::compute::libvirt::qemu::vnc_tls_verify\\\": true, \\\"nova::compute::libvirt::qemu::nbd_tls\\\": true, \\\"nova::migration::libvirt::live_migration_with_native_tls\\\": true}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::libvirt\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_virtlogd.json\\\": {\\\"command\\\": \\\"/usr/local/bin/virtlogd_wrapper\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtsecretd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtnodedevd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtstoraged.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtqemud.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtproxyd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}}, \\\"container_config_scripts\\\": {\\\"nova_libvirt_init_secret.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -e\\\\n\\\\nCEPH_INFO=($*)\\\\n\\\\nif [ -z \\\\\\\"$CEPH_INFO\\\\\\\" ]; then\\\\n    echo \\\\\\\"error: At least one CLUSTER:CLIENT tuple must be specified\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\necho \\\\\\\"------------------------------------------------\\\\\\\"\\\\necho \\\\\\\"Initializing virsh secrets for: ${CEPH_INFO[@]}\\\\\\\"\\\\n\\\\nfor INFO in ${CEPH_INFO[@]}; do\\\\n    IFS=: read CLUSTER CLIENT <<< $INFO\\\\n    if [ ! -f /etc/ceph/${CLUSTER}.conf ]; then\\\\n        echo \\\\\\\"Error: /etc/ceph/${CLUSTER}.conf was not found\\\\\\\"\\\\n        echo \\\\\\\"Path to nova_libvirt_init_secret was ${CEPH_INFO}\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\n    FSID=$(awk \'$1 == \\\\\\\"fsid\\\\\\\" {print $3}\' /etc/ceph/${CLUSTER}.conf)\\\\n    if [ -z \\\\\\\"${FSID}\\\\\\\" ]; then\\\\n        echo \\\\\\\"Error: /etc/ceph/${CLUSTER}.conf contained an empty fsid definition\\\\\\\"\\\\n        echo \\\\\\\"Check your ceph configuration\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\n\\\\n    echo \\\\\\\"--------\\\\\\\"\\\\n    echo \\\\\\\"Initializing the virsh secret for \'$CLUSTER\' cluster ($FSID) \'$CLIENT\' client\\\\\\\"\\\\n\\\\n    # Ensure the secret XML file exists. Puppet should have created a secret.xml\\\\n    # file for the first cluster\'s secret, so detect when to use that file.\\\\n    if grep -q $FSID /etc/nova/secret.xml; then\\\\n        SECRET_FILE=\\\\\\\"/etc/nova/secret.xml\\\\\\\"\\\\n        SECRET_NAME=\\\\\\\"client.${CLIENT} secret\\\\\\\"\\\\n    else\\\\n        SECRET_FILE=\\\\\\\"/etc/nova/${CLUSTER}-secret.xml\\\\\\\"\\\\n        SECRET_NAME=\\\\\\\"${CLUSTER}.client.${CLIENT} secret\\\\\\\"\\\\n    fi\\\\n\\\\n    if [ ! -f $SECRET_FILE ]; then\\\\n        echo \\\\\\\"Creating $SECRET_FILE\\\\\\\"\\\\n        cat <<EOF > $SECRET_FILE\\\\n<secret ephemeral=\'no\' private=\'no\'>\\\\n  <usage type=\'ceph\'>\\\\n    <name>${SECRET_NAME}</name>\\\\n  </usage>\\\\n  <uuid>${FSID}</uuid>\\\\n</secret>\\\\nEOF\\\\n    else\\\\n        echo \\\\\\\"The $SECRET_FILE file already exists\\\\\\\"\\\\n    fi\\\\n\\\\n    # Ensure the libvirt secret is defined\\\\n    if /usr/bin/virsh secret-list | grep -q $FSID; then\\\\n        echo \\\\\\\"The virsh secret for $FSID has already been defined\\\\\\\"\\\\n    else\\\\n        /usr/bin/virsh secret-define --file $SECRET_FILE\\\\n    fi\\\\n\\\\n    # Fetch the key from the keyring and ensure the secret is set\\\\n    KEY=$(awk \'$1 == \\\\\\\"key\\\\\\\" {print $3}\' /etc/ceph/${CLUSTER}.client.${CLIENT}.keyring)\\\\n    if /usr/bin/virsh secret-get-value $FSID 2>/dev/null | grep -q $KEY; then\\\\n        echo \\\\\\\"The virsh secret for $FSID has already been set\\\\\\\"\\\\n    else\\\\n        /usr/bin/virsh secret-set-value --secret $FSID --base64 $KEY\\\\n    fi\\\\ndone\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"nova_virtqemud_init_logs\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R tss:tss /var/log/swtpm\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781337374\\\"}}, \\\"create_virtlogd_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::nova::virtlogd_wrapper\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781337374\\\"}}}, \\\"step_3\\\": {\\\"nova_virtlogd_wrapper\\\": {\\\"start_order\\\": 0, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"nova_virtsecretd\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtnodedevd\\\": {\\\"start_order\\\": 2, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtstoraged\\\": {\\\"start_order\\\": 3, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtqemud\\\": {\\\"start_order\\\": 4, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\\\"]}, \\\"nova_virtproxyd\\\": {\\\"start_order\\\": 5, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Ensure recovery of containerized virtqemud\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"become\\\": true, \\\"block\\\": [{\\\"name\\\": \\\"Create virtqemud recovery script\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/usr/libexec/recover_tripleo_nova_virtqemud.sh\\\", \\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/bin/bash\\\\npgrep -f /sbin/virtqemud\\\\n[ $? -eq 0 ] && exit 0\\\\nkill -9 $(cat /run/nova_virtqemud.pid)\\\\n\\\"}}, {\\\"name\\\": \\\"Create virtqemud recovery trigger service\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\\\", \\\"mode\\\": \\\"0644\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Check and recover tripleo_nova_virtqemud\\\\nAfter=tripleo_nova_virtqemud.service\\\\nRequisite=tripleo_nova_virtqemud.service\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}}, {\\\"name\\\": \\\"Create virtqemud recovery trigger timer\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\\\", \\\"mode\\\": \\\"0644\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\\\nPartOf=tripleo_nova_virtqemud.service\\\\n[Timer]\\\\nOnCalendar=*:5/10\\\\nOnActiveSec=120\\\\nOnUnitActiveSec=60\\\\nRandomizedDelaySec=1m\\\\n[Install]\\\\nWantedBy=timers.target\\\\n\\\"}}, {\\\"name\\\": \\\"Enable virtqemud recovery trigger service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_virtqemud_recover.service\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}, {\\\"name\\\": \\\"Enable virtqemud recovery trigger timer\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_virtqemud_recover.timer\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"register\\\": \\\"virtqemud_recover_timer_result\\\"}, {\\\"name\\\": \\\"Really enable virtqemud recovery trigger timer\\\", \\\"shell\\\": {\\\"cmd\\\": \\\"systemctl enable --now tripleo_nova_virtqemud_recover.timer\\\"}, \\\"when\\\": \\\"virtqemud_recover_timer_result.status.UnitFileState != \\\\\\\"enabled\\\\\\\"\\\"}]}, {\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create dirs for certificates and keys\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"directory\\\", \\\"serole\\\": \\\"object_r\\\", \\\"setype\\\": \\\"cert_t\\\", \\\"seuser\\\": \\\"system_u\\\"}, \\\"with_items\\\": [\\\"/etc/pki/libvirt\\\", \\\"/etc/pki/libvirt/private\\\", \\\"/etc/pki/qemu\\\"]}, {\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"libvirt-server-cert\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"libvirt/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp /etc/ipa/ca.crt /etc/pki/CA/cacert.pem\\\\nchown root:root /etc/pki/CA/cacert.pem\\\\nchmod 644 /etc/pki/CA/cacert.pem\\\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"libvirt-client-cert\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"libvirt/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-server-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"qemu/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to qemu dir\\\\ncp /etc/ipa/ca.crt /etc/pki/qemu/ca-cert.pem\\\\nchown root:root /etc/pki/qemu/ca-cert.pem\\\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\\\nchgrp qemu /etc/pki/qemu/server-*\\\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\\\nchmod 0640 /etc/pki/qemu/server-key.pem\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-client-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"qemu/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to qemu dir\\\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\\\nchgrp qemu /etc/pki/qemu/client-*\\\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\\\nchmod 0640 /etc/pki/qemu/client-key.pem\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}, {\\\"name\\\": \\\"Set up systemd target for libvirt services\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create systemd file\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt.target\\\", \\\"mode\\\": \\\"0644\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"content\\\": \\\"[Unit]\\\\nWants=tripleo_nova_virtsecretd.service\\\\nWants=tripleo_nova_virtnodedevd.service\\\\nWants=tripleo_nova_virtstoraged.service\\\\nWants=tripleo_nova_virtproxyd.service\\\\nWants=tripleo_nova_virtqemud.service\\\\nAfter=tripleo_nova_virtsecretd.service\\\\nAfter=tripleo_nova_virtnodedevd.service\\\\nAfter=tripleo_nova_virtstoraged.service\\\\nAfter=tripleo_nova_virtproxyd.service\\\\nAfter=tripleo_nova_virtqemud.service\\\\n\\\"}, \\\"become\\\": true, \\\"register\\\": \\\"libvirt_target_result\\\"}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt.target\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"become\\\": true, \\\"when\\\": \\\"libvirt_target_result.changed\\\"}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\", \\\"mode\\\": \\\"{{ item.mode | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/secrets\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/qemu\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/cache/libvirt\\\"}, {\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/run/libvirt\\\"}, {\\\"path\\\": \\\"/var/log/containers/libvirt/swtpm\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0770\\\"}]}, {\\\"name\\\": \\\"ensure qemu group is present on the host\\\", \\\"group\\\": {\\\"name\\\": \\\"qemu\\\", \\\"gid\\\": 107, \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"ensure qemu user is present on the host\\\", \\\"user\\\": {\\\"name\\\": \\\"qemu\\\", \\\"uid\\\": 107, \\\"group\\\": \\\"qemu\\\", \\\"state\\\": \\\"present\\\", \\\"shell\\\": \\\"/sbin/nologin\\\", \\\"comment\\\": \\\"qemu user\\\"}}, {\\\"name\\\": \\\"create directory for vhost-user sockets with qemu ownership\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/vhost_sockets\\\", \\\"state\\\": \\\"directory\\\", \\\"owner\\\": \\\"qemu\\\", \\\"group\\\": \\\"qemu\\\", \\\"setype\\\": \\\"virt_cache_t\\\", \\\"seuser\\\": \\\"system_u\\\"}}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"with_items\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": \\\"libvirt_installed.rc == 0\\\"}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"Enable os_enable_vtpm SELinux boolean for vTPM\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"os_enable_vtpm\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, [{\\\"name\\\": \\\"remove gnutls-qemu.config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/crypto-policies/local.d/gnutls-qemu.config\\\", \\\"state\\\": \\\"absent\\\"}, \\\"register\\\": \\\"update_gnutls_config\\\"}], {\\\"name\\\": \\\"update crypto policies\\\", \\\"command\\\": \\\"update-crypto-policies\\\", \\\"when\\\": \\\"update_gnutls_config.changed\\\"}], \\\"metadata_settings\\\": [{\\\"service\\\": \\\"libvirt\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"qemu\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"libvirt-vnc\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Fail if we are on RHEL8 as this is monolithic libvirt deployment\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\\\"}}, {\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"Get container virtlogd image\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"always\\\", \\\"set_fact\\\": {\\\"virtlogd_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}}, {\\\"name\\\": \\\"Force pull image novalibvirt\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ virtlogd_image }}\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Diff OS release in container image and baremetal\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\\\n\\\", \\\"args\\\": {\\\"executable\\\": \\\"/bin/bash\\\"}, \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_ubi_diff\\\"}, {\\\"name\\\": \\\"Fail if UBI of the container does not match RHEL of running host\\\", \\\"when\\\": [\\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"step|int == 1\\\", \\\"libvirt_ubi_diff.rc == 1\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"The host operating system versus container UBI does not match.\\\\n{{ libvirt_ubi_diff.stdout }}\\\\nMost likely container passed to NovaLibvirt was EL8 one.\\\\nYou have to pass the correct container for container-image-prepare.\\\\nIf you would continue all running workloads would get destroyed.\\\\n\\\"}}, {\\\"name\\\": \\\"Switch virtlogd image before system upgrade\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get running image version\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"old_virtlogd_image\\\"}, {\\\"name\\\": \\\"Switch running image to new image in wrapper script\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\\\n\\\", \\\"when\\\": [\\\"old_virtlogd_image.stdout != virtlogd_image\\\", \\\"old_virtlogd_image.stdout != \'\'\\\"]}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"check systemd-container package present or not\\\", \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}, \\\"check_mode\\\": true, \\\"register\\\": \\\"is_systemd_container_package\\\"}, {\\\"name\\\": \\\"download systemd-container package if not present\\\", \\\"yum\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\", \\\"download_only\\\": true, \\\"download_dir\\\": \\\"/var/tmp/\\\"}, \\\"when\\\": \\\"is_systemd_container_package.changed\\\"}, {\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]}, {\\\"service_name\\\": \\\"nova_libvirt_guests\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\\\": false, \\\"nova::compute::libvirt_guests::shutdown_timeout\\\": \\\"300\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::compute::libvirt_guests\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}}, {\\\"service_name\\\": \\\"nova_migration_target\\\", \\\"firewall_rules\\\": {\\\"113 nova_migration_target accept libvirt subnet 172.17.0.0/24\\\": {\\\"source\\\": \\\"172.17.0.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 2022}, \\\"113 nova_migration_target accept api subnet 172.17.0.0/24\\\": {\\\"source\\\": \\\"172.17.0.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 2022}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::sshd::bannertext\\\": \\\"\\\", \\\"tripleo::profile::base::sshd::motd\\\": \\\"\\\", \\\"tripleo::profile::base::sshd::options\\\": {\\\"HostKey\\\": [\\\"/etc/ssh/ssh_host_rsa_key\\\", \\\"/etc/ssh/ssh_host_ecdsa_key\\\", \\\"/etc/ssh/ssh_host_ed25519_key\\\"], \\\"SyslogFacility\\\": \\\"AUTHPRIV\\\", \\\"AuthorizedKeysFile\\\": \\\".ssh/authorized_keys\\\", \\\"ChallengeResponseAuthentication\\\": \\\"no\\\", \\\"GSSAPIAuthentication\\\": \\\"no\\\", \\\"GSSAPICleanupCredentials\\\": \\\"no\\\", \\\"UsePAM\\\": \\\"yes\\\", \\\"UseDNS\\\": \\\"no\\\", \\\"PrintMotd\\\": \\\"no\\\", \\\"X11Forwarding\\\": \\\"yes\\\", \\\"AcceptEnv\\\": [\\\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\\\", \\\"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\\\", \\\"LC_IDENTIFICATION LC_ALL LANGUAGE\\\", \\\"XMODIFIERS\\\"], \\\"Subsystem\\\": \\\"sftp  /usr/libexec/openssh/sftp-server\\\"}, \\\"tripleo::profile::base::sshd::password_authentication\\\": \\\"yes\\\", \\\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\\\": [\\\"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\\\"], \\\"tripleo::profile::base::nova::migration::target::ssh_localaddrs\\\": [\\\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\\\", \\\"%{hiera(\'live_migration_ssh_inbound_addr\')}\\\"], \\\"live_migration_ssh_inbound_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"cold_migration_ssh_inbound_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::sshd::port\\\": [22]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::sshd\\\\ninclude tripleo::profile::base::nova::migration::target\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova-migration-target.json\\\": {\\\"command\\\": \\\"dumb-init --single-child -- /usr/sbin/sshd -D -p 2022\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/host-ssh/ssh_host_*_key\\\", \\\"dest\\\": \\\"/etc/ssh/\\\", \\\"owner\\\": \\\"root\\\", \\\"perm\\\": \\\"0600\\\"}]}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\"}, \\\"loop\\\": [{\\\"path\\\": \\\"/run/libvirt\\\", \\\"setype\\\": \\\"virt_var_run_t\\\"}]}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}], \\\"docker_config\\\": {\\\"step_4\\\": {\\\"nova_migration_target\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/ssh:/host-ssh:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"validate nova-migration-target container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_migration_target\\\"}, \\\"register\\\": \\\"nova_migration_target_infos\\\", \\\"failed_when\\\": [\\\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 5\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"nova_migration_target_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"nova_migration_target_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]}, {\\\"service_name\\\": \\\"logrotate_crond\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::logging::logrotate::maxsize\\\": \\\"10M\\\", \\\"tripleo::profile::base::logging::logrotate::rotation\\\": \\\"daily\\\", \\\"tripleo::profile::base::logging::logrotate::rotate\\\": \\\"14\\\", \\\"tripleo::profile::base::logging::logrotate::purge_after_days\\\": \\\"14\\\", \\\"tripleo::profile::base::logging::logrotate::dateext\\\": false}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"allow logrotate to read inside containers\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"logrotate_read_inside_containers\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"configure tmpwatch on the host\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Push script\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/usr/local/sbin/containers-tmpwatch\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"mode\\\": 493, \\\"content\\\": \\\"#!/bin/sh\\\\ntmpwatch --nodirs \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*log\\\\\\\" \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*/*log\\\\\\\" \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*err\\\\\\\" \\\\\\\\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\\\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\\\n\\\"}, \\\"vars\\\": {\\\"LogrotatePurgeAfterDays\\\": \\\"14\\\"}}, {\\\"name\\\": \\\"Insert cronjob in root crontab\\\", \\\"cron\\\": {\\\"name\\\": \\\"Remove old logs\\\", \\\"special_time\\\": \\\"daily\\\", \\\"user\\\": \\\"root\\\", \\\"job\\\": \\\"/usr/local/sbin/containers-tmpwatch\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Ensure old cron.daily is absent\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/cron.daily/containers-tmpwatch\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure old cron.daily is absent\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/cron.daily/containers-tmpwatch\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"crond\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::logging::logrotate\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/logrotate-crond.json\\\": {\\\"command\\\": \\\"/usr/sbin/crond -s -n\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"logrotate_crond\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/usr/share/openstack-tripleo-common/healthcheck/cron\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers:/var/log/containers:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop logrotate container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"logrotate_crond\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}, {\\\"service_name\\\": \\\"podman\\\", \\\"config_settings\\\": {}, \\\"step_config\\\": \\\"\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Install and configure Podman\\\", \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}, [{\\\"name\\\": \\\"Configure tripleo_container_manage to generate systemd drop-in dependencies\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/sysconfig/podman_drop_in\\\", \\\"content\\\": \\\"This file makes tripleo_container_manage generate additional systemd\\\\ndependencies for containers that have special\\\\nstart/stop ordering constraints. It ensures that\\\\nthose constraints are enforced on reboot/shutdown.\\\\n\\\"}}]], \\\"deploy_steps_tasks\\\": [{\\\"when\\\": [\\\"(step|int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Pre-fetch all the containers\\\", \\\"become\\\": true, \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ prefetch_image }}\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}, \\\"register\\\": \\\"result\\\", \\\"until\\\": \\\"result is succeeded\\\", \\\"retries\\\": 5, \\\"delay\\\": 5, \\\"loop_control\\\": {\\\"loop_var\\\": \\\"prefetch_image\\\"}, \\\"loop\\\": \\\"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\\\"}]}], \\\"service_config_settings\\\": {}, \\\"workaround_upgrade_tasks\\\": [{\\\"name\\\": \\\"Configure Podman registry\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"tags\\\": [\\\"setup_packages\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Make sure the Undercloud hostname is included in /etc/hosts\\\", \\\"when\\\": [\\\"undercloud_hosts_entries is defined\\\"], \\\"lineinfile\\\": {\\\"dest\\\": \\\"/etc/hosts\\\", \\\"line\\\": \\\"{{ undercloud_hosts_entries | join(\'\') }}\\\", \\\"state\\\": \\\"present\\\"}}]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"tags\\\": [\\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"setup_packages\\\"], \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}, {\\\"name\\\": \\\"Comment infra_image in container.conf\\\", \\\"lineinfile\\\": {\\\"dest\\\": \\\"/usr/share/containers/containers.conf\\\", \\\"regexp\\\": \\\"(?i)^(infra_image.*)\\\", \\\"line\\\": \\\"#\\\\\\\\1\\\", \\\"backrefs\\\": true, \\\"state\\\": \\\"present\\\"}, \\\"tags\\\": [\\\"setup_packages\\\"], \\\"when\\\": [\\\"step|int == 0\\\"]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Configure Podman registry\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Make sure the Undercloud hostname is included in /etc/hosts\\\", \\\"when\\\": [\\\"undercloud_hosts_entries is defined\\\"], \\\"lineinfile\\\": {\\\"dest\\\": \\\"/etc/hosts\\\", \\\"line\\\": \\\"{{ undercloud_hosts_entries | join(\'\') }}\\\", \\\"state\\\": \\\"present\\\"}}]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"tags\\\": [\\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Force pre-fetch of container images\\\", \\\"when\\\": [\\\"(step|int) == 5\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Pre-fetch all the containers\\\", \\\"become\\\": true, \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ prefetch_image }}\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}, \\\"register\\\": \\\"result\\\", \\\"until\\\": \\\"result is succeeded\\\", \\\"retries\\\": 5, \\\"delay\\\": 5, \\\"loop_control\\\": {\\\"loop_var\\\": \\\"prefetch_image\\\"}, \\\"loop\\\": \\\"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\\\"}]}], \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Purge Podman\\\", \\\"when\\\": [\\\"(step | int) == 3\\\", \\\"container_cli == \'podman\'\\\", \\\"deployment_source_hosts not in group_names\\\"], \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_purge.yml\\\"}, \\\"vars\\\": {\\\"deployment_source_hosts\\\": \\\"Undercloud\\\"}}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Purge Podman\\\", \\\"when\\\": [\\\"(step | int) == 3\\\", \\\"container_cli == \'podman\'\\\", \\\"deployment_source_hosts not in group_names\\\"], \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_purge.yml\\\"}, \\\"vars\\\": {\\\"deployment_source_hosts\\\": \\\"Undercloud\\\"}}]}, {\\\"service_name\\\": \\\"rsyslog\\\", \\\"config_settings\\\": {\\\"rsyslog::server::global_config\\\": {\\\"WorkDirectory\\\": {\\\"type\\\": \\\"legacy\\\", \\\"target\\\": \\\"00_rsyslog.conf\\\", \\\"value\\\": \\\"/var/lib/rsyslog\\\"}, \\\"MaxMessageSize\\\": {\\\"type\\\": \\\"legacy\\\", \\\"target\\\": \\\"00_rsyslog.conf\\\", \\\"value\\\": \\\"32k\\\"}}, \\\"rsyslog::confdir\\\": \\\"/etc/rsyslog.d\\\", \\\"rsyslog::package_name\\\": \\\"rsyslog\\\", \\\"rsyslog::package_version\\\": \\\"installed\\\", \\\"rsyslog::manage_package\\\": true, \\\"rsyslog::manage_confdir\\\": true, \\\"rsyslog::purge_config_files\\\": true, \\\"rsyslog::override_default_config\\\": true, \\\"rsyslog::config_file\\\": \\\"/etc/rsyslog.conf\\\", \\\"rsyslog::manage_service\\\": true, \\\"rsyslog::service_name\\\": \\\"rsyslog\\\", \\\"rsyslog::service_status\\\": \\\"running\\\", \\\"rsyslog::service_enabled\\\": true, \\\"rsyslog::external_service\\\": false, \\\"rsyslog::use_upstream_repo\\\": false, \\\"rsyslog::feature_packages\\\": [\\\"rsyslog-elasticsearch\\\", \\\"rsyslog-mmnormalize\\\"], \\\"rsyslog::global_config_priority\\\": 10, \\\"rsyslog::module_load_priority\\\": 20, \\\"rsyslog::input_priority\\\": 30, \\\"rsyslog::main_queue_priority\\\": 40, \\\"rsyslog::parser_priority\\\": 45, \\\"rsyslog::template_priority\\\": 50, \\\"rsyslog::filter_priority\\\": 55, \\\"rsyslog::action_priority\\\": 60, \\\"rsyslog::ruleset_priority\\\": 65, \\\"rsyslog::lookup_table_priority\\\": 70, \\\"rsyslog::legacy_config_priority\\\": 80, \\\"rsyslog::custom_priority\\\": 90, \\\"rsyslog::target_file\\\": \\\"50_openstack_logs.conf\\\", \\\"rsyslog::server::modules\\\": {\\\"imfile\\\": {}, \\\"omelasticsearch\\\": {}, \\\"omamqp1\\\": {}}, \\\"rsyslog::server::templates\\\": {\\\"rsyslog-node-index\\\": {\\\"type\\\": \\\"list\\\", \\\"list_descriptions\\\": [{\\\"constant\\\": {\\\"value\\\": \\\"%{hiera(\'fqdn_canonical\')}-\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"year\\\"}}, {\\\"constant\\\": {\\\"value\\\": \\\".\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"month\\\"}}, {\\\"constant\\\": {\\\"value\\\": \\\".\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"day\\\"}}]}, \\\"rsyslog-record\\\": {\\\"type\\\": \\\"list\\\", \\\"options\\\": {\\\"jsonf\\\": \\\"on\\\"}, \\\"list_descriptions\\\": [{\\\"property\\\": {\\\"outname\\\": \\\"@timestamp\\\", \\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"rfc3339\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"host\\\", \\\"name\\\": \\\"hostname\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"severity\\\", \\\"name\\\": \\\"syslogseverity\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"facility\\\", \\\"name\\\": \\\"syslogfacility-text\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"tag\\\", \\\"name\\\": \\\"syslogtag\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"source\\\", \\\"name\\\": \\\"app-name\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"message\\\", \\\"name\\\": \\\"msg\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"file\\\", \\\"name\\\": \\\"$!metadata!filename\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"constant\\\": {\\\"outname\\\": \\\"cloud\\\", \\\"value\\\": \\\"overcloud.ooo.test\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"constant\\\": {\\\"outname\\\": \\\"region\\\", \\\"value\\\": \\\"regionOne\\\", \\\"format\\\": \\\"jsonf\\\"}}]}}, \\\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\\\": \\\"on\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rsyslog\\\", \\\"puppet_tags\\\": \\\"rsyslog::generate_concat,concat::fragment\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::logging::rsyslog\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rsyslog.json\\\": {\\\"command\\\": \\\"/usr/sbin/rsyslogd -n -iNONE\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rsyslog\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/rsyslog\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"rsyslog\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers:/var/log/containers:ro\\\", \\\"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\\\", \\\"/var/log:/var/log/host:ro\\\", \\\"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent logs directory for rsyslog\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/log/containers/rsyslog\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}}, {\\\"name\\\": \\\"create persistent state directory for rsyslog\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/rsyslog.container\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}]}, {\\\"service_name\\\": \\\"snmp\\\", \\\"firewall_rules\\\": {\\\"124 snmp 192.168.122.0/24\\\": {\\\"dport\\\": 161, \\\"proto\\\": \\\"udp\\\", \\\"source\\\": \\\"192.168.122.0/24\\\"}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::snmp::snmpd_user\\\": \\\"ro_snmp_user\\\", \\\"tripleo::profile::base::snmp::snmpd_password\\\": \\\"FKQdo7NuIE9RbMdjCuC9b8sG\\\", \\\"snmp::agentaddress\\\": [\\\"udp:161\\\", \\\"udp6:[::1]:161\\\"], \\\"snmp::snmpd_options\\\": \\\"-LS0-5d\\\"}, \\\"step_config\\\": \\\"include tripleo::profile::base::snmp\\\\n\\\", \\\"upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check if snmpd is enabled\\\", \\\"command\\\": \\\"systemctl is-enabled --quiet snmpd\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"snmpd_enabled_result\\\"}, {\\\"name\\\": \\\"Set fact snmpd_enabled\\\", \\\"set_fact\\\": {\\\"snmpd_enabled\\\": \\\"{{ snmpd_enabled_result.rc == 0 }}\\\"}}]}, {\\\"name\\\": \\\"Stop snmp service\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"snmpd_enabled|bool\\\"], \\\"service\\\": \\\"name=snmpd state=stopped\\\"}]}, {\\\"service_name\\\": \\\"sshd\\\", \\\"firewall_rules\\\": {\\\"003 accept ssh from all\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22, \\\"extras\\\": {\\\"ensure\\\": \\\"present\\\"}}}, \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_sshd\\\"}, \\\"vars\\\": {\\\"tripleo_sshd_server_options\\\": {\\\"HostKey\\\": [\\\"/etc/ssh/ssh_host_rsa_key\\\", \\\"/etc/ssh/ssh_host_ecdsa_key\\\", \\\"/etc/ssh/ssh_host_ed25519_key\\\"], \\\"SyslogFacility\\\": \\\"AUTHPRIV\\\", \\\"AuthorizedKeysFile\\\": \\\".ssh/authorized_keys\\\", \\\"ChallengeResponseAuthentication\\\": \\\"no\\\", \\\"GSSAPIAuthentication\\\": \\\"no\\\", \\\"GSSAPICleanupCredentials\\\": \\\"no\\\", \\\"UsePAM\\\": \\\"yes\\\", \\\"UseDNS\\\": \\\"no\\\", \\\"PrintMotd\\\": \\\"no\\\", \\\"X11Forwarding\\\": \\\"yes\\\", \\\"AcceptEnv\\\": [\\\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\\\", \\\"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\\\", \\\"LC_IDENTIFICATION LC_ALL LANGUAGE\\\", \\\"XMODIFIERS\\\"], \\\"Subsystem\\\": \\\"sftp  /usr/libexec/openssh/sftp-server\\\"}, \\\"tripleo_sshd_password_authentication\\\": \\\"yes\\\", \\\"tripleo_sshd_banner_enabled\\\": false, \\\"tripleo_sshd_banner_text\\\": \\\"\\\", \\\"tripleo_sshd_motd_enabled\\\": false, \\\"tripleo_sshd_message_of_the_day\\\": \\\"\\\"}}]}, {\\\"service_name\\\": \\\"chrony\\\", \\\"firewall_rules\\\": {\\\"105 ntp\\\": {\\\"dport\\\": 123, \\\"proto\\\": \\\"udp\\\"}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Check for NTP service\\\", \\\"shell\\\": \\\"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\\\", \\\"failed_when\\\": false, \\\"become\\\": true, \\\"register\\\": \\\"ntp_service_check\\\"}, {\\\"name\\\": \\\"Disable NTP before configuring Chrony\\\", \\\"service\\\": {\\\"name\\\": \\\"ntpd\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"when\\\": [\\\"ntp_service_check.rc is defined\\\", \\\"ntp_service_check.rc == 0\\\"]}, {\\\"name\\\": \\\"Install, Configure and Run Chrony\\\", \\\"include_role\\\": {\\\"name\\\": \\\"chrony\\\"}}, {\\\"name\\\": \\\"Force NTP sync\\\", \\\"command\\\": \\\"chronyc makestep\\\"}, {\\\"name\\\": \\\"Ensure system is NTP time synced\\\", \\\"command\\\": \\\"chronyc waitsync 30\\\"}], \\\"ansible_group_vars\\\": {\\\"chrony_role_action\\\": \\\"all\\\", \\\"chrony_ntp_servers\\\": [\\\"pool.ntp.org\\\"], \\\"chrony_ntp_pools\\\": [], \\\"chrony_global_server_settings\\\": \\\"iburst minpoll 6 maxpoll 10\\\", \\\"chrony_global_pool_settings\\\": \\\"iburst minpoll 6 maxpoll 10\\\", \\\"chrony_manage_package\\\": true, \\\"chrony_acl_rules\\\": [\\\"deny all\\\"]}}, {\\\"service_name\\\": \\\"timezone\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Run timezone role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_timezone\\\"}, \\\"vars\\\": {\\\"tripleo_timezone\\\": \\\"UTC\\\"}}]}, {\\\"service_name\\\": \\\"tripleo_firewall\\\", \\\"config_settings\\\": {\\\"tripleo::firewall::manage_firewall\\\": false, \\\"tripleo::firewall::purge_firewall_rules\\\": false}, \\\"ansible_group_vars\\\": {\\\"tripleo_nftables_debug\\\": true}, \\\"firewall_rules\\\": {\\\"003 accept ssh from ctlplane subnet 192.168.122.0/24\\\": {\\\"source\\\": \\\"192.168.122.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Notice - ctlplane subnet is set\\\", \\\"debug\\\": {\\\"msg\\\": \\\"CIDRs found in the ctlplane network tags.\\\\n\\\"}}], \\\"host_firewall_tasks\\\": [{\\\"name\\\": \\\"Run firewall role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_firewall\\\"}}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Cleanup tripleo-iptables services\\\", \\\"when\\\": [\\\"(step | int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable tripleo-iptables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-iptables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_iptables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-iptables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-iptables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Disable tripleo-ip6tables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-ip6tables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_ip6tables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-ip6tables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-ip6tables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\\\"]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Cleanup tripleo-iptables services\\\", \\\"when\\\": [\\\"(step | int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable tripleo-iptables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-iptables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_iptables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-iptables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-iptables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Disable tripleo-ip6tables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-ip6tables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_ip6tables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-ip6tables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-ip6tables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\\\"]}]}, {\\\"when\\\": [\\\"(step | int) == 3\\\"], \\\"block\\\": [{\\\"name\\\": \\\"blank ipv6 rule before activating ipv6 firewall.\\\", \\\"shell\\\": \\\"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\\\", \\\"args\\\": {\\\"creates\\\": \\\"/etc/sysconfig/ip6tables.n-o-upgrade\\\"}}, {\\\"name\\\": \\\"cleanup unmanaged rules pushed by iptables-services\\\", \\\"shell\\\": \\\"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\\\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\\\n\\\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\\\n\\\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\\\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\\\n\\\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -d fe80::\\\\\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\\"}]}]}, {\\\"service_name\\\": \\\"tripleo_packages\\\", \\\"config_settings\\\": {\\\"tripleo::packages::enable_install\\\": true}, \\\"step_config\\\": \\\"include ::tripleo::packages\\\\n\\\", \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Gather missing facts\\\", \\\"setup\\\": {\\\"gather_subset\\\": [\\\"!all\\\", \\\"!min\\\", \\\"distribution\\\"]}, \\\"tags\\\": [\\\"always\\\"]}, {\\\"name\\\": \\\"Set leapp facts\\\", \\\"set_fact\\\": {\\\"upgrade_leapp_enabled\\\": \\\"{{ _upgradeLeappEnabled | bool and\\\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\\\", \\\"upgrade_leapp_debug\\\": false, \\\"upgrade_leapp_devel_skip\\\": \\\"\\\", \\\"upgrade_leapp_command_options\\\": \\\"\\\", \\\"upgrade_leapp_reboot_timeout\\\": 3600, \\\"upgrade_leapp_post_reboot_delay\\\": 120}, \\\"vars\\\": {\\\"_upgradeLeappEnabled\\\": false}, \\\"tags\\\": [\\\"always\\\"]}, {\\\"name\\\": \\\"system_upgrade_prepare step 3\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Run LeappRepoInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Remove firewalld bindings\\\", \\\"package\\\": {\\\"name\\\": \\\"python3-firewall\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"install leapp\\\", \\\"package\\\": {\\\"name\\\": \\\"leapp-repository-openstack\\\", \\\"state\\\": \\\"latest\\\"}}, {\\\"name\\\": \\\"Run LeappInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Remove vdo\\\", \\\"package\\\": {\\\"name\\\": \\\"vdo\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"add packages into Leapp\'s to_remove file\\\", \\\"vars\\\": {\\\"pkg_to_remove\\\": []}, \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/leapp/transaction/to_remove\\\", \\\"line\\\": \\\"{{ item }}\\\"}, \\\"loop\\\": \\\"{{ pkg_to_remove }}\\\"}, {\\\"name\\\": \\\"add packages into Leapp\'s to_install file\\\", \\\"vars\\\": {\\\"pkg_to_install\\\": []}, \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/leapp/transaction/to_install\\\", \\\"line\\\": \\\"{{ item }}\\\"}, \\\"loop\\\": \\\"{{ pkg_to_install }}\\\"}, {\\\"name\\\": \\\"check sshd_config file\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/ssh/sshd_config\\\"}, \\\"register\\\": \\\"sshd_config_result\\\"}, {\\\"name\\\": \\\"add PermitRootLogin option for leapp\\\", \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/ssh/sshd_config\\\", \\\"regexp\\\": \\\"^(# *)?PermitRootLogin\\\", \\\"line\\\": \\\"PermitRootLogin without-password\\\"}}, {\\\"name\\\": \\\"Remove paunch-services\\\", \\\"package\\\": {\\\"name\\\": \\\"paunch-services\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"tripleo_container_manage reconfiguration\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_manage\\\", \\\"tasks_from\\\": \\\"shutdown.yml\\\"}}]}, {\\\"name\\\": \\\"system_upgrade_prepare step 4\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 4\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\\\", \\\"vars\\\": {\\\"modules_to_unload\\\": []}, \\\"shell\\\": \\\"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\\\\\"{{ item }}\\\\\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\\\n\\\", \\\"loop\\\": \\\"{{ modules_to_unload }}\\\"}, {\\\"name\\\": \\\"Remove leapp actors to prevent them inhibiting the upgrade\\\", \\\"vars\\\": {\\\"actors_to_remove\\\": []}, \\\"command\\\": {\\\"cmd\\\": \\\"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\\\\\"{}\\\\\\\" +\\\"}, \\\"loop\\\": \\\"{{ actors_to_remove }}\\\"}, {\\\"name\\\": \\\"set leapp required answers\\\", \\\"shell\\\": \\\"leapp answer --add --section check_vdo.confirm=True\\\\n\\\"}, {\\\"name\\\": \\\"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"efigrub.yml\\\"}}, {\\\"name\\\": \\\"Keep nics with prefix in NICsPrefixesToUdev from renaming\\\", \\\"vars\\\": {\\\"nics_prefixes_to_keep\\\": []}, \\\"shell\\\": \\\"ip -j link show | \\\\\\\\ jq -r --arg prefix \\\\\\\"{{ item }}\\\\\\\" \'.[] |\\\\n  select((.ifname | startswith($prefix)) and\\\\n  (.ifname | test(\\\\\\\"^.*v[0-9]*$\\\\\\\") | not) and\\\\n  (.ifname | test(\\\\\\\"^.*_[0-9]*$\\\\\\\") | not) and\\\\n  (.ifname | test(\\\\\\\"^.*\\\\\\\\\\\\\\\\..*$\\\\\\\") | not)) |\\\\n  if .permaddr? then .address=.permaddr else . end |\\\\n  \\\\\\\"SUBSYSTEM==\\\\\\\\\\\\\\\"net\\\\\\\\\\\\\\\",ACTION==\\\\\\\\\\\\\\\"add\\\\\\\\\\\\\\\",DRIVERS==\\\\\\\\\\\\\\\"?*\\\\\\\\\\\\\\\",\\\\\\\" + \\\\\\\"NAME=\\\\\\\\\\\\\\\"\\\\\\\" + .ifname +\\\\\\\"\\\\\\\\\\\\\\\" ,ATTR{address}==\\\\\\\\\\\\\\\"\\\\\\\" + .address + \\\\\\\"\\\\\\\\\\\\\\\"\\\\\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\\\n\\\", \\\"loop\\\": \\\"{{ nics_prefixes_to_keep|list }}\\\"}, {\\\"name\\\": \\\"run leapp upgrade (download packages)\\\", \\\"shell\\\": \\\"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\\\n\\\", \\\"when\\\": \\\"upgrade_leapp_enabled\\\"}]}, {\\\"name\\\": \\\"system_upgrade_run step 4\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_reboot\\\"], \\\"when\\\": [\\\"step|int == 4\\\", \\\"upgrade_leapp_enabled\\\", \\\"\'Undercloud\' not in group_names\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Run LeappPreRebootCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Check that nova_libvirt is running\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"is_virtlogd_image_running\\\"}, {\\\"name\\\": \\\"Remove systemd files to disable them\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/{{ item }}\\\", \\\"state\\\": \\\"absent\\\"}, \\\"with_items\\\": [\\\"tripleo_nova_libvirt.service\\\", \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_libvirt.target\\\"], \\\"when\\\": \\\"is_virtlogd_image_running.stdout != \'\'\\\"}, {\\\"name\\\": \\\"reboot to perform the upgrade\\\", \\\"reboot\\\": {\\\"reboot_timeout\\\": \\\"{{upgrade_leapp_reboot_timeout}}\\\", \\\"test_command\\\": \\\"source /etc/os-release; [ \\\\\\\"${VERSION_ID%.*}\\\\\\\" -ge \\\\\\\"8\\\\\\\" ] && systemctl is-system-running | grep -qE \\\\\\\"running|degraded\\\\\\\" || exit 1\\\", \\\"post_reboot_delay\\\": \\\"{{ upgrade_leapp_post_reboot_delay }}\\\"}}, {\\\"name\\\": \\\"Set selinux back to enforcing after leapp reboot\\\", \\\"selinux\\\": {\\\"policy\\\": \\\"targeted\\\", \\\"state\\\": \\\"enforcing\\\"}}, {\\\"name\\\": \\\"Run LeappPostRebootCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}]}, {\\\"name\\\": \\\"Host packages setup step0\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Package and repo update tasks\\\", \\\"block\\\": [{\\\"name\\\": \\\"Run UpgradeInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\nif [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Run UpgradeInitCommonCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Ensure DNF modules have the right stream\\\", \\\"vars\\\": {\\\"dnf_module_list\\\": []}, \\\"dnf\\\": {\\\"name\\\": \\\"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"loop\\\": \\\"{{ dnf_module_list|list }}\\\", \\\"when\\\": [\\\"dnf_module_list|length > 0\\\", \\\"item.distribution_version is defined\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\\\"]}, {\\\"name\\\": \\\"Ensure TripleO prerequisite packages are installed\\\", \\\"package\\\": {\\\"name\\\": [\\\"jq\\\", \\\"lvm2\\\", \\\"openstack-selinux\\\", \\\"os-net-config\\\", \\\"puppet-tripleo\\\", \\\"python3-heat-agent*\\\", \\\"rsync\\\"], \\\"state\\\": \\\"present\\\"}, \\\"when\\\": \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"}, {\\\"name\\\": \\\"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\\\", \\\"vars\\\": {\\\"base_tripleo_packages\\\": []}, \\\"package\\\": {\\\"name\\\": \\\"{{ base_tripleo_packages }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\", \\\"base_tripleo_packages|length > 0\\\"]}, {\\\"name\\\": \\\"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\\\", \\\"shell\\\": \\\"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\\\ndo\\\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\\\\\"signatures\\\\\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\\\ndone\\\\n\\\", \\\"when\\\": \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"}]}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"loop\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": [\\\"libvirt_installed.rc == 0\\\"]}]}, {\\\"name\\\": \\\"Host packages setup step2\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Special treatment for OpenvSwitch\\\", \\\"tripleo_ovs_upgrade\\\": null, \\\"register\\\": \\\"ovs_upgrade\\\"}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"ovs_upgrade.changed|bool\\\"]}]}, {\\\"name\\\": \\\"Host packages setup step3\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 3\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check for os-net-config upgrade\\\", \\\"shell\\\": \\\"yum check-upgrade | awk \'/os-net-config/{print}\'\\\", \\\"register\\\": \\\"os_net_config_need_upgrade\\\"}, {\\\"name\\\": \\\"Check that os-net-config has legacy configuration\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/os-net-config/config.json\\\", \\\"get_attributes\\\": false, \\\"get_checksum\\\": false, \\\"get_mime\\\": false}, \\\"register\\\": \\\"stat_config_json\\\"}, {\\\"name\\\": \\\"Check that os-net-config has new configuration\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/os-net-config/config.yaml\\\", \\\"get_attributes\\\": false, \\\"get_checksum\\\": false, \\\"get_mime\\\": false}, \\\"register\\\": \\\"stat_config_yaml\\\"}, {\\\"name\\\": \\\"Slurp the os-net-config config.json\\\", \\\"slurp\\\": {\\\"src\\\": \\\"/etc/os-net-config/config.json\\\"}, \\\"register\\\": \\\"os_config_json\\\", \\\"when\\\": [\\\"stat_config_json.stat.exists\\\", \\\"not stat_config_yaml.stat.exists\\\"]}, {\\\"name\\\": \\\"Write updated /etc/os-net-config/config.yaml\\\", \\\"copy\\\": {\\\"content\\\": \\\"{{ os_config_json.content | b64decode | from_json | to_yaml }}\\\", \\\"dest\\\": \\\"/etc/os-net-config/config.yaml\\\"}, \\\"when\\\": [\\\"stat_config_json.stat.exists\\\", \\\"not stat_config_yaml.stat.exists\\\"]}, {\\\"name\\\": \\\"Remove legacy os-net-config configuration\\\", \\\"command\\\": \\\"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\\\", \\\"when\\\": [\\\"stat_config_json.stat.exists\\\"]}, {\\\"block\\\": [{\\\"name\\\": \\\"Upgrade os-net-config\\\", \\\"package\\\": \\\"name=os-net-config state=latest\\\"}, {\\\"name\\\": \\\"take new os-net-config parameters into account now\\\", \\\"command\\\": \\\"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\\\", \\\"register\\\": \\\"os_net_config_upgrade\\\", \\\"failed_when\\\": \\\"os_net_config_upgrade.rc not in [0,2]\\\", \\\"changed_when\\\": \\\"os_net_config_upgrade.rc == 2\\\"}], \\\"when\\\": [\\\"os_net_config_need_upgrade.stdout\\\", \\\"stat_config_yaml.stat.exists or stat_config_json.stat.exists\\\"]}, {\\\"name\\\": \\\"Update all packages\\\", \\\"when\\\": [\\\"not skip_package_update|bool\\\"], \\\"yum\\\": {\\\"name\\\": \\\"*\\\", \\\"state\\\": \\\"latest\\\", \\\"exclude\\\": \\\"ansible-core\\\"}, \\\"vars\\\": {\\\"skip_package_update\\\": false}}, {\\\"name\\\": \\\"Check whether openvswitch exits\\\", \\\"command\\\": \\\"systemctl status openvswitch.service\\\", \\\"register\\\": \\\"ovs_service\\\", \\\"ignore_errors\\\": true}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"ovs_service.stderr != \\\\\\\"Unit openvswitch.service could not be found.\\\\\\\"\\\"]}]}], \\\"external_upgrade_tasks\\\": [{\\\"name\\\": \\\"Clean up upgrade artifacts\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_cleanup\\\"], \\\"block\\\": [{\\\"name\\\": \\\"cleanup tripleo_persist\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_persist\\\", \\\"tasks_from\\\": \\\"cleanup.yml\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Enforce RHOSP rules regarding subscription.\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_redhat_enforce\\\"}, \\\"vars\\\": {\\\"skip_rhel_enforcement\\\": false}, \\\"when\\\": [\\\"step|int == 0\\\", \\\"ansible_facts[\'distribution\'] == \'RedHat\'\\\", \\\"not (skip_rhel_enforcement | bool)\\\"]}, {\\\"name\\\": \\\"Ensure DNF modules have the right stream enabled\\\", \\\"vars\\\": {\\\"dnf_module_list\\\": []}, \\\"tripleo_dnf_stream\\\": {\\\"name\\\": \\\"{{ item.module }}:{{ item.stream }}\\\", \\\"state\\\": \\\"enabled\\\"}, \\\"loop\\\": \\\"{{ dnf_module_list|list }}\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"dnf_module_list|length > 0\\\", \\\"item.distribution_version is defined\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\\\"]}, {\\\"name\\\": \\\"Check for existing yum.pid\\\", \\\"stat\\\": \\\"path=/run/yum.pid\\\", \\\"register\\\": \\\"yum_pid_file\\\", \\\"when\\\": \\\"step|int == 0 or step|int == 3\\\"}, {\\\"name\\\": \\\"Exit if existing yum process\\\", \\\"fail\\\": \\\"msg=\\\\\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\\\\\"\\\", \\\"when\\\": \\\"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\\\"}, {\\\"name\\\": \\\"Special treatment for OpenvSwitch\\\", \\\"tripleo_ovs_upgrade\\\": null, \\\"when\\\": [\\\"step|int == 2\\\"], \\\"register\\\": \\\"ovs_upgrade\\\"}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"step|int == 2\\\", \\\"ovs_upgrade.changed|bool\\\"]}, {\\\"name\\\": \\\"Update packages and EFI grub.cfg\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"not skip_package_update|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Update all packages\\\", \\\"yum\\\": {\\\"name\\\": \\\"*\\\", \\\"state\\\": \\\"latest\\\", \\\"exclude\\\": \\\"ansible-core\\\"}}, {\\\"name\\\": \\\"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"efigrub.yml\\\"}}], \\\"vars\\\": {\\\"skip_package_update\\\": false}}, {\\\"name\\\": \\\"Ensure openvswitch is running after update\\\", \\\"when\\\": \\\"step|int == 3\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"ignore_errors\\\": true}]}, {\\\"service_name\\\": \\\"tuned\\\", \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tuned\\\"}}], \\\"ansible_group_vars\\\": {\\\"tuned_profile\\\": \\\"throughput-performance\\\", \\\"tuned_custom_profile\\\": \\\"\\\"}}, {\\\"service_name\\\": \\\"ovn_controller\\\", \\\"firewall_rules\\\": {\\\"118 neutron vxlan networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 4789, \\\"state\\\": []}, \\\"119 neutron geneve networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"state\\\": []}, \\\"120 neutron geneve networks no conntrack\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"table\\\": \\\"raw\\\", \\\"chain\\\": \\\"OUTPUT\\\", \\\"jump\\\": \\\"NOTRACK\\\", \\\"action\\\": \\\"append\\\", \\\"state\\\": [\\\"INVALID\\\"]}, \\\"121 neutron geneve networks no conntrack\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"table\\\": \\\"raw\\\", \\\"chain\\\": \\\"PREROUTING\\\", \\\"jump\\\": \\\"NOTRACK\\\", \\\"action\\\": \\\"append\\\", \\\"state\\\": [\\\"INVALID\\\"]}}, \\\"config_settings\\\": {\\\"ovn::controller::ovn_bridge_mappings\\\": [\\\"datacentre:br-ex\\\"], \\\"ovn::controller::ovn_cms_options\\\": \\\"\\\", \\\"ovn::controller::ovn_encap_tos\\\": \\\"0\\\", \\\"vswitch::ovs::enable_hw_offload\\\": false, \\\"container_cpuset_cpus\\\": \\\"\\\", \\\"ContainerOvnControllerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"ContainerOvnControllerConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"ovn::southbound::port\\\": 6642, \\\"ovn::controller::ovn_encap_ip\\\": \\\"%{hiera(\'tenant\')}\\\", \\\"ovn::controller::ovn_encap_type\\\": \\\"geneve\\\", \\\"ovn::controller::ovn_bridge\\\": \\\"br-int\\\", \\\"ovn::controller::hostname\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ovn::controller::ovn_remote_probe_interval\\\": 60000, \\\"ovn::controller::ovn_openflow_probe_interval\\\": 60, \\\"ovn::controller::ovn_ofctrl_wait_before_clear\\\": 8000, \\\"ovn::controller::garp_max_timeout_sec\\\": 0, \\\"ovn::controller::ovn_monitor_all\\\": true, \\\"tripleo::profile::base::neutron::agents::ovn::protocol\\\": \\\"ssl\\\"}, \\\"service_config_settings\\\": {}, \\\"puppet_config\\\": {\\\"puppet_tags\\\": \\\"vs_config,exec\\\", \\\"config_volume\\\": \\\"ovn_controller\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::agents::ovn\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"volumes\\\": [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/etc/sysconfig/modules:/etc/sysconfig/modules\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_controller.json\\\": {\\\"command\\\": \\\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock -p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C /etc/ipa/ca.crt\\\", \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/openvswitch\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/ovn\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"ovn_controller\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"docker_config\\\": {\\\"step_4\\\": {\\\"configure_cms_options\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\\\\\"$CMS_OPTS\\\\\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781337374\\\"}}, \\\"ovn_controller\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"openvswitch.service\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck 6642\\\"}, \\\"volumes\\\": [\\\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run:/run\\\", \\\"/var/lib/openvswitch/ovn:/run/ovn:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/openvswitch:z\\\", \\\"/var/log/containers/openvswitch:/var/log/ovn:z\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\\\", \\\"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_controller\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"ovn_controller/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"systemctl restart tripleo_ovn_controller\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/openvswitch\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/openvswitch/ovn\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"name\\\": \\\"Copy in cleanup script\\\", \\\"copy\\\": {\\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Cleanup neutron OVS bridges. To be called on startup to avoid\\\\n# \\\\\\\"difficult-to-debug\\\\\\\" issues with partially configured resources.\\\\n\\\\nNEUTRON_OVS_CONF=/var/lib/config-data/puppet-generated/neutron/etc/neutron/plugins/ml2/openvswitch_agent.ini\\\\n\\\\nif [ -e ${NEUTRON_OVS_CONF} ];\\\\nthen\\\\n    INT_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs integration_bridge`\\\\n    TUN_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs tunnel_bridge`\\\\nfi\\\\n\\\\nfor port in `ovs-vsctl list-ports ${INT_BRIDGE:-\\\\\\\"br-int\\\\\\\"}`;\\\\ndo\\\\n    skip_cleanup=`ovs-vsctl --if-exists get Interface $port external_ids:skip_cleanup`\\\\n    if ! [[ \\\\\\\"x$skip_cleanup\\\\\\\" == \\\\\\\"x\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\" ]];\\\\n    then\\\\n        ovs-vsctl del-port ${INT_BRIDGE:-\\\\\\\"br-int\\\\\\\"} $port\\\\n    fi\\\\ndone\\\\n\\\\novs-vsctl --if-exists del-br ${TUN_BRIDGE:-\\\\\\\"br-tun\\\\\\\"}\\\\n\\\\n# Clean up trunk port bridges\\\\nfor br in $(ovs-vsctl list-br | egrep \'tbr-[0-9a-f\\\\\\\\-]+\'); do\\\\n    ovs-vsctl --if-exists del-br $br\\\\ndone\\\\n\\\", \\\"dest\\\": \\\"/usr/libexec/neutron-cleanup\\\", \\\"force\\\": true, \\\"mode\\\": \\\"0755\\\"}}, {\\\"name\\\": \\\"Copy in cleanup service\\\", \\\"copy\\\": {\\\"content\\\": \\\"[Unit]\\\\nDescription=Neutron cleanup on startup\\\\nAfter=openvswitch.service network.target\\\\nBefore=tripleo_neutron_ovs_agent.service tripleo_neutron_dhcp.service tripleo_neutron_l3_agent.service tripleo_nova_compute.service\\\\nRefuseManualStop=yes\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/libexec/neutron-cleanup\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\", \\\"dest\\\": \\\"/usr/lib/systemd/system/neutron-cleanup.service\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Enabling the cleanup service\\\", \\\"service\\\": {\\\"name\\\": \\\"neutron-cleanup\\\", \\\"enabled\\\": true}, \\\"when\\\": \\\"not (ansible_check_mode|bool)\\\"}], \\\"external_deploy_tasks\\\": [{\\\"when\\\": [\\\"step|int == 0\\\"], \\\"name\\\": \\\"ovn_controller_external_deploy_init\\\", \\\"block\\\": [{\\\"name\\\": \\\"create ovn mac address for Compute role nodes\\\", \\\"tripleo_ovn_mac_addresses\\\": {\\\"playbook_dir\\\": \\\"{{ playbook_dir }}\\\", \\\"stack_name\\\": \\\"overcloud\\\", \\\"role_name\\\": \\\"Compute\\\", \\\"server_resource_names\\\": \\\"{{ groups[\\\\\\\"Compute\\\\\\\"] }}\\\", \\\"ovn_bridge_mappings\\\": [\\\"datacentre:br-ex\\\"], \\\"ovn_static_bridge_mac_mappings\\\": {}}}]}], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"become\\\": true, \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_controller_image_update\\\", \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Was the ovn_controller image pull successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovn_controller_image_update\\\"], \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_controller_image_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"OVN Container image used\\\", \\\"debug\\\": {\\\"msg\\\": \\\"ovn container will be using {{ image }}\\\"}, \\\"vars\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Update OVN OVS related parameters before update.\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true, \\\"vars\\\": {\\\"timeout\\\": 8000}, \\\"shell\\\": \\\"set -e\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\\\n\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovs_vsctl\\\", \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"name\\\": \\\"Was the update of OVN OVS related parameter successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovs_vsctl\\\"], \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\"], \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovs_vsctl.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"set_fact\\\": {\\\"any_ovn_host\\\": \\\"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\\\"}, \\\"tags\\\": \\\"ovn\\\", \\\"when\\\": \\\"step|int == 1\\\"}, {\\\"name\\\": \\\"Find ovn_controller configs in container-startup-configs\\\", \\\"find\\\": {\\\"paths\\\": \\\"/var/lib/tripleo-config/container-startup-config/\\\", \\\"patterns\\\": \\\"*ovn_controller.json\\\", \\\"recurse\\\": true}, \\\"register\\\": \\\"ovn_cont_17_0\\\", \\\"delegate_to\\\": \\\"{{ any_ovn_host }}\\\", \\\"when\\\": \\\"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\\\", \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true}, {\\\"name\\\": \\\"get directory path from the ovn_cont_17_0\\\", \\\"set_fact\\\": {\\\"ovn_config_path\\\": \\\"{{ ovn_cont_17_0.files.0.path | dirname }}\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Get PIDfile used by systemd on each ovn node\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"set -e\\\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\\\n\\\", \\\"register\\\": \\\"pidfile\\\", \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"name\\\": \\\"Update ovn_controller.\\\", \\\"vars\\\": {\\\"config_step\\\": \\\"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\\\", \\\"query\\\": \\\"results[?item == \'{{item}}\'].stdout\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\", \\\"become\\\": true, \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_controller_update\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"{{ ovn_config_path }}\\\", \\\"config_patterns\\\": \\\"*ovn_controller.json\\\", \\\"config_id\\\": [\\\"tripleo_step{{config_step}}\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\".*ovn_controller\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"conmon_pidfile\\\": \\\"{{ pidfile | json_query(query) | first }}\\\", \\\"name\\\": \\\"ovn_controller\\\"}}}}, {\\\"name\\\": \\\"Was the ovn_controller successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovn_controller_update\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_controller_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"Pause for 30s to give ovn_controllers time to reconnect to dbs\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Fetch running ovn_controller image\\\", \\\"shell\\\": \\\"set -e\\\\npodman inspect --format \\\\\\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\\\\\" ovn_controller\\\\n\\\", \\\"register\\\": \\\"running_ovn_image\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"]}, {\\\"name\\\": \\\"Run ovn_controller upgrade\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"vars\\\": {\\\"ovn_controller_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\"}, \\\"when\\\": [\\\"step|int == 4\\\", \\\"running_ovn_image.stdout != ovn_controller_image\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Update OVN OVS related parameters before update.\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"vars\\\": {\\\"timeout\\\": 8000}, \\\"shell\\\": \\\"set -e\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\\\n\\\"}, {\\\"name\\\": \\\"Find ovn_controller configs in container-startup-configs\\\", \\\"find\\\": {\\\"paths\\\": \\\"/var/lib/tripleo-config/container-startup-config/\\\", \\\"patterns\\\": \\\"*ovn_controller.json\\\", \\\"recurse\\\": true}, \\\"register\\\": \\\"ovn_cont_17_0\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"]}, {\\\"name\\\": \\\"get directory path from the ovn_cont_17_0\\\", \\\"set_fact\\\": {\\\"ovn_config_path\\\": \\\"{{ ovn_cont_17_0.files.0.path | dirname }}\\\"}, \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Get PIDfile used by systemd on each ovn node\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"shell\\\": \\\"set -e\\\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\\\n\\\", \\\"register\\\": \\\"pidfile\\\"}, {\\\"name\\\": \\\"Update ovn_controller.\\\", \\\"vars\\\": {\\\"config_step\\\": \\\"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\\\"}, \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": \\\"ovn\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"{{ ovn_config_path }}\\\", \\\"config_patterns\\\": \\\"*ovn_controller.json\\\", \\\"config_id\\\": [\\\"tripleo_step{{config_step}}\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\".*ovn_controller\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"conmon_pidfile\\\": \\\"{{ pidfile.stdout }}\\\", \\\"name\\\": \\\"ovn_controller\\\"}}}}, {\\\"name\\\": \\\"Pause for 30s to give ovn_controllers time to reconnect to dbs\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}]}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": \\\"overcloud\\\"}, \\\"block\\\": [{\\\"name\\\": \\\"Get neutron agents ID\\\", \\\"command\\\": \\\"openstack network agent list --column ID --column Host --column Binary --format yaml\\\", \\\"register\\\": \\\"neutron_agents_result\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"Filter only current host\\\", \\\"set_fact\\\": {\\\"neutron_agents\\\": \\\"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"Deleting OVN agents\\\", \\\"block\\\": [{\\\"name\\\": \\\"Stop OVN containers\\\", \\\"loop\\\": [\\\"tripleo_ovn_controller\\\", \\\"tripleo_ovn_metadata_agent\\\"], \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"become\\\": true, \\\"register\\\": \\\"stop_containers\\\", \\\"failed_when\\\": \\\"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\\\"}, {\\\"name\\\": \\\"Delete neutron agents\\\", \\\"loop\\\": \\\"{{ neutron_agents }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"agent\\\", \\\"label\\\": \\\"{{ agent.Host }}/{{ agent.Binary }}\\\"}, \\\"command\\\": \\\"openstack network agent delete {{ agent.ID }}\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}]}]}]}, {\\\"service_name\\\": \\\"ovn_metadata\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ovn-metadata\\\", \\\"config_settings\\\": {\\\"neutron::notification_driver\\\": [\\\"noop\\\"], \\\"neutron::core_plugin\\\": \\\"ml2\\\", \\\"neutron::service_plugins\\\": [\\\"qos\\\", \\\"ovn-router\\\", \\\"trunk\\\", \\\"segments\\\", \\\"port_forwarding\\\", \\\"log\\\"], \\\"neutron::report_interval\\\": 300, \\\"neutron::logging::debug\\\": true, \\\"neutron::purge_config\\\": false, \\\"neutron::allow_overlapping_ips\\\": true, \\\"neutron::dhcp_agent_notification\\\": false, \\\"neutron::dns_domain\\\": \\\"ooo.test\\\", \\\"neutron::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"neutron::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"neutron::db::database_db_max_retries\\\": -1, \\\"neutron::db::database_max_retries\\\": -1, \\\"neutron::db::sync::db_sync_timeout\\\": 900, \\\"neutron::global_physnet_mtu\\\": 1350, \\\"neutron::db::sync::extra_params\\\": \\\"\\\", \\\"neutron::vlan_transparent\\\": false, \\\"neutron::rabbit_heartbeat_in_pthread\\\": false, \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\\\": true, \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\\\": \\\"/var/lib/neutron/ovn_metadata_haproxy_wrapper\\\", \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\\\": true, \\\"tripleo::profile::base::neutron::container_cli\\\": \\\"podman\\\", \\\"neutron::agents::ovn_metadata::shared_secret\\\": \\\"9YON7EEIL9wZNadx52fLDIzpR\\\", \\\"neutron::agents::ovn_metadata::auth_password\\\": \\\"ynYFMrrhBYym7oMTANCe2Hdxj\\\", \\\"neutron::agents::ovn_metadata::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"neutron::agents::ovn_metadata::auth_tenant\\\": \\\"service\\\", \\\"neutron::agents::ovn_metadata::metadata_host\\\": \\\"overcloud.internalapi.ooo.test\\\", \\\"neutron::agents::ovn_metadata::ovsdb_connection_timeout\\\": 180, \\\"neutron::agents::ovn_metadata::ovsdb_probe_interval\\\": 60000, \\\"neutron::agents::ovn_metadata::hwol_qos_enabled\\\": false, \\\"ovn::northbound::port\\\": 6641, \\\"ovn::southbound::port\\\": 6642, \\\"neutron::agents::ovn_metadata::debug\\\": true, \\\"neutron::agents::ovn_metadata::metadata_protocol\\\": \\\"https\\\", \\\"neutron::agents::ovn_metadata::metadata_workers\\\": \\\"1\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::protocol\\\": \\\"ssl\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\"}, \\\"puppet_config\\\": {\\\"puppet_tags\\\": \\\"neutron_config,ovn_metadata_agent_config\\\", \\\"config_volume\\\": \\\"neutron\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::ovn_metadata\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\\\", \\\"volumes\\\": [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_metadata_agent.json\\\": {\\\"command\\\": \\\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini --log-file=/var/log/neutron/ovn-metadata-agent.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/lib/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"create_haproxy_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/var/lib/neutron:/var/lib/neutron:shared,z\\\"]}}, \\\"step_4\\\": {\\\"setup_ovs_manager\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"exec\\\", \\\"include tripleo::profile::base::neutron::ovn_metadata\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781337374\\\"}}, \\\"ovn_metadata_agent\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"cgroupns\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/neutron:/var/log/neutron:z\\\", \\\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/var/lib/neutron:/var/lib/neutron:shared,z\\\", \\\"/run/netns:/run/netns:shared\\\", \\\"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\\\", \\\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\\\", \\\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"ovn_metadata\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_metadata\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"ovn_metadata/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"systemctl restart tripleo_ovn_metadata_agent\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/neutron\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"create /run/netns with temp namespace\\\", \\\"command\\\": \\\"ip netns add ns_temp\\\", \\\"register\\\": \\\"ipnetns_add_result\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"remove temp namespace\\\", \\\"command\\\": \\\"ip netns delete ns_temp\\\", \\\"failed_when\\\": false, \\\"when\\\": [\\\"ipnetns_add_result.rc is defined\\\", \\\"ipnetns_add_result.rc == 0\\\"]}, {\\\"name\\\": \\\"create /var/lib/neutron\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/neutron\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}, {\\\"name\\\": \\\"set conditions\\\", \\\"set_fact\\\": {\\\"haproxy_wrapper_enabled\\\": true, \\\"debug_enabled\\\": true, \\\"docker_additional_sockets\\\": [\\\"/var/lib/openstack/docker.sock\\\"]}}, {\\\"name\\\": \\\"create kill_scripts directory within /var/lib/neutron\\\", \\\"file\\\": {\\\"state\\\": \\\"directory\\\", \\\"path\\\": \\\"/var/lib/neutron/kill_scripts\\\"}}, {\\\"name\\\": \\\"create haproxy kill script\\\", \\\"when\\\": \\\"haproxy_wrapper_enabled|bool\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/var/lib/neutron/kill_scripts/haproxy-kill\\\", \\\"mode\\\": 493, \\\"content\\\": \\\"#!/bin/bash\\\\n{% if debug_enabled|bool -%}\\\\nset -x\\\\n{% endif -%}\\\\nadd_date() {\\\\n  echo \\\\\\\"$(date) $@\\\\\\\"\\\\n}\\\\n\\\\n# Set up script logging for debugging purpose.\\\\n# It will be taken care of by logrotate since there is the .log\\\\n# suffix.\\\\nexec 3>&1 4>&2\\\\ntrap \'exec 2>&4 1>&3\' 0 1 2 3\\\\nexec 1>>/var/log/neutron/kill-script.log 2>&1\\\\n\\\\nSIG=$1\\\\nPID=$2\\\\nNETNS=$(ip netns identify ${PID})\\\\n\\\\nif [ \\\\\\\"x${NETNS}\\\\\\\" == \\\\\\\"x\\\\\\\" ]; then\\\\n  CLI=\\\\\\\"nsenter --all --preserve-credentials -t 1 podman\\\\\\\"\\\\n  SIG=9\\\\nelse\\\\n  CLI=\\\\\\\"nsenter --net=/run/netns/${NETNS} --preserve-credentials -m -t 1 podman\\\\\\\"\\\\nfi\\\\n\\\\nkill_container() {\\\\n  add_date \\\\\\\"Killing container $1 ($2)\\\\\\\"\\\\n  signal_container $1 $2 9\\\\n}\\\\n\\\\nstop_container() {\\\\n  add_date \\\\\\\"Stopping container $1 ($2)\\\\\\\"\\\\n  $CLI stop $2\\\\n}\\\\n\\\\nsignal_container() {\\\\n  SIGNAL=$3\\\\n  if [ -z \\\\\\\"$SIGNAL\\\\\\\" ]; then\\\\n      SIGNAL=\\\\\\\"HUP\\\\\\\"\\\\n  fi\\\\n  add_date \\\\\\\"Sending signal \'$SIGNAL\' to $1 ($2)\\\\\\\"\\\\n  $CLI kill --signal $SIGNAL $2\\\\n}\\\\n\\\\ndelete_container() {\\\\n  add_date \\\\\\\"Deleting container $1 ($2)\\\\\\\"\\\\n  $CLI rm $2 || echo \\\\\\\"Deleting container $1 ($2) failed\\\\\\\"\\\\n}\\\\n\\\\n\\\\n{% raw -%}\\\\nif [ -f /proc/$PID/cgroup ]; then\\\\n  # Get container ID based on process cgroups\\\\n  CT_ID=$(awk \'BEGIN {FS=\\\\\\\".scope|-\\\\\\\"} /\\\\\\\\/libpod-/ {if ($(NF-1)) print $(NF-1);exit}\' /proc/$PID/cgroup)\\\\n  CT_NAME=$($CLI inspect -f \'{{.Name}}\' $CT_ID)\\\\n\\\\n  case $SIG in\\\\n    HUP)\\\\n      signal_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    9)\\\\n      kill_container $CT_NAME $CT_ID\\\\n      delete_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    15)\\\\n      stop_container $CT_NAME $CT_ID\\\\n      delete_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    *)\\\\n      add_date \\\\\\\"Unknown action ${SIG} for ${CT_NAME} ${CT_ID}\\\\\\\"\\\\n      exit 1\\\\n      ;;\\\\n  esac\\\\n\\\\nelse\\\\n  add_date \\\\\\\"No such PID: ${PID}\\\\\\\"\\\\n  exit 1\\\\nfi\\\\n{% endraw %}\\\\n\\\"}}], \\\"upgrade_tasks\\\": [], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Check if python3-openvswitch3.1 workaround is needed\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\\\n\\\", \\\"register\\\": \\\"metadata_python_ovs_3_1\\\", \\\"failed_when\\\": false, \\\"loop\\\": \\\"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}, {\\\"name\\\": \\\"Update ovn_metadata_agents\\\", \\\"vars\\\": {\\\"hosts_to_update_metadata\\\": \\\"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\\\"}, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"hosts_to_update_metadata | length > 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"become\\\": true, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_metadata_image_update\\\", \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Was the ovn_metadata_agent image pull successful.\\\", \\\"when\\\": [\\\"\'results\' in ovn_metadata_image_update\\\"], \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_metadata_image_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"Now rotate all ovn_metadata_agents\\\", \\\"tags\\\": [\\\"ovn_metadata_parallel\\\"], \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"ovn_metadata_agent\\\"], \\\"config_patterns\\\": \\\"*ovn_metadata_agent.json\\\", \\\"config_overrides\\\": {\\\".*ovn_metadata_agent\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"name\\\": \\\"ovn_metadata_agent\\\"}}}, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0}]}, {\\\"name\\\": \\\"Now rotate all ovn_metadata_agents\\\", \\\"vars\\\": {\\\"hosts_to_update_metadata\\\": \\\"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\\\"}, \\\"tags\\\": [\\\"never\\\", \\\"ovn_metadata_serial\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"hosts_to_update_metadata | length > 0\\\"], \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"ovn_metadata_agent\\\"], \\\"config_patterns\\\": \\\"*ovn_metadata_agent.json\\\", \\\"config_overrides\\\": {\\\".*ovn_metadata_agent\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"name\\\": \\\"ovn_metadata_agent\\\"}}}, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"loop_control\\\": {\\\"pause\\\": 1}}]}]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(196,'2026-06-13 07:57:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(197,'2026-06-13 07:57:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat CloudWatch API service, disabled by default since Pike\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the disabled Heat CloudWatch API\", \"value\": {\"service_name\": \"heat_api_cloudwatch_disabled\", \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(198,'2026-06-13 07:57:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Keystone service\\n\", \"parameters\": {\"ContainerKeystoneImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}, \"ContainerKeystoneConfigImage\": {\"description\": \"The container image to use for the keystone config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\"}, \"KeystoneTokenProvider\": {\"description\": \"The keystone token format\", \"type\": \"string\", \"default\": \"fernet\", \"constraints\": [{\"allowed_values\": [\"fernet\"]}]}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"PublicTLSCAFile\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the public network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"KeystoneSSLCertificate\": {\"default\": \"\", \"description\": \"Keystone certificate for verifying token validity.\", \"type\": \"string\"}, \"KeystoneSSLCertificateKey\": {\"default\": \"\", \"description\": \"Keystone key for signing tokens.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneNotificationFormat\": {\"description\": \"The Keystone notification format\", \"default\": \"basic\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"basic\", \"cadf\"]}]}, \"KeystoneNotificationTopics\": {\"description\": \"Keystone notification topics to enable\", \"default\": [], \"type\": \"comma_delimited_list\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"KeystoneDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Keystone service.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"AdminToken\": {\"description\": \"The keystone auth secret and db password.\", \"type\": \"string\", \"hidden\": true, \"default\": \"JbpiTehj2VnTm8w0BPor698KI\"}, \"TokenExpiration\": {\"default\": 3600, \"description\": \"Set a token expiration time in seconds.\", \"type\": \"number\"}, \"KeystoneWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for keystone::wsgi::apache\", \"default\": 1}, \"MonitoringSubscriptionKeystone\": {\"default\": \"overcloud-keystone\", \"type\": \"string\"}, \"KeystoneCredential0\": {\"type\": \"string\", \"description\": \"The first Keystone credential key. Must be a valid key.\", \"default\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\"}, \"KeystoneCredential1\": {\"type\": \"string\", \"description\": \"The second Keystone credential key. Must be a valid key.\", \"default\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\"}, \"KeystoneFernetKeys\": {\"type\": \"json\", \"description\": \"Mapping containing keystone\'s fernet keys and their paths.\", \"default\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}}, \"KeystoneFernetMaxActiveKeys\": {\"type\": \"number\", \"description\": \"The maximum active keys in the keystone fernet key repository.\", \"default\": 5}, \"ManageKeystoneFernetKeys\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Whether TripleO should manage the keystone fernet keys or not. If set to true, the fernet keys will get the values from the saved keys repository in mistral (the KeystoneFernetKeys variable). If set to false, only the stack creation initializes the keys, but subsequent updates won\'t touch them.\"}, \"KeystoneLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.keystone\", \"file\": \"/var/log/containers/keystone/keystone.log\"}}, \"KeystonePolicies\": {\"description\": \"A hash of policies to configure for Keystone.\\ne.g. { keystone-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"KeystoneLDAPDomainEnable\": {\"description\": \"Trigger to call ldap_backend puppet keystone define.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneLDAPBackendConfigs\": {\"description\": \"Hash containing the configurations for the LDAP backends configured in keystone.\", \"type\": \"json\", \"default\": {}, \"hidden\": true}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"KeystoneNotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Driver or drivers to handle sending notifications. This parameter is\\nspecific to Keystone.\\n\"}, \"KeystoneEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Keystone database.\\n\", \"type\": \"boolean\"}, \"KeystoneCronTrustFlushEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Ensure\\n\", \"default\": \"present\"}, \"KeystoneCronTrustFlushMinute\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Minute\\n\", \"default\": \"1\"}, \"KeystoneCronTrustFlushHour\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Hour\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Month Day\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMonth\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Month\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Week Day\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMaxDelay\": {\"type\": \"number\", \"description\": \"Cron to purge expired or soft-deleted trusts - Max Delay\\n\", \"default\": 0}, \"KeystoneCronTrustFlushDestination\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Log destination\\n\", \"default\": \"/var/log/keystone/keystone-trustflush.log\"}, \"KeystoneCronTrustFlushUser\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - User\\n\", \"default\": \"keystone\"}, \"KeystoneChangePasswordUponFirstUse\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Enabling this option requires users to change their password when the user is created, or upon administrative reset.\", \"constraints\": [{\"allowed_values\": [\"\", \"true\", \"True\", \"TRUE\", \"false\", \"False\", \"FALSE\"]}]}, \"KeystoneDisableUserAccountDaysInactive\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The maximum number of days a user can go without authenticating before being considered \\\"inactive\\\" and automatically disabled (locked).\"}, \"KeystoneLockoutDuration\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of seconds a user account will be locked when the maximum number of failed authentication attempts (as specified by KeystoneLockoutFailureAttempts) is exceeded.\"}, \"KeystoneLockoutFailureAttempts\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The maximum number of times that a user can fail to authenticate before the user account is locked for the number of seconds specified by KeystoneLockoutDuration.\"}, \"KeystoneMinimumPasswordAge\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of days that a password must be used before the user can change it. This prevents users from changing their passwords immediately in order to wipe out their password history and reuse an old password.\"}, \"KeystonePasswordExpiresDays\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of days for which a password will be considered valid before requiring it to be changed.\"}, \"KeystonePasswordRegex\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The regular expression used to validate password strength requirements.\"}, \"KeystonePasswordRegexDescription\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Describe your password regular expression here in language for humans.\"}, \"KeystoneUniqueLastPasswordCount\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This controls the number of previous user password iterations to keep in history, in order to enforce that newly created passwords are unique.\"}, \"KeystoneCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"KeystoneEnableMember\": {\"description\": \"Create the _member_ role, useful for undercloud deployment.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneFederationEnable\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable support for federated authentication.\"}, \"KeystoneTrustedDashboards\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"A list of dashboard URLs trusted for single sign-on.\"}, \"KeystoneAuthMethods\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"A list of methods used for authentication.\"}, \"KeystoneOpenIdcEnable\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable support for OpenIDC federation.\"}, \"KeystoneOpenIdcIdpName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The name associated with the IdP in Keystone.\"}, \"KeystoneOpenIdcProviderMetadataUrl\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The url that points to your OpenID Connect provider metadata\"}, \"KeystoneOpenIdcClientId\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The client ID to use when handshaking with your OpenID Connect provider\"}, \"KeystoneOpenIdcClientSecret\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The client secret to use when handshaking with your OpenID Connect provider\"}, \"KeystoneOpenIdcCryptoPassphrase\": {\"type\": \"string\", \"default\": \"openstack\", \"description\": \"Passphrase to use when encrypting data for OpenID Connect handshake.\"}, \"KeystoneOpenIdcOutgoingProxy\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The outgoing proxy to use for OpenID connections.\"}, \"KeystoneOpenIdcResponseType\": {\"type\": \"string\", \"default\": \"id_token\", \"description\": \"Response type to be expected from the OpenID Connect provider.\"}, \"KeystoneOpenIdcRemoteIdAttribute\": {\"type\": \"string\", \"default\": \"OIDC-iss\", \"description\": \"Attribute to be used to obtain the entity ID of the Identity Provider from the environment.\"}, \"KeystoneOpenIdcEnableOAuth\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable OAuth 2.0 integration.\"}, \"KeystoneOpenIdcIntrospectionEndpoint\": {\"type\": \"string\", \"default\": \"\", \"description\": \"OAuth 2.0 introspection endpoint for mod_auth_openidc\"}, \"KeystoneOpenIdcClaimDelimiter\": {\"type\": \"string\", \"default\": \";\", \"description\": \"The delimiter to use when setting multi-valued claims.\"}, \"KeystoneOpenIdcPassUserInfoAs\": {\"type\": \"string\", \"default\": \"claims\", \"description\": \"Define the way(s) in which the claims resolved from the userinfo endpoint are passed to the application according to OIDCPassClaimsAs.\", \"constraints\": [{\"allowed_values\": [\"claims\", \"json\", \"jwt\"]}]}, \"KeystoneOpenIdcPassClaimsAs\": {\"type\": \"string\", \"default\": \"both\", \"description\": \"Define the way in which the claims and tokens are passed to the application environment: \\\"none\\\": no claims/tokens are passed \\\"environment\\\": claims/tokens are passed as environment variables \\\"headers\\\": claims/tokens are passed in headers (also useful in reverse proxy scenario\'s) \\\"both\\\": claims/tokens are passed as both headers as well as environment variables (default)\", \"constraints\": [{\"allowed_values\": [\"none\", \"environment\", \"headers\", \"both\"]}]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"KeystoneLogging\": {\"type\": \"OS::TripleO::Services::Logging::Keystone\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerKeystoneImage\": \"ContainerKeystoneImage\", \"ContainerKeystoneConfigImage\": \"ContainerKeystoneConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerKeystoneImage\": {\"get_param\": \"ContainerKeystoneImage\"}, \"ContainerKeystoneConfigImage\": {\"get_param\": \"ContainerKeystoneConfigImage\"}}}]}}}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}, \"keystone_fernet_tokens\": {\"equals\": [{\"get_param\": \"KeystoneTokenProvider\"}, \"fernet\"]}, \"nontls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"not\": {\"get_param\": \"MemcachedTLS\"}}]}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"keystone_outgoing_proxy\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"KeystoneOpenIdcOutgoingProxy\"}, \"\"]}}, {\"get_param\": \"KeystoneOpenIdcEnable\"}]}, \"change_password_upon_first_use_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneChangePasswordUponFirstUse\"}, \"\"]}}, \"disable_user_account_days_inactive_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneDisableUserAccountDaysInactive\"}, \"\"]}}, \"lockout_duration_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneLockoutDuration\"}, \"\"]}}, \"lockout_failure_attempts_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneLockoutFailureAttempts\"}, \"\"]}}, \"minimum_password_age_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneMinimumPasswordAge\"}, \"\"]}}, \"password_expires_days_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordExpiresDays\"}, \"\"]}}, \"password_regex_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordRegex\"}, \"\"]}}, \"password_regex_description_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordRegexDescription\"}, \"\"]}}, \"unique_last_password_count_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneUniqueLastPasswordCount\"}, \"\"]}}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneCorsAllowedOrigin\"}, \"\"]}}, \"keystone_notification_driver_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneNotificationDriver\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Keystone API role.\", \"value\": {\"service_name\": \"keystone\", \"firewall_rules\": {\"111 keystone\": {\"dport\": [5000, {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 keystone_public_haproxy_frontend\": {\"dport\": [5000]}, \"100 keystone_admin_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}]}}, \"firewall_ssl_frontend_rules\": {\"100 keystone_public_haproxy_frontend_ssl\": {\"dport\": [13000]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionKeystone\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"if\": [\"cors_allowed_origin_set\", {\"keystone::cors::allowed_origin\": {\"get_param\": \"KeystoneCorsAllowedOrigin\"}}]}, {\"keystone::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"keystone\", \"password\": {\"get_param\": \"AdminToken\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/keystone\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"keystone\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"keystone::token_expiration\": {\"get_param\": \"TokenExpiration\"}, \"keystone::policy::policies\": {\"get_param\": \"KeystonePolicies\"}, \"keystone_ssl_certificate\": {\"get_param\": \"KeystoneSSLCertificate\"}, \"keystone_ssl_certificate_key\": {\"get_param\": \"KeystoneSSLCertificateKey\"}, \"keystone::token_provider\": {\"get_param\": \"KeystoneTokenProvider\"}, \"keystone::enable_fernet_setup\": {\"if\": [\"keystone_fernet_tokens\", true, false]}, \"keystone::fernet_max_active_keys\": {\"get_param\": \"KeystoneFernetMaxActiveKeys\"}, \"keystone::enable_proxy_headers_parsing\": true, \"keystone::enable_credential_setup\": true, \"keystone::credential_keys\": {\"/etc/keystone/credential-keys/0\": {\"content\": {\"get_param\": \"KeystoneCredential0\"}}, \"/etc/keystone/credential-keys/1\": {\"content\": {\"get_param\": \"KeystoneCredential1\"}}}, \"keystone::fernet_keys\": {\"get_param\": \"KeystoneFernetKeys\"}, \"keystone::fernet_replace_keys\": {\"get_param\": \"ManageKeystoneFernetKeys\"}, \"keystone::logging::debug\": {\"if\": [{\"get_param\": \"KeystoneDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"keystone::notification_driver\": {\"if\": [\"keystone_notification_driver_set\", {\"get_param\": \"KeystoneNotificationDriver\"}, {\"get_param\": \"NotificationDriver\"}]}, \"keystone::notification_format\": {\"get_param\": \"KeystoneNotificationFormat\"}, \"tripleo::profile::base::keystone::extra_notification_topics\": {\"get_param\": \"KeystoneNotificationTopics\"}, \"keystone_enable_db_purge\": {\"get_param\": \"KeystoneEnableDBPurge\"}, \"keystone::cron::trust_flush::ensure\": {\"get_param\": \"KeystoneCronTrustFlushEnsure\"}, \"keystone::cron::trust_flush::minute\": {\"get_param\": \"KeystoneCronTrustFlushMinute\"}, \"keystone::cron::trust_flush::hour\": {\"get_param\": \"KeystoneCronTrustFlushHour\"}, \"keystone::cron::trust_flush::monthday\": {\"get_param\": \"KeystoneCronTrustFlushMonthday\"}, \"keystone::cron::trust_flush::month\": {\"get_param\": \"KeystoneCronTrustFlushMonth\"}, \"keystone::cron::trust_flush::weekday\": {\"get_param\": \"KeystoneCronTrustFlushWeekday\"}, \"keystone::cron::trust_flush::maxdelay\": {\"get_param\": \"KeystoneCronTrustFlushMaxDelay\"}, \"keystone::cron::trust_flush::destination\": {\"get_param\": \"KeystoneCronTrustFlushDestination\"}, \"keystone::cron::trust_flush::user\": {\"get_param\": \"KeystoneCronTrustFlushUser\"}, \"keystone::rabbit_heartbeat_timeout_threshold\": 60, \"keystone::rabbit_heartbeat_in_pthread\": false, \"keystone::service_name\": \"httpd\", \"keystone::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"keystone::wsgi::apache::api_port\": [5000, {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}], \"keystone::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"keystone::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}}}, \"keystone::wsgi::apache::workers\": {\"get_param\": \"KeystoneWorkers\"}, \"keystone::wsgi::apache::threads\": 1, \"keystone::db::database_db_max_retries\": -1, \"keystone::db::database_max_retries\": -1, \"keystone::wsgi::apache::bind_host\": [{\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}}}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}}}]}, {\"keystone::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"keystone::cache::backend_argument\": [{\"str_replace\": {\"template\": \"memcached_expire_time: $EXPIRATION\", \"params\": {\"$EXPIRATION\": {\"get_param\": \"TokenExpiration\"}}}}], \"keystone::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"keystone::cache::backend\": \"dogpile.cache.pymemcache\", \"keystone::token_caching\": true}, {\"keystone::cache::backend\": \"dogpile.cache.memcached\"}]}, {\"if\": [{\"get_param\": \"KeystoneFederationEnable\"}, {\"keystone_federation_enabled\": true, \"keystone::federation::trusted_dashboards\": {\"get_param\": \"KeystoneTrustedDashboards\"}}]}, {\"if\": [{\"get_param\": \"KeystoneOpenIdcEnable\"}, {\"keystone_openidc_enabled\": true, \"keystone::federation::openidc::methods\": {\"get_param\": \"KeystoneAuthMethods\"}, \"keystone::federation::openidc::keystone_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"keystone::federation::openidc::idp_name\": {\"get_param\": \"KeystoneOpenIdcIdpName\"}, \"keystone::federation::openidc::openidc_provider_metadata_url\": {\"get_param\": \"KeystoneOpenIdcProviderMetadataUrl\"}, \"keystone::federation::openidc::openidc_client_id\": {\"get_param\": \"KeystoneOpenIdcClientId\"}, \"keystone::federation::openidc::openidc_client_secret\": {\"get_param\": \"KeystoneOpenIdcClientSecret\"}, \"keystone::federation::openidc::openidc_crypto_passphrase\": {\"get_param\": \"KeystoneOpenIdcCryptoPassphrase\"}, \"keystone::federation::openidc::openidc_response_type\": {\"get_param\": \"KeystoneOpenIdcResponseType\"}, \"keystone::federation::openidc::remote_id_attribute\": {\"get_param\": \"KeystoneOpenIdcRemoteIdAttribute\"}, \"keystone::federation::openidc::openidc_enable_oauth\": {\"get_param\": \"KeystoneOpenIdcEnableOAuth\"}, \"keystone::federation::openidc::openidc_introspection_endpoint\": {\"get_param\": \"KeystoneOpenIdcIntrospectionEndpoint\"}, \"keystone::federation::openidc::openidc_pass_userinfo_as\": {\"get_param\": \"KeystoneOpenIdcPassUserInfoAs\"}, \"keystone::federation::openidc::openidc_pass_claim_as\": {\"get_param\": \"KeystoneOpenIdcPassClaimsAs\"}, \"keystone::federation::openidc::openidc_claim_delimiter\": {\"get_param\": \"KeystoneOpenIdcClaimDelimiter\"}, \"keystone::federation::openidc::openidc_cache_type\": {\"if\": [\"nontls_cache_enabled\", \"memcache\"]}}]}, {\"if\": [\"keystone_outgoing_proxy\", {\"keystone::federation::openidc::openidc_outgoing_proxy\": {\"get_param\": \"KeystoneOpenIdcOutgoingProxy\"}}]}, {\"if\": [{\"get_param\": \"KeystoneLDAPDomainEnable\"}, {\"tripleo::profile::base::keystone::ldap_backend_enable\": true, \"keystone::using_domain_config\": true, \"tripleo::profile::base::keystone::ldap_backends_config\": {\"get_param\": \"KeystoneLDAPBackendConfigs\"}}]}, {\"if\": [\"change_password_upon_first_use_set\", {\"keystone::security_compliance::change_password_upon_first_use\": {\"get_param\": \"KeystoneChangePasswordUponFirstUse\"}}]}, {\"if\": [\"disable_user_account_days_inactive_set\", {\"keystone::security_compliance::disable_user_account_days_inactive\": {\"get_param\": \"KeystoneDisableUserAccountDaysInactive\"}}]}, {\"if\": [\"lockout_duration_set\", {\"keystone::security_compliance::lockout_duration\": {\"get_param\": \"KeystoneLockoutDuration\"}}]}, {\"if\": [\"lockout_failure_attempts_set\", {\"keystone::security_compliance::lockout_failure_attempts\": {\"get_param\": \"KeystoneLockoutFailureAttempts\"}}]}, {\"if\": [\"minimum_password_age_set\", {\"keystone::security_compliance::minimum_password_age\": {\"get_param\": \"KeystoneMinimumPasswordAge\"}}]}, {\"if\": [\"password_expires_days_set\", {\"keystone::security_compliance::password_expires_days\": {\"get_param\": \"KeystonePasswordExpiresDays\"}}]}, {\"if\": [\"password_regex_set\", {\"keystone::security_compliance::password_regex\": {\"get_param\": \"KeystonePasswordRegex\"}}]}, {\"if\": [\"password_regex_description_set\", {\"keystone::security_compliance::password_regex_description\": {\"get_param\": \"KeystonePasswordRegexDescription\"}}]}, {\"if\": [\"unique_last_password_count_set\", {\"keystone::security_compliance::unique_last_password_count\": {\"get_param\": \"KeystoneUniqueLastPasswordCount\"}}]}, {\"apache::default_vhost\": false}, {\"get_attr\": [\"KeystoneLogging\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_keystone\": {\"get_param\": \"KeystoneLoggingSource\"}}, \"mysql\": {\"keystone::db::mysql::password\": {\"get_param\": \"AdminToken\"}, \"keystone::db::mysql::user\": \"keystone\", \"keystone::db::mysql::host\": \"%\", \"keystone::db::mysql::dbname\": \"keystone\"}, \"pacemaker\": {\"keystone::endpoint::public_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"keystone::endpoint::internal_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"keystone::endpoint::admin_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"keystone::endpoint::region\": {\"get_param\": \"KeystoneRegion\"}, \"keystone::admin_password\": {\"get_param\": \"AdminPassword\"}}, \"horizon\": {\"if\": [{\"get_param\": \"KeystoneLDAPDomainEnable\"}, {\"horizon::keystone_multidomain_support\": true, \"horizon::keystone_default_domain\": \"Default\"}]}}, \"puppet_config\": {\"config_volume\": \"keystone\", \"puppet_tags\": \"keystone_config,keystone_domain_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Keystone_user\', \'Keystone_endpoint\', \'Keystone_domain\', \'Keystone_tenant\', \'Keystone_user_role\', \'Keystone_role\', \'Keystone_service\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::base::keystone\\n\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/keystone.json\": {\"command\": \"/usr/sbin/httpd\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/keystone/fernet-keys\", \"dest\": \"/etc/keystone/fernet-keys\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/keystone_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"KeystoneLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"keystone_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/etc/openldap:/etc/openldap:ro\", \"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"KeystoneLogging\", \"environment\"]}, {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}]}, \"command\": [\"/usr/bin/bootstrap_host_exec\", \"keystone\", \"/usr/local/bin/kolla_start\"]}, \"keystone\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/etc/openldap:/etc/openldap:ro\", \"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"keystone_bootstrap\": {\"start_order\": 3, \"action\": \"exec\", \"user\": \"root\", \"command\": [\"keystone\", \"/usr/bin/bootstrap_host_exec\", \"keystone\", \"keystone-manage\", \"bootstrap\"], \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"OS_BOOTSTRAP_PASSWORD\": {\"get_param\": \"AdminPassword\"}, \"OS_BOOTSTRAP_USERNAME\": \"admin\", \"OS_BOOTSTRAP_PROJECT_NAME\": \"admin\", \"OS_BOOTSTRAP_ROLE_NAME\": \"admin\", \"OS_BOOTSTRAP_SERVICE_NAME\": \"keystone\", \"OS_BOOTSTRAP_ADMIN_URL\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_PUBLIC_URL\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_INTERNAL_URL\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_REGION_ID\": {\"get_param\": \"KeystoneRegion\"}}}, \"keystone_cron\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"user\": \"root\", \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron keystone\"}, \"command\": [\"/bin/bash\", \"-c\", \"/usr/local/bin/kolla_set_configs && /usr/sbin/crond -n\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/keystone_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"keystone_refresh\": {\"start_order\": 1, \"action\": \"exec\", \"user\": \"root\", \"command\": [\"keystone\", \"pkill\", \"--signal\", \"USR1\", \"httpd\"]}}}, \"external_deploy_tasks\": [{\"name\": \"Manage clouds.yaml files\", \"when\": [\"step|int == 1\", \"not ansible_check_mode|bool\"], \"block\": [{\"name\": \"Create /etc/openstack directory if it does not exist\", \"become\": true, \"file\": {\"mode\": \"0755\", \"owner\": \"root\", \"path\": \"/etc/openstack\", \"state\": \"directory\"}}, {\"name\": \"Configure /etc/openstack/clouds.yaml\", \"include_role\": {\"name\": \"tripleo_keystone_resources\", \"tasks_from\": \"clouds\"}, \"vars\": {\"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"tripleo_keystone_resources_cloud_config\": {\"auth\": {\"auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"password\": {\"get_param\": \"AdminPassword\"}, \"project_domain_name\": \"Default\", \"project_name\": \"admin\", \"user_domain_name\": \"Default\", \"username\": \"admin\"}, \"cacert\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"PublicTLSCAFile\"}, \"\"]}, \"identity_api_version\": \"3\", \"volume_api_version\": \"3\", \"region_name\": {\"get_param\": \"KeystoneRegion\"}}}}]}, {\"name\": \"Manage Keystone resources\", \"become\": true, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"], \"block\": [{\"name\": \"Manage Keystone resources for OpenStack services\", \"include_role\": {\"name\": \"tripleo_keystone_resources\"}, \"vars\": {\"tripleo_keystone_resources_catalog_config\": \"{{ keystone_resources }}\", \"tripleo_keystone_resources_service_project\": \"service\", \"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"tripleo_keystone_resources_region\": {\"get_param\": \"KeystoneRegion\"}, \"tripleo_keystone_resources_admin_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_public_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_internal_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_admin_password\": {\"get_param\": \"AdminPassword\"}, \"tripleo_keystone_resources_member_role_enabled\": {\"get_param\": \"KeystoneEnableMember\"}}}, {\"name\": \"is Keystone LDAP enabled\", \"set_fact\": {\"keystone_ldap_domain_enabled\": {\"get_param\": \"KeystoneLDAPDomainEnable\"}}}, {\"name\": \"Set fact for tripleo_keystone_ldap_domains\", \"set_fact\": {\"tripleo_keystone_ldap_domains\": {\"get_param\": \"KeystoneLDAPBackendConfigs\"}}, \"when\": \"keystone_ldap_domain_enabled|bool\"}, {\"name\": \"Manage Keystone domains from LDAP config\", \"when\": \"keystone_ldap_domain_enabled|bool\", \"include_role\": {\"name\": \"tripleo_keystone_resources\", \"tasks_from\": \"domains\"}, \"vars\": {\"tripleo_keystone_resources_catalog_config\": \"{{ keystone_resources }}\", \"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"batched_tripleo_keystone_resources_domains\": \"{{ tripleo_keystone_ldap_domains | list }}\"}}]}], \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"validate keystone container state\", \"containers.podman.podman_container_info\": {\"name\": \"keystone\"}, \"register\": \"keystone_infos\", \"failed_when\": [\"keystone_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in keystone_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-keystone\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 4\"]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"KeystoneLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check if file certs_valid exist\", \"stat\": {\"path\": \"/etc/openldap/certs/certs_valid\"}, \"register\": \"certs_valid_stat\"}, {\"name\": \"Check if file cert9.db exist\", \"stat\": {\"path\": \"/etc/openldap/certs/cert9.db\"}, \"register\": \"cert9_stat\", \"when\": \"not certs_valid_stat.stat.exists\"}, {\"name\": \"Check if file key4.db exist\", \"stat\": {\"path\": \"/etc/openldap/certs/key4.db\"}, \"register\": \"key4_stat\", \"when\": \"not certs_valid_stat.stat.exists\"}, {\"fail\": {\"msg\": \"Keys and/or certificates were found in /etc/openldap/certs but these conflicts with keystone python LDAP calls.  If you know those certificates are valid and not causing any conflicts, you can touch /etc/openldap/certs/certs_valid in order to skip this failure and retry or you can delete the files located in /etc/openldap/certs and retry.\\n\"}, \"when\": \"( cert9_stat.stat.exists or key4_stat.stat.exists ) and not certs_valid_stat.stat.exists\"}]]}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop keystone container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"keystone\", \"keystone_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'keystone\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (199,'2026-06-13 07:57:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(200,'2026-06-13 07:57:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Add services and subhosts to IPA server\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"PythonInterpreter\": {\"type\": \"string\", \"description\": \"The python interpreter to use for python and ansible actions\", \"default\": \"$(command -v python3 || command -v python)\"}, \"IdMDomain\": {\"default\": \"ooo.test\", \"description\": \"IDM domain to register IDM client. Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"string\"}, \"IdMServer\": {\"default\": \"ipa.ooo.test\", \"description\": \"FQDN for the FreeIPA server.  If you set this value, IdMDomain also has to be provided.  Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"comma_delimited_list\"}, \"IdMNovaKeytab\": {\"default\": \"FILE:/etc/novajoin/krb5.keytab\", \"description\": \"keytab for the nova/[host fqdn] user on the FreeIPA server.\", \"type\": \"string\"}, \"IdMNovaCredentialCache\": {\"default\": \"/etc/novajoin/krb5.cache\", \"description\": \"credential cache for nova/[host fqdn] user\", \"type\": \"string\"}, \"MakeHomeDir\": {\"type\": \"boolean\", \"description\": \"Configure PAM to create a users home directory if it does not exist.\", \"default\": false}, \"IdMNoNtpSetup\": {\"default\": false, \"description\": \"Set to true to add --no-ntp to the IDM client install call. This will cause IDM client install not to set up NTP.\", \"type\": \"boolean\"}, \"IdMEnrollBaseServer\": {\"default\": true, \"description\": \"Set to true to enroll the base server (computes, controllers)\", \"type\": \"boolean\"}, \"IdMInstallClientPackages\": {\"default\": false, \"description\": \"Set to True to have ansible-freeipa install ipa client packages on the overcloud node.\", \"type\": \"boolean\"}, \"IdMModifyDNS\": {\"default\": true, \"description\": \"Set to false to disable DNS records manipulation in the FreeIPA server.\", \"type\": \"boolean\"}, \"IdMZoneSplitIPv4\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}, \"IdMZoneSplitIPv6\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}}, \"conditions\": {\"idm_server_provided\": {\"not\": {\"equals\": [{\"get_param\": \"IdMServer\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ipaservice service\", \"value\": {\"service_name\": \"ipaservice\", \"upgrade_tasks\": [], \"step_config\": \"\", \"ipa_registration_tasks\": [{\"name\": \"Get undercloud FQDN\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"set_fact\": {\"undercloud_fqdn\": \"{{ ansible_facts[\'fqdn\'] }}\"}}, {\"include_role\": {\"name\": \"tripleo_ipa_registration\", \"apply\": {\"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ undercloud_fqdn }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}}, \"vars\": {\"tripleo_ipa_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}, \"tripleo_ipa_delegate_server\": \"{{ inventory_hostname }}\", \"tripleo_ipa_base_server_fqdn\": \"{{ fqdn_canonical }}\", \"tripleo_ipa_server_metadata\": \"{{ service_metadata_settings | to_json }}\"}, \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}, {\"name\": \"Enroll the node as an ipa client\", \"vars\": {\"ipaclient_install_packages\": {\"get_param\": \"IdMInstallClientPackages\"}, \"idm_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}}, \"block\": [{\"name\": \"check if default.conf exists\", \"stat\": {\"path\": \"/etc/ipa/default.conf\"}, \"register\": \"ipa_conf_exists\"}, {\"name\": \"install openssl-perl\", \"become\": true, \"package\": {\"name\": \"openssl-perl\", \"state\": \"present\"}, \"when\": [\"ipaclient_install_packages|bool\"]}, {\"name\": \"register as an ipa client\", \"include_role\": {\"name\": \"ipaclient\", \"apply\": {\"become\": true}}, \"vars\": {\"map_merge\": [{\"state\": \"present\", \"ipaclient_otp\": \"{{ ipa_host_otp }}\", \"ipaclient_mkhomedir\": {\"get_param\": \"MakeHomeDir\"}, \"ipaclient_no_ntp\": {\"get_param\": \"IdMNoNtpSetup\"}, \"ipaclient_force\": true, \"ipaclient_hostname\": \"{{ fqdn_canonical }}\", \"ansible_fqdn\": \"{{ ipaclient_hostname }}\", \"ipaclients\": [\"ipaclient_hostname\"], \"ansible_distribution\": \"{{ ansible_facts[\'distribution\'] }}\", \"ansible_distribution_major_version\": \"{{ ansible_facts[\'distribution_major_version\'] }}\", \"ansible_distribution_release\": \"{{ ansible_facts[\'distribution_release\'] }}\", \"ansible_distribution_version\": \"{{ ansible_facts[\'distribution_version\'] }}\", \"ansible_os_family\": \"{{ ansible_facts[\'os_family\'] }}\"}, {\"if\": [\"idm_server_provided\", {\"ipaclient_servers\": {\"get_param\": \"IdMServer\"}, \"ipaclient_domain\": {\"get_param\": \"IdMDomain\"}}]}]}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"restart certmonger service\", \"become\": true, \"systemd\": {\"state\": \"restarted\", \"daemon_reload\": true, \"name\": \"certmonger.service\"}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"set discovered ipa realm\", \"set_fact\": {\"idm_realm\": {\"str_replace\": {\"template\": \"{{ lookup(\'ini\', \'realm default=DEFAULT section=global file=/etc/ipa/default.conf\')}}\", \"params\": {\"DEFAULT\": {\"yaql\": {\"expression\": \"$.data.toUpper()\", \"data\": {\"get_param\": \"IdMDomain\"}}}}}}}}], \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}], \"external_deploy_tasks\": [{\"name\": \"add the DNS entries into IPA in step 1\", \"when\": \"step|int == 1\", \"block\": [{\"include_role\": {\"name\": \"tripleo_ipa_dns\"}, \"vars\": {\"tripleo_ipa_ptr_zone_split_ipv4\": {\"get_param\": \"IdMZoneSplitIPv4\"}, \"tripleo_ipa_ptr_zone_split_ipv6\": {\"get_param\": \"IdMZoneSplitIPv6\"}}, \"when\": {\"get_param\": \"IdMModifyDNS\"}}], \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ ansible_facts[\'fqdn\'] }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}], \"scale_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"down\", \"block\": [{\"name\": \"unregister node from ipa server\", \"import_role\": {\"name\": \"tripleo_ipa_cleanup\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"vars\": {\"tripleo_ipa_keytab\": {\"get_param\": \"IdMNovaKeytab\"}, \"tripleo_ipa_hosts_to_delete\": [\"{{ fqdn_canonical }}\"]}}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"check if ipa server has required permissions\", \"import_role\": {\"name\": \"tls_everywhere\", \"tasks_from\": \"ipa-server-check\"}, \"tags\": [\"opendev-validation\", \"opendev-validation-tls-everywhere\"]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(201,'2026-06-13 07:57:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Manila API service\\n\", \"parameters\": {\"ContainerManilaApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"ContainerManilaConfigImage\": {\"description\": \"The container image to use for the manila config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"ManilaWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for manila::wsgi::apache\", \"default\": \"%{::os_workers}\"}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"LManwx6EEaNykAvaoGtYAIiL4\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"ManilaApiPolicies\": {\"description\": \"A hash of policies to configure for Manila API.\\ne.g. { manila-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"MonitoringSubscriptionManilaApi\": {\"default\": \"overcloud-manila-api\", \"type\": \"string\"}, \"ManilaEnabledShareProtocols\": {\"default\": \"\", \"description\": \"List of protocols to be allowed for share creation in manila. When not set, the list is inferred via the storage back end/s enabled.\", \"type\": \"comma_delimited_list\"}, \"ManilaCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"ManilaCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"ManilaCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"manila\"}, \"ManilaCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"ManilaCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/manila/manila-rowsflush.log\"}, \"ManilaCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ManilaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerManilaApiImage\": \"ContainerManilaApiImage\", \"ContainerManilaConfigImage\": \"ContainerManilaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerManilaApiImage\": {\"get_param\": \"ContainerManilaApiImage\"}, \"ContainerManilaConfigImage\": {\"get_param\": \"ContainerManilaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila API role.\", \"value\": {\"service_name\": \"manila_api\", \"firewall_rules\": {\"150 manila\": {\"dport\": [8786]}}, \"firewall_frontend_rules\": {\"100 manila_haproxy_frontend\": {\"dport\": [8786]}}, \"firewall_ssl_frontend_rules\": {\"100 manila_haproxy_frontend_ssl\": {\"dport\": [13786]}}, \"keystone_resources\": {\"manila\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Public\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Internal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Admin\", \"uri\"]}}, \"users\": {\"manila\": {\"password\": {\"get_param\": \"ManilaPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"share\"}, \"manilav2\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"uri\"]}}, \"users\": {\"manilav2\": {\"password\": {\"get_param\": \"ManilaPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"sharev2\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionManilaApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ManilaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"manila::keystone::authtoken::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"manila::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"manila::keystone::authtoken::project_name\": \"service\", \"manila::keystone::authtoken::user_domain_name\": \"Default\", \"manila::keystone::authtoken::project_domain_name\": \"Default\", \"manila::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"manila::keystone::authtoken::interface\": \"internal\", \"manila::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"manila::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"manila::api::service_name\": \"httpd\", \"manila::api::enable_proxy_headers_parsing\": true, \"manila::api::default_share_type\": \"default\", \"manila_enabled_share_protocols\": {\"get_param\": \"ManilaEnabledShareProtocols\"}, \"manila::policy::policies\": {\"get_param\": \"ManilaApiPolicies\"}, \"manila::cron::db_purge::minute\": {\"get_param\": \"ManilaCronDbPurgeMinute\"}, \"manila::cron::db_purge::hour\": {\"get_param\": \"ManilaCronDbPurgeHour\"}, \"manila::cron::db_purge::monthday\": {\"get_param\": \"ManilaCronDbPurgeMonthday\"}, \"manila::cron::db_purge::month\": {\"get_param\": \"ManilaCronDbPurgeMonth\"}, \"manila::cron::db_purge::weekday\": {\"get_param\": \"ManilaCronDbPurgeWeekday\"}, \"manila::cron::db_purge::user\": {\"get_param\": \"ManilaCronDbPurgeUser\"}, \"manila::cron::db_purge::age\": {\"get_param\": \"ManilaCronDbPurgeAge\"}, \"manila::cron::db_purge::destination\": {\"get_param\": \"ManilaCronDbPurgeDestination\"}, \"manila::cron::db_purge::maxdelay\": {\"get_param\": \"ManilaCronDbPurgeMaxDelay\"}, \"manila::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::workers\": {\"get_param\": \"ManilaWorkers\"}}]}, \"service_config_settings\": {\"get_attr\": [\"ManilaBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"manila\", \"puppet_tags\": \"manila_config,manila_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::manila::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/manila_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/manila_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec manila_api su manila -s /bin/bash -c \'/usr/bin/manila-manage db sync\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/manila_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"manila_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R manila:manila /var/log/manila\"]}}, \"step_3\": {\"manila_api_db_sync\": {\"user\": \"root\", \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"manila_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"manila_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron manila\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"Create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/manila\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/manila-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop manila api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"manila_api\"], \"tripleo_delegate_to\": \"{{ groups[\'manila_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(202,'2026-06-13 07:57:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(203,'2026-06-13 07:57:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(204,'2026-06-13 07:57:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat Engine service\\n\", \"parameters\": {\"ContainerHeatEngineImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\"}, \"ContainerHeatConfigImage\": {\"description\": \"The container image to use for the heat config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"HeatEngineLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.engine\", \"file\": \"/var/log/containers/heat/heat-engine.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781337374, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"HeatEngineOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"HeatEngineOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"HeatEnableDBPurge\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in the Heat database.\\n\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatMaxNestedStackDepth\": {\"default\": 6, \"description\": \"Maximum number of nested stack depth.\", \"type\": \"number\"}, \"HeatReauthenticationAuthMethod\": {\"description\": \"Allow reauthentication on token expiry, such that long-running tasks may complete. Note this defeats the expiry of any provided user tokens.\", \"type\": \"string\", \"default\": \"\", \"constraints\": [{\"allowed_values\": [\"\", \"trusts\"]}]}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\"}, \"HeatStackDomainAdminPassword\": {\"description\": \"Password for heat_stack_domain_admin user.\", \"type\": \"string\", \"hidden\": true, \"default\": \"PRAvvytqJJ4jsEaDgx88UWuGA\"}, \"HeatAuthEncryptionKey\": {\"description\": \"Auth encryption key for heat-engine\", \"type\": \"string\", \"hidden\": true, \"default\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\"}, \"MonitoringSubscriptionHeatEngine\": {\"default\": \"overcloud-heat-engine\", \"type\": \"string\"}, \"HeatConvergenceEngine\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Enables the heat engine with the convergence architecture.\"}, \"HeatMaxResourcesPerStack\": {\"type\": \"number\", \"default\": 1000, \"description\": \"Maximum resources allowed per top-level stack. -1 stands for unlimited.\"}, \"HeatEnginePluginDirs\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"An array of directories to search for plug-ins.\"}, \"HeatConfigureDelegatedRoles\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Create delegated roles\"}, \"ClientRetryLimit\": {\"type\": \"number\", \"default\": 2, \"description\": \"Client retries for transient errors.\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatEngineLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatEngine\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatEngineImage\": \"ContainerHeatEngineImage\", \"ContainerHeatConfigImage\": \"ContainerHeatConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatEngineImage\": {\"get_param\": \"ContainerHeatEngineImage\"}, \"ContainerHeatConfigImage\": {\"get_param\": \"ContainerHeatConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat Engine role.\", \"value\": {\"service_name\": \"heat_engine\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatEngine\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::engine::configure_delegated_roles\": {\"get_param\": \"HeatConfigureDelegatedRoles\"}, \"heat::engine::trusts_delegated_roles\": [], \"heat::engine::max_nested_stack_depth\": {\"get_param\": \"HeatMaxNestedStackDepth\"}, \"heat::engine::max_resources_per_stack\": {\"get_param\": \"HeatMaxResourcesPerStack\"}, \"heat::engine::reauthentication_auth_method\": {\"get_param\": \"HeatReauthenticationAuthMethod\"}, \"heat::engine::heat_metadata_server_url\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}, \"heat::engine::heat_waitcondition_server_url\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1/waitcondition\"}}, \"heat::engine::convergence_engine\": {\"get_param\": \"HeatConvergenceEngine\"}, \"heat::engine::client_retry_limit\": {\"get_param\": \"ClientRetryLimit\"}, \"tripleo::profile::base::heat::manage_db_purge\": {\"get_param\": \"HeatEnableDBPurge\"}, \"heat::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"heat\", \"password\": {\"get_param\": \"HeatPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/heat\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"heat\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"heat::keystone_ec2_uri\": {\"list_join\": [\"\", [{\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"/ec2tokens\"]]}, \"heat::keystone::domain::domain_password\": {\"get_param\": \"HeatStackDomainAdminPassword\"}, \"heat::engine::auth_encryption_key\": {\"get_param\": \"HeatAuthEncryptionKey\"}, \"heat::engine::plugin_dirs\": {\"get_param\": \"HeatEnginePluginDirs\"}}, {\"if\": [\"heat_workers_set\", {\"heat::engine::num_engine_workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_engine\": [{\"get_param\": \"HeatEngineLoggingSource\"}]}, \"mysql\": {\"heat::db::mysql::password\": {\"get_param\": \"HeatPassword\"}, \"heat::db::mysql::user\": \"heat\", \"heat::db::mysql::host\": \"%\", \"heat::db::mysql::dbname\": \"heat\"}}, \"puppet_config\": {\"config_volume\": \"heat\", \"puppet_tags\": \"heat_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::heat::engine\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_engine.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/heat-engine --config-file /usr/share/heat/heat-dist.conf --config-file /etc/heat/heat.conf\", {\"get_attr\": [\"HeatEngineLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/heat_engine_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec heat_engine su heat -s /bin/bash -c \'heat-manage db_sync\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatEngineLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"heat_engine_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatEngineImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatEngineLogging\", \"volumes\"]}, {\"get_param\": \"HeatEngineOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_engine_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatEngineOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}]}}}, \"step_4\": {\"heat_engine\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatEngineImage\"]}, \"net\": \"host\", \"privileged\": false, \"stop_grace_period\": 60, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatEngineLogging\", \"volumes\"]}, {\"get_param\": \"HeatEngineOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_engine.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatEngineOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HeatEngineLogging\", \"host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat engine container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_engine\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_engine\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(205,'2026-06-13 07:57:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(206,'2026-06-13 07:57:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (207,'2026-06-13 07:57:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Manila base service. Shared by manila-api/scheduler/share services\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ManilaIPv6\": {\"default\": false, \"description\": \"Set to True to enable IPv6 access in manila.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ManilaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Manila services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"LManwx6EEaNykAvaoGtYAIiL4\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"ManilaStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Manila service\'s storage availability zone.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila Base service.\", \"value\": {\"service_name\": \"manila_base\", \"config_settings\": {\"manila::storage_availability_zone\": {\"get_param\": \"ManilaStorageAvailabilityZone\"}, \"manila::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"manila::logging::debug\": {\"if\": [{\"get_param\": \"ManilaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"manila::db::database_db_max_retries\": -1, \"manila::db::database_max_retries\": -1, \"manila::sql_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"manila\", \"password\": {\"get_param\": \"ManilaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/manila\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"manila\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"manila::network::neutron::network_plugin_ipv6_enabled\": {\"get_param\": \"ManilaIPv6\"}, \"manila::network::neutron::network_plugin_ipv4_enabled\": {\"if\": [{\"get_param\": \"ManilaIPv6\"}, false, true]}, \"manila::rabbit_heartbeat_in_pthread\": false}, \"service_config_settings\": {\"mysql\": {\"manila::db::mysql::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::db::mysql::user\": \"manila\", \"manila::db::mysql::host\": \"%\", \"manila::db::mysql::dbname\": \"manila\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(208,'2026-06-13 07:57:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(209,'2026-06-13 07:57:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Keystone service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerKeystoneImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerKeystoneImage\": \"ContainerKeystoneImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerKeystoneImage\": {\"get_param\": \"ContainerKeystoneImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/keystone:/var/log/keystone:z\", \"/var/log/containers/httpd/keystone:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"keystone_init_log\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R keystone:keystone /var/log/keystone\"], \"volumes\": [\"/var/log/containers/keystone:/var/log/keystone:z\", \"/var/log/containers/httpd/keystone:/var/log/httpd:z\"]}}}}, \"environment\": {\"description\": \"Extra environment variables needed for the service to log to files.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/keystone\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/keystone\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(211,'2026-06-13 07:57:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(212,'2026-06-13 07:57:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(213,'2026-06-13 07:57:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API CFN service\\n\", \"parameters\": {\"ContainerHeatApiCfnImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\"}, \"ContainerHeatApiCfnConfigImage\": {\"description\": \"The container image to use for the heat_api_cfn config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\"}, \"HeatApiCfnLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api.cfn\", \"file\": \"/var/log/containers/heat/heat_api_cfn.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApiCnf\": {\"default\": \"overcloud-heat-api-cfn\", \"type\": \"string\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiCfnLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApiCfn\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiCfnImage\": \"ContainerHeatApiCfnImage\", \"ContainerHeatApiCfnConfigImage\": \"ContainerHeatApiCfnConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiCfnImage\": {\"get_param\": \"ContainerHeatApiCfnImage\"}, \"ContainerHeatApiCfnConfigImage\": {\"get_param\": \"ContainerHeatApiCfnConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API CFN role.\", \"value\": {\"service_name\": \"heat_api_cfn\", \"firewall_rules\": {\"125 heat_cfn\": {\"dport\": [8000]}}, \"firewall_frontend_rules\": {\"100 heat_api_cfn_haproxy_frontend\": {\"dport\": [8000]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_cfn_haproxy_frontend_ssl\": {\"dport\": [13005]}}, \"keystone_resources\": {\"heat-cfn\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"uri\"]}}, \"users\": {\"heat-cfn\": {\"password\": {\"get_param\": \"HeatPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"cloudformation\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApiCnf\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiCfnLogging\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api_cfn::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}, \"heat::wsgi::apache_api_cfn::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::api_cfn::service_name\": \"httpd\", \"heat::wsgi::apache_api_cfn::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}, \"heat::wsgi::apache_api_cfn::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api_cfn::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api_cfn\": [{\"get_param\": \"HeatApiCfnLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api_cfn\", \"puppet_tags\": \"heat_config,file,concat,file_line\", \"step_config\": \"include tripleo::profile::base::heat::api_cfn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiCfnConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api_cfn.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiCfnLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api_cfn\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiCfnImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiCfnLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cfn.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api_cfn:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiCfnLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat cfn container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api_cfn\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api_cfn\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(214,'2026-06-13 07:57:31',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-0\", \"NodeIndex\": \"0\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"f588373c-8574-4ff5-b868-0ebda1ffa146\"}}, \"1\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-1\", \"NodeIndex\": \"1\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"f588373c-8574-4ff5-b868-0ebda1ffa146\"}}, \"2\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-2\", \"NodeIndex\": \"2\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"f588373c-8574-4ff5-b868-0ebda1ffa146\"}}}, \"outputs\": {\"hostname\": {\"value\": [{\"get_attr\": [\"0\", \"hostname\"]}, {\"get_attr\": [\"1\", \"hostname\"]}, {\"get_attr\": [\"2\", \"hostname\"]}]}, \"storage_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_ip_address\"]}, {\"get_attr\": [\"1\", \"storage_ip_address\"]}, {\"get_attr\": [\"2\", \"storage_ip_address\"]}]}, \"hosts_entry\": {\"value\": [{\"get_attr\": [\"0\", \"hosts_entry\"]}, {\"get_attr\": [\"1\", \"hosts_entry\"]}, {\"get_attr\": [\"2\", \"hosts_entry\"]}]}, \"nova_server_resource\": {\"value\": [{\"get_attr\": [\"0\", \"nova_server_resource\"]}, {\"get_attr\": [\"1\", \"nova_server_resource\"]}, {\"get_attr\": [\"2\", \"nova_server_resource\"]}]}, \"ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"ip_address\"]}, {\"get_attr\": [\"1\", \"ip_address\"]}, {\"get_attr\": [\"2\", \"ip_address\"]}]}, \"blacklist_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"1\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"2\", \"blacklist_ip_address\"]}]}, \"ansible_host_vars_map\": {\"value\": [{\"get_attr\": [\"0\", \"ansible_host_vars_map\"]}, {\"get_attr\": [\"1\", \"ansible_host_vars_map\"]}, {\"get_attr\": [\"2\", \"ansible_host_vars_map\"]}]}, \"attributes, nova_server_resource\": {\"value\": {\"0\": {\"get_attr\": [\"0\", \"nova_server_resource\"]}, \"1\": {\"get_attr\": [\"1\", \"nova_server_resource\"]}, \"2\": {\"get_attr\": [\"2\", \"nova_server_resource\"]}}}, \"tenant_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"tenant_ip_address\"]}, {\"get_attr\": [\"1\", \"tenant_ip_address\"]}, {\"get_attr\": [\"2\", \"tenant_ip_address\"]}]}, \"internal_api_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"internal_api_ip_address\"]}, {\"get_attr\": [\"1\", \"internal_api_ip_address\"]}, {\"get_attr\": [\"2\", \"internal_api_ip_address\"]}]}, \"blacklist_hostname\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_hostname\"]}, {\"get_attr\": [\"1\", \"blacklist_hostname\"]}, {\"get_attr\": [\"2\", \"blacklist_hostname\"]}]}, \"hostname_map\": {\"value\": [{\"get_attr\": [\"0\", \"hostname_map\"]}, {\"get_attr\": [\"1\", \"hostname_map\"]}, {\"get_attr\": [\"2\", \"hostname_map\"]}]}, \"refs_map\": {\"value\": {\"0\": {\"get_resource\": \"0\"}, \"1\": {\"get_resource\": \"1\"}, \"2\": {\"get_resource\": \"2\"}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(215,'2026-06-13 07:57:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (216,'2026-06-13 07:57:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(217,'2026-06-13 07:57:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(218,'2026-06-13 07:57:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Compute node configured by Puppet\", \"parameters\": {\"OvercloudComputeFlavor\": {\"description\": \"Flavor for the Compute node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"NovaImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"DEPRECATED Use ComputeImage instead\"}, \"ComputeImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ComputeIPs\": {\"default\": {}, \"type\": \"json\"}, \"NovaComputeIPs\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeIPs instead\", \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"ooo.test\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ComputeServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"NovaComputeServerMetadata\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeServerMetadata instead\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {\"ipa_enroll\": true}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"NovaImage\", \"NovaComputeServerMetadata\", \"NovaComputeIPs\"]}], \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"deprecated_param_image_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaImage\"}, \"overcloud-full\"]}}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"Compute_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"NovaCompute\": {\"type\": \"OS::TripleO::ComputeServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"if\": [\"deprecated_param_image_set\", {\"get_param\": \"NovaImage\"}, {\"get_param\": \"ComputeImage\"}]}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"get_param\": \"OvercloudComputeFlavor\"}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, {\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"NovaComputeServerMetadata\"}, {\"get_param\": \"ComputeServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ComputeSchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::Compute::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::Compute::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::Compute::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"NovaCompute\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::Compute::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"ComputeExtraConfigPre\": {\"type\": \"OS::TripleO::ComputeExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ComputeExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"NovaComputeAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"NovaComputeAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for Compute server\", \"value\": {\"get_resource\": \"NovaCompute\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.227\", \"host_nobrackets\": \"172.21.0.227\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.227:2049\", \"uri_no_suffix\": \"nfs://172.21.0.227:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-1\", \"CloudDomain\": \"ooo.test\", \"ComputeSchedulerHints\": {}, \"NodeIndex\": 1, \"ServiceNames\": \"boot_params_service,ca_certs,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,ipaservice,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"f588373c-8574-4ff5-b868-0ebda1ffa146\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(219,'2026-06-13 07:57:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000072650\", \"overcloud-controller-1\": \"np0000072651\", \"overcloud-controller-2\": \"np0000072652\", \"overcloud-novacompute-0\": \"np0000072653\", \"overcloud-novacompute-1\": \"np0000072654\", \"overcloud-novacompute-2\": \"np0000072655\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000072650-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072651-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072652-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072653-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072654-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000072655-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000072650\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072651\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072652\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072653\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072654\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000072655\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.227\", \"ip_address_uri\": \"172.21.0.227\", \"ip_subnet\": \"172.21.0.227/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.182\", \"ip_address_uri\": \"172.17.0.182\", \"ip_subnet\": \"172.17.0.182/24\"}, \"storage\": {\"ip_address\": \"172.18.0.245\", \"ip_address_uri\": \"172.18.0.245\", \"ip_subnet\": \"172.18.0.245/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.237\", \"ip_address_uri\": \"172.20.0.237\", \"ip_subnet\": \"172.20.0.237/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"7kZ83jSDnSHXNWS4BIZ8oJJlN\", \"AdminToken\": \"JbpiTehj2VnTm8w0BPor698KI\", \"CeilometerMeteringSecret\": \"yqhKYusTcTIo9QJ6Mn8tKY3cT\", \"CeilometerPassword\": \"GX4yCM0w7B4kiWgXu5CvQui7Y\", \"CephClientKey\": \"AQAeDS1qAAAAABAAyCOODrQlLXl4gBCxU/zz0Q==\", \"CephClusterFSID\": \"b5752d85-3538-4992-bfb2-0baef5c2e05b\", \"CinderPassword\": \"FTS40yQUd1tjPXxKb5UK1sScA\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781337374, \"GlancePassword\": \"lqkY0i4mVQtV6AhrdDowFXhCQ\", \"HAProxyStatsPassword\": \"uV80OdWAFFrCjeW3b3kCveIzm\", \"HeatAuthEncryptionKey\": \"enCxzOJBEaFFRxqqYVQRBfUUPlLDB1yG\", \"HeatPassword\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\", \"HeatStackDomainAdminPassword\": \"PRAvvytqJJ4jsEaDgx88UWuGA\", \"HorizonSecret\": \"YJSs8dHdzh\", \"KeystoneCredential0\": \"LIkARRTHrF2zybjY9bAPLmXl8kwG5EneHPk5SIGX5Ps=\", \"KeystoneCredential1\": \"O-4oQgPunQgI4xuAVmI3Mbw80tE2EyQ-AziJB5by0-s=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"mTO_voEIfIv-1wOoGqFdowWwKZAC1f1N_9mdF6JK7yM=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"llolFINSKkh3Tl2UvdzmFUPSFyrGinLfoqm7EZ04hY4=\"}}, \"LibvirtTLSPassword\": \"5vV3yOn6qpexwWmJwHuYNQL1Q\", \"ManilaPassword\": \"LManwx6EEaNykAvaoGtYAIiL4\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA/XCPsz/02evtSVVVENiBO/D4lHSaJsL663oo/E98PlXoVgRs\\nWvTPTJfUlPgSxNOfK9pHqlqwmWo9yIQH2yP/OillrRjG3E0MlKkKRboqEaTlYaVt\\npjisb+lj8G6+a9HBLnVswexDqWoPTy8PyNOEjR9D9yCNxxEf/Van97ZauuHUteLs\\n9B/neJi1AHZeWbq64hXR4AvsgE2ixHxNDUWEeOaAgdIorbwImpg2mvL7Rn8fqOMg\\nTfDAtd/O8ZVYL27jTmUobfjpld0N/bDRigOAwrpzZMmN+zMkneuvL4+03QIKLPU+\\nediY70EGZsHqiZUfdCd3Hw/jsP+Ulm/YTBtWyQIDAQABAoIBAClstJA/6+2Sun46\\nDGVsffMmN/tL88ZSKGFE3l4fP9eQgyFMJ8nWKewDBSQ0SB0T2fh4/S3DFQp+awrT\\nSdVv1M/U5GGeoyJvFZdW6e7rtuSbZ0LGn12D9et04njyIP3Okxzc5KHt1EFkrIvs\\nzU+uAwRuD9Xc5E+dZPUrrNi4Xawd2joFwDh57B2ewTvJ5mnoF53ylfgC+hh+MZwN\\nXXaK35hbPfP9Iz0E3Rpk3M715MlteBiL+dELA1WpTdowt5joLChAsZ+JZmXTGJPy\\n2eMlIjnJnnVKS4cJU0q7J/tkoF3Uy6lJdFbs5qNzP2qwFGG2P+5HEtx637dyHPhb\\nZ/V9ZOECgYEA/dJ7OYz6i0UkvXpbSUf5y2AL75Z+BbozQwaGOQ0NC77M5Nr8iLXq\\nRdFRvmbON8gVIULm8SRUd+qvNPUgqHRbt8k4FF2feIwNz9j9XYgh/GhPKxqF/znQ\\nUDSkSEBWK1Z5k5pb1sLSQjhHmgkhrrDSoOb1qDscIFLKjA1NdVZ7Sy8CgYEA/509\\nZQ71Ejjtx9t936MXgdAuf5KQuAqKjP/yBugfeHVlW9A/j6pi0kpHor9DdIyy/a5Z\\nC3tSw4UauOAAyLzNEwm+hvZGkDhsb9/7lSFzQ8HzZuf5vV+SwxuAsYhBeiv6YA7w\\npLHVQwOYbDlP9RCGCjONKyYoPUpHqgexAT3EH4cCgYAhAV+4qhZiSclvQhvguZVH\\n1uN2cjFM+Vt1GcIWZRYPMu5dzAQOmuktzvw8MA4cvs3Ql2yEat75APFrh3yJqyfK\\nDEZYj5wPBtc88dBweyVANygkSLyn5ZKq+01pf8Q0unfws5/Bm2/P4JWe+BUDLEcX\\nWTEUgSs1IM7py0kJOwepTQKBgQD7tcN3eLssLpM4c5QIXXoQgwjG53VLRlYZcxDK\\nbFpRLImbV/6/YnHd0ven8+BhLQw1czKMc+yUTMZ7t1oOUp0/WiEclff2nRlrMY10\\n1XPEDYG6nET5jtve9X5NVHfl7tinLw8Zn2T6kNfP+sAZ+yODeDBThUeq0zKu5NQQ\\n/NnckQKBgQD4TF4HuKllqgCYzIreLqkj2HJOIjqaUQILxTbOQ+6l1xsr3XSNo9xA\\nXpGh4MpaQuEEew3G1ip97FznB4mfQJtwS/cZSj+EQ709bvF3bu/NhkE403Ch03Wy\\ncFIgk6cLr8iCCDfzjMVP8J1jvKmeYSkdDiCfsWu7VWk0CTnTw3bAAg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQD9cI+zP/TZ6+1JVVUQ2IE78PiUdJomwvrreij8T3w+VehWBGxa9M9Ml9SU+BLE058r2keqWrCZaj3IhAfbI/86KWWtGMbcTQyUqQpFuioRpOVhpW2mOKxv6WPwbr5r0cEudWzB7EOpag9PLw/I04SNH0P3II3HER/9Vqf3tlq64dS14uz0H+d4mLUAdl5ZurriFdHgC+yATaLEfE0NRYR45oCB0iitvAiamDaa8vtGfx+o4yBN8MC1387xlVgvbuNOZSht+OmV3Q39sNGKA4DCunNkyY37MySd668vj7TdAgos9T552JjvQQZmweqJlR90J3cfD+Ow/5SWb9hMG1bJ Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"LOZ9ZtUAwfPALS7L80T4luRla\", \"MysqlMariabackupPassword\": \"BPG3WjZPZv5qvP0EkZZVMzSTF\", \"MysqlRootPassword\": \"pEuTysnhbk\", \"NeutronMetadataProxySharedSecret\": \"9YON7EEIL9wZNadx52fLDIzpR\", \"NeutronPassword\": \"ynYFMrrhBYym7oMTANCe2Hdxj\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"QEj61Nsh9s8dBHEcrZuvWC9pV\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"ZgsfU5NAl3kUnBNL\", \"PlacementPassword\": \"hEpTmySNpG4wGJSvCTrv5Aa7a\", \"RabbitCookie\": \"3Ou1LXX6IJjAiPoFYONp\", \"RabbitPassword\": \"kg1L2F4n3i2Bq1Xx4HqxsLiFU\", \"RedisPassword\": \"0plrFXAbintMcjJGm66MGfoQJ\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"Yp8QdWN9huCnvVDaS2dtYrub7\", \"SnmpdReadonlyUserPassword\": \"FKQdo7NuIE9RbMdjCuC9b8sG\", \"SwiftHashSuffix\": \"5LjCp5W4WF8EMVKzPwaADNpgk\", \"SwiftPassword\": \"TSD7ta8SwXPTvXcqEAzHDi6TA\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(220,'2026-06-13 07:57:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"a1Y61wiSl5xAQVXLjkcVfuC4P\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.245\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.245\", \"storage_mgmt\": \"172.20.0.237\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.237\", \"internal_api\": \"172.17.0.182\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.182\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.227\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.227\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlp